@@ -22,7 +22,6 @@
 #
 #
 #
-
 """
 .. module:: key_ring
 
@@ -53,35 +52,30 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import strng
-from lib import serialization
+from bitdust.lib import strng
+from bitdust.lib import serialization
 
-from main import settings
-from main import events
+from bitdust.main import settings
 
-from contacts import identitycache
-from contacts import contactsdb
+from bitdust.contacts import identitycache
+from bitdust.contacts import contactsdb
 
-from p2p import online_status
-from p2p import p2p_service
-from p2p import commands
+from bitdust.p2p import online_status
+from bitdust.p2p import p2p_service
+from bitdust.p2p import commands
 
-from crypt import key
-from crypt import my_keys
-from crypt import encrypted
+from bitdust.crypt import key
+from bitdust.crypt import my_keys
+from bitdust.crypt import encrypted
 
-from storage import backup_control
-from storage import backup_fs
-from storage import backup_matrix
+from bitdust.storage import backup_matrix
 
-from supplier import list_files
+from bitdust.interface import api
 
-from interface import api
-
-from userid import global_id
-from userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -89,6 +83,7 @@ _MyKeysInSync = False
 
 #------------------------------------------------------------------------------
 
+
 def init():
     if _Debug:
         lg.out(_DebugLevel, 'key_ring.init')
@@ -102,14 +97,18 @@ def shutdown():
 
 #------------------------------------------------------------------------------
 
+
 def _do_request_service_keys_registry(key_id, idurl, include_private, include_signature, timeout, result):
-    p2p_service.SendRequestService(idurl, 'service_keys_registry', callbacks={
-        commands.Ack(): lambda response, info:
-            _on_service_keys_registry_response(response, info, key_id, idurl, include_private, include_signature, result, timeout),
-        commands.Fail(): lambda response, info:
-            result.errback(Exception('"service_keys_registry" not started on remote node')),
-        None: lambda pkt_out: result.errback(Exception('timeout')),
-    })
+    p2p_service.SendRequestService(
+        idurl,
+        'service_keys_registry',
+        timeout=timeout,
+        callbacks={
+            commands.Ack(): lambda response, info: _on_service_keys_registry_response(response, info, key_id, idurl, include_private, include_signature, result, timeout),
+            commands.Fail(): lambda response, info: result.errback(Exception('"service_keys_registry" not started on remote node')),
+            None: lambda pkt_out: result.errback(Exception('timeout')),
+        },
+    )
     return result
 
 
@@ -159,12 +158,14 @@ def _on_transfer_key_response(response, info, key_id, result):
     return None
 
 
-def transfer_key(key_id, trusted_idurl, include_private=False, include_signature=False, timeout=10, result=None):
+def transfer_key(key_id, trusted_idurl, include_private=False, include_signature=False, timeout=None, result=None):
     """
     Actually sending given key to remote user.
     """
     if _Debug:
         lg.out(_DebugLevel, 'key_ring.transfer_key  %s -> %s' % (key_id, trusted_idurl))
+    if not timeout:
+        timeout = settings.P2PTimeOut()
     key_id = my_keys.latest_key_id(key_id)
     if not result:
         result = Deferred()
@@ -224,7 +225,7 @@ def transfer_key(key_id, trusted_idurl, include_private=False, include_signature
     return result
 
 
-def share_key(key_id, trusted_idurl, include_private=False, include_signature=False, timeout=15):
+def share_key(key_id, trusted_idurl, include_private=False, include_signature=False, timeout=None):
     """
     Method to be used to send given key to one trusted user.
     Make sure remote user is identified and connected.
@@ -232,6 +233,8 @@ def share_key(key_id, trusted_idurl, include_private=False, include_signature=Fa
     """
     if _Debug:
         lg.args(_DebugLevel, key_id=key_id, trusted_idurl=trusted_idurl)
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     key_id = my_keys.latest_key_id(key_id)
     result = Deferred()
     d = online_status.ping(
@@ -241,13 +244,20 @@ def share_key(key_id, trusted_idurl, include_private=False, include_signature=Fa
         keep_alive=False,
     )
     d.addCallback(lambda ok: _do_request_service_keys_registry(
-        key_id, trusted_idurl, include_private, include_signature, timeout, result,
+        key_id,
+        trusted_idurl,
+        include_private,
+        include_signature,
+        timeout,
+        result,
     ))
     d.addErrback(result.errback)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def _on_audit_public_key_response(response, info, key_id, untrusted_idurl, test_sample, result):
     try:
         response_sample = base64.b64decode(response.Payload)
@@ -267,15 +277,15 @@ def _on_audit_public_key_response(response, info, key_id, untrusted_idurl, test_
         orig_sample = my_keys.encrypt(key_id, test_sample)
     if response_sample == orig_sample:
         if _Debug:
-            lg.out(_DebugLevel, 'key_ring._on_audit_public_key_response : %s on %s' % (key_id, untrusted_idurl, ))
+            lg.out(_DebugLevel, 'key_ring._on_audit_public_key_response : %s on %s' % (key_id, untrusted_idurl))
         result.callback(True)
         return True
-    lg.warn('key %s on %s is not OK' % (key_id, untrusted_idurl, ))
+    lg.warn('key %s on %s is not OK' % (key_id, untrusted_idurl))
     result.callback(False)
     return False
 
 
-def audit_public_key(key_id, untrusted_idurl, timeout=10):
+def audit_public_key(key_id, untrusted_idurl, timeout=None):
     """
     Be sure remote user stores given public key.
     I also need to stores that public key in order to do such audit.
@@ -285,6 +295,8 @@ def audit_public_key(key_id, untrusted_idurl, timeout=10):
     """
     if _Debug:
         lg.out(_DebugLevel, 'key_ring.audit_public_key   testing %s from %s' % (key_id, untrusted_idurl))
+    if not timeout:
+        timeout = settings.P2PTimeOut()
     key_id = my_keys.latest_key_id(key_id)
     result = Deferred()
     recipient_id_obj = identitycache.FromCache(untrusted_idurl)
@@ -310,7 +322,7 @@ def audit_public_key(key_id, untrusted_idurl, timeout=10):
         'audit': {
             'public_sample': base64.b64encode(public_test_sample),
             'private_sample': '',
-        }
+        },
     }
     raw_payload = serialization.DictToBytes(json_payload, values_to_text=True)
     block = encrypted.Block(
@@ -328,16 +340,17 @@ def audit_public_key(key_id, untrusted_idurl, timeout=10):
         packet_id=key_id,
         timeout=timeout,
         callbacks={
-            commands.Ack(): lambda response, info:
-                _on_audit_public_key_response(response, info, key_id, untrusted_idurl, public_test_sample, result),
+            commands.Ack(): lambda response, info: _on_audit_public_key_response(response, info, key_id, untrusted_idurl, public_test_sample, result),
             commands.Fail(): lambda response, info: result.errback(Exception(response)),
             None: lambda pkt_out: result.errback(Exception('timeout')),  # timeout
         },
     )
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def _on_audit_private_key_response(response, info, key_id, untrusted_idurl, test_sample, result):
     try:
         response_sample = base64.b64decode(response.Payload)
@@ -347,15 +360,15 @@ def _on_audit_private_key_response(response, info, key_id, untrusted_idurl, test
         return False
     if response_sample == test_sample:
         if _Debug:
-            lg.out(_DebugLevel, 'key_ring._on_audit_private_key_response : %s on %s' % (key_id, untrusted_idurl, ))
+            lg.out(_DebugLevel, 'key_ring._on_audit_private_key_response : %s on %s' % (key_id, untrusted_idurl))
         result.callback(True)
         return True
-    lg.warn('key %s on %s is not OK' % (key_id, untrusted_idurl, ))
+    lg.warn('key %s on %s is not OK' % (key_id, untrusted_idurl))
     result.callback(False)
     return False
 
 
-def audit_private_key(key_id, untrusted_idurl, timeout=10):
+def audit_private_key(key_id, untrusted_idurl, timeout=None):
     """
     Be sure remote user possess given private key.
     I need to possess the public key to be able to audit.
@@ -365,6 +378,8 @@ def audit_private_key(key_id, untrusted_idurl, timeout=10):
     """
     if _Debug:
         lg.out(_DebugLevel, 'key_ring.audit_private_key   testing %s from %s' % (key_id, untrusted_idurl))
+    if not timeout:
+        timeout = settings.P2PTimeOut()
     key_id = my_keys.latest_key_id(key_id)
     result = Deferred()
     recipient_id_obj = identitycache.FromCache(untrusted_idurl)
@@ -380,21 +395,21 @@ def audit_private_key(key_id, untrusted_idurl, timeout=10):
     remote_idurl = recipient_id_obj.getIDURL()
     private_test_sample = key.NewSessionKey(session_key_type=key.SessionKeyType())
     if untrusted_idurl == creator_idurl and key_alias == 'master':
-        lg.info('doing audit of master key %r for remote user %r' % (key_id, remote_idurl, ))
+        lg.info('doing audit of master key %r for remote user %r' % (key_id, remote_idurl))
         private_test_encrypted_sample = recipient_id_obj.encrypt(private_test_sample)
     else:
         if not my_keys.is_key_registered(key_id):
             lg.warn('unknown key: "%s"' % key_id)
             result.errback(Exception('unknown key: "%s"' % key_id))
             return result
-        lg.info('doing audit of private key %r for remote user %r' % (key_id, remote_idurl, ))
+        lg.info('doing audit of private key %r for remote user %r' % (key_id, remote_idurl))
         private_test_encrypted_sample = my_keys.encrypt(key_id, private_test_sample)
     json_payload = {
         'key_id': key_id,
         'audit': {
             'public_sample': '',
             'private_sample': base64.b64encode(private_test_encrypted_sample),
-        }
+        },
     }
     raw_payload = serialization.DictToBytes(json_payload, values_to_text=True)
     block = encrypted.Block(
@@ -412,16 +427,17 @@ def audit_private_key(key_id, untrusted_idurl, timeout=10):
         packet_id=key_id,
         timeout=timeout,
         callbacks={
-            commands.Ack(): lambda response, info:
-                _on_audit_private_key_response(response, info, key_id, untrusted_idurl, private_test_sample, result),
+            commands.Ack(): lambda response, info: _on_audit_private_key_response(response, info, key_id, untrusted_idurl, private_test_sample, result),
             commands.Fail(): lambda response, info: result.errback(Exception(response)),
             None: lambda pkt_out: result.errback(Exception('timeout')),  # timeout
         },
     )
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def on_key_received(newpacket, info, status, error_message):
     """
     Callback will be executed when I receive a new key from one remote user.
@@ -547,8 +563,10 @@ def on_audit_key_received(newpacket, info, status, error_message):
     p2p_service.SendFail(newpacket, 'wrong audit request')
     return False
 
+
 #------------------------------------------------------------------------------
 
+
 def do_backup_key(key_id, keys_folder=None):
     """
     Send given key to my suppliers to store it remotely.
@@ -571,10 +589,10 @@ def do_backup_key(key_id, keys_folder=None):
     else:
         local_key_filepath = os.path.join(keys_folder, '%s.public' % key_id)
         remote_path_for_key = '.keys/%s.public' % key_id
-    global_key_path = global_id.MakeGlobalID(
-        key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
+    global_key_path = global_id.MakeGlobalID(key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
     res = api.file_exists(global_key_path)
     if res['status'] == 'OK' and res['result'] and res['result'].get('exist'):
+        from bitdust.storage import backup_control
         lg.warn('key %s already exists in catalog' % global_key_path)
         global_key_path_id = res['result'].get('path_id')
         if global_key_path_id and backup_control.IsPathInProcess(global_key_path_id):
@@ -585,11 +603,8 @@ def do_backup_key(key_id, keys_folder=None):
                 backup_job = backup_control.GetRunningBackupObject(backup_id)
                 if backup_job:
                     backup_result = Deferred()
-                    backup_job.resultDefer.addCallback(
-                        lambda resp: backup_result.callback(True) if resp == 'done' else backup_result.errback(
-                            Exception('failed to upload key "%s", task was not started: %r' % (global_key_path, resp))))
-                    if _Debug:
-                        backup_job.resultDefer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='key_ring.do_backup_key')
+                    backup_job.resultDefer.addCallback(lambda resp: backup_result.callback(True) if resp == 'done' else backup_result.errback(Exception('failed to upload key "%s", task was not started: %r' % (global_key_path, resp))))
+                    backup_job.resultDefer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='key_ring.do_backup_key')
                     backup_job.resultDefer.addErrback(backup_result.errback)
                     if _Debug:
                         lg.args(_DebugLevel, backup_id=backup_id, global_key_path_id=global_key_path_id)
@@ -649,7 +664,7 @@ def do_restore_key(key_id, is_private, keys_folder=None, wait_result=False):
     Restore given key from my suppliers if I do not have it locally.
     """
     if _Debug:
-        lg.out(_DebugLevel, 'key_ring.do_restore_key     key_id=%r    is_private=%r' % (key_id, is_private, ))
+        lg.out(_DebugLevel, 'key_ring.do_restore_key     key_id=%r    is_private=%r' % (key_id, is_private))
     key_id = my_keys.latest_key_id(key_id)
     if my_keys.is_key_registered(key_id):
         lg.err('local key already exist: "%s"' % key_id)
@@ -662,8 +677,7 @@ def do_restore_key(key_id, is_private, keys_folder=None, wait_result=False):
         remote_path_for_key = '.keys/%s.private' % key_id
     else:
         remote_path_for_key = '.keys/%s.public' % key_id
-    global_key_path = global_id.MakeGlobalID(
-        key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
+    global_key_path = global_id.MakeGlobalID(key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
     ret = api.file_download_start(
         remote_path=global_key_path,
         destination_path=keys_folder,
@@ -714,8 +728,7 @@ def do_delete_key(key_id, is_private):
         remote_path_for_key = '.keys/%s.private' % key_id
     else:
         remote_path_for_key = '.keys/%s.public' % key_id
-    global_key_path = global_id.MakeGlobalID(
-        key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
+    global_key_path = global_id.MakeGlobalID(key_alias='master', customer=my_id.getGlobalID(), path=remote_path_for_key)
     res = api.file_delete(global_key_path)
     if res['status'] != 'OK':
         lg.err('failed to delete key "%s": %r' % (global_key_path, res))
@@ -724,19 +737,19 @@ def do_delete_key(key_id, is_private):
         lg.out(_DebugLevel, 'key_ring.do_delete_key key_id=%s  is_private=%r : %r' % (key_id, is_private, res))
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def on_files_received(newpacket, info):
     list_files_global_id = global_id.ParseGlobalID(newpacket.PacketID)
     if not list_files_global_id['idurl']:
         lg.warn('invalid PacketID: %s' % newpacket.PacketID)
         return False
-    trusted_customer_idurl = list_files_global_id['idurl']
     incoming_key_id = list_files_global_id['key_id']
     if not my_keys.is_valid_key_id(incoming_key_id):
         lg.warn('ignore, invalid key id in packet %s' % newpacket)
         return False
-    # if trusted_customer_idurl == my_id.getIDURL():
     if list_files_global_id['key_alias'] == 'master':
         if _Debug:
             lg.dbg(_DebugLevel, 'ignore %s packet which seems to came from my own supplier' % newpacket)
@@ -746,11 +759,12 @@ def on_files_received(newpacket, info):
         lg.warn('private key is not registered : %s' % incoming_key_id)
         p2p_service.SendFail(newpacket, 'private key is not registered')
         return False
+    if list_files_global_id['key_alias'].startswith('share_'):
+        from bitdust.access import shared_access_coordinator
+        return shared_access_coordinator.on_list_files_verified(newpacket, list_files_global_id)
+    # for other shared files that are not controlled by shared_access_coordinator(): message archive keys are starting with "group_"
     try:
-        block = encrypted.Unserialize(
-            newpacket.Payload,
-            decrypt_key=incoming_key_id,
-        )
+        block = encrypted.Unserialize(newpacket.Payload, decrypt_key=incoming_key_id)
     except:
         lg.exc(newpacket.Payload)
         return False
@@ -762,65 +776,39 @@ def on_files_received(newpacket, info):
     except:
         lg.exc()
         return False
-#     if block.CreatorID == trusted_customer_idurl:
-#         # this is a trusted guy sending some shared files to me
-#         return False
-#         try:
-#             json_data = serialization.BytesToDict(raw_files, keys_to_text=True, encoding='utf-8')
-#         except:
-#             lg.exc()
-#             return False
-#         count, updated_keys = backup_fs.Unserialize(
-#             json_data=json_data,
-#             customer_idurl=trusted_customer_idurl,
-#         )
-#         p2p_service.SendAck(newpacket)
-#         if not updated_keys:
-#             lg.warn('no files were imported during file sharing')
-#         else:
-#             for key_alias in updated_keys:
-#                 backup_fs.SaveIndex(trusted_customer_idurl, key_alias)
-#             # backup_control.Save()
-#             lg.info('imported %d shared files from %s, key_id=%s' % (
-#                 count, trusted_customer_idurl, incoming_key_id, ))
-#         events.send('shared-list-files-received', data=dict(
-#             customer_idurl=trusted_customer_idurl,
-#             new_items=count,
-#         ))
-#         return True
-
+    from bitdust.storage import index_synchronizer
+    from bitdust.storage import backup_control
+    from bitdust.storage import backup_fs
     # otherwise this must be an external supplier sending us a files he stores for trusted customer
     external_supplier_idurl = block.CreatorID
     try:
-        supplier_raw_list_files = list_files.UnpackListFiles(raw_files, settings.ListFilesFormat())
+        supplier_raw_list_files = backup_control.UnpackListFiles(raw_files, settings.ListFilesFormat())
     except:
         lg.exc()
         return False
     # need to detect supplier position from the list of packets
     # and place that supplier on the correct position in contactsdb
     supplier_pos = backup_matrix.DetectSupplierPosition(supplier_raw_list_files)
+    trusted_customer_idurl = list_files_global_id['idurl']
     known_supplier_pos = contactsdb.supplier_position(external_supplier_idurl, trusted_customer_idurl)
     if known_supplier_pos < 0:
-        lg.warn('received %r from an unknown node %r which is not a supplier of %r' % (newpacket, external_supplier_idurl, trusted_customer_idurl, ))
+        lg.warn('received %r from an unknown node %r which is not a supplier of %r' % (newpacket, external_supplier_idurl, trusted_customer_idurl))
         return False
     if _Debug:
-        lg.args(_DebugLevel, supplier_pos=supplier_pos, known_supplier_pos=known_supplier_pos, external_supplier=external_supplier_idurl,
-                trusted_customer=trusted_customer_idurl, key_id=incoming_key_id)
+        lg.args(_DebugLevel, sz=len(supplier_raw_list_files), s=external_supplier_idurl, pos=supplier_pos, known_pos=known_supplier_pos, pid=newpacket.PacketID)
     if supplier_pos >= 0:
         if known_supplier_pos != supplier_pos:
-            lg.err('known external supplier %r position %d is not matching with received list files position %d for customer %s' % (
-                external_supplier_idurl, known_supplier_pos,  supplier_pos, trusted_customer_idurl))
+            lg.err('known external supplier %r position %d is not matching with received list files position %d for customer %s' % (external_supplier_idurl, known_supplier_pos, supplier_pos, trusted_customer_idurl))
             return False
     else:
-        lg.warn('not possible to detect external supplier position for customer %s from received list files, known position is %s' % (
-            trusted_customer_idurl, known_supplier_pos))
+        lg.warn('not possible to detect external supplier position for customer %s from received list files, known position is %s' % (trusted_customer_idurl, known_supplier_pos))
         supplier_pos = known_supplier_pos
+    is_in_sync = index_synchronizer.is_synchronized() and backup_fs.revision() > 0
     remote_files_changed, _, _, _ = backup_matrix.process_raw_list_files(
         supplier_num=supplier_pos,
         list_files_text_body=supplier_raw_list_files,
         customer_idurl=trusted_customer_idurl,
-        is_in_sync=True,
-        auto_create=True,
+        is_in_sync=is_in_sync,
     )
     if remote_files_changed:
         backup_matrix.SaveLatestRawListFiles(
