@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: shared_access_donor
 .. role:: red
@@ -58,37 +56,38 @@ import time
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import packetid
-from lib import serialization
-from lib import strng
+from bitdust.lib import packetid
+from bitdust.lib import serialization
+from bitdust.lib import strng
 
-from main import events
+from bitdust.main import events
 
-from contacts import identitycache
-from contacts import contactsdb
+from bitdust.contacts import identitycache
+from bitdust.contacts import contactsdb
 
-from p2p import p2p_service
-from p2p import online_status
-from p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import online_status
+from bitdust.p2p import commands
 
-from crypt import key
-from crypt import my_keys
-from crypt import encrypted
+from bitdust.crypt import key
+from bitdust.crypt import my_keys
+from bitdust.crypt import encrypted
 
-from userid import my_id
-from userid import global_id
-from userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import id_url
 
-from access import key_ring
+from bitdust.access import key_ring
 
-from storage import backup_fs
+from bitdust.storage import backup_fs
 
 #------------------------------------------------------------------------------
 
+
 class SharedAccessDonor(automat.Automat):
     """
     This class implements all the functionality of the ``shared_access_donor()`` state machine.
@@ -106,14 +105,7 @@ class SharedAccessDonor(automat.Automat):
         Create shared_access_donor() state machine.
         Use this method if you need to call Automat.__init__() in a special way.
         """
-        super(SharedAccessDonor, self).__init__(
-            name="shared_access_donor",
-            state='AT_STARTUP',
-            debug_level=debug_level or _DebugLevel,
-            log_events=log_events or _Debug,
-            publish_events=publish_events,
-            **kwargs
-        )
+        super(SharedAccessDonor, self).__init__(name='shared_access_donor', state='AT_STARTUP', debug_level=debug_level or _DebugLevel, log_events=log_events or _Debug, publish_events=publish_events, **kwargs)
 
     def init(self):
         """
@@ -191,11 +183,11 @@ class SharedAccessDonor(automat.Automat):
         elif self.state == 'PUB_KEY':
             if event == 'ack':
                 self.doCheckAllAcked(*args, **kwargs)
-            elif event == 'fail' or ( event == 'timer-15sec' and not self.isSomeSuppliersAcked(*args, **kwargs) ):
+            elif event == 'fail' or (event == 'timer-15sec' and not self.isSomeSuppliersAcked(*args, **kwargs)):
                 self.state = 'CLOSED'
                 self.doReportFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'all-suppliers-acked' or ( event == 'timer-2sec' and self.isSomeSuppliersAcked(*args, **kwargs) ):
+            elif event == 'all-suppliers-acked' or (event == 'timer-2sec' and self.isSomeSuppliersAcked(*args, **kwargs)):
                 self.state = 'PRIV_KEY'
                 self.doSendPrivKeyToUser(*args, **kwargs)
         #---PRIV_KEY---
@@ -274,12 +266,8 @@ class SharedAccessDonor(automat.Automat):
         """
         master_key_id = my_keys.make_key_id(alias='master', creator_idurl=self.remote_idurl)
         d = key_ring.audit_private_key(master_key_id, self.remote_idurl)
-        d.addCallback(lambda audit_result: (
-            self.automat('audit-ok') if audit_result else self.automat('fail', Exception(
-                'remote user master key audit process failed')),
-        ))
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='shared_access_donor.doAuditUserMasterKey')
+        d.addCallback(lambda audit_result: (self.automat('audit-ok') if audit_result else self.automat('fail', Exception('remote user master key audit process failed')), ))
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='shared_access_donor.doAuditUserMasterKey')
         d.addErrback(lambda err: self.automat('fail', err))
 
     def doSendPubKeyToSuppliers(self, *args, **kwargs):
@@ -319,15 +307,14 @@ class SharedAccessDonor(automat.Automat):
         self.automat('list-files-ok')
         return
         # TODO: cleanup
-        json_list_files = backup_fs.Serialize(
+        json_list_files = backup_fs.SerializeIndex(
             customer_idurl=global_id.glob2idurl(self.key_id),
             to_json=True,
             filter_cb=lambda path_id, path, info: True if strng.to_text(info.key_id) == strng.to_text(self.key_id) else False,
         )
         raw_list_files = serialization.DictToBytes(json_list_files, keys_to_text=True, values_to_text=True, encoding='utf-8')
         if _Debug:
-            lg.out(_DebugLevel, 'shared_access_donor.doSendMyListFiles prepared list of files for %s :\n%s' % (
-                self.remote_idurl, raw_list_files))
+            lg.out(_DebugLevel, 'shared_access_donor.doSendMyListFiles prepared list of files for %s :\n%s' % (self.remote_idurl, raw_list_files))
         block = encrypted.Block(
             CreatorID=my_id.getIDURL(),
             BackupID=self.key_id,
@@ -337,7 +324,10 @@ class SharedAccessDonor(automat.Automat):
             EncryptKey=self.key_id,
         )
         encrypted_list_files = block.Serialize()
-        packet_id = "%s:%s" % (self.key_id, packetid.UniqueID(), )
+        packet_id = '%s:%s' % (
+            self.key_id,
+            packetid.UniqueID(),
+        )
         p2p_service.SendFiles(
             idurl=self.remote_idurl,
             raw_list_files_info=encrypted_list_files,
@@ -353,7 +343,7 @@ class SharedAccessDonor(automat.Automat):
         """
         Action method.
         """
-        lg.info('share key [%s] with %r finished with success' % (self.key_id, self.remote_idurl, ))
+        lg.info('share key [%s] with %r finished with success' % (self.key_id, self.remote_idurl))
         events.send('private-key-shared', data=dict(
             global_id=global_id.UrlToGlobalID(self.remote_idurl),
             remote_idurl=self.remote_idurl,
@@ -366,16 +356,16 @@ class SharedAccessDonor(automat.Automat):
         """
         Action method.
         """
-        lg.warn('share key [%s] with %s failed: %s' % (self.key_id, self.remote_idurl, args, ))
+        lg.warn('share key [%s] with %s failed: %s' % (self.key_id, self.remote_idurl, args))
         reason = 'key transfer failed with unknown reason'
         if args and args[0]:
             reason = args[0]
         else:
             if self.remote_identity is None:
-                reason='remote identity caching failed',
+                reason = 'remote identity caching failed',
             else:
                 if self.ping_response is None:
-                    reason='remote node not responding',
+                    reason = 'remote node not responding',
                 else:
                     if self.suppliers_responses:
                         reason = 'connection timeout with my suppliers'
@@ -428,7 +418,7 @@ class SharedAccessDonor(automat.Automat):
         return None
 
     def _on_user_priv_key_shared(self, response):
-        lg.info('your private key %s was sent to %s' % (self.key_id, self.remote_idurl, ))
+        lg.info('your private key %s was sent to %s' % (self.key_id, self.remote_idurl))
         self.automat('priv-key-ok', response)
         return None
 
