@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: automat.
 
@@ -214,10 +213,11 @@ def communicate(index, event, *args, **kwargs):
     if not A:
         return fail(Exception('state machine with index %d not exist' % index))
     d = Deferred()
-    args = tuple(list(args) + [d, ])
+    args = tuple(list(args) + [d])
     A.automat(event, *args, **kwargs)
     return d
 
+
 #------------------------------------------------------------------------------
 
 
@@ -313,6 +313,7 @@ def SetGlobalLogTransitions(value=False):
     global _GlobalLogTransitions
     _GlobalLogTransitions = value
 
+
 #------------------------------------------------------------------------------
 
 
@@ -368,19 +369,7 @@ class Automat(object):
     You also must set that flag in the MS Visio document and rebuild the code:
     put ``[post]`` string into the last line of the LABEL shape.
     """
-
-    def __init__(
-            self,
-            name,
-            state,
-            debug_level=_DebugLevel,
-            log_events=_Debug,
-            log_transitions=_Debug,
-            publish_events=False,
-            publish_event_state_not_changed=False,
-            publish_fast=True,
-            **kwargs
-        ):
+    def __init__(self, name, state, debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, publish_events=False, publish_event_state_not_changed=False, publish_fast=True, **kwargs):
         self.id, self.index = create_index(name)
         self.name = name
         self.state = state
@@ -393,8 +382,7 @@ class Automat(object):
         try:
             self.init(**kwargs)
         except Exception as exc:
-            self.exc(msg='Exception in {}:{} automat init(), state is {}: {}'.format(
-                self.id, self.name, self.state, exc))
+            self.exc(msg='Exception in {}:{} automat init(), state is {}: {}'.format(self.id, self.name, self.state, exc))
             raise exc
         self.startTimers()
         self.register()
@@ -402,8 +390,7 @@ class Automat(object):
         self.publish_event_state_not_changed = publish_event_state_not_changed
         self.publish_fast = publish_fast
         if _GlobalLogTransitions or self.log_transitions:
-            self.log(self.debug_level, 'CREATED AUTOMAT with index %d, total running %d' % (
-                self.index, len(objects())))
+            self.log(self.debug_level, 'CREATED AUTOMAT with index %d, total running %d' % (self.index, len(objects())))
 
     def __del__(self):
         """
@@ -425,8 +412,7 @@ class Automat(object):
             erase_index(automatid)
         if _GlobalLogTransitions or self.log_transitions:
             if _LogFile:
-                self.log(debug_level, 'DESTROYED AUTOMAT with index %d, total running %d' % (
-                    index, len(objects())))
+                self.log(debug_level, 'DESTROYED AUTOMAT with index %d, total running %d' % (index, len(objects())))
 
     def __repr__(self):
         """
@@ -512,7 +498,7 @@ class Automat(object):
         d = Deferred()
         if not args:
             args = tuple()
-        args = tuple(list(args) + [d, ])
+        args = tuple(list(args) + [d])
         self.automat(event_string, args)
         return d
 
@@ -542,27 +528,33 @@ class Automat(object):
         global _StateChangedCallback
         if _GlobalLogEvents or self.log_events:
             if self.log_events or not event.startswith('timer-'):
-                self.log(self.debug_level, '%s fired with event "%s"' % (repr(self), event, ))
+                self.log(self.debug_level, '%s fired with event "%s"' % (
+                    repr(self),
+                    event,
+                ))
         old_state = self.state
         if self.post:
             try:
                 new_state = self.A(event, *args, **kwargs)
             except Exception as exc:
-                self.exc(msg='Exception in {}:{} automat, state is {}, event="{}" : {}'.format(
-                    self.id, self.name, self.state, event, exc))
+                self.exc(msg='Exception in {}:{} automat, state is {}, event="{}" : {}'.format(self.id, self.name, self.state, event, exc))
                 return self
             self.state = new_state
         else:
             try:
                 self.A(event, *args, **kwargs)
             except Exception as exc:
-                self.exc(msg='Exception in {}:{} automat, state is {}, event="{}" : {}'.format(
-                    self.id, self.name, self.state, event, exc))
+                self.exc(msg='Exception in {}:{} automat, state is {}, event="{}" : {}'.format(self.id, self.name, self.state, event, exc))
                 return self
             new_state = self.state
         if old_state != new_state:
             if _GlobalLogTransitions or self.log_transitions:
-                self.log(self.debug_level, '%s(%s): (%s)->(%s)' % (repr(self), event, old_state, new_state, ))
+                self.log(self.debug_level, '%s(%s): (%s)->(%s)' % (
+                    repr(self),
+                    event,
+                    old_state,
+                    new_state,
+                ))
             self.stopTimers()
             self.state_changed(old_state, new_state, event, *args, **kwargs)
             if self.publish_events:
@@ -672,7 +664,11 @@ class Automat(object):
                 self.log(0, msg)
             self.log(0, e)
         if _LogExceptionsHandler is not None:
-            _LogExceptionsHandler(msg=msg, exc_info=(exc_type, exc_value, exc_traceback, ))
+            _LogExceptionsHandler(msg=msg, exc_info=(
+                exc_type,
+                exc_value,
+                exc_traceback,
+            ))
 
     def log(self, level, text):
         """
@@ -686,7 +682,10 @@ class Automat(object):
         global _LifeBeginsTime
         global _LogOutputHandler
         if not text.startswith(self.name):
-            text = '%s(): %s' % (self.name, text, )
+            text = '%s(): %s' % (
+                self.name,
+                text,
+            )
         if _LogOutputHandler is not None:
             _LogOutputHandler(level, text)
         else:
@@ -696,13 +695,13 @@ class Automat(object):
                     _LogFile.close()
                     _LogFile = open(_LogFilename, 'w')
                     _LogsCount = 0
-                s = ' ' * level + text + '\n'
+                s = ' '*level + text + '\n'
                 tm_str = time.strftime('%H:%M:%S')
                 if _LifeBeginsTime != 0:
                     dt = time.time() - _LifeBeginsTime
                     mn = dt // 60
-                    sc = dt - mn * 60
-                    tm_str += ('/%02d:%02d.%02d' % (mn, sc, (sc - int(sc)) * 100))
+                    sc = dt - mn*60
+                    tm_str += ('/%02d:%02d.%02d' % (mn, sc, (sc - int(sc))*100))
                 s = tm_str + s
                 if sys.version_info[0] == 3:
                     if not isinstance(s, str):
@@ -734,11 +733,17 @@ class Automat(object):
             machineB.addStateChangedCallback(method_B)
 
         """
-        key = (oldstate, newstate, )
+        key = (
+            oldstate,
+            newstate,
+        )
         if key not in self._state_callbacks:
             self._state_callbacks[key] = []
         if cb not in self._state_callbacks[key]:
-            self._state_callbacks[key].append((callback_id, cb, ))
+            self._state_callbacks[key].append((
+                callback_id,
+                cb,
+            ))
         return True
 
     def removeStateChangedCallback(self, cb=None, callback_id=None):
@@ -768,7 +773,10 @@ class Automat(object):
         the moment when state gets changed.
         """
         for key in list(self._state_callbacks.keys()):
-            if key == (oldstate, newstate, ):
+            if key == (
+                oldstate,
+                newstate,
+            ):
                 self._state_callbacks.pop(key)
                 break
 
@@ -805,7 +813,7 @@ class Automat(object):
 
     def pushEvent(self, oldstate, newstate, event_string, publisher=None):
         """
-        Can be used to 
+        Can be used to
         """
         state_snapshot = dict(
             index=self.index,
@@ -821,5 +829,5 @@ class Automat(object):
             else:
                 reactor.callLater(0, publisher, state_snapshot)  # @UndefinedVariable
             return
-        from main import events
+        from bitdust.main import events
         events.send('state-changed', data=state_snapshot, fast=self.publish_fast)
