@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -44,10 +43,7 @@ _Debug = False
 
 #------------------------------------------------------------------------------
 
-import os
 import json
-from collections import OrderedDict
-from hashlib import md5
 
 #------------------------------------------------------------------------------
 
@@ -58,17 +54,17 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import utime
+from bitdust.lib import utime
 
-from crypt import key
-
-from userid import my_id
+from bitdust.crypt import key
 
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
+
 def storage_contract_open(customer_idurl, duration, amount, price=1.0, trustee=None):
     """
     + type of resources: storage space (can be also : cpu, traffic, etc.)
@@ -81,43 +77,43 @@ def storage_contract_open(customer_idurl, duration, amount, price=1.0, trustee=N
     + price: 1.0 by default
     """
     return {
-        "miner": {
-            "prev": "",
+        'miner': {
+            'prev': '',
         },
-        "payload": {
-            "type": "storage",
-            "amount": amount,
-            "duration": duration,
-            "customer": customer_idurl,
-            "supplier": my_id.getIDURL(),
-            "trustee": trustee,
-            "started": utime.utcnow_to_sec1970(),
-            "price": price,
+        'payload': {
+            'type': 'storage',
+            'amount': amount,
+            'duration': duration,
+            'customer': customer_idurl,
+            'supplier': my_id.getIDURL(),
+            'trustee': trustee,
+            'started': utime.utcnow_to_sec1970(),
+            'price': price,
         },
     }
 
 
 def storage_contract_accept(prev_coin_json):
     return {
-        "miner": {
+        'miner': {
             # populate previous hash from existing coin
-            "prev": prev_coin_json['miner']['hash'],
+            'prev': prev_coin_json['miner']['hash'],
         },
-        "payload": {
-            "accepted": utime.utcnow_to_sec1970(),
+        'payload': {
+            'accepted': utime.utcnow_to_sec1970(),
         },
     }
 
 
 def storage_contract_continue(prev_coin_json, duration):
     return {
-        "miner": {
+        'miner': {
             # populate previous hash from existing coin
-            "prev": prev_coin_json['miner']['hash'],
+            'prev': prev_coin_json['miner']['hash'],
         },
-        "payload": {
-            "extended": utime.utcnow_to_sec1970(),
-            "duration": duration,
+        'payload': {
+            'extended': utime.utcnow_to_sec1970(),
+            'duration': duration,
         },
     }
 
@@ -151,7 +147,6 @@ def set_prev_hash(coin_json, prev_hash):
     return coin_json
 
 
-
 # def signed_coin(coin_json):
 #     scoin = {
 #         "creator": my_id.getIDURL(),
@@ -167,6 +162,7 @@ def set_prev_hash(coin_json, prev_hash):
 def coin_to_string(coin_json):
     return json.dumps(coin_json, sort_keys=True)
 
+
 def coins_to_string(coins_list):
     return json.dumps(coins_list, sort_keys=True)
 
@@ -182,6 +178,8 @@ def get_coin_hash(coin_json):
 
 def get_coin_base(coin_json):
     return coin_json
+
+
 #     bcoin = coin_json.copy()
 #     bcoin.pop('creator')
 #     bcoin.pop('signature')
@@ -189,12 +187,13 @@ def get_coin_base(coin_json):
 #     return bcoin
 
 
-def bought_storage(partner, ):
+def bought_storage(partner):
     pass
 
 
 #------------------------------------------------------------------------------
 
+
 def read_query_from_packet(newpacket):
     try:
         query_j = json.loads(newpacket.Payload)
@@ -214,8 +213,10 @@ def read_coins_from_packet(newpacket):
     # TODO: verify all input coins here
     return coins_list
 
+
 #------------------------------------------------------------------------------
 
+
 def validate_coin(coin_json):
     # TODO: validate sub-fields, hashes, query on DB, etc.
     # if 'miner' not in coin_json:
@@ -237,6 +238,7 @@ def verify_coin(coin_json, role):
     #     return False
     return True
 
+
 #------------------------------------------------------------------------------
 
 #------------------------------------------------------------------------------
@@ -246,6 +248,6 @@ def _test():
     pass
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     lg.set_debug_level(20)
     _test()
