@@ -19,7 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
 """
 .. module:: contactsdb.
 
@@ -47,31 +46,31 @@ from twisted.internet.defer import DeferredList
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import nameurl
-from lib import strng
-from lib import jsn
+from bitdust.lib import nameurl
+from bitdust.lib import strng
+from bitdust.lib import jsn
 
-from system import bpio
-from system import local_fs
+from bitdust.system import bpio
+from bitdust.system import local_fs
 
-from main import settings
-from main import listeners
+from bitdust.main import settings
+from bitdust.main import listeners
 
-from services import driver
+from bitdust.services import driver
 
-from userid import id_url
-from userid import my_id
-from userid import global_id
+from bitdust.userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import global_id
 
-from contacts import identitycache
+from bitdust.contacts import identitycache
 
 #-------------------------------------------------------------------------------
 
-_CustomersList = []      # comes from settings.CustomerIDsFilename()
-_SuppliersList = {}      # comes from settings.SuppliersDir()
-_CorrespondentsList = []   # comes from settings.CorrespondentIDsFilename()
+_CustomersList = []  # comes from settings.CustomerIDsFilename()
+_SuppliersList = {}  # comes from settings.SuppliersDir()
+_CorrespondentsList = []  # comes from settings.CorrespondentIDsFilename()
 _CorrespondentsDict = {}
 
 _SuppliersChangedCallback = None
@@ -98,11 +97,10 @@ def init():
     global _CustomersChangedCallback
     global _CorrespondentsChangedCallback
     if _Debug:
-        lg.out(_DebugLevel, "contactsdb.init")
+        lg.out(_DebugLevel, 'contactsdb.init')
     d = cache_contacts()
     d.addCallback(lambda _: load_contacts())
-    if _Debug:
-        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='contactsdb.init')
+    d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='contactsdb.init')
     return d
 
 
@@ -110,15 +108,17 @@ def shutdown():
     global _SuppliersChangedCallback
     global _CustomersChangedCallback
     if _Debug:
-        lg.out(_DebugLevel, "contactsdb.shutdown")
+        lg.out(_DebugLevel, 'contactsdb.shutdown')
     RemoveContactsChangedCallback(on_contacts_changed)
     if _SuppliersChangedCallback is not None:
         _SuppliersChangedCallback = None
     if _CustomersChangedCallback is not None:
         _CustomersChangedCallback = None
 
+
 #------------------------------------------------------------------------------
 
+
 def suppliers(customer_idurl=None):
     """
     Return list of suppliers ID's for given customer - me or another user.
@@ -187,7 +187,7 @@ def update_suppliers(idlist, customer_idurl=None):
     set_suppliers(idlist, customer_idurl=customer_idurl)
     if _SuppliersChangedCallback is not None:
         _SuppliersChangedCallback(oldsuppliers, suppliers(customer_idurl=customer_idurl))
-    if id_url.to_original_list(oldcontacts) != id_url.to_original_list(contacts()): 
+    if id_url.to_original_list(oldcontacts) != id_url.to_original_list(contacts()):
         for cb in _ContactsChangedCallbacks:
             cb(id_url.to_original_list(oldcontacts), id_url.to_original_list(contacts()))
 
@@ -209,20 +209,21 @@ def add_supplier(idurl, position=None, customer_idurl=None):
     if _Debug:
         lg.args(_DebugLevel, idurl=idurl, position=position, customer_idurl=customer_idurl)
     if position is None or position == -1:
-        lg.warn('position unknown, added supplier "%s" to the end of the list for customer %s' % (idurl, customer_idurl, ))
+        lg.warn('position unknown, added supplier "%s" to the end of the list for customer %s' % (idurl, customer_idurl))
         _SuppliersList[customer_idurl].append(idurl)
         return len(_SuppliersList[customer_idurl]) - 1
     current_suppliers = _SuppliersList[customer_idurl]
     if position >= len(current_suppliers):
-        empty_suppliers = [id_url.field(b''), ] * (1 + position - len(current_suppliers))
+        empty_suppliers = [
+            id_url.field(b''),
+        ]*(1 + position - len(current_suppliers))
         current_suppliers.extend(empty_suppliers)
         if _Debug:
             lg.out(_DebugLevel, 'contactsdb.add_supplier   %d empty suppliers added for customer %r' % (len(empty_suppliers), customer_idurl))
     if current_suppliers[position] and current_suppliers[position] != idurl:
-        lg.info('replacing known supplier "%s" by "%s" at position %d for customer %s' % (
-            current_suppliers[position], idurl, position, customer_idurl, ))
+        lg.info('replacing known supplier "%s" by "%s" at position %d for customer %s' % (current_suppliers[position], idurl, position, customer_idurl))
     else:
-        lg.info('added supplier "%s" at position %d for customer %s' % (idurl, position, customer_idurl, ))
+        lg.info('added supplier "%s" at position %d for customer %s' % (idurl, position, customer_idurl))
     current_suppliers[position] = idurl
     update_suppliers(idlist=current_suppliers, customer_idurl=customer_idurl)
     return position
@@ -275,6 +276,7 @@ def clear_all_suppliers():
 
 #------------------------------------------------------------------------------
 
+
 def known_customers():
     """
     Return list of all known customers : if I need to connect to their suppliers.
@@ -338,6 +340,7 @@ def clear_customers():
 
 #------------------------------------------------------------------------------
 
+
 def contacts(include_all=False, include_enabled=True):
     """
     Return a union of suppliers and customers ID's.
@@ -351,7 +354,7 @@ def contacts(include_all=False, include_enabled=True):
         result.update(set(correspondents_ids()))
     if include_all or include_enabled:
         if driver.is_enabled('service_message_broker') or driver.is_on('service_message_broker'):
-            from stream import message_peddler
+            from bitdust.stream import message_peddler
             result.update(set(message_peddler.list_customers()))
             result.update(set(message_peddler.list_consumers_producers(include_consumers=True, include_producers=True)))
             result.update(set(message_peddler.list_known_brokers()))
@@ -372,6 +375,7 @@ def contacts_remote(include_all=False, include_enabled=True):
     l = id_url.to_bin_list(contacts(include_all=include_all, include_enabled=include_enabled))
     return [i for i in id_url.fields_list(l) if not id_url.is_the_same(i, my_id.getIDURL())]
 
+
 #------------------------------------------------------------------------------
 
 
@@ -416,7 +420,10 @@ def add_correspondent(idurl, nickname=''):
     global _CorrespondentsChangedCallback
     curlist = list(_CorrespondentsList)
     idurl = id_url.field(idurl)
-    _CorrespondentsList.append((idurl.to_bin(), nickname, ))
+    _CorrespondentsList.append((
+        idurl.to_bin(),
+        nickname,
+    ))
     if _CorrespondentsChangedCallback is not None:
         _CorrespondentsChangedCallback(curlist, _CorrespondentsList)
     listeners.push_snapshot('correspondent', snap_id=idurl.to_bin(), data=dict(
@@ -455,8 +462,10 @@ def populate_correspondents():
             nickname=corr[1],
         ))
 
+
 #-------------------------------------------------------------------------------
 
+
 def is_customer(idurl):
     """
     Return True if given ID is found in customers list.
@@ -483,8 +492,10 @@ def is_correspondent(idurl):
         return False
     return id_url.field(idurl).to_bin() in id_url.to_bin_list(correspondents_ids())
 
+
 #------------------------------------------------------------------------------
 
+
 def num_customers():
     """
     Return current number of customers.
@@ -513,8 +524,10 @@ def num_correspondents():
     """
     return len(correspondents())
 
+
 #------------------------------------------------------------------------------
 
+
 def supplier_position(idurl, customer_idurl=None):
     """
     Return position of supplier with given ID or -1.
@@ -566,8 +579,10 @@ def contact_position(idurl):
         index = -1
     return index
 
+
 #-------------------------------------------------------------------------------
 
+
 def save_suppliers(path=None, customer_idurl=None):
     """
     Write current suppliers list on the disk, ``path`` is a file path to save.
@@ -584,7 +599,7 @@ def save_suppliers(path=None, customer_idurl=None):
         bpio._dirs_make(os.path.dirname(path))
     bpio._write_list(path, lst)
     if _Debug:
-        lg.out(_DebugLevel, 'contactsdb.save_suppliers for customer [%s]:\n%r' % (customer_id, lst, ))
+        lg.out(_DebugLevel, 'contactsdb.save_suppliers for customer [%s]:\n%r' % (customer_id, lst))
     return True
 
 
@@ -669,8 +684,10 @@ def cache_suppliers(path=None):
         lg.out(_DebugLevel, 'contactsdb.cache_suppliers prepared %d idurls to be cached' % len(dl))
     return DeferredList(dl, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
+
 def save_customers(path=None, save_meta_info=False):
     """
     Write current customers list on the disk, ``path`` is a file path to save.
@@ -684,9 +701,13 @@ def save_customers(path=None, save_meta_info=False):
     if save_meta_info:
         json_info = id_url.to_bin_dict(_CustomersMetaInfo)
         local_fs.WriteTextFile(settings.CustomersMetaInfoFilename(), jsn.dumps(
-            json_info, indent=2, sort_keys=True, keys_to_text=True, ))
+            json_info,
+            indent=2,
+            sort_keys=True,
+            keys_to_text=True,
+        ))
     if _Debug:
-        lg.out(_DebugLevel, 'contactsdb.save_customers save_meta_info=%r : %r' % (save_meta_info, lst, ))
+        lg.out(_DebugLevel, 'contactsdb.save_customers save_meta_info=%r : %r' % (save_meta_info, lst))
 
 
 def load_customers(path=None):
@@ -727,8 +748,10 @@ def cache_customers(path=None):
         lg.out(_DebugLevel, 'contactsdb.cache_customers prepared %d idurls to be cached' % len(dl))
     return DeferredList(dl, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
+
 def save_correspondents(path=None):
     """
     Write current correspondents list on the disk, ``path`` is a file path to
@@ -736,7 +759,10 @@ def save_correspondents(path=None):
     """
     if path is None:
         path = settings.CorrespondentIDsFilename()
-    lst = ["%s %s" % (strng.to_text(t[0]), strng.to_text(t[1]),) for t in correspondents()]
+    lst = ['%s %s' % (
+        strng.to_text(t[0]),
+        strng.to_text(t[1]),
+    ) for t in correspondents()]
     bpio._write_list(path, lst)
 
 
@@ -782,9 +808,15 @@ def cache_correspondents(path=None):
         lg.out(_DebugLevel, 'contactsdb.cache_correspondents prepared %d idurls to be cached' % len(dl))
     return DeferredList(dl, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
-def cache_contacts(suppliers_path=None, customers_path=None, correspondents_path=None, ):
+
+def cache_contacts(
+    suppliers_path=None,
+    customers_path=None,
+    correspondents_path=None,
+):
     """
     Make sure identities of all my known contacts are cached.
     """
@@ -813,8 +845,10 @@ def load_contacts():
         listeners.populate_later().remove('correspondent')
         populate_correspondents()
 
+
 #------------------------------------------------------------------------------
 
+
 def get_contact_identity(idurl):
     """
     The Main Method Here - return identity object for given ID or None if not found.
@@ -825,6 +859,8 @@ def get_contact_identity(idurl):
     idurl = id_url.field(idurl)
     if idurl.to_bin() == my_id.getIDURL().to_bin():
         return my_id.getLocalIdentity()
+
+
 #     if is_supplier(idurl):
 #         return identitycache.FromCache(idurl)
 #     if is_customer(idurl):
@@ -834,7 +870,7 @@ def get_contact_identity(idurl):
     if identitycache.HasKey(idurl):
         # lg.warn("who is %s ?" % nameurl.GetName(idurl))
         return identitycache.FromCache(idurl)
-    lg.warn("%s is NOT FOUND IN CACHE" % idurl)
+    lg.warn('%s is NOT FOUND IN CACHE' % idurl)
     # TODO:
     # this is not correct:
     # need to check if other contacts is fine - if internet is turned off we can get lots of fails ...
@@ -884,17 +920,21 @@ def find_correspondent_by_nickname(nickname):
             return idurl
     return None
 
+
 #------------------------------------------------------------------------------
 
+
 def on_contacts_changed(old_contacts_list, new_contacts_list):
-    from main import events
+    from bitdust.main import events
     events.send('contacts-changed', data=dict(
         old_contacts=old_contacts_list,
         new_contacts=new_contacts_list,
     ))
 
+
 #------------------------------------------------------------------------------
 
+
 def read_customers_meta_info_all():
     global _CustomersMetaInfo
     return _CustomersMetaInfo
@@ -906,7 +946,11 @@ def write_customers_meta_info_all(new_customers_info):
     json_info = {k: jsn.dict_keys_to_text(v) for k, v in id_url.to_bin_dict(_CustomersMetaInfo).items()}
     try:
         raw_data = jsn.dumps(
-            json_info, indent=2, sort_keys=True, keys_to_text=True, values_to_text=True,
+            json_info,
+            indent=2,
+            sort_keys=True,
+            keys_to_text=True,
+            values_to_text=True,
         )
     except:
         lg.exc()
@@ -922,8 +966,7 @@ def add_customer_meta_info(customer_idurl, info):
         if customer_idurl.original() in _CustomersMetaInfo:
             if customer_idurl.to_bin() not in _CustomersMetaInfo:
                 _CustomersMetaInfo[customer_idurl.to_bin()] = _CustomersMetaInfo.pop(customer_idurl.original())
-                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (
-                    customer_idurl.original(), customer_idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (customer_idurl.original(), customer_idurl.to_bin()))
     customer_idurl = id_url.to_bin(customer_idurl)
     if 'family_snapshot' in info:
         info['family_snapshot'] = id_url.to_bin_list(info['family_snapshot'])
@@ -931,18 +974,20 @@ def add_customer_meta_info(customer_idurl, info):
         info['ecc_map'] = strng.to_text(info['ecc_map'])
     if customer_idurl not in _CustomersMetaInfo:
         if _Debug:
-            lg.out(_DebugLevel, 'contactsdb.add_customer_meta_info   store new meta info for customer %r: %r' % (
-                customer_idurl, info, ))
+            lg.out(_DebugLevel, 'contactsdb.add_customer_meta_info   store new meta info for customer %r: %r' % (customer_idurl, info))
         _CustomersMetaInfo[customer_idurl] = {}
     else:
         if _Debug:
-            lg.out(_DebugLevel, 'contactsdb.add_customer_meta_info   update existing meta info for customer %r: %r' % (
-                customer_idurl, info, ))
+            lg.out(_DebugLevel, 'contactsdb.add_customer_meta_info   update existing meta info for customer %r: %r' % (customer_idurl, info))
         _CustomersMetaInfo[customer_idurl].update(info)
     json_info = {k: jsn.dict_keys_to_text(v) for k, v in id_url.to_bin_dict(_CustomersMetaInfo).items()}
     try:
         raw_data = jsn.dumps(
-            json_info, indent=2, sort_keys=True, keys_to_text=True, values_to_text=True,
+            json_info,
+            indent=2,
+            sort_keys=True,
+            keys_to_text=True,
+            values_to_text=True,
         )
     except:
         lg.exc()
@@ -958,8 +1003,7 @@ def remove_customer_meta_info(customer_idurl):
         if customer_idurl.original() in _CustomersMetaInfo:
             if customer_idurl.to_bin() not in _CustomersMetaInfo:
                 _CustomersMetaInfo[customer_idurl.to_bin()] = _CustomersMetaInfo.pop(customer_idurl.original())
-                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (
-                    customer_idurl.original(), customer_idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (customer_idurl.original(), customer_idurl.to_bin()))
     customer_idurl = id_url.to_bin(customer_idurl)
     if customer_idurl not in _CustomersMetaInfo:
         lg.warn('meta info for customer %r not exist' % customer_idurl)
@@ -969,7 +1013,11 @@ def remove_customer_meta_info(customer_idurl):
     _CustomersMetaInfo.pop(customer_idurl)
     json_info = {k: jsn.dict_keys_to_text(v) for k, v in id_url.to_bin_dict(_CustomersMetaInfo).items()}
     local_fs.WriteTextFile(settings.CustomersMetaInfoFilename(), jsn.dumps(
-        json_info, indent=2, sort_keys=True, keys_to_text=True, values_to_text=True,
+        json_info,
+        indent=2,
+        sort_keys=True,
+        keys_to_text=True,
+        values_to_text=True,
     ))
     return True
 
@@ -981,13 +1029,14 @@ def get_customer_meta_info(customer_idurl):
         if customer_idurl.original() in _CustomersMetaInfo:
             if customer_idurl.to_bin() not in _CustomersMetaInfo:
                 _CustomersMetaInfo[customer_idurl.to_bin()] = _CustomersMetaInfo.pop(customer_idurl.original())
-                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (
-                    customer_idurl.original(), customer_idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for customer meta info : %r -> %r' % (customer_idurl.original(), customer_idurl.to_bin()))
     customer_idurl = id_url.to_bin(customer_idurl)
     return jsn.dict_keys_to_text(jsn.dict_values_to_text(_CustomersMetaInfo.get(customer_idurl, {})))
 
+
 #------------------------------------------------------------------------------
 
+
 def add_supplier_meta_info(supplier_idurl, info, customer_idurl=None):
     global _SuppliersMetaInfo
     if not customer_idurl:
@@ -1000,8 +1049,7 @@ def add_supplier_meta_info(supplier_idurl, info, customer_idurl=None):
         _SuppliersMetaInfo[customer_idurl][supplier_idurl] = {}
     _SuppliersMetaInfo[customer_idurl][supplier_idurl].update(info)
     if _Debug:
-        lg.out(_DebugLevel, 'contactsdb.add_supplier_meta_info   for supplier %s of customer %s: %s' % (
-            supplier_idurl, customer_idurl, _SuppliersMetaInfo[customer_idurl][supplier_idurl]))
+        lg.out(_DebugLevel, 'contactsdb.add_supplier_meta_info   for supplier %s of customer %s: %s' % (supplier_idurl, customer_idurl, _SuppliersMetaInfo[customer_idurl][supplier_idurl]))
 
 
 def remove_supplier_meta_info(supplier_idurl, customer_idurl=None):
@@ -1028,11 +1076,12 @@ def get_supplier_meta_info(supplier_idurl, customer_idurl=None):
         return {}
     customer_idurl = id_url.field(customer_idurl)
     supplier_idurl = id_url.field(supplier_idurl)
-    return jsn.dict_keys_to_text(jsn.dict_values_to_text(
-        _SuppliersMetaInfo.get(customer_idurl, {}).get(supplier_idurl, {})))
+    return jsn.dict_keys_to_text(jsn.dict_values_to_text(_SuppliersMetaInfo.get(customer_idurl, {}).get(supplier_idurl, {})))
+
 
 #------------------------------------------------------------------------------
 
+
 def SetSuppliersChangedCallback(cb):
     """
     Set callback to fire when suppliers is changed.
