@@ -19,14 +19,11 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: geth_service
 
 """
 
-
 #------------------------------------------------------------------------------
 
 from __future__ import absolute_import
@@ -56,17 +53,17 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from main import settings
-
-from updates import git_proc
+from bitdust.main import settings
 
+from bitdust.updates import git_proc
 
 #------------------------------------------------------------------------------
 
+
 def init():
     lg.out(4, 'geth_service.init')
     try:
@@ -80,10 +77,12 @@ def init():
 def shutdown():
     lg.out(4, 'geth_service.shutdown')
 
+
 #------------------------------------------------------------------------------
 
+
 def verify_local_install():
-    ethereum_location = os.path.join(settings.BaseDir(), "ethereum")
+    ethereum_location = os.path.join(settings.BaseDir(), 'ethereum')
     if not os.path.isdir(ethereum_location):
         raise ValueError('Ethereum root location not found: {}'.format(ethereum_location))
     geth_location = os.path.join(ethereum_location, 'go-ethereum')
@@ -94,51 +93,74 @@ def verify_local_install():
         raise ValueError('Ethereum geth process executable not found: {}'.format(geth_bin_path))
     return True
 
+
 def verify_global_install():
     # TODO: try to run "geth" in shell
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def clone(callback=None):
-    ethereum_location = os.path.join(settings.BaseDir(), "ethereum")
+    ethereum_location = os.path.join(settings.BaseDir(), 'ethereum')
     if not os.path.isdir(ethereum_location):
         os.makedirs(ethereum_location)
     geth_location = os.path.join(ethereum_location, 'go-ethereum')
     if os.path.exists(geth_location):
         bpio.rmdir_recursive(geth_location)
     git_proc.run(
-        ['clone', '--verbose', '--depth', '1', 'https://github.com/ethereum/go-ethereum', geth_location, ],
+        [
+            'clone',
+            '--verbose',
+            '--depth',
+            '1',
+            'https://github.com/ethereum/go-ethereum',
+            geth_location,
+        ],
         base_dir=ethereum_location,
         env=os.environ,
         callback_func=callback,
     )
 
+
 def make(callback=None):
-    geth_location = os.path.join(settings.BaseDir(), "ethereum", "go-ethereum")
+    geth_location = os.path.join(settings.BaseDir(), 'ethereum', 'go-ethereum')
     execute(['make', 'geth'], base_dir=geth_location, env=os.environ, callback=callback)
 
+
 def deploy(callback=None):
     def _clone(out, retcode):
         make(callback=callback)
+
     clone(callback=_clone)
 
+
 #------------------------------------------------------------------------------
 
+
 def run(cmdargs, callback=None):
-    geth_location = os.path.join(settings.BaseDir(), "ethereum", "go-ethereum",)
-    cmdargs = ['build/bin/geth', ] + cmdargs
+    geth_location = os.path.join(
+        settings.BaseDir(),
+        'ethereum',
+        'go-ethereum',
+    )
+    cmdargs = [
+        'build/bin/geth',
+    ] + cmdargs
     execute(cmdargs, base_dir=geth_location, env=os.environ, callback=callback)
 
+
 def run_geth_node():
-    geth_datadir = os.path.join(settings.BaseDir(), "ethereum", "datadir")
+    geth_datadir = os.path.join(settings.BaseDir(), 'ethereum', 'datadir')
     if not os.path.isdir(geth_datadir):
         os.makedirs(geth_datadir)
-    run(['--datadir="{}"'.format(geth_datadir),
-         '--verbosity', '4', '--ipcdisable', '--port', '30300', '--rpcport', '8100', '--networkid', '1'])
+    run(['--datadir="{}"'.format(geth_datadir), '--verbosity', '4', '--ipcdisable', '--port', '30300', '--rpcport', '8100', '--networkid', '1'])
+
 
 #------------------------------------------------------------------------------
 
+
 def execute(cmdargs, base_dir=None, process_protocol=None, env=None, callback=None):
     global _CurrentProcess
     if _Debug:
@@ -148,25 +170,20 @@ def execute(cmdargs, base_dir=None, process_protocol=None, env=None, callback=No
         from twisted.internet import _dumbwin32proc
         real_CreateProcess = _dumbwin32proc.win32process.CreateProcess
 
-        def fake_createprocess(_appName, _commandLine, _processAttributes,
-                               _threadAttributes, _bInheritHandles, creationFlags,
-                               _newEnvironment, _currentDirectory, startupinfo):
+        def fake_createprocess(_appName, _commandLine, _processAttributes, _threadAttributes, _bInheritHandles, creationFlags, _newEnvironment, _currentDirectory, startupinfo):
             import win32con
             import subprocess
             flags = win32con.CREATE_NO_WINDOW
             startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
             startupinfo.wShowWindow = subprocess.SW_HIDE
-            return real_CreateProcess(_appName, _commandLine,
-                                      _processAttributes, _threadAttributes,
-                                      _bInheritHandles, flags, _newEnvironment,
-                                      _currentDirectory, startupinfo)
+            return real_CreateProcess(_appName, _commandLine, _processAttributes, _threadAttributes, _bInheritHandles, flags, _newEnvironment, _currentDirectory, startupinfo)
+
         setattr(_dumbwin32proc.win32process, 'CreateProcess', fake_createprocess)
 
     if process_protocol is None:
         process_protocol = GethProcessProtocol(callback)
     try:
-        _CurrentProcess = reactor.spawnProcess(
-            process_protocol, executable, cmdargs, path=base_dir, env=env)
+        _CurrentProcess = reactor.spawnProcess(process_protocol, executable, cmdargs, path=base_dir, env=env)
     except:
         lg.exc()
         return None
@@ -174,10 +191,11 @@ def execute(cmdargs, base_dir=None, process_protocol=None, env=None, callback=No
         setattr(_dumbwin32proc.win32process, 'CreateProcess', real_CreateProcess)
     return _CurrentProcess
 
+
 #------------------------------------------------------------------------------
 
-class GethProcessProtocol(protocol.ProcessProtocol):
 
+class GethProcessProtocol(protocol.ProcessProtocol):
     def __init__(self, callback):
         """
         """
@@ -209,10 +227,10 @@ class GethProcessProtocol(protocol.ProcessProtocol):
         if self.callback:
             self.callback(self.out, reason.value.exitCode)
 
+
 #------------------------------------------------------------------------------
 
-
-if __name__ == "__main__":
+if __name__ == '__main__':
     bpio.init()
     lg.set_debug_level(18)
     reactor.callWhenRunning(run_geth_node)
