@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: supplier_finder.
 
@@ -51,20 +49,20 @@ _DebugLevel = 10
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import strng
+from bitdust.lib import strng
 
-from p2p import lookup
-from p2p import online_status
+from bitdust.p2p import lookup
+from bitdust.p2p import online_status
 
-from contacts import identitycache
-from contacts import contactsdb
+from bitdust.contacts import identitycache
+from bitdust.contacts import contactsdb
 
-from userid import my_id
-from userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import id_url
 
 #------------------------------------------------------------------------------
 
@@ -73,6 +71,7 @@ _SuppliersToHire = []
 
 #------------------------------------------------------------------------------
 
+
 def AddSupplierToHire(idurl):
     global _SuppliersToHire
     idurl = strng.to_bin(idurl)
@@ -90,6 +89,7 @@ def InsertSupplierToHire(idurl):
         if _Debug:
             lg.dbg(_DebugLevel, 'added %r as a FIRST supplier candidate' % idurl)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -135,14 +135,14 @@ class SupplierFinder(automat.Automat):
         if self.state == 'AT_STARTUP':
             if event == 'start' and not self.isSomeCandidatesListed(*args, **kwargs):
                 self.state = 'RANDOM_USER'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doInit(*args, **kwargs)
                 self.doDHTFindRandomUser(*args, **kwargs)
             elif event == 'start' and self.isSomeCandidatesListed(*args, **kwargs):
                 self.state = 'ACK?'
                 self.doInit(*args, **kwargs)
                 self.doPopCandidate(*args, **kwargs)
-                self.Attempts=1
+                self.Attempts = 1
                 self.doSendMyIdentity(*args, **kwargs)
         #---RANDOM_USER---
         elif self.state == 'RANDOM_USER':
@@ -154,15 +154,15 @@ class SupplierFinder(automat.Automat):
                 self.state = 'ACK?'
                 self.doCleanPrevUser(*args, **kwargs)
                 self.doRememberUser(*args, **kwargs)
-                self.Attempts+=1
+                self.Attempts += 1
                 self.doSendMyIdentity(*args, **kwargs)
         #---ACK?---
         elif self.state == 'ACK?':
-            if self.Attempts==5 and ( event == 'timer-10sec' or event == 'ping-failed' ):
+            if self.Attempts == 5 and (event == 'timer-10sec' or event == 'ping-failed'):
                 self.state = 'FAILED'
                 self.doDestroyMe(*args, **kwargs)
                 self.doReportFailed(*args, **kwargs)
-            elif ( event == 'ping-failed' or event == 'timer-10sec' ) and self.Attempts<5:
+            elif (event == 'ping-failed' or event == 'timer-10sec') and self.Attempts < 5:
                 self.state = 'RANDOM_USER'
                 self.doDHTFindRandomUser(*args, **kwargs)
             elif event == 'ack-received':
@@ -174,13 +174,13 @@ class SupplierFinder(automat.Automat):
                 self.state = 'DONE'
                 self.doDestroyMe(*args, **kwargs)
                 self.doReportDone(*args, **kwargs)
-            elif self.Attempts<5 and event == 'supplier-not-connected':
+            elif self.Attempts < 5 and event == 'supplier-not-connected':
                 self.state = 'RANDOM_USER'
                 self.doDHTFindRandomUser(*args, **kwargs)
-            elif event == 'timer-30sec' and self.Attempts<5:
+            elif event == 'timer-30sec' and self.Attempts < 5:
                 self.state = 'RANDOM_USER'
                 self.doDHTFindRandomUser(*args, **kwargs)
-            elif self.Attempts==5 and ( event == 'timer-30sec' or event == 'supplier-not-connected' ):
+            elif self.Attempts == 5 and (event == 'timer-30sec' or event == 'supplier-not-connected'):
                 self.state = 'FAILED'
                 self.doDestroyMe(*args, **kwargs)
                 self.doReportFailed(*args, **kwargs)
@@ -227,9 +227,9 @@ class SupplierFinder(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
-        from customer import fire_hire
-        from raid import eccmap
+        from bitdust.customer import supplier_connector
+        from bitdust.customer import fire_hire
+        from bitdust.raid import eccmap
         position = self.family_position
         if position is None or position == -1:
             lg.warn('position for new supplier is unknown, will "guess"')
@@ -268,7 +268,7 @@ class SupplierFinder(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
+        from bitdust.customer import supplier_connector
         if id_url.is_cached(self.target_idurl):
             sc = supplier_connector.by_idurl(self.target_idurl)
             if sc:
@@ -293,28 +293,27 @@ class SupplierFinder(automat.Automat):
                 self.target_idurl = id_url.field(idurl)
                 _SuppliersToHire.remove(idurl)
                 break
-        lg.info('populate supplier %r from "hire" list, %d more in the list' % (
-            self.target_idurl, len(_SuppliersToHire)))
+        lg.info('populate supplier %r from "hire" list, %d more in the list' % (self.target_idurl, len(_SuppliersToHire)))
 
     def doReportDone(self, *args, **kwargs):
         """
         Action method.
         """
-        from customer import fire_hire
+        from bitdust.customer import fire_hire
         fire_hire.A('supplier-connected', *args, **kwargs)
 
     def doReportFailed(self, *args, **kwargs):
         """
         Action method.
         """
-        from customer import fire_hire
+        from bitdust.customer import fire_hire
         fire_hire.A('search-failed', *args, **kwargs)
 
     def doDestroyMe(self, *args, **kwargs):
         """
         Remove all references to the state machine object to destroy it.
         """
-        from customer import supplier_connector
+        from bitdust.customer import supplier_connector
         global _SupplierFinder
         del _SupplierFinder
         _SupplierFinder = None
@@ -336,10 +335,10 @@ class SupplierFinder(automat.Automat):
             return
         found_idurl = None
         for idurl in idurls:
-#             if id_url.is_in(idurl, contactsdb.suppliers(), as_field=True):
-#                 if _Debug:
-#                     lg.out('    skip %r because already my supplier' % idurl)
-#                 continue
+            #             if id_url.is_in(idurl, contactsdb.suppliers(), as_field=True):
+            #                 if _Debug:
+            #                     lg.out('    skip %r because already my supplier' % idurl)
+            #                 continue
             ident = identitycache.FromCache(idurl)
             remoteprotos = set(ident.getProtoOrder())
             myprotos = set(my_id.getLocalIdentity().getProtoOrder())
@@ -360,7 +359,10 @@ class SupplierFinder(automat.Automat):
     def _supplier_connector_state(self, supplier_idurl, newstate, **kwargs):
         if id_url.field(supplier_idurl) != self.target_idurl:
             return
-        if newstate in ['DISCONNECTED', 'NO_SERVICE', ]:
+        if newstate in [
+            'DISCONNECTED',
+            'NO_SERVICE',
+        ]:
             self.automat('supplier-not-connected')
             return
         if newstate != 'CONNECTED':
