@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: jsn.
 
@@ -37,19 +35,17 @@ _Debug = False
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
+
 def dict_keys_to_text(dct, encoding='utf-8', errors='strict'):
     """
     Returns dict where all keys are converted to text strings.
     Only works for keys in a "root" level of the dict.
     """
-    return {
-        (k.decode(encoding, errors=errors) if strng.is_bin(k) else k) : v
-        for k, v in dct.items()
-    }
+    return {(k.decode(encoding, errors=errors) if strng.is_bin(k) else k): v for k, v in dct.items()}
 
 
 def dict_keys_to_bin(dct, encoding='utf-8', errors='strict'):
@@ -57,10 +53,7 @@ def dict_keys_to_bin(dct, encoding='utf-8', errors='strict'):
     Returns dict where all keys are converted to binary strings.
     Only works for keys in a "root" level of the dict.
     """
-    return {
-        (k.encode(encoding, errors=errors) if strng.is_text(k) else k) : v
-        for k, v in dct.items()
-    }
+    return {(k.encode(encoding, errors=errors) if strng.is_text(k) else k): v for k, v in dct.items()}
 
 
 def dict_values_to_text(dct, encoding='utf-8', errors='strict'):
@@ -69,7 +62,7 @@ def dict_values_to_text(dct, encoding='utf-8', errors='strict'):
     Can go recursively, but not super smart.
     If value is a list of dicts - will not be converted.
     """
-    # TODO: make it fully recursive... for example if list of lists is passed 
+    # TODO: make it fully recursive... for example if list of lists is passed
     _d = {}
     for k, v in dct.items():
         _v = v
@@ -122,8 +115,10 @@ def dict_items_to_text(dct, encoding='utf-8', errors='strict'):
         _d[_k] = _v
     return _d
 
+
 #------------------------------------------------------------------------------
 
+
 def pack_dict(dct, encoding='utf-8', errors='strict'):
     """
     Creates another dict from input dict where types of keys and values are also present.
@@ -166,7 +161,11 @@ def pack_dict(dct, encoding='utf-8', errors='strict'):
             _vtyp = 't'
         elif _v is None:
             _vtyp = 'n'
-        _d[_k] = (_ktyp, _vtyp, _v, )
+        _d[_k] = (
+            _ktyp,
+            _vtyp,
+            _v,
+        )
     return _d
 
 
@@ -198,8 +197,8 @@ def unpack_dict(dct, encoding='utf-8', errors='strict'):
 
 #------------------------------------------------------------------------------
 
-def dumps(obj, indent=None, separators=None, sort_keys=None, ensure_ascii=False, encoding='utf-8', 
-          keys_to_text=False, values_to_text=False, empty_result='{}', **kw):
+
+def dumps(obj, indent=None, separators=None, sort_keys=None, ensure_ascii=False, encoding='utf-8', keys_to_text=False, values_to_text=False, empty_result='{}', **kw):
     """
     Calls `json.dumps()` with parameters.
     Always translates every byte string json value into text using encoding.
@@ -224,26 +223,9 @@ def dumps(obj, indent=None, separators=None, sort_keys=None, ensure_ascii=False,
 
     try:
         if sys.version_info[0] < 3:
-            return json.dumps(
-                obj=obj,
-                indent=indent,
-                separators=separators,
-                sort_keys=sort_keys,
-                ensure_ascii=ensure_ascii,
-                default=_to_text,
-                encoding=encoding,
-                **kw
-            )
+            return json.dumps(obj=obj, indent=indent, separators=separators, sort_keys=sort_keys, ensure_ascii=ensure_ascii, default=_to_text, encoding=encoding, **kw)
         else:
-            return json.dumps(
-                obj=obj,
-                indent=indent,
-                separators=separators,
-                sort_keys=sort_keys,
-                ensure_ascii=ensure_ascii,
-                default=_to_text,
-                **kw
-            )
+            return json.dumps(obj=obj, indent=indent, separators=separators, sort_keys=sort_keys, ensure_ascii=ensure_ascii, default=_to_text, **kw)
     except Exception as exc:
         if _Debug:
             import os
@@ -262,6 +244,7 @@ def dumps(obj, indent=None, separators=None, sort_keys=None, ensure_ascii=False,
 
 #------------------------------------------------------------------------------
 
+
 def loads(s, encoding='utf-8', keys_to_bin=False, **kw):
     """
     Calls `json.loads()` with parameters.
@@ -276,15 +259,11 @@ def loads(s, encoding='utf-8', keys_to_bin=False, **kw):
             if strng.is_text(dct[k]):
                 dct[k] = dct[k].encode(encoding)
         if keys_to_bin:
-            return {(k.encode(encoding) if strng.is_text(k) else k) : v for k, v in dct.items()}
+            return {(k.encode(encoding) if strng.is_text(k) else k): v for k, v in dct.items()}
         return dct
 
     try:
-        return json.loads(
-            s=s,
-            object_hook=_to_bin,
-            **kw
-        )
+        return json.loads(s=s, object_hook=_to_bin, **kw)
     except Exception as exc:
         if _Debug:
             try:
@@ -297,8 +276,10 @@ def loads(s, encoding='utf-8', keys_to_bin=False, **kw):
                 pass
         raise exc
 
+
 #------------------------------------------------------------------------------
 
+
 def loads_text(s, encoding='utf-8', **kw):
     """
     Calls `json.loads()` with parameters.
@@ -310,11 +291,7 @@ def loads_text(s, encoding='utf-8', **kw):
     enc_errors = kw.pop('errors', 'strict')
 
     try:
-        return json.loads(
-            s=s,
-            object_hook=lambda itm: dict_items_to_text(itm, encoding=encoding, errors=enc_errors),
-            **kw
-        )
+        return json.loads(s=s, object_hook=lambda itm: dict_items_to_text(itm, encoding=encoding, errors=enc_errors), **kw)
     except Exception as exc:
         if _Debug:
             import os
