@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: misc.
 
@@ -37,7 +36,7 @@ TODO:
 
 from __future__ import absolute_import
 from __future__ import print_function
-import six.moves.urllib.parse # @UnresolvedImport
+import six.moves.urllib.parse  # @UnresolvedImport
 from six.moves import range  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
@@ -65,15 +64,15 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import local_fs
+from bitdust.system import bpio
+from bitdust.system import local_fs
 
-from main import settings
+from bitdust.main import settings
 
-from lib import packetid
-from lib import strng
+from bitdust.lib import packetid
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
@@ -97,6 +96,7 @@ def init():
     """
     lg.out(4, 'misc.init')
 
+
 #------------------------------------------------------------------------------
 
 
@@ -136,8 +136,10 @@ def writeSupplierData(supplier_idurl, filename, data, customer_idurl):
     path = settings.SupplierPath(supplier_idurl, customer_idurl, filename)
     return bpio.WriteTextFile(path, data)
 
+
 #-------------------------------------------------------------------------------
 
+
 def cmp(a, b):
     return (a > b) - (a < b)
 
@@ -151,11 +153,11 @@ def NewBackupID(time_st=None):
     """
     if time_st is None:
         time_st = time.localtime()
-    ampm = time.strftime("%p", time_st)
+    ampm = time.strftime('%p', time_st)
     if not ampm:
         lg.warn('time.strftime() returns empty string')
         ampm = 'AM' if time.time() % 86400 < 43200 else 'PM'
-    result = "F" + time.strftime("%Y%m%d%I%M%S", time_st) + ampm
+    result = 'F' + time.strftime('%Y%m%d%I%M%S', time_st) + ampm
     return result
 
 
@@ -183,7 +185,7 @@ def TimeFromBackupID(backupID):
     try:
         return time.mktime(TimeStructFromVersion(backupID))
     except:
-        lg.exc()
+        lg.exc('backupID=%r' % backupID)
         return None
 
 
@@ -258,8 +260,10 @@ def sorted_versions(versions, reverse=False):
     sorted_versions_list = sorted(versions, key=functools.cmp_to_key(version_compare), reverse=reverse)
     return sorted_versions_list
 
+
 #------------------------------------------------------------------------------
 
+
 def DigitsOnly(inpt, includes=''):
     """
     Very basic method to convert string to number.
@@ -298,19 +302,21 @@ def ToFloat(inpt, default=0.0):
     except:
         return default
 
+
 #------------------------------------------------------------------------------
 
+
 def ValidKeyAlias(key_alias):
     if len(key_alias) > 50:
-        lg.warn("key_alias is too long")
+        lg.warn('key_alias is too long')
         return False
     if len(key_alias) < settings.MinimumUsernameLength():
-        lg.warn("key_alias is too short")
+        lg.warn('key_alias is too short')
         return False
     pos = 0
     for c in key_alias:
         if c not in settings.LegalUsernameChars():
-            lg.warn("key_alias has illegal character at position: %d" % pos)
+            lg.warn('key_alias has illegal character at position: %d' % pos)
             return False
         pos += 1
     if key_alias[0] not in set('abcdefghijklmnopqrstuvwxyz'):
@@ -324,15 +330,15 @@ def ValidUserName(username):
     A method to validate account name entered by user.
     """
     if len(username) < settings.MinimumUsernameLength():
-        lg.warn("username is too short")
+        lg.warn('username is too short')
         return False
     if len(username) > settings.MaximumUsernameLength():
-        lg.warn("username is too long")
+        lg.warn('username is too long')
         return False
     pos = 0
     for c in username:
         if c not in settings.LegalUsernameChars():
-            lg.warn("username has illegal character at position: %d" % pos)
+            lg.warn('username has illegal character at position: %d' % pos)
             return False
         pos += 1
     if username[0] not in set('abcdefghijklmnopqrstuvwxyz'):
@@ -413,7 +419,7 @@ def MakeValidHTMLComment(text):
     """
     ret = ''
     for c in text:
-        if c in set("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-+*/=_()[]{}:;,.?!@#$%|~ "):
+        if c in set('abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-+*/=_()[]{}:;,.?!@#$%|~ '):
             ret += c
     return ret
 
@@ -427,9 +433,9 @@ def ValidateBitCoinAddress(strAddr):
     http://www.rugatu.com/questions/3255/anybody-has-python-code-to-verifyvalidate-bitcoin-address
     """
     # The first character indicates the "version" of the address.
-    CHARS_OK_FIRST = "123"
+    CHARS_OK_FIRST = '123'
     # alphanumeric characters without : l I O 0
-    CHARS_OK = "123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz"
+    CHARS_OK = '123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz'
     # We do not check the high length limit of the adress.
     if len(strAddr) < 27:
         return False
@@ -442,6 +448,7 @@ def ValidateBitCoinAddress(strAddr):
     # if one of the character is not valid, the next ones are not tested.
     return all((char in CHARS_OK for char in strAddr[1:]))
 
+
 #------------------------------------------------------------------------------
 
 
@@ -456,7 +463,7 @@ def RoundupString(data, stepsize):
     addon = ''
     if mod > 0:
         increase = stepsize - mod
-        addon = ' ' * increase
+        addon = ' '*increase
     return data + addon
 
 
@@ -464,24 +471,26 @@ def AddNL(s):
     """
     Just return a same string but with '\n' symbol at the end.
     """
-    return s + "\n"
+    return s + '\n'
 
 
 def Data():
     """
     An alias for Data packets.
     """
-    return "Data"
+    return 'Data'
 
 
 def Parity():
     """
     An alias for Parity packets.
     """
-    return "Parity"
+    return 'Parity'
+
 
 #------------------------------------------------------------------------------
 
+
 def pack_url_param(s):
     """
     A wrapper for built-in ``urllib.quote`` method.
@@ -510,8 +519,10 @@ def unpack_url_param(s, default=None):
         lg.exc()
         return default
 
+
 #------------------------------------------------------------------------------
 
+
 def rndstr(length):
     """
     This generates a random string of given ``length`` - with only digits and letters.
@@ -561,34 +572,28 @@ def calculate_best_dimension(sz, maxsize=8):
     :param sz: number of items to be organized
     :param maxsize: the maximum width of the matrix.
     """
-    cached = {2: (2, 1),
-              4: (4, 1),
-              7: (4, 2),
-              13: (5, 3),
-              18: (6, 3),
-              26: (7, 4),
-              64: (8, 8)}.get(sz, None)
+    cached = {2: (2, 1), 4: (4, 1), 7: (4, 2), 13: (5, 3), 18: (6, 3), 26: (7, 4), 64: (8, 8)}.get(sz, None)
     if cached:
         return cached
     try:
         w = math.sqrt(sz)
-        h = sz / w
+        h = sz/w
     except:
         lg.exc()
-    w = w * 1.4
-    h = h / 1.4
-    if int(w) * int(h) < sz and int(h) > 0:
+    w = w*1.4
+    h = h/1.4
+    if int(w)*int(h) < sz and int(h) > 0:
         w += 1.0
     if w > maxsize:
         w = float(maxsize)
-        h = sz / w
+        h = sz/w
     w = int(w)
     h = int(h)
     w = 1 if w == 0 else w
     h = 1 if h == 0 else h
-    if w * h < sz:
+    if w*h < sz:
         h += 1
-    if w * h - sz > h:
+    if w*h - sz > h:
         w -= 1
     return w, h
 
@@ -602,9 +607,9 @@ def calculate_padding(w, h):
     imgW = 64
     imgH = 64
     if w >= 4:
-        imgW = 4 * imgW / w
-        imgH = 4 * imgH / w
-    padding = 64 / w - 8
+        imgW = 4*imgW/w
+        imgH = 4*imgH/w
+    padding = 64/w - 8
     return imgW, imgH, padding
 
 
@@ -615,10 +620,10 @@ def getDeltaTime(tm):
     try:
         #        tm = time.mktime(time.strptime(self.backupID, "F%Y%m%d%I%M%S%p"))
         dt = round(time.time() - tm)
-        if dt > 2 * 60 * 60:
-            return round(dt / (60.0 * 60.0)), 'hours'
+        if dt > 2*60*60:
+            return round(dt/(60.0*60.0)), 'hours'
         if dt > 60:
-            return round(dt / 60.0), 'minutes'
+            return round(dt/60.0), 'minutes'
         return dt, 'seconds'
     except:
         return None, None
@@ -666,14 +671,14 @@ def percent2string(percent, precis=3):
     A tool to make a string (with % at the end) from given float, ``precis`` is
     precision to round the number.
     """
-    s = float2str(round(percent, precis), mask=("%%3.%df" % (precis + 2)))
+    s = float2str(round(percent, precis), mask=('%%3.%df' % (precis + 2)))
     return s + '%'
 
 
 def value2percent(value, total, precis=3):
     if not total:
         return '0%'
-    return percent2string(100.0 * (float(value) / float(total)), precis)
+    return percent2string(100.0*(float(value)/float(total)), precis)
 
 
 def float2str(float_value, mask='%6.8f', no_trailing_zeros=True):
@@ -702,7 +707,7 @@ def seconds_to_time_left_string(seconds):
     years = s // 31104000
     if years > 1:
         return '%d years' % years
-    s = s - (years * 31104000)
+    s = s - (years*31104000)
     months = s // 2592000
     if years == 1:
         r = 'one year'
@@ -711,7 +716,7 @@ def seconds_to_time_left_string(seconds):
         return r
     if months > 1:
         return '%d months' % months
-    s = s - (months * 2592000)
+    s = s - (months*2592000)
     days = s // 86400
     if months == 1:
         r = 'one month'
@@ -720,16 +725,16 @@ def seconds_to_time_left_string(seconds):
         return r
     if days > 1:
         return '%d days' % days
-    s = s - (days * 86400)
+    s = s - (days*86400)
     hours = s // 3600
     if days == 1:
         r = 'one day'
         if hours > 0:
             r += ' and %d hours' % hours
         return r
-    s = s - (hours * 3600)
+    s = s - (hours*3600)
     minutes = s // 60
-    seconds = s - (minutes * 60)
+    seconds = s - (minutes*60)
     if hours >= 6:
         return '%d hours' % hours
     if hours >= 1:
@@ -763,7 +768,9 @@ def unicode_to_str_safe(unicode_string, encodings=None):
         except:
             pass
     if encodings is None:
-        encodings = [locale.getpreferredencoding(), ]  # 'utf-8'
+        encodings = [
+            locale.getpreferredencoding(),
+        ]  # 'utf-8'
     output = ''
     for i in range(len(unicode_string)):
         unicode_char = unicode_string[i]
@@ -805,8 +812,10 @@ def isEnglishString(s):
     else:
         return True
 
+
 #------------------------------------------------------------------------------
 
+
 def getClipboardText():
     """
     A portable way to get a clipboard data - some sort of Ctrl-V.
@@ -881,6 +890,7 @@ def setClipboardText(txt):
         except:
             lg.exc()
 
+
 #------------------------------------------------------------------------------
 
 
@@ -914,6 +924,7 @@ def file_hash(path):
         return None
     return get_hash(src)
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -962,8 +973,10 @@ def str2gmtime(time_string, format):
     """
     return time.mktime(time.strptime(time_string, format))
 
+
 #------------------------------------------------------------------------------
 
+
 def ReadRepoLocation():
     """
     This method reutrn a tuple of two strings: "name of the current repo" and
@@ -987,6 +1000,7 @@ def ReadRepoLocation():
         return settings.DefaultRepo(), settings.DefaultRepoURL(settings.DefaultRepo())
     return l[0], l[1]
 
+
 #------------------------------------------------------------------------------
 
 
@@ -1003,19 +1017,25 @@ def DoRestart(param='', detach=False, std_out='/dev/null', std_err='/dev/null'):
             if not os.path.isfile(starter_filepath):
                 # lg.out(2, "misc.DoRestart ERROR %s not found" % starter_filepath)
                 main_filepath = os.path.join(bpio.getExecutableDir(), settings.WindowsMainScriptFileName())
-                cmdargs = [os.path.basename(main_filepath), ]
+                cmdargs = [
+                    os.path.basename(main_filepath),
+                ]
                 if param != '':
                     cmdargs.append(param)
                 # lg.out(2, "misc.DoRestart cmdargs="+str(cmdargs))
                 return os.spawnve(os.P_DETACH, main_filepath, cmdargs, os.environ)  # @UndefinedVariable
-            cmdargs = [os.path.basename(starter_filepath), ]
+            cmdargs = [
+                os.path.basename(starter_filepath),
+            ]
             if param != '':
                 cmdargs.append(param)
             # lg.out(2, "misc.DoRestart cmdargs="+str(cmdargs))
             return os.spawnve(os.P_DETACH, starter_filepath, cmdargs, os.environ)  # @UndefinedVariable
 
         pypath = sys.executable
-        cmdargs = [sys.executable, ]
+        cmdargs = [
+            sys.executable,
+        ]
         cmdargs.append(sys.argv[0])
         cmdargs += sys.argv[1:]
         if param != '' and not sys.argv.count(param):
@@ -1027,13 +1047,15 @@ def DoRestart(param='', detach=False, std_out='/dev/null', std_err='/dev/null'):
         if cmdargs.count('daemon'):
             cmdargs.remove('daemon')
         if detach:
-            from system import child_process
+            from bitdust.system import child_process
             cmdargs = [strng.to_text(a) for a in cmdargs]
             return child_process.detach(cmdargs)
         return os.execvpe(pypath, cmdargs, os.environ)
 
     pypyth = sys.executable
-    cmdargs = [sys.executable, ]
+    cmdargs = [
+        sys.executable,
+    ]
     if sys.argv[0] == '/usr/share/bitdust/bitdust.py':
         cmdargs.append('/usr/bin/bitdust')
     else:
@@ -1056,10 +1078,16 @@ def DoRestart(param='', detach=False, std_out='/dev/null', std_err='/dev/null'):
         cmd = '/usr/bin/nohup ' + (' '.join(cmdargs)) + ' &'
         BITDUST_COVERAGE_PROCESS_START = os.environ.get('COVERAGE_PROCESS_START')
         if BITDUST_COVERAGE_PROCESS_START:
-            cmd = 'COVERAGE_PROCESS_START="%s" %s' % (BITDUST_COVERAGE_PROCESS_START, cmd, )
+            cmd = 'COVERAGE_PROCESS_START="%s" %s' % (
+                BITDUST_COVERAGE_PROCESS_START,
+                cmd,
+            )
         BITDUST_LOG_USE_COLORS = os.environ.get('BITDUST_LOG_USE_COLORS')
         if BITDUST_LOG_USE_COLORS:
-            cmd = 'BITDUST_LOG_USE_COLORS="%s" %s' % (BITDUST_LOG_USE_COLORS, cmd, )
+            cmd = 'BITDUST_LOG_USE_COLORS="%s" %s' % (
+                BITDUST_LOG_USE_COLORS,
+                cmd,
+            )
         return os.system(cmd)
     return os.execvpe(pypyth, cmdargs, os.environ)
 
@@ -1080,7 +1108,7 @@ def ExplorePathInOS(filepath):
             subprocess.Popen(['`which xdg-open`', filepath])
 
         elif bpio.Mac():
-            subprocess.Popen(["open", "-R", filepath])
+            subprocess.Popen(['open', '-R', filepath])
 
     except:
         try:
@@ -1090,8 +1118,10 @@ def ExplorePathInOS(filepath):
             lg.exc()
     return
 
+
 #------------------------------------------------------------------------------
 
+
 def LoopAttenuation(current_delay, go_faster, min_delay, max_delay):
     """
     Pretty common method. Twisted reactor is very nice, you can call
@@ -1118,8 +1148,8 @@ def LoopAttenuation(current_delay, go_faster, min_delay, max_delay):
             current_delay = max_delay
     return current_delay
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     lg.set_debug_level(10)
