@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: nameurl.
 
@@ -48,7 +47,7 @@ from __future__ import print_function
 #------------------------------------------------------------------------------
 
 import six
-import six.moves.urllib.request, six.moves.urllib.parse, six.moves.urllib.error  # @UnresolvedImport
+import six.moves.urllib.parse  # @UnresolvedImport
 import six.moves.urllib.parse  # @UnresolvedImport
 from six.moves import range  # @UnresolvedImport
 
@@ -58,11 +57,11 @@ import re
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
-legalchars = "#.-_()ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
+legalchars = '#.-_()ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789'
 legalset = set(legalchars)
 
 #------------------------------------------------------------------------------
@@ -75,7 +74,12 @@ def UrlParse(url):
         nameurl.UrlParse('http://id.bitdust.io/veselin.xml')
         ('http', 'id.bitdust.io', '', 'veselin.xml')
     """
-    if not url or (isinstance(url, six.string_types) and url in ['None', b'None', '', b'', ]):
+    if not url or (isinstance(url, six.string_types) and url in [
+        'None',
+        b'None',
+        '',
+        b'',
+    ]):
         return '', '', '', ''
     url = strng.to_bin(url)
     o = six.moves.urllib.parse.urlparse(url)
@@ -143,11 +147,16 @@ def UrlFilename(url):
     'http###id.bitdust.io#veselin.xml'
     """
     # TODO: switch all that to global ID format
-    if not url or (isinstance(url, six.string_types) and url in ['None', b'None', '', b'', ]):
+    if not url or (isinstance(url, six.string_types) and url in [
+        'None',
+        b'None',
+        '',
+        b'',
+    ]):
         return None
     result = strng.to_text(url)
-    result = result.replace("://", "###")
-    result = result.replace("/", "#")
+    result = result.replace('://', '###')
+    result = result.replace('/', '#')
     result = re.sub('(\:)(\d+)', '(#\g<2>#)', result)
     result = result.lower()
     return result
@@ -184,8 +193,10 @@ def UrlFilenameHTML(url):
             o += x
     return o
 
+
 #------------------------------------------------------------------------------
 
+
 def IdContactSplit(contact):
     try:
         return strng.to_text(contact).split('://')
@@ -200,22 +211,32 @@ def GetName(url):
 
     nameurl.GetName('http://id.bitdust.io/kinggeorge.xml') 'kinggeorge'
     """
-    if not url or (isinstance(url, six.string_types) and url in ['None', b'None', '', b'', ]):
+    if not url or (isinstance(url, six.string_types) and url in [
+        'None',
+        b'None',
+        '',
+        b'',
+    ]):
         return ''
     url = strng.to_text(url)
     if not url.endswith('.xml'):
         return url
-    return url[url.rfind("/") + 1:-4]  # return url[url.rfind("/")+1:url.rfind(".")]
+    return url[url.rfind('/') + 1:-4]  # return url[url.rfind("/")+1:url.rfind(".")]
 
 
 def GetFileName(url):
     """
     Almost the same, but keeps the file extension.
     """
-    if not url or (isinstance(url, six.string_types) and url in ['None', b'None', '', b'', ]):
+    if not url or (isinstance(url, six.string_types) and url in [
+        'None',
+        b'None',
+        '',
+        b'',
+    ]):
         return ''
     url = strng.to_text(url)
-    return url[url.rfind("/") + 1:]
+    return url[url.rfind('/') + 1:]
 
 
 def GetHost(url):
@@ -224,8 +245,10 @@ def GetHost(url):
     """
     return UrlParse(url)[1]
 
+
 #------------------------------------------------------------------------------
 
+
 def Quote(s):
     """
     A wrapper for built-in method ``urllib.quote()``.
@@ -242,6 +265,7 @@ def UnQuote(s):
 
 #------------------------------------------------------------------------------
 
+
 def DjangoQuote(s):
     """
     Ensure that primary key values do not confuse the admin URLs by escaping
@@ -279,7 +303,8 @@ def DjangoUnQuote(s):
                 myappend('_' + item)
         else:
             myappend('_' + item)
-    return "".join(res)
+    return ''.join(res)
+
 
 #------------------------------------------------------------------------------
 
@@ -290,5 +315,6 @@ def main():
     """
     print(GetName(str(None)))
 
+
 if __name__ == '__main__':
     main()
