@@ -65,13 +65,14 @@ from twisted.web import iweb
 from twisted.web import client
 from twisted.web import http_headers
 from twisted.web.client import downloadPage, HTTPDownloader, Agent, _ReadBodyProtocol
+
 from twisted.web.http_headers import Headers
 
 from zope.interface import implementer
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
@@ -80,14 +81,8 @@ _ConnectionFailedCallbackFunc = None
 
 #------------------------------------------------------------------------------
 
-_UserAgentString = "BitDust-http-agent"
-_ProxySettings = {
-    'host': '',
-    'port': '',
-    'ssl': 'False',
-    'username': '',
-    'password': ''
-}
+_UserAgentString = 'BitDust-http-agent'
+_ProxySettings = {'host': '', 'port': '', 'ssl': 'False', 'username': '', 'password': ''}
 
 #------------------------------------------------------------------------------
 
@@ -99,8 +94,10 @@ def init():
 def shutdown():
     pass
 
+
 #------------------------------------------------------------------------------
 
+
 def SetConnectionDoneCallbackFunc(f):
     """
     Here is a place to set a callback to catch events for ````successful````
@@ -144,8 +141,10 @@ def ConnectionFailed(param=None, proto=None, info=None):
         return None
     return param
 
+
 #------------------------------------------------------------------------------
 
+
 def normalize_address(host_port, default_port=80):
     """
     Input argument `host` can be string: "123.45.67.89:8080" or tuple: (b"123.45.67.89", 8080)
@@ -157,13 +156,25 @@ def normalize_address(host_port, default_port=80):
         host_port = host_port.decode('utf-8')
     if isinstance(host_port, six.string_types):
         host_port = host_port.split(':')
-        host_port = (host_port[0], int(host_port[1]), )
+        host_port = (
+            host_port[0],
+            int(host_port[1]),
+        )
     if not host_port[1]:
-        host_port = (host_port[0], default_port, )
+        host_port = (
+            host_port[0],
+            default_port,
+        )
     if isinstance(host_port[0], six.binary_type):
-        host_port = (host_port[0].decode('utf-8'), int(host_port[1]), )
+        host_port = (
+            host_port[0].decode('utf-8'),
+            int(host_port[1]),
+        )
     if isinstance(host_port[0], six.text_type):
-        host_port = (host_port[0].encode('utf-8'), int(host_port[1]), )
+        host_port = (
+            host_port[0].encode('utf-8'),
+            int(host_port[1]),
+        )
     return host_port
 
 
@@ -189,8 +200,10 @@ def pack_address_text(host_port, proto=None, default_port=80):
         return None
     return strng.to_text(pack_address(host_port, proto=proto, default_port=default_port))
 
+
 #------------------------------------------------------------------------------
 
+
 def parse_url(url, defaultPort=None):
     """
     Split the given URL into the scheme, host, port, and path.
@@ -230,6 +243,7 @@ def parse_credentials(host):
     username, password = credentials.split(':', 1)
     return host, username, password
 
+
 #------------------------------------------------------------------------------
 
 
@@ -238,12 +252,7 @@ def detect_proxy_settings():
     Do some work and return dictionary with Proxy server settings for that
     machine.
     """
-    d = {
-        'host': '',
-        'port': '',
-        'username': '',
-        'password': '',
-        'ssl': 'False'}
+    d = {'host': '', 'port': '', 'username': '', 'password': '', 'ssl': 'False'}
     return d
 
     # TODO: to be fixed later
@@ -342,6 +351,7 @@ def proxy_is_on():
     """
     return get_proxy_host() != ''
 
+
 #------------------------------------------------------------------------------
 
 
@@ -352,6 +362,7 @@ def downloadPageTwisted(url, filename):
     global _UserAgentString
     return downloadPage(url, filename, agent=_UserAgentString)
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -363,7 +374,6 @@ class HTTPProgressDownloader(HTTPDownloader):
     ugins/mediadownloader/src/HTTPProgressDownloader.py?rev=1.1;cvsroot=
     enigma2-plugins;only_with_tag=HEAD
     """
-
     def __init__(self, url, fileOrName, writeProgress=None, *args, **kwargs):
         HTTPDownloader.__init__(self, url, fileOrName, supportPartial=0, *args, **kwargs)
         # Save callback(s) locally
@@ -412,6 +422,7 @@ def downloadWithProgressTwisted(url, file, progress_func):
         reactor.connectTCP(host, port, factory)  # @UndefinedVariable
     return factory.deferred
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -444,7 +455,6 @@ def downloadSSL(url, fileOrName, progress_func, certificates_filenames):
     from OpenSSL import SSL  # @UnresolvedImport
 
     class MyClientContextFactory(ssl.ClientContextFactory):
-
         def __init__(self, certificates_filenames):
             self.certificates_filenames = list(certificates_filenames)
 
@@ -463,7 +473,9 @@ def downloadSSL(url, fileOrName, progress_func, certificates_filenames):
 
     scheme, host, port, path = parse_url(url)
     if not isinstance(certificates_filenames, list):
-        certificates_filenames = [certificates_filenames, ]
+        certificates_filenames = [
+            certificates_filenames,
+        ]
     cert_found = False
     for cert in certificates_filenames:
         if os.path.isfile(cert) and os.access(cert, os.R_OK):
@@ -477,18 +489,24 @@ def downloadSSL(url, fileOrName, progress_func, certificates_filenames):
     reactor.connectSSL(host, port, factory, contextFactory)  # @UndefinedVariable
     return factory.deferred
 
+
 #------------------------------------------------------------------------------
 
-
 # class ProxyClientFactory(client.HTTPClientFactory):
-# 
+#
 #     def setURL(self, url):
 #         client.HTTPClientFactory.setURL(self, url)
 #         self.path = url
 
 
-def readBody(response):
+class custom_ReadBodyProtocol(_ReadBodyProtocol):
+    def connectionLost(self, reason):
+        if self.deferred.called:
+            return
+        super(custom_ReadBodyProtocol, self).connectionLost(reason)
 
+
+def readBody(response):
     def cancel(deferred):
         abort = getAbort()
         if abort is not None:
@@ -496,7 +514,7 @@ def readBody(response):
 
     d = Deferred(cancel)
     d.addErrback(twisted_log.err)
-    protocol = _ReadBodyProtocol(response.code, response.phrase, d)
+    protocol = custom_ReadBodyProtocol(response.code, response.phrase, d)
 
     def getAbort():
         return getattr(protocol.transport, 'abortConnection', None)
@@ -512,63 +530,66 @@ def readBodyFailed(result):
 
 
 def readResponse(response, timeout):
-#     print('Response version:', response.version)
-#     print('Response code:', response.code)
-#     print('Response phrase:', response.phrase)
-#     print('Response headers:')
-#     print(list(response.headers.getAllRawHeaders()))
+    #     print('Response version:', response.version)
+    #     print('Response code:', response.code)
+    #     print('Response phrase:', response.phrase)
+    #     print('Response headers:')
+    #     print(list(response.headers.getAllRawHeaders()))
     if response.code != 200:
         return fail(Exception('Bad response from the server: [%d] %s' % (
-            response.code, response.phrase.strip(),)))
+            response.code,
+            response.phrase.strip(),
+        ), ))
     d = readBody(response)
     d.addTimeout(timeout=timeout, clock=reactor)
     d.addErrback(readBodyFailed)
     return d
 
 
-def getPageTwisted(url, timeout=10, method=b'GET'):
+def getPageTwisted(url, timeout=15, method=b'GET'):
     """
     A smart way to download pages from HTTP hosts.
     """
-#     def getPageTwistedTimeout(_d):
-#         _d.cancel()
-#     def getPageTwistedTimeoutDisconnect(_tcpcall):
-#         _tcpcall.disconnect()
-#     def getPageTwistedCancelTimeout(x, _t):
-#         if _t.active():
-#             _t.cancel()
-#         return x
+    #     def getPageTwistedTimeout(_d):
+    #         _d.cancel()
+    #     def getPageTwistedTimeoutDisconnect(_tcpcall):
+    #         _tcpcall.disconnect()
+    #     def getPageTwistedCancelTimeout(x, _t):
+    #         if _t.active():
+    #             _t.cancel()
+    #         return x
     global _UserAgentString
 
     url = strng.to_bin(url)
 
-#     if proxy_is_on():
-#         factory = ProxyClientFactory(url, agent=_UserAgentString, timeout=timeout)
-#         tcp_call = reactor.connectTCP(get_proxy_host(), get_proxy_port(), factory)
-# #         if timeout:
-# #             timeout_call = reactor.callLater(timeout, getPageTwistedTimeoutDisconnect, tcp_call)
-# #             factory.deferred.addBoth(getPageTwistedCancelTimeout, timeout_call)
-#         factory.deferred.addCallback(ConnectionDone, 'http', 'getPageTwisted proxy %s' % (url))
-#         factory.deferred.addErrback(ConnectionFailed, 'http', 'getPageTwisted proxy %s' % (url))
-#         return factory.deferred
+    #     if proxy_is_on():
+    #         factory = ProxyClientFactory(url, agent=_UserAgentString, timeout=timeout)
+    #         tcp_call = reactor.connectTCP(get_proxy_host(), get_proxy_port(), factory)
+    # #         if timeout:
+    # #             timeout_call = reactor.callLater(timeout, getPageTwistedTimeoutDisconnect, tcp_call)
+    # #             factory.deferred.addBoth(getPageTwistedCancelTimeout, timeout_call)
+    #         factory.deferred.addCallback(ConnectionDone, 'http', 'getPageTwisted proxy %s' % (url))
+    #         factory.deferred.addErrback(ConnectionFailed, 'http', 'getPageTwisted proxy %s' % (url))
+    #         return factory.deferred
 
     agent = Agent(reactor, connectTimeout=timeout)
 
     d = agent.request(
         method=method,
         uri=url,
-        headers=Headers({b'User-Agent': [_UserAgentString, ]}),
+        headers=Headers({b'User-Agent': [_UserAgentString]}),
     )
-#     d = getPage(url, agent=_UserAgentString, timeout=timeout)
-#     if timeout:
-#         timeout_call = reactor.callLater(timeout, getPageTwistedTimeout, d)
-#         d.addBoth(getPageTwistedCancelTimeout, timeout_call)
+    #     d = getPage(url, agent=_UserAgentString, timeout=timeout)
+    #     if timeout:
+    #         timeout_call = reactor.callLater(timeout, getPageTwistedTimeout, d)
+    #         d.addBoth(getPageTwistedCancelTimeout, timeout_call)
     d.addCallback(readResponse, timeout)
     # d.addTimeout(timeout=timeout, clock=reactor)
     d.addCallback(ConnectionDone, 'http', 'getPageTwisted %r' % url)
     d.addErrback(ConnectionFailed, 'http', 'getPageTwisted %r' % url)
     return d
 
+
 #------------------------------------------------------------------------------
 
 
@@ -586,6 +607,7 @@ def downloadHTTP(url, fileOrName):
     reactor.connectTCP(host, port, factory)  # @UndefinedVariable
     return factory.deferred
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -613,6 +635,7 @@ def IpIsLocal(ip):
             return True
     return False
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -631,7 +654,7 @@ def getLocalIp():
 
     try:
         ipaddr = socket.gethostbyname(socket.gethostname())
-        if not(ipaddr.startswith('127')):
+        if not (ipaddr.startswith('127')):
             #print('Can use Method 1: ' + ipaddr)
             return ipaddr
     except:
@@ -688,6 +711,7 @@ def getLocalIp():
 
     return '127.0.0.1'  # uh oh, we're in trouble, but don't want to return none
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -696,7 +720,7 @@ def TestInternetConnectionOld(remote_host='www.google.com'):  # 74.125.113.99
     Ancient method to check Internet connection.
     """
     try:
-        (family, socktype, proto, garbage, address) = socket.getaddrinfo(remote_host, "http")[0]
+        (family, socktype, proto, garbage, address) = socket.getaddrinfo(remote_host, 'http')[0]
     except Exception as e:
         return False
 
@@ -709,10 +733,11 @@ def TestInternetConnectionOld(remote_host='www.google.com'):  # 74.125.113.99
 
     return result is None or result == 0
 
+
 #------------------------------------------------------------------------------
 
 
-def TestInternetConnectionOld2(remote_hosts=None, timeout=10):
+def TestInternetConnectionOld2(remote_hosts=None, timeout=15):
     """
     A little bit more smart method to check Internet connection.
     """
@@ -741,27 +766,34 @@ def TestInternetConnectionOld2(remote_hosts=None, timeout=10):
         d = getPageTwisted(hosts[index])
         d.addCallback(_response, result)
         d.addErrback(_fail, hosts, index, result)
+
     result = Deferred()
     reactor.callLater(0, _call, remote_hosts, 0, result)  # @UndefinedVariable
     return result
 
+
 #------------------------------------------------------------------------------
 
 
-def TestInternetConnection(remote_hosts=None, timeout=10):
+def TestInternetConnection(remote_hosts=None, timeout=15):
     if remote_hosts is None:
         remote_hosts = []
-        from userid import known_servers
+        from bitdust.userid import known_servers
         for host, ports in known_servers.by_host().items():
-            remote_hosts.append('http://%s:%d' % (host, ports[0], ))
+            remote_hosts.append('http://%s:%d' % (
+                host,
+                ports[0],
+            ))
     random.shuffle(remote_hosts)
     dl = []
     for host in remote_hosts[:5]:
         dl.append(getPageTwisted(host, timeout=timeout))
     return DeferredList(dl, fireOnOneCallback=True, fireOnOneErrback=False, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
+
 def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
     """
     A smart way to upload a file over HTTP POST method.
@@ -771,9 +803,8 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
 
     http://marianoiglesias.com.ar/python/file-uploading-with-multi-part-encoding-using-twisted/
     """
-
     class StringReceiver(protocol.Protocol):
-        buffer = ""
+        buffer = ''
 
         def __init__(self, deferred=None):
             self._deferred = deferred
@@ -787,11 +818,10 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
             else:
                 self._deferred.errback(Exception(self.buffer))
 
-
     @implementer(iweb.IBodyProducer)
     class MultiPartProducer:
 
-        CHUNK_SIZE = 2 ** 8
+        CHUNK_SIZE = 2**8
 
         def __init__(self, files={}, data={}, callback=None, deferred=None):
             self._files = files
@@ -807,14 +837,14 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
             self._current_deferred = Deferred()
             self._sent = 0
             self._paused = False
-            if not hasattr(self, "_chunk_headers"):
+            if not hasattr(self, '_chunk_headers'):
                 self._build_chunk_headers()
             if self._data:
-                block = ""
+                block = ''
                 for field in self._data:
                     block += self._chunk_headers[field]
                     block += self._data[field]
-                    block += "\r\n"
+                    block += '\r\n'
                 self._send_to_consumer(block)
             if self._files:
                 self._files_iterator = six.iterkeys(self._files)
@@ -843,7 +873,7 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
         def stopProducing(self):
             self._finish(True)
             if self._deferred and self._sent < self.length:
-                self._deferred.errback(Exception("Consumer asked to stop production of request body (%d sent out of %d)" % (self._sent, self.length)))
+                self._deferred.errback(Exception('Consumer asked to stop production of request body (%d sent out of %d)' % (self._sent, self.length)))
 
         def _produce(self):
             if self._paused:
@@ -855,14 +885,14 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
                     self._current_file_path = self._files[field]
                     self._current_file_sent = 0
                     self._current_file_length = self._file_lengths[field]
-                    self._current_file_handle = open(self._current_file_path, "rb")
+                    self._current_file_handle = open(self._current_file_path, 'rb')
                     self._send_to_consumer(self._chunk_headers[field])
                 chunk = self._current_file_handle.read(self.CHUNK_SIZE)
                 if chunk:
                     self._send_to_consumer(chunk)
                     self._current_file_sent += len(chunk)
                 if not chunk or self._current_file_sent == self._current_file_length:
-                    self._send_to_consumer("\r\n")
+                    self._send_to_consumer('\r\n')
                     self._current_file_handle.close()
                     self._current_file_handle = None
                     self._current_file_sent = 0
@@ -871,12 +901,12 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
                 if self._files_sent == self._files_length:
                     done = True
             if done:
-                self._send_to_consumer("--%s--\r\n" % self.boundary)
+                self._send_to_consumer('--%s--\r\n' % self.boundary)
                 self._finish()
                 return succeed(None)
 
         def _finish(self, forced=False):
-            if hasattr(self, "_current_file_handle") and self._current_file_handle:
+            if hasattr(self, '_current_file_handle') and self._current_file_handle:
                 self._current_file_handle.close()
             if self._current_deferred:
                 self._current_deferred.callback(self._sent)
@@ -908,7 +938,7 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
             return length
 
         def _build_chunk_headers(self):
-            if hasattr(self, "_chunk_headers") and self._chunk_headers:
+            if hasattr(self, '_chunk_headers') and self._chunk_headers:
                 return
             self._chunk_headers = {}
             for field in self._files:
@@ -918,25 +948,25 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
 
         def _headers(self, name, is_file=False):
             value = self._files[name] if is_file else self._data[name]
-            _boundary = self.boundary.encode("utf-8") if isinstance(self.boundary, six.text_type) else six.moves.urllib.parse.quote_plus(self.boundary)
-            headers = ["--%s" % _boundary]
+            _boundary = self.boundary.encode('utf-8') if isinstance(self.boundary, six.text_type) else six.moves.urllib.parse.quote_plus(self.boundary)
+            headers = ['--%s' % _boundary]
             if is_file:
                 disposition = 'form-data; name="%s"; filename="%s"' % (name, os.path.basename(value))
             else:
                 disposition = 'form-data; name="%s"' % name
-            headers.append("Content-Disposition: %s" % disposition)
+            headers.append('Content-Disposition: %s' % disposition)
             if is_file:
                 file_type = self._file_type(name)
             else:
-                file_type = "text/plain; charset=utf-8"
-            headers.append("Content-Type: %s" % file_type)
+                file_type = 'text/plain; charset=utf-8'
+            headers.append('Content-Type: %s' % file_type)
             if is_file:
-                headers.append("Content-Length: %i" % self._file_size(name))
+                headers.append('Content-Length: %i' % self._file_size(name))
             else:
-                headers.append("Content-Length: %i" % len(value))
-            headers.append("")
-            headers.append("")
-            return "\r\n".join(headers)
+                headers.append('Content-Length: %i' % len(value))
+            headers.append('')
+            headers.append('')
+            return '\r\n'.join(headers)
 
         def _boundary(self):
             boundary = None
@@ -952,12 +982,12 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
 
         def _file_type(self, field):
             typ = mimetypes.guess_type(self._files[field])[0]
-            return typ.encode("utf-8") if isinstance(typ, six.text_type) else str(typ)
+            return typ.encode('utf-8') if isinstance(typ, six.text_type) else str(typ)
 
         def _file_size(self, field):
             size = 0
             try:
-                handle = open(self._files[field], "r")
+                handle = open(self._files[field], 'r')
                 size = os.fstat(handle.fileno()).st_size
                 handle.close()
             except:
@@ -972,15 +1002,17 @@ def uploadHTTP(url, files, data, progress=None, receiverDeferred=None):
     myReceiver = StringReceiver(receiverDeferred)
 
     headers = http_headers.Headers()
-    headers.addRawHeader("Content-Type", "multipart/form-data; boundary=%s" % myProducer.boundary)
+    headers.addRawHeader('Content-Type', 'multipart/form-data; boundary=%s' % myProducer.boundary)
 
     agent = client.Agent(reactor)
-    request = agent.request(b"POST", url, headers, myProducer)
+    request = agent.request(b'POST', url, headers, myProducer)
     request.addCallback(lambda response: response.deliverBody(myReceiver))
     return request
 
+
 #------------------------------------------------------------------------------
 
+
 @implementer(iweb.IBodyProducer)
 class BytesProducer(object):
     def __init__(self, body):
@@ -1001,18 +1033,23 @@ class BytesProducer(object):
 def http_post_data(url, data, connectTimeout=15):
     agent = Agent(reactor, connectTimeout=connectTimeout)
     body = BytesProducer(data)
-    requested = agent.request(b"POST", url, Headers({"User-Agent": ["BitDust HTTP client", ], }), body)
+    requested = agent.request(
+        b'POST',
+        url,
+        Headers({
+            'User-Agent': ['BitDust HTTP client'],
+        }),
+        body,
+    )
     return requested
 
+
 #------------------------------------------------------------------------------
 
 
 def getIfconfig(iface='en0'):
     try:
-        result = subprocess.check_output(
-            'ifconfig %s | grep -w inet' % (iface),
-            shell=True, stderr=subprocess.STDOUT
-        )
+        result = subprocess.check_output('ifconfig %s | grep -w inet' % (iface), shell=True, stderr=subprocess.STDOUT)
     except:
         return None
     ip = ''
@@ -1061,7 +1098,7 @@ def getNetworkInterfaces():
 
     elif plat == 'Linux':
         try:
-            pipe = os.popen("`which ip` -f inet a")
+            pipe = os.popen('`which ip` -f inet a')
         except IOError:
             return []
         try:
@@ -1072,25 +1109,29 @@ def getNetworkInterfaces():
         ips = set()
         for line in lines:
             check = line.strip('\n').strip().split(' ')
-            if check[0] == "inet":
-                if check[2] == "brd":
+            if check[0] == 'inet':
+                if check[2] == 'brd':
                     check.pop(2)
                     check.pop(2)
-                ipaddress = check[1].split("/")[0]
+                ipaddress = check[1].split('/')[0]
                 ips.add(str(ipaddress))
         return list(ips)
 
     elif plat == 'Darwin':
         try:
             # TODO: try to avoid socket connect to remote host
-            return [_f for _f in [
-                l for l in (
-                    [ip for ip in socket.gethostbyname_ex(socket.gethostname())[2] if not ip.startswith("127.")][:1],
-                    # TODO: replace 8.8.8.8 with random seed node
-                    [[(s.connect(('8.8.8.8', 53)), s.getsockname()[0], s.close()) for s in [socket.socket(socket.AF_INET, socket.SOCK_DGRAM)]][0][1]],
-                ) if l
-            ][0] if _f]
+            return [
+                _f for _f in [
+                    l for l in (
+                        [ip for ip in socket.gethostbyname_ex(socket.gethostname())[2] if not ip.startswith('127.')][:1],
+                        # TODO: replace 8.8.8.8 with random seed node
+                        [[(s.connect(('8.8.8.8', 53)), s.getsockname()[0], s.close()) for s in [socket.socket(socket.AF_INET, socket.SOCK_DGRAM)]][0][1]],
+                    ) if l
+                ][0] if _f
+            ]
         except:
             eth0 = getIfconfig('eth0')
             en0 = getIfconfig('en0')
-            return [_f for _f in [en0 or eth0, ] if _f]
+            return [_f for _f in [
+                en0 or eth0,
+            ] if _f]
