@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -75,11 +74,14 @@ _TimeCountsDict = {}
 
 #------------------------------------------------------------------------------
 
+
 def fqn(o):
-    return o.__module__ + "." + o.__name__
+    return o.__module__ + '.' + o.__name__
+
 
 #------------------------------------------------------------------------------
 
+
 def out(_DebugLevel, msg, nl='\n', log_name='stdout', showtime=False):
     """
     Prints a text line to the log file or console.
@@ -113,15 +115,15 @@ def out(_DebugLevel, msg, nl='\n', log_name='stdout', showtime=False):
     if level % 2:
         level -= 1
     if level:
-        s = ' ' * level + s
+        s = ' '*level + s
     if _IsAndroid is None:
         _IsAndroid = (sys.executable == 'android_python' or ('ANDROID_ARGUMENT' in os.environ))
-    if ( _ShowTime and level > 0 ) or showtime:
+    if (_ShowTime and level > 0) or showtime:
         tm_string = time.strftime('%H:%M:%S')
         if _LifeBeginsTime != 0:
             dt = time.time() - _LifeBeginsTime
             mn = dt // 60
-            sc = dt - mn * 60
+            sc = dt - mn*60
             if _GlobalDebugLevel >= 6:
                 tm_string += '/%02d:%06.3f' % (mn, sc)
             else:
@@ -161,7 +163,7 @@ def out(_DebugLevel, msg, nl='\n', log_name='stdout', showtime=False):
         else:
             if _LogFileName:
                 if log_name not in _AllLogFiles:
-                    filename = os.path.join(os.path.dirname(_LogFileName), log_name + '.log') 
+                    filename = os.path.join(os.path.dirname(_LogFileName), log_name + '.log')
                     if not os.path.isdir(os.path.dirname(os.path.abspath(filename))):
                         os.makedirs(os.path.dirname(os.path.abspath(filename)))
                     _AllLogFiles[log_name] = open(os.path.abspath(filename), 'w')
@@ -219,7 +221,10 @@ def args(_DebugLevel, *args, **kwargs):
     for k in kwargs:
         funcargs.append('%s=%r' % (k, kwargs.get(k)))
     funcname = '%s.%s' % (modul, caller)
-    o = '%s(%s)' % (funcname, ', '.join(funcargs), )
+    o = '%s(%s)' % (
+        funcname,
+        ', '.join(funcargs),
+    )
     if message:
         o += ' ' + message
     out(level, o, showtime=True)
@@ -233,9 +238,17 @@ def info(message, level=2):
     cod = sys._getframe().f_back.f_code
     modul = os.path.basename(cod.co_filename).replace('.py', '')
     caller = cod.co_name
-    output_string = 'INFO %s in %s.%s()' % (message, modul, caller, )
+    output_string = 'INFO %s in %s.%s()' % (
+        message,
+        modul,
+        caller,
+    )
     if _UseColors:
-        output_string = '\033[0;49;92mINFO %s \033[0m\033[0;49;37min %s.%s()\033[0m' % (message, modul, caller, )
+        output_string = '\033[0;49;92mINFO %s \033[0m\033[0;49;37min %s.%s()\033[0m' % (
+            message,
+            modul,
+            caller,
+        )
     out(level, output_string, showtime=True)
     # out(level, output_string, log_name='info', showtime=True)
     return message
@@ -248,9 +261,17 @@ def warn(message, level=2):
     cod = sys._getframe().f_back.f_code
     modul = os.path.basename(cod.co_filename).replace('.py', '')
     caller = cod.co_name
-    output_string = 'WARNING %s in %s.%s()' % (message, modul, caller, )
+    output_string = 'WARNING %s in %s.%s()' % (
+        message,
+        modul,
+        caller,
+    )
     if _UseColors:
-        output_string = '\033[0;35mWARNING %s \033[0m\033[0;49;37min %s.%s()\033[0m' % (message, modul, caller, )
+        output_string = '\033[0;35mWARNING %s \033[0m\033[0;49;37min %s.%s()\033[0m' % (
+            message,
+            modul,
+            caller,
+        )
     out(level, output_string, showtime=True)
     # out(level, output_string, log_name='warn', showtime=True)
     return message
@@ -272,7 +293,7 @@ def err(message, level=0):
         message = ' %s in %s()' % (message, funcname)
     if not message.count('ERROR'):
         message = 'ERROR ' + message
-    message = '%s%s   ' % ((' ' * (level + 11)), message)
+    message = '%s%s   ' % ((' '*(level + 11)), message)
     if _UseColors:
         message = '\033[1;37;41m%s\033[0m' % message
     out(level, message, showtime=True)
@@ -294,7 +315,11 @@ def cb(result, *args, **kwargs):
     _debug_level = kwargs.pop('debug_level', 0)
     _method = kwargs.pop('method', 'unknown')
     if _debug and is_debug(_debug_level):
-        dbg(_debug_level, 'Deferred.callback() from "%s" method : args=%r  kwargs=%r' % (_method, args, kwargs, ))
+        dbg(_debug_level, 'Deferred.callback() from "%s" method : args=%r  kwargs=%r' % (
+            _method,
+            args,
+            kwargs,
+        ))
     return result
 
 
@@ -305,7 +330,11 @@ def errback(err, *args, **kwargs):
     _ignore = kwargs.pop('ignore', False)
     if _debug and is_debug(_debug_level):
         dbg(_debug_level, 'Deferred.errback() from "%s" method with %r : args=%r  kwargs=%r' % (
-            repr(err).replace('\n', ''), _method, args, kwargs, ))
+            _method,
+            repr(err).replace('\n', ''),
+            args,
+            kwargs,
+        ))
     if _ignore:
         return None
     return err
@@ -332,7 +361,7 @@ def exception(level, maxTBlevel, exc_info, message=None):
     excArgs = ''
     if value:
         try:
-            excArgs = value.__dict__["args"]
+            excArgs = value.__dict__['args']
         except KeyError:
             excArgs = ''
     if trbk:
@@ -370,7 +399,7 @@ def exception(level, maxTBlevel, exc_info, message=None):
     if _StoreExceptionsEnabled and _LogFileName:
         if message:
             s = message + '\n' + s
-        s = '\n%s\n' % datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f") + s
+        s = '\n%s\n' % datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S.%f') + s
         exc_label = exc_name.lower().replace(' ', '_').replace('-', '_')[:80]
         exc_label = ''.join([c for c in exc_label if c in '0123456789abcdefghijklmnopqrstuvwxyz_'])
         exc_filename = os.path.join(os.path.dirname(_LogFileName), 'exception_' + exc_label + '.log')
@@ -400,7 +429,7 @@ def format_exception(maxTBlevel=100, exc_info=None):
     else:
         exc_type, value, trbk = exc_info
     try:
-        excArgs = value.__dict__["args"]
+        excArgs = value.__dict__['args']
     except KeyError:
         excArgs = ''
     excTb = traceback.format_tb(trbk, maxTBlevel)
@@ -526,7 +555,7 @@ def out_globals(level, glob_dict):
     keys = sorted(glob_dict.keys())
     for k in keys:
         if k != '__builtins__':
-            out(level, "%s : %s" % (k, glob_dict[k]))
+            out(level, '%s : %s' % (k, glob_dict[k]))
 
 
 def time_push(t):
@@ -570,7 +599,7 @@ def print_total_time():
     for t in _TimeTotalDict.keys():
         total = _TimeTotalDict[t]
         counts = _TimeCountsDict[t]
-        out(2, 'total=%f sec. count=%d, avarage=%f: %s' % (total, counts, total / counts, t))
+        out(2, 'total=%f sec. count=%d, avarage=%f: %s' % (total, counts, total/counts, t))
 
 
 def exception_hook(typ, value, traceback):
@@ -792,22 +821,27 @@ def set_weblog_func(webstreamfunc):
     global _WebStreamFunc
     _WebStreamFunc = webstreamfunc
 
+
 #------------------------------------------------------------------------------
 
+
 class STDOUT_redirected(object):
     """
     Emulate system STDOUT, useful to log any program output.
     """
     softspace = 0
 
-    def read(self): pass
+    def read(self):
+        pass
 
     def write(self, s):
         out(0, s.rstrip())
 
-    def flush(self): pass
+    def flush(self):
+        pass
 
-    def close(self): pass
+    def close(self):
+        pass
 
 
 class STDERR_redirected(object):
@@ -816,14 +850,17 @@ class STDERR_redirected(object):
     """
     softspace = 0
 
-    def read(self): pass
+    def read(self):
+        pass
 
     def write(self, s):
         err(s.rstrip(), level=0)
 
-    def flush(self): pass
+    def flush(self):
+        pass
 
-    def close(self): pass
+    def close(self):
+        pass
 
 
 class STDOUT_black_hole(object):
@@ -832,13 +869,17 @@ class STDOUT_black_hole(object):
     """
     softspace = 0
 
-    def read(self): pass
+    def read(self):
+        pass
 
-    def write(self, s): pass
+    def write(self, s):
+        pass
 
-    def flush(self): pass
+    def flush(self):
+        pass
 
-    def close(self): pass
+    def close(self):
+        pass
 
 
 class STDERR_black_hole(object):
@@ -847,17 +888,20 @@ class STDERR_black_hole(object):
     """
     softspace = 0
 
-    def read(self): pass
+    def read(self):
+        pass
 
-    def write(self, s): pass
+    def write(self, s):
+        pass
 
-    def flush(self): pass
+    def flush(self):
+        pass
 
-    def close(self): pass
+    def close(self):
+        pass
 
 
 class STDOUT_unbuffered(object):
-
     def __init__(self, stream):
         self.stream = stream
 
@@ -880,7 +924,6 @@ class STDOUT_unbuffered(object):
 
 
 class STDERR_unbuffered(object):
-
     def __init__(self, stream):
         self.stream = stream
 
