@@ -25,7 +25,6 @@
 #
 #
 #
-
 """
 .. module:: bpmain.
 
@@ -53,6 +52,7 @@ AppDataDir = ''
 
 #-------------------------------------------------------------------------------
 
+
 def print_text(msg, nl='\n'):
     """
     Send some text output to the console.
@@ -60,13 +60,15 @@ def print_text(msg, nl='\n'):
     sys.stdout.write(msg + nl)
     sys.stdout.flush()
 
+
 #-------------------------------------------------------------------------------
 
+
 def show():
     """
     Just calls ``p2p.web.control.show()`` to open the GUI.
     """
-    # from main import control
+    # from bitdust.main import control
     # TODO: raise up electron window?
     return 0
 
@@ -82,49 +84,49 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
     """
     global AppDataDir
 
-    from logs import lg
+    from bitdust.logs import lg
     if _Debug:
         lg.out(_DebugLevel, 'bpmain.init UI="%s"' % UI)
 
-    from system import bpio
+    from bitdust.system import bpio
     if _Debug:
         lg.out(_DebugLevel, 'bpmain.init ostype=%r' % bpio.ostype())
 
     #---settings---
-    from main import settings
+    from bitdust.main import settings
     if overDict:
         settings.override_dict(overDict)
     settings.init(AppDataDir)
     if not options or options.debug is None:
         lg.set_debug_level(settings.getDebugLevel())
-    from main import config
-    config.conf().addConfigNotifier('logs/debug-level',
-                                    lambda p, value, o, r: lg.set_debug_level(value))
+    from bitdust.main import config
+    config.conf().addConfigNotifier('logs/debug-level', lambda p, value, o, r: lg.set_debug_level(value))
 
     #---USE_TRAY_ICON---
-    if os.path.isfile(settings.LocalIdentityFilename()) and os.path.isfile(settings.KeyFileName()):
-        try:
-            from system.tray_icon import USE_TRAY_ICON
-            if bpio.Mac() or not bpio.isGUIpossible():
-                if _Debug:
-                    lg.out(_DebugLevel, '    GUI is not possible')
-                USE_TRAY_ICON = False
-            if USE_TRAY_ICON:
-                from twisted.internet import wxreactor
-                wxreactor.install()
-                if _Debug:
-                    lg.out(_DebugLevel, '    wxreactor installed')
-        except:
-            USE_TRAY_ICON = False
-            lg.exc()
-    else:
-        if _Debug:
-            lg.out(_DebugLevel, '    local identity or key file is not ready')
-        USE_TRAY_ICON = False
+    #     if os.path.isfile(settings.LocalIdentityFilename()) and os.path.isfile(settings.KeyFileName()):
+    #         try:
+    #             from bitdust.system.tray_icon import USE_TRAY_ICON
+    #             if bpio.Mac() or not bpio.isGUIpossible():
+    #                 if _Debug:
+    #                     lg.out(_DebugLevel, '    GUI is not possible')
+    #                 USE_TRAY_ICON = False
+    #             if USE_TRAY_ICON:
+    #                 from twisted.internet import wxreactor
+    #                 wxreactor.install()
+    #                 if _Debug:
+    #                     lg.out(_DebugLevel, '    wxreactor installed')
+    #         except:
+    #             USE_TRAY_ICON = False
+    #             lg.exc()
+    #     else:
+    #         if _Debug:
+    #             lg.out(_DebugLevel, '    local identity or key file is not ready')
+    #         USE_TRAY_ICON = False#         USE_TRAY_ICON = False
+    USE_TRAY_ICON = False
     if _Debug:
         lg.out(_DebugLevel, '    USE_TRAY_ICON=' + str(USE_TRAY_ICON))
     if USE_TRAY_ICON:
-        from system import tray_icon
+        from bitdust.system import tray_icon
         icons_path = bpio.portablePath(os.path.join(bpio.getExecutableDir(), 'icons'))
         if _Debug:
             lg.out(_DebugLevel, 'bpmain.init call tray_icon.init(%s)' % icons_path)
@@ -132,15 +134,16 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
 
         def _tray_control_func(cmd):
             if cmd == 'exit':
-                from main import shutdowner
+                from bitdust.main import shutdowner
                 shutdowner.A('stop', 'exit')
+
         tray_icon.SetControlFunc(_tray_control_func)
 
     #---OS Windows init---
     if bpio.Windows():
         try:
             from win32event import CreateMutex  # @UnresolvedImport
-            mutex = CreateMutex(None, False, "BitDust")
+            mutex = CreateMutex(None, False, 'BitDust')
             if _Debug:
                 lg.out(_DebugLevel, 'bpmain.init created a Mutex: %s' % str(mutex))
         except:
@@ -167,10 +170,10 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
 #         if bpio.Windows() and bpio.isFrozen():
 #             lg.stdout_start_redirecting()
 
-    #---memdebug---
+#---memdebug---
     if config.conf().getBool('logs/memdebug-enabled'):
         try:
-            from logs import memdebug
+            from bitdust.logs import memdebug
             memdebug_port = int(config.conf().getData('logs/memdebug-port'))
             memdebug.start(memdebug_port)
             reactor.addSystemEventTrigger('before', 'shutdown', memdebug.stop)  # @UndefinedVariable
@@ -195,16 +198,16 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
     #     monitorDelayedCalls(reactor)
 
     if _Debug:
-        lg.out(_DebugLevel, "    python executable is: %s" % sys.executable)
-        lg.out(_DebugLevel, "    python version is:\n%s" % sys.version)
-        lg.out(_DebugLevel, "    python sys.path is:\n                %s" % ('\n                '.join(sys.path)))
+        lg.out(_DebugLevel, '    python executable is: %s' % sys.executable)
+        lg.out(_DebugLevel, '    python version is:\n%s' % sys.version)
+        lg.out(_DebugLevel, '    python sys.path is:\n                %s' % ('\n                '.join(sys.path)))
         lg.out(_DebugLevel, '\n' + bpio.osinfofull())
 
     if _Debug:
         lg.out(_DebugLevel, 'bpmain.init going to initialize state machines')
 
     #---START!---
-    from automats import automat
+    from bitdust.automats import automat
     automat.LifeBegins(lg.when_life_begins())
     automat.SetGlobalLogEvents(config.conf().getBool('logs/automat-events-enabled'))
     automat.SetGlobalLogTransitions(config.conf().getBool('logs/automat-transitions-enabled'))
@@ -212,13 +215,13 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
     automat.SetLogOutputHandler(lambda debug_level, message: lg.out(debug_level, message, log_name='state'))
     # automat.OpenLogFile(settings.AutomatsLog())
 
-    from main import events
+    from bitdust.main import events
     events.init()
 
-    from main import listeners
+    from bitdust.main import listeners
     listeners.init()
 
-    from main import initializer
+    from bitdust.main import initializer
     IA = initializer.A()
     if _Debug:
         lg.out(_DebugLevel, 'bpmain.init is sending event "run" to initializer()')
@@ -228,29 +231,30 @@ def init(UI='', options=None, args=None, overDict=None, executablePath=None):
         reactor.callWhenRunning(IA.automat, 'run', UI)  # @UndefinedVariable
     return IA
 
+
 #------------------------------------------------------------------------------
 
 
 def shutdown():
-    from logs import lg
-    from main import config
-    from system import bpio
+    from bitdust.logs import lg
+    from bitdust.main import config
+    from bitdust.system import bpio
     if _Debug:
         lg.out(_DebugLevel, 'bpmain.shutdown')
 
     if config.conf():
         config.conf().removeConfigNotifier('logs/debug-level')
 
-    from main import shutdowner
+    from bitdust.main import shutdowner
     shutdowner.A('reactor-stopped')
 
-    from main import listeners
+    from bitdust.main import listeners
     listeners.shutdown()
 
-    from main import events
+    from bitdust.main import events
     events.shutdown()
 
-    from automats import automat
+    from bitdust.automats import automat
     automat.objects().clear()
     if len(automat.index()) > 0:
         lg.warn('%d automats was not cleaned' % len(automat.index()))
@@ -281,16 +285,17 @@ def shutdown():
     lg.stdout_stop_redirecting()
     lg.stderr_stop_redirecting()
 
-    from main import settings
+    from bitdust.main import settings
     settings.shutdown()
 
     return 0
 
+
 #------------------------------------------------------------------------------
 
 
 def run_twisted_reactor():
-    from logs import lg
+    from bitdust.logs import lg
     try:
         from twisted.internet import reactor  # @UnresolvedImport
     except:
@@ -328,6 +333,7 @@ def run(UI='', options=None, args=None, overDict=None, executablePath=None, star
 
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -337,75 +343,93 @@ def parser():
     """
     from optparse import OptionParser, OptionGroup
     parser = OptionParser(usage=usage_text(), prog='BitDust')
-    group = OptionGroup(parser, "Logs")
-    group.add_option('-d', '--debug',
-                     dest='debug',
-                     type='int',
-                     help='set debug level',)
-    group.add_option('-q', '--quite',
-                     dest='quite',
-                     action='store_true',
-                     help='quite mode, do not print any messages to stdout',)
-    group.add_option('-v', '--verbose',
-                     dest='verbose',
-                     action='store_true',
-                     help='verbose mode, print more messages',)
-    group.add_option('--coverage',
-                     dest='coverage',
-                     action='store_true',
-                     help='record code coverage',)
-    group.add_option('--coverage_config',
-                     dest='coverage_config',
-                     type='string',
-                     help='coverage configuration file path')
-    group.add_option('--coverage_report',
-                     dest='coverage_report',
-                     type='string',
-                     help='file path to be used to store coverage report')
-    group.add_option('-n', '--no-logs',
-                     dest='no_logs',
-                     action='store_true',
-                     help='do not use logs',)
-    group.add_option('-o', '--output',
-                     dest='output',
-                     type='string',
-                     help='print log messages to the file',)
-    group.add_option('-a', '--appdir',
-                     dest='appdir',
-                     type='string',
-                     help='set alternative location for application data files, default is ~/.bitdust/',)
-#    group.add_option('-t', '--tempdir',
-#                        dest='tempdir',
-#                        type='string',
-#                        help='set location for temporary files, default is ~/.bitdust/temp',)
-    group.add_option('--twisted',
-                     dest='twisted',
-                     action='store_true',
-                     help='show twisted log messages too',)
-    group.add_option('--cpu-profile',
-                     dest='cpu_profile',
-                     action='store_true',
-                     help='use cProfile to profile performance, output is in the file /tmp/bitdust.profile',)
-#    group.add_option('--memdebug',
-#                        dest='memdebug',
-#                        action='store_true',
-#                        help='start web server to debug memory usage, need cherrypy and dozer modules',)
+    group = OptionGroup(parser, 'Logs')
+    group.add_option(
+        '-d',
+        '--debug',
+        dest='debug',
+        type='int',
+        help='set debug level',
+    )
+    group.add_option(
+        '-q',
+        '--quite',
+        dest='quite',
+        action='store_true',
+        help='quite mode, do not print any messages to stdout',
+    )
+    group.add_option(
+        '-v',
+        '--verbose',
+        dest='verbose',
+        action='store_true',
+        help='verbose mode, print more messages',
+    )
+    group.add_option(
+        '--coverage',
+        dest='coverage',
+        action='store_true',
+        help='record code coverage',
+    )
+    group.add_option('--coverage_config', dest='coverage_config', type='string', help='coverage configuration file path')
+    group.add_option('--coverage_report', dest='coverage_report', type='string', help='file path to be used to store coverage report')
+    group.add_option(
+        '-n',
+        '--no-logs',
+        dest='no_logs',
+        action='store_true',
+        help='do not use logs',
+    )
+    group.add_option(
+        '-o',
+        '--output',
+        dest='output',
+        type='string',
+        help='print log messages to the file',
+    )
+    group.add_option(
+        '-a',
+        '--appdir',
+        dest='appdir',
+        type='string',
+        help='set alternative location for application data files, default is ~/.bitdust/',
+    )
+    #    group.add_option('-t', '--tempdir',
+    #                        dest='tempdir',
+    #                        type='string',
+    #                        help='set location for temporary files, default is ~/.bitdust/temp',)
+    group.add_option(
+        '--twisted',
+        dest='twisted',
+        action='store_true',
+        help='show twisted log messages too',
+    )
+    group.add_option(
+        '--cpu-profile',
+        dest='cpu_profile',
+        action='store_true',
+        help='use cProfile to profile performance, output is in the file /tmp/bitdust.profile',
+    )
+    #    group.add_option('--memdebug',
+    #                        dest='memdebug',
+    #                        action='store_true',
+    #                        help='start web server to debug memory usage, need cherrypy and dozer modules',)
     parser.add_option_group(group)
-#    group = OptionGroup(parser, "Network")
-#    group.add_option('--tcp-port',
-#                        dest='tcp_port',
-#                        type='int',
-#                        help='set tcp port number for incoming connections',)
-#    group.add_option('--no-upnp',
-#                        dest='no_upnp',
-#                        action='store_true',
-#                        help='do not use UPnP',)
-#    group.add_option('--memdebug-port',
-#                        dest='memdebug_port',
-#                        type='int',
-#                        default=9996,
-#                        help='set port number for memdebug web server, default is 9995',)
-#    parser.add_option_group(group)
+    #    group = OptionGroup(parser, "Network")
+    #    group.add_option('--tcp-port',
+    #                        dest='tcp_port',
+    #                        type='int',
+    #                        help='set tcp port number for incoming connections',)
+    #    group.add_option('--no-upnp',
+    #                        dest='no_upnp',
+    #                        action='store_true',
+    #                        help='do not use UPnP',)
+    #    group.add_option('--memdebug-port',
+    #                        dest='memdebug_port',
+    #                        type='int',
+    #                        default=9996,
+    #                        help='set port number for memdebug web server, default is 9995',)
+    #    parser.add_option_group(group)
     return parser
 
 
@@ -418,10 +442,10 @@ def override_options(opts, args):
     for new options.
     """
     overDict = {}
-#    if opts.tcp_port:
-#        overDict['services/tcp-connections/tcp-port'] = str(opts.tcp_port)
-#    if opts.no_upnp:
-#        overDict['services/tcp-connections/upnp-enabled'] = 'false'
+    #    if opts.tcp_port:
+    #        overDict['services/tcp-connections/tcp-port'] = str(opts.tcp_port)
+    #    if opts.no_upnp:
+    #        overDict['services/tcp-connections/upnp-enabled'] = 'false'
     if opts.debug or str(opts.debug) == '0':
         overDict['logs/debug-level'] = str(opts.debug)
 #    if opts.memdebug:
@@ -432,6 +456,7 @@ def override_options(opts, args):
 #            overDict['logs/memdebug-port'] = '9996'
     return overDict
 
+
 #------------------------------------------------------------------------------
 
 
@@ -439,7 +464,7 @@ def kill():
     """
     Kill all running BitDust processes (except current).
     """
-    from system import bpio
+    from bitdust.system import bpio
     total_count = 0
     found = False
     while True:
@@ -474,8 +499,8 @@ def wait_then_kill(x):
     ``kill()``.
     """
     from twisted.internet import reactor  # @UnresolvedImport
-    from logs import lg
-    from system import bpio
+    from bitdust.logs import lg
+    from bitdust.system import bpio
     total_count = 0
     while True:
         appList = bpio.lookup_main_process()
@@ -491,8 +516,8 @@ def wait_then_kill(x):
             return ret
         time.sleep(1)
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 _OriginalCallLater = None
 _LastCallableID = 0
@@ -504,13 +529,12 @@ class _callable():
 
     I tried to decrease the number of delayed calls.
     """
-
     def __init__(self, delay, callabl, *args, **kw):
         self.callabl = callabl
         self.to_call = lambda: self.run(*args, **kw)
 
     def run(self, *args, **kw):
-        from logs import measure_it
+        from bitdust.logs import measure_it
         measure_it.run(self.callabl, *args, **kw)
 
     def call(self):
@@ -545,17 +569,18 @@ def monitorDelayedCalls(r):
     """
     Print out all delayed calls.
     """
-    from logs import measure_it
-    from logs import lg
+    from bitdust.logs import measure_it
+    from bitdust.logs import lg
     stats = measure_it.top_calls()
     if _Debug:
         lg.out(_DebugLevel, '\nslowest calls:\n%s' % stats)
     r.callLater(30, monitorDelayedCalls, r)
 
+
 #------------------------------------------------------------------------------
 
-class TwistedUnhandledErrorsObserver:
 
+class TwistedUnhandledErrorsObserver:
     def __init__(self, level):
         self.level = level
 
@@ -563,11 +588,9 @@ class TwistedUnhandledErrorsObserver:
         if event_dict.get('log_level') == self.level:
             if 'log_failure' in event_dict:
                 f = event_dict['log_failure']
-                from logs import lg
-                lg.exc(
-                    msg=f'Unhandled error in Deferred:\n{event_dict.get("debugInfo", "")}',
-                    exc_info=(f.type, f.value, f.getTracebackObject(), ),
-                )
+                from bitdust.logs import lg
+                lg.exc(msg=f'Unhandled error in Deferred:\n{event_dict.get("debugInfo", "")}', exc_info=(f.type, f.value, f.getTracebackObject()))
+
 
 #-------------------------------------------------------------------------------
 
@@ -578,7 +601,7 @@ def usage_text():
     from command line.
     """
     try:
-        from main import help
+        from bitdust.main import help
         return help.usage_text()
     except:
         return ''
@@ -589,7 +612,7 @@ def help_text():
     Same thing, calls ``p2p.help.help_text()`` to show detailed instructions.
     """
     try:
-        from main import help
+        from bitdust.main import help
         return help.help_text()
     except:
         return ''
@@ -600,7 +623,7 @@ def backup_schedule_format():
     See ``p2p.help.schedule_format()`` method.
     """
     try:
-        from main import help
+        from bitdust.main import help
         return help.schedule_format()
     except:
         return ''
@@ -635,24 +658,62 @@ def main(executable_path=None, start_reactor=True):
         cmd = args[0].lower()
 
     try:
-        from system import deploy
+        from bitdust.system import deploy
     except:
         dirpath = os.path.dirname(os.path.abspath(sys.argv[0]))
         sys.path.insert(0, os.path.abspath(os.path.join(dirpath, '..')))
         from distutils.sysconfig import get_python_lib
         sys.path.append(os.path.join(get_python_lib(), 'bitdust'))
         try:
-            from system import deploy
+            from bitdust.system import deploy
         except:
             print_text('ERROR! can not import working code.  Python Path:')
             print_text('\n'.join(sys.path))
             return 1
 
     #---install---
-    if cmd in ['deploy', 'install', 'venv', 'virtualenv', ]:
-        from system import deploy
+    if cmd in [
+        'deploy',
+        'install',
+        'venv',
+        'virtualenv',
+    ]:
+        from bitdust.system import deploy
         return deploy.run(args)
 
+    #---integrate---
+    if cmd == 'integrate' or cmd == 'alias' or cmd == 'shell':
+        """
+        This is a helper command to make a "system-wide" command called "bitdust" for fast access to the app.
+
+        Run:
+            python3 bitdust.py alias > /usr/local/bin/bitdust
+            chmod +x /usr/local/bin/bitdust
+
+        This will create an executable file /usr/local/bin/bitdust with such content:
+            #!/bin/sh
+            python3 [path to `bitdust` folder]/bitdust.py "$@"
+        """
+        from bitdust.system import bpio
+        if bpio.Windows():
+            # TODO:
+            # src = u"""@echo off
+            # C:\Users\veselin\BITDUS~2\venv\Scripts\python.exe C:\Users\veselin\BITDUS~2\src\bitdust.py %*
+            # """
+            print_text('this feature is not yet available for Windows')
+            return 0
+        python_path = os.path.abspath(os.path.join(os.path.expanduser('~'), '.bitdust', 'venv', 'bin', 'python'))
+        curpath = os.path.abspath(os.path.join(bpio.getExecutableDir(), '..'))
+        src = '#!/bin/sh\n'
+        src += '# This is a very short shell script to help you create an alias "bitdust" in your OS for the BitDust software.\n'
+        src += '# NOTICE: BitDust do not require root permissions to run, please always start it as normal user.\n'
+        src += '# Run:\n'
+        src += '#     python3 bitdust.py alias > /usr/local/bin/bitdust\n'
+        src += '#     chmod +x /usr/local/bin/bitdust\n'
+        src += '%s %s/bitdust.py "$@"\n' % (python_path, curpath)
+        print_text(src)
+        return 0
+
     if opts.appdir:
         appdata = opts.appdir
         AppDataDir = appdata
@@ -674,10 +735,10 @@ def main(executable_path=None, start_reactor=True):
     #---BitDust Home
     deploy.init_base_dir(base_dir=AppDataDir)
 
-    from logs import lg
+    from bitdust.logs import lg
 
     #---init IO module
-    from system import bpio
+    from bitdust.system import bpio
     bpio.init()
 
     appList = bpio.find_main_process(pid_file_path=os.path.join(appdata, 'metadata', 'processid'))
@@ -709,10 +770,7 @@ def main(executable_path=None, start_reactor=True):
     # try to read debug level value at the early stage - no problem if fail here
     try:
         if cmd == '' or cmd == 'start' or cmd == 'go' or cmd == 'show' or cmd == 'open':
-            lg.set_debug_level(int(
-                bpio.ReadTextFile(
-                    os.path.abspath(
-                        os.path.join(appdata, 'config', 'logs', 'debug-level')))))
+            lg.set_debug_level(int(bpio.ReadTextFile(os.path.abspath(os.path.join(appdata, 'config', 'logs', 'debug-level')))))
     except:
         pass
 
@@ -740,7 +798,18 @@ def main(executable_path=None, start_reactor=True):
 
     if logpath:
         if not appList:
-            if cmd not in ['detach', 'daemon', 'stop', 'kill', 'shutdown', 'restart', 'reboot', 'reconnect', 'show', 'open', ]:
+            if cmd not in [
+                'detach',
+                'daemon',
+                'stop',
+                'kill',
+                'shutdown',
+                'restart',
+                'reboot',
+                'reconnect',
+                'show',
+                'open',
+            ]:
                 lg.open_log_file(logpath)
         if bpio.Windows() and bpio.isFrozen():
             need_redirecting = True
@@ -790,11 +859,10 @@ def main(executable_path=None, start_reactor=True):
                 if opts.coverage_report:
                     cov.report(file=open(opts.coverage_report, 'w'))
             return 0
-        from lib import misc
+        from bitdust.lib import misc
         print_text('new BitDust process will be started in daemon mode\n', nl='')
         result = misc.DoRestart(
-            detach=True,
-            # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
+            detach=True,  # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
             # std_err=os.path.join(appdata, 'logs', 'stderr.log'),
         )
         if result is not None:
@@ -842,24 +910,24 @@ def main(executable_path=None, start_reactor=True):
                     kill()
                 except:
                     lg.exc()
-                from lib import misc
+                from bitdust.lib import misc
                 reactor.addSystemEventTrigger(  # @UndefinedVariable
                     'after',
                     'shutdown',
                     misc.DoRestart,
                     param='show' if ui else '',
-                    detach=True,
-                    # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
+                    detach=True,  # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
                     # std_err=os.path.join(appdata, 'logs', 'stderr.log'),
                 )
                 reactor.stop()  # @UndefinedVariable
+
             try:
                 from twisted.internet import reactor  # @UnresolvedImport
                 # from interface.command_line import run_url_command
                 # d = run_url_command('?action=restart', False)
-                # from interface import cmd_line
+                # from bitdust.interface import cmd_line
                 # d = cmd_line.call_xmlrpc_method('restart', ui)
-                from interface import cmd_line_json
+                from bitdust.interface import cmd_line_json
                 d = cmd_line_json.call_websocket_method('process_restart', websocket_timeout=5)
                 d.addCallback(done)
                 d.addErrback(failed)
@@ -932,9 +1000,7 @@ def main(executable_path=None, start_reactor=True):
                 if opts.coverage_report:
                     cov.report(file=open(opts.coverage_report, 'w'))
             return ret
-        appList = bpio.find_main_process(
-            pid_file_path=os.path.join(appdata, 'metadata', 'processid'),
-        )
+        appList = bpio.find_main_process(pid_file_path=os.path.join(appdata, 'metadata', 'processid'))
         if len(appList) > 0:
             if cmd == 'kill':
                 print_text('found main BitDust process: %s, about to kill running process ... ' % appList, nl='')
@@ -962,7 +1028,7 @@ def main(executable_path=None, start_reactor=True):
                     bpio.shutdown()
 
                 print_text('found main BitDust process: %s ... ' % appList, nl='')
-                from interface import cmd_line_json
+                from bitdust.interface import cmd_line_json
                 cmd_line_json.call_websocket_method('process_stop', websocket_timeout=2).addBoth(_stopped)
                 reactor.run()  # @UndefinedVariable
                 if opts.coverage:
@@ -984,8 +1050,7 @@ def main(executable_path=None, start_reactor=True):
         else:
             appListAllChilds = bpio.find_main_process(
                 check_processid_file=False,
-                extra_lookups=[
-                ],
+                extra_lookups=[],
             )
             if len(appListAllChilds) > 0:
                 print_text('BitDust child processes found: %s, performing "kill process" action ...\n' % appListAllChilds, nl='')
@@ -1007,7 +1072,7 @@ def main(executable_path=None, start_reactor=True):
             return 0
 
     #---command_line---
-    from interface import cmd_line_json as cmdln
+    from bitdust.interface import cmd_line_json as cmdln
     ret = cmdln.run(opts, args, pars, overDict, executable_path)
     if ret == 2:
         print_text(usage_text())
@@ -1022,10 +1087,10 @@ def main(executable_path=None, start_reactor=True):
 
     return ret
 
+
 #------------------------------------------------------------------------------
 
-
-if __name__ == "__main__":
+if __name__ == '__main__':
     ret = main()
     if ret == 2:
         print(usage_text())
