@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -48,15 +47,15 @@ import re
 
 #------------------------------------------------------------------------------
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     import os.path as _p
     sys.path.append(_p.join(_p.dirname(_p.abspath(sys.argv[0])), '..'))
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
-from logs import lg
+from bitdust.logs import lg
 
 #------------------------------------------------------------------------------
 
@@ -83,17 +82,19 @@ def shutdown():
         del _Config
         _Config = None
 
+
 #------------------------------------------------------------------------------
 
+
 def conf():
     global _Config
     return _Config
 
+
 #------------------------------------------------------------------------------
 
 
 class BaseConfig(object):
-
     def __init__(self, configDir):
         self.configDir = configDir
 
@@ -128,7 +129,7 @@ class BaseConfig(object):
 
     def listAllEntries(self):
         try:
-            from system import bpio
+            from bitdust.system import bpio
             l = []
             abspth = bpio.portablePath(os.path.abspath(self.getConfigDir()))
             for subpath in bpio.list_dir_recursive(abspth):
@@ -156,7 +157,7 @@ class BaseConfig(object):
         if s is None:
             return default
         try:
-            s = s.strip().strip('"')
+            s = str(s).strip().strip('"')
             return int(s)
         except ValueError:
             return default
@@ -168,7 +169,12 @@ class BaseConfig(object):
         data = self.getData(entryPath)
         if data is None:
             return default
-        return True if data.strip() in ['true', '1', 'on', ] else False
+        return True if str(data).strip() in [
+            'True',
+            'true',
+            '1',
+            'on',
+        ] else False
 
     def setBool(self, entryPath, value):
         return self._set(entryPath, 'true' if value else 'false')
@@ -177,7 +183,7 @@ class BaseConfig(object):
         data = self.getData(entryPath)
         if data is None:
             return default
-        data = data.strip()
+        data = str(data).strip()
         if len(data) < 2:
             return default
         if not (data[0] == data[-1] == '"'):
@@ -305,6 +311,7 @@ class BaseConfig(object):
             lg.exc('error writing to file: %s' % fpath)
         return False
 
+
 #------------------------------------------------------------------------------
 
 
@@ -328,11 +335,11 @@ class DefaultsConfig(BaseConfig):
     def getOriginalData(self, entryPath):
         return BaseConfig.getData(self, entryPath)
 
+
 #------------------------------------------------------------------------------
 
 
 class NotifiableConfig(DefaultsConfig):
-
     def __init__(self, configDir):
         super(NotifiableConfig, self).__init__(configDir)
         self.callbacks = {}
@@ -370,15 +377,15 @@ class NotifiableConfig(DefaultsConfig):
                     cb(entryPath, newValue, oldValue, result)
         return result
 
+
 #------------------------------------------------------------------------------
 
 
 class FixedTypesConfig(NotifiableConfig):
-
     def __init__(self, configDir):
         super(FixedTypesConfig, self).__init__(configDir)
         try:
-            from main import config_types
+            from bitdust.main import config_types
             self._types = config_types.defaults()
             self._labels = config_types.labels()
         except:
@@ -401,56 +408,80 @@ class FixedTypesConfig(NotifiableConfig):
         return self._labels.get(self.getType(entryPath))
 
     def getTypeMetaInfo(self, entryPath):
-        from main import config_types
+        from bitdust.main import config_types
         typ = self.getType(entryPath)
         if not typ:
             return {}
-        if typ in [config_types.TYPE_STRING,
-                   config_types.TYPE_TEXT,
-                   config_types.TYPE_UNDEFINED,
-                   config_types.TYPE_PASSWORD,
-                   config_types.TYPE_INTEGER,
-                   config_types.TYPE_BOOLEAN, ]:
+        if typ in [
+            config_types.TYPE_STRING,
+            config_types.TYPE_TEXT,
+            config_types.TYPE_UNDEFINED,
+            config_types.TYPE_PASSWORD,
+            config_types.TYPE_INTEGER,
+            config_types.TYPE_BOOLEAN,
+        ]:
             return {}
         if typ == config_types.TYPE_POSITIVE_INTEGER:
-            return {'min': 0, }
+            return {
+                'min': 0,
+            }
         if typ == config_types.TYPE_PORT_NUMBER:
-            return {'min': 1, 'max': 65535, }
+            return {
+                'min': 1,
+                'max': 65535,
+            }
         if typ == config_types.TYPE_NON_ZERO_POSITIVE_INTEGER:
-            return {'min': 1, }
-        if typ in [config_types.TYPE_FOLDER_PATH, config_types.TYPE_FILE_PATH, ]:
+            return {
+                'min': 1,
+            }
+        if typ in [
+            config_types.TYPE_FOLDER_PATH,
+            config_types.TYPE_FILE_PATH,
+        ]:
             # TODO: to be decided later
             return {}
         elif typ == config_types.TYPE_COMBO_BOX:
             if entryPath == 'services/customer/suppliers-number':
-                from raid import eccmap
-                return {'possible_values': eccmap.SuppliersNumbers(), }
+                from bitdust.raid import eccmap
+                return {
+                    'possible_values': eccmap.SuppliersNumbers(),
+                }
             else:
                 raise TypeError('unexpected option type for %r' % entryPath)
         return {}
 
     def getValueOfType(self, entryPath):
-        from main import config_types
+        from bitdust.main import config_types
         typ = self.getType(entryPath)
         value = None
-        if not typ or typ in [config_types.TYPE_STRING,
-                              config_types.TYPE_TEXT,
-                              config_types.TYPE_UNDEFINED, ]:
+        if not typ or typ in [
+            config_types.TYPE_STRING,
+            config_types.TYPE_TEXT,
+            config_types.TYPE_UNDEFINED,
+        ]:
             value = self.getData(entryPath)
-        elif typ in [config_types.TYPE_BOOLEAN, ]:
+        elif typ in [
+            config_types.TYPE_BOOLEAN,
+        ]:
             value = self.getBool(entryPath)
-        elif typ in [config_types.TYPE_INTEGER,
-                     config_types.TYPE_POSITIVE_INTEGER,
-                     config_types.TYPE_NON_ZERO_POSITIVE_INTEGER,
-                     config_types.TYPE_PORT_NUMBER, ]:
+        elif typ in [
+            config_types.TYPE_INTEGER,
+            config_types.TYPE_POSITIVE_INTEGER,
+            config_types.TYPE_NON_ZERO_POSITIVE_INTEGER,
+            config_types.TYPE_PORT_NUMBER,
+        ]:
             value = self.getInt(entryPath)
-        elif typ in [config_types.TYPE_FOLDER_PATH,
-                     config_types.TYPE_FILE_PATH,
-                     config_types.TYPE_PASSWORD, ]:
+        elif typ in [
+            config_types.TYPE_FOLDER_PATH,
+            config_types.TYPE_FILE_PATH,
+            config_types.TYPE_PASSWORD,
+        ]:
             value = self.getString(entryPath) or ''
-            if typ in [config_types.TYPE_FOLDER_PATH, ]:
+            if typ in [
+                config_types.TYPE_FOLDER_PATH,
+            ]:
                 if value:
-                    from system import bpio
+                    from bitdust.system import bpio
                     if bpio.Windows():
                         if not value.endswith(u'/') and not value.endswith(u'\\'):
                             value = value + u'\\'
@@ -466,26 +497,38 @@ class FixedTypesConfig(NotifiableConfig):
         return value
 
     def setValueOfType(self, entryPath, value):
-        from main import config_types
+        from bitdust.main import config_types
         typ = self.getType(entryPath)
-        if not typ or typ in [config_types.TYPE_STRING,
-                              config_types.TYPE_TEXT,
-                              config_types.TYPE_UNDEFINED, ]:
+        if not typ or typ in [
+            config_types.TYPE_STRING,
+            config_types.TYPE_TEXT,
+            config_types.TYPE_UNDEFINED,
+        ]:
             self.setData(entryPath, strng.text_type(value))
-        elif typ in [config_types.TYPE_BOOLEAN, ]:
+        elif typ in [
+            config_types.TYPE_BOOLEAN,
+        ]:
             if strng.is_string(value):
-                vl = strng.to_text(value).strip().lower() in ['true', '1', 'on', ]
+                vl = strng.to_text(value).strip().lower() in [
+                    'true',
+                    '1',
+                    'on',
+                ]
             else:
                 vl = bool(value)
             self.setBool(entryPath, vl)
-        elif typ in [config_types.TYPE_INTEGER,
-                     config_types.TYPE_POSITIVE_INTEGER,
-                     config_types.TYPE_NON_ZERO_POSITIVE_INTEGER,
-                     config_types.TYPE_PORT_NUMBER, ]:
+        elif typ in [
+            config_types.TYPE_INTEGER,
+            config_types.TYPE_POSITIVE_INTEGER,
+            config_types.TYPE_NON_ZERO_POSITIVE_INTEGER,
+            config_types.TYPE_PORT_NUMBER,
+        ]:
             self.setInt(entryPath, int(value))
-        elif typ in [config_types.TYPE_FOLDER_PATH,
-                     config_types.TYPE_FILE_PATH,
-                     config_types.TYPE_PASSWORD, ]:
+        elif typ in [
+            config_types.TYPE_FOLDER_PATH,
+            config_types.TYPE_FILE_PATH,
+            config_types.TYPE_PASSWORD,
+        ]:
             self.setString(entryPath, value)
         elif typ == config_types.TYPE_COMBO_BOX:
             if entryPath == 'services/customer/suppliers-number':
@@ -496,6 +539,7 @@ class FixedTypesConfig(NotifiableConfig):
             self.setData(entryPath, strng.text_type(value))
         return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -533,6 +577,7 @@ class CachedConfig(FixedTypesConfig):
         """
         # TODO
 
+
 #------------------------------------------------------------------------------
 
 
@@ -545,7 +590,7 @@ class DetailedConfig(CachedConfig):
     def __init__(self, configDir):
         super(DetailedConfig, self).__init__(configDir)
         try:
-            from main import config_details
+            from bitdust.main import config_details
             self._load_details(config_details.raw())
         except:
             lg.exc()
@@ -594,6 +639,7 @@ class DetailedConfig(CachedConfig):
         result.update(self.getTypeMetaInfo(entryPath))
         return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -601,9 +647,9 @@ def main():
     """
     Read settings from 'config' file and prints values from your queries to stdout.
     """
-    from logs import lg
+    from bitdust.logs import lg
     lg.set_debug_level(24)
-    from main import settings
+    from bitdust.main import settings
     settings.init()
     init(settings.ConfigDir())
     print(conf().listEntries(''))
@@ -626,6 +672,7 @@ def main():
     settings.shutdown()
     return
 
+
 #    last = ''
 #    for entry in sorted(conf()._types.keys()):
 #        parent, key = entry.rsplit('/', 1)
@@ -638,10 +685,9 @@ def main():
 #            print parent
 #            last = parent
 #        print ' ' * (last.count(' ') + 1) * 2, key, '\t\t\t\t', conf().get_type_label(entry).upper()
-    # print '\n'.join(map(lambda x: "    '%s':\t\t\tNode," % x, sorted(conf().listAllEntries())))
-    # s = conf().getData('details')
-    # conf()._load_details(s)
+# print '\n'.join(map(lambda x: "    '%s':\t\t\tNode," % x, sorted(conf().listAllEntries())))
+# s = conf().getData('details')
+# conf()._load_details(s)
 
-
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
