@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -40,8 +39,8 @@ def reset(conf_obj):
     Here all items suppose to have some widget in UI to interact with human.
     Keep it simple and understandable.
     """
-    from lib import diskspace
-    from main import settings
+    from bitdust.lib import diskspace
+    from bitdust.main import settings
 
     conf_obj.setDefaultValue('interface/api/auth-secret-enabled', 'true')
 
@@ -131,6 +130,7 @@ def reset(conf_obj):
     conf_obj.setDefaultValue('services/employer/candidates', '')
 
     conf_obj.setDefaultValue('services/gateway/enabled', 'true')
+    conf_obj.setDefaultValue('services/gateway/p2p-timeout', 15)
 
     conf_obj.setDefaultValue('services/http-connections/enabled', 'false')
     conf_obj.setDefaultValue('services/http-connections/http-port', settings.DefaultHTTPPort())
@@ -247,4 +247,3 @@ def reset(conf_obj):
     conf_obj.setDefaultValue('services/udp-transport/receiving-enabled', 'true')
     conf_obj.setDefaultValue('services/udp-transport/sending-enabled', 'true')
     conf_obj.setDefaultValue('services/udp-transport/priority', 20)
-
