@@ -23,14 +23,12 @@
 #
 #
 #
-
 """
 ..
 
 module:: config_types
 """
 
-
 TYPE_UNDEFINED = 0
 TYPE_BOOLEAN = 1
 TYPE_STRING = 2
@@ -71,10 +69,8 @@ def defaults():
         'interface/api/rest-http-port': TYPE_PORT_NUMBER,
         'interface/api/web-socket-enabled': TYPE_BOOLEAN,
         'interface/api/web-socket-port': TYPE_PORT_NUMBER,
-
         'interface/ftp/enabled': TYPE_BOOLEAN,
         'interface/ftp/port': TYPE_PORT_NUMBER,
-
         'logs/api-enabled': TYPE_BOOLEAN,
         'logs/automat-events-enabled': TYPE_BOOLEAN,
         'logs/automat-transitions-enabled': TYPE_BOOLEAN,
@@ -89,15 +85,12 @@ def defaults():
         'logs/traffic-port': TYPE_PORT_NUMBER,
 
         # 'other/upnp-at-startup': TYPE_BOOLEAN,
-
         'paths/backups': TYPE_FOLDER_PATH,
         'paths/customers': TYPE_FOLDER_PATH,
         'paths/messages': TYPE_FOLDER_PATH,
         'paths/receipts': TYPE_FOLDER_PATH,
         'paths/restore': TYPE_FOLDER_PATH,
-
         'personal/private-key-size': TYPE_STRING,
-
         'services/accountant/enabled': TYPE_BOOLEAN,
         'services/backup-db/enabled': TYPE_BOOLEAN,
         'services/backups/block-size': TYPE_DISK_SPACE,
@@ -138,6 +131,7 @@ def defaults():
         'services/employer/replace-critically-offline-enabled': TYPE_BOOLEAN,
         'services/employer/candidates': TYPE_STRING,
         'services/gateway/enabled': TYPE_BOOLEAN,
+        'services/gateway/p2p-timeout': TYPE_POSITIVE_INTEGER,
         'services/http-connections/enabled': TYPE_BOOLEAN,
         'services/http-connections/http-port': TYPE_PORT_NUMBER,
         'services/http-transport/enabled': TYPE_BOOLEAN,
@@ -198,8 +192,7 @@ def defaults():
         'services/proxy-transport/priority': TYPE_POSITIVE_INTEGER,
         'services/proxy-transport/my-original-identity': TYPE_TEXT,
         'services/proxy-transport/current-router': TYPE_STRING,
-        'services/proxy-transport/preferred-routers': TYPE_TEXT,
-        # 'services/proxy-transport/router-lifetime-seconds': TYPE_POSITIVE_INTEGER,
+        'services/proxy-transport/preferred-routers': TYPE_TEXT,  # 'services/proxy-transport/router-lifetime-seconds': TYPE_POSITIVE_INTEGER,
         'services/rebuilding/enabled': TYPE_BOOLEAN,
         'services/restores/enabled': TYPE_BOOLEAN,
         'services/shared-data/enabled': TYPE_BOOLEAN,
