@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: initializer.
 
@@ -81,19 +80,19 @@ except:
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import local_fs
+from bitdust.system import bpio
+from bitdust.system import local_fs
 
-from crypt import cipher
+from bitdust.crypt import cipher
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from automats import automat
+from bitdust.automats import automat
 
-from services import driver
+from bitdust.services import driver
 
 #------------------------------------------------------------------------------
 
@@ -142,25 +141,25 @@ class Initializer(automat.Automat):
         self.is_installed = None
 
     def A(self, event, *args, **kwargs):
-        from main import installer
-        from main import shutdowner
+        from bitdust.main import installer
+        from bitdust.main import shutdowner
         #---AT_STARTUP---
         if self.state == 'AT_STARTUP':
             if event == 'run':
                 self.state = 'LOCAL'
                 shutdowner.A('init')
                 self.doInitLocal(*args, **kwargs)
-                self.flagCmdLine=False
+                self.flagCmdLine = False
             elif event == 'run-cmd-line-register':
                 self.state = 'INSTALL'
                 shutdowner.A('init')
-                self.flagCmdLine=True
+                self.flagCmdLine = True
                 installer.A('register-cmd-line', *args, **kwargs)
                 shutdowner.A('ready')
             elif event == 'run-cmd-line-recover':
                 self.state = 'INSTALL'
                 shutdowner.A('init')
-                self.flagCmdLine=True
+                self.flagCmdLine = True
                 installer.A('recover-cmd-line', *args, **kwargs)
                 shutdowner.A('ready')
         #---LOCAL---
@@ -172,10 +171,10 @@ class Initializer(automat.Automat):
                 self.doInitInterfaces(*args, **kwargs)
                 self.doShowGUI(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            elif (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'STOPPING'
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'init-local-done' and ( ( not self.isInstalled(*args, **kwargs) and not self.isGUIPossible(*args, **kwargs) ) or self.isInstalled(*args, **kwargs) ):
+            elif event == 'init-local-done' and ((not self.isInstalled(*args, **kwargs) and not self.isGUIPossible(*args, **kwargs)) or self.isInstalled(*args, **kwargs)):
                 self.state = 'INTERFACES'
                 shutdowner.A('ready')
                 self.doInitInterfaces(*args, **kwargs)
@@ -185,28 +184,28 @@ class Initializer(automat.Automat):
                 self.state = 'READY'
                 self.doUpdate(*args, **kwargs)
                 self.doShowGUI(*args, **kwargs)
-            elif ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            elif (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doDestroyMe(*args, **kwargs)
         #---INSTALL---
         elif self.state == 'INSTALL':
-            if not self.flagCmdLine and ( event == 'installer.state' and args[0] == 'DONE' ):
+            if not self.flagCmdLine and (event == 'installer.state' and args[0] == 'DONE'):
                 self.state = 'STOPPING'
-                shutdowner.A('stop', "restartnshow")
-            elif self.flagCmdLine and ( event == 'installer.state' and args[0] == 'DONE' ):
+                shutdowner.A('stop', 'restartnshow')
+            elif self.flagCmdLine and (event == 'installer.state' and args[0] == 'DONE'):
                 self.state = 'STOPPING'
-                shutdowner.A('stop', "exit")
-            elif ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+                shutdowner.A('stop', 'exit')
+            elif (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doDestroyMe(*args, **kwargs)
         #---READY---
         elif self.state == 'READY':
-            if ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            if (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doDestroyMe(*args, **kwargs)
         #---STOPPING---
         elif self.state == 'STOPPING':
-            if ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            if (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doUpdate(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
@@ -219,7 +218,7 @@ class Initializer(automat.Automat):
                 self.state = 'MODULES'
                 self.doInitModules(*args, **kwargs)
                 shutdowner.A('ready')
-            elif ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            elif (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doDestroyMe(*args, **kwargs)
         #---INTERFACES---
@@ -227,7 +226,7 @@ class Initializer(automat.Automat):
             if event == 'init-interfaces-done':
                 self.state = 'SERVICES'
                 self.doInitServices(*args, **kwargs)
-            elif ( event == 'shutdowner.state' and args[0] == 'FINISHED' ):
+            elif (event == 'shutdowner.state' and args[0] == 'FINISHED'):
                 self.state = 'EXIT'
                 self.doDestroyMe(*args, **kwargs)
         return None
@@ -241,13 +240,9 @@ class Initializer(automat.Automat):
         return bpio.isGUIpossible()
 
     def doUpdate(self, *args, **kwargs):
-        # from main import control
-        # control.request_update()
         pass
 
     def doInitLocal(self, *args, **kwargs):
-        """
-        """
         self.flagGUI = args[0].strip() == 'show'
         if _Debug:
             lg.out(_DebugLevel, 'initializer.doInitLocal flagGUI=%s' % self.flagGUI)
@@ -277,7 +272,7 @@ class Initializer(automat.Automat):
             lg.out(_DebugLevel, 'initializer.doInitInterfaces')
         # if settings.enableFTPServer():
         #     try:
-        #         from interface import ftp_server
+        #         from bitdust.interface import ftp_server
         #         ftp_server.init()
         #     except:
         #         lg.exc()
@@ -289,13 +284,13 @@ class Initializer(automat.Automat):
                 lg.info('generated new API auth secret text and stored in %r' % settings.APISecretFile())
         if settings.enableRESTHTTPServer():
             try:
-                from interface import api_rest_http_server
+                from bitdust.interface import api_rest_http_server
                 api_rest_http_server.init(port=settings.getRESTHTTPServerPort())
             except:
                 lg.exc()
         if settings.enableWebSocketServer():
             try:
-                from interface import api_web_socket
+                from bitdust.interface import api_web_socket
                 api_web_socket.init(port=settings.getWebSocketServerPort())
             except:
                 lg.exc()
@@ -310,26 +305,24 @@ class Initializer(automat.Automat):
     def doShowGUI(self, *args, **kwargs):
         if _Debug:
             lg.out(_DebugLevel, 'initializer.doShowGUI')
-        # from main import control
-        # control.init()
         try:
-            from system.tray_icon import USE_TRAY_ICON
+            from bitdust.system.tray_icon import USE_TRAY_ICON
         except:
             USE_TRAY_ICON = False
             lg.exc()
         if USE_TRAY_ICON:
-            from system import tray_icon
+            from bitdust.system import tray_icon
             tray_icon.SetControlFunc(self._on_tray_icon_command)
         # TODO: raise up electron window ?
 
     def doDestroyMe(self, *args, **kwargs):
         global _Initializer
         try:
-            from system.tray_icon import USE_TRAY_ICON
+            from bitdust.system.tray_icon import USE_TRAY_ICON
         except:
             USE_TRAY_ICON = False
         if USE_TRAY_ICON:
-            from system import tray_icon
+            from bitdust.system import tray_icon
             tray_icon.SetControlFunc(None)
         del _Initializer
         _Initializer = None
@@ -344,14 +337,14 @@ class Initializer(automat.Automat):
         """
         if _Debug:
             lg.out(_DebugLevel, 'initializer._check_install')
-        from userid import identity
-        from crypt import key
+        from bitdust.userid import identity
+        from bitdust.crypt import key
         keyfilename = settings.KeyFileName()
         keyfilenamelocation = settings.KeyFileNameLocation()
-        if os.path.exists(keyfilenamelocation):
-            keyfilename = bpio.ReadTextFile(keyfilenamelocation)
-            if not os.path.exists(keyfilename):
-                keyfilename = settings.KeyFileName()
+        if os.path.isfile(keyfilenamelocation):
+            keyfilename_custom = bpio.ReadTextFile(keyfilenamelocation).strip()
+            if os.path.isfile(keyfilename_custom):
+                keyfilename = keyfilename_custom
         idfilename = settings.LocalIdentityFilename()
         if not os.path.exists(keyfilename) or not os.path.exists(idfilename):
             if _Debug:
@@ -396,28 +389,28 @@ class Initializer(automat.Automat):
         return True
 
     def _init_local(self):
-        from p2p import commands
-        from lib import net_misc
-        from lib import misc
-        from system import tmpfile
-        from system import run_upnpc
-        from raid import eccmap
-        from contacts import identitydb
-        from crypt import my_keys
-        from userid import id_url
-        from userid import my_id
+        from bitdust.p2p import commands
+        from bitdust.lib import net_misc
+        from bitdust.lib import misc
+        from bitdust.system import tmpfile
+        from bitdust.system import run_upnpc
+        from bitdust.raid import eccmap
+        from bitdust.contacts import identitydb
+        from bitdust.crypt import my_keys
+        from bitdust.userid import id_url
+        from bitdust.userid import my_id
         id_url.init()
         identitydb.init()
         my_id.init()
         if settings.enableWebStream():
             try:
-                from logs import weblog
+                from bitdust.logs import weblog
                 weblog.init(settings.getWebStreamPort())
             except:
                 lg.exc()
         if settings.enableWebTraffic():
             try:
-                from logs import webtraffic
+                from bitdust.logs import webtraffic
                 webtraffic.init(port=settings.getWebTrafficPort())
             except:
                 lg.exc()
@@ -432,9 +425,9 @@ class Initializer(automat.Automat):
         # if sys.argv.count('--twisted'):
         #     from twisted.python import log as twisted_log
         #     twisted_log.startLogging(MyTwistedOutputLog(), setStdout=0)
-            # import twisted.python.failure as twisted_failure
-            # twisted_failure.startDebugMode()
-            # twisted_log.defaultObserver.stop()
+        # import twisted.python.failure as twisted_failure
+        # twisted_failure.startDebugMode()
+        # twisted_log.defaultObserver.stop()
         # if settings.getDebugLevel() > 10:
         #     defer.setDebugging(True)
         if settings.enableMemoryProfile():
@@ -443,12 +436,12 @@ class Initializer(automat.Automat):
                 hp = hpy()
                 hp.setrelheap()
                 if _Debug:
-                    lg.out(_DebugLevel, 'hp.heap():\n'+str(hp.heap()))
-                    lg.out(_DebugLevel, 'hp.heap().byrcs:\n'+str(hp.heap().byrcs))
-                    lg.out(_DebugLevel, 'hp.heap().byvia:\n'+str(hp.heap().byvia))
+                    lg.out(_DebugLevel, 'hp.heap():\n' + str(hp.heap()))
+                    lg.out(_DebugLevel, 'hp.heap().byrcs:\n' + str(hp.heap().byrcs))
+                    lg.out(_DebugLevel, 'hp.heap().byvia:\n' + str(hp.heap().byvia))
             except:
                 if _Debug:
-                    lg.out(_DebugLevel, "guppy package is not installed")
+                    lg.out(_DebugLevel, 'guppy package is not installed')
         if _Debug:
             lg.dbg(_DebugLevel, 'all local modules are initialized, ready to start the engine')
 
@@ -461,7 +454,7 @@ class Initializer(automat.Automat):
         if False:
             # TODO: add an option to the settings
             return
-        from main import shutdowner
+        from bitdust.main import shutdowner
         shutdowner.A('stop', 'restart')
 
     def _init_modules(self):
@@ -469,16 +462,16 @@ class Initializer(automat.Automat):
         Finish initialization part, run delayed methods.
         """
         if _Debug:
-            lg.out(_DebugLevel, "initializer._init_modules")
-        from updates import git_proc
+            lg.out(_DebugLevel, 'initializer._init_modules')
+        from bitdust.updates import git_proc
         git_proc.init()
         events.add_subscriber(self._on_software_code_updated, 'source-code-fetched')
 
     def _on_tray_icon_command(self, cmd):
         if _Debug:
-            lg.out(_DebugLevel, "initializer._on_tray_icon_command : [%s]" % cmd)
+            lg.out(_DebugLevel, 'initializer._on_tray_icon_command : [%s]' % cmd)
         try:
-            from main import shutdowner
+            from bitdust.main import shutdowner
             if cmd == 'exit':
                 shutdowner.A('stop', 'exit')
 
@@ -486,7 +479,7 @@ class Initializer(automat.Automat):
                 shutdowner.A('stop', 'restart')
 
             elif cmd == 'reconnect':
-                from p2p import network_connector
+                from bitdust.p2p import network_connector
                 if driver.is_on('service_network'):
                     network_connector.A('reconnect')
 
@@ -496,8 +489,8 @@ class Initializer(automat.Automat):
 
             elif cmd == 'sync':
                 try:
-                    from updates import git_proc
-                    from system import tray_icon
+                    from bitdust.updates import git_proc
+                    from bitdust.system import tray_icon
 
                     def _sync_callback(result):
                         if result == 'error':
@@ -526,6 +519,7 @@ class Initializer(automat.Automat):
         except:
             lg.exc()
 
+
 #------------------------------------------------------------------------------
 
 
