@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: install_wizard.
 
@@ -52,14 +51,14 @@ EVENTS:
 from __future__ import absolute_import
 import sys
 try:
-    from twisted.internet import reactor  # @UnresolvedImport
+    pass
 except:
     sys.exit('Error initializing twisted.internet.reactor in install_wizard.py')
 
-from main import config
-from automats import automat
+from bitdust.main import config
+from bitdust.automats import automat
 
-from main import installer
+from bitdust.main import installer
 
 #------------------------------------------------------------------------------
 
@@ -104,8 +103,6 @@ class InstallWizard(automat.Automat):
             # TODO:
             # here just skip Contacts page!
             # we do not need that now, but can back to that soon when add chat
-        # from main import control
-        # control.request_update()
         installer.A('install_wizard.state', newstate)
 
     def A(self, event, *args, **kwargs):
