@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: installer.
 
@@ -79,27 +78,27 @@ _DebugLevel = 4
 #------------------------------------------------------------------------------
 
 try:
-    from twisted.internet import reactor  # @UnresolvedImport
+    pass
 except:
     sys.exit('Error initializing twisted.internet.reactor in installer.py')
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from system import bpio
+from bitdust.system import bpio
 
-from main import settings
+from bitdust.main import settings
 
-from lib import misc
-from lib import nameurl
+from bitdust.lib import misc
+from bitdust.lib import nameurl
 
-from userid import id_registrator
-from userid import id_restorer
+from bitdust.userid import id_registrator
+from bitdust.userid import id_restorer
 
-from main import initializer
+from bitdust.main import initializer
 
 #------------------------------------------------------------------------------
 
@@ -112,8 +111,10 @@ def IsExist():
     global _Installer
     return _Installer is not None
 
+
 #------------------------------------------------------------------------------
 
+
 def A(event=None, *args, **kwargs):
     """
     Access method to interact with the state machine.
@@ -131,8 +132,10 @@ def A(event=None, *args, **kwargs):
         _Installer.automat(event, *args, **kwargs)
     return _Installer
 
+
 #------------------------------------------------------------------------------
 
+
 class Installer(automat.Automat):
     """
     A class to control the whole process of program installation.
@@ -150,7 +153,8 @@ class Installer(automat.Automat):
         'idurl_not_exist': ('Identity URL address not exist or not reachable at this moment', 'blue'),
         'signing_error': ('unable to sign the local Identity file', 'red'),
         'signature_not_match': ('remote Identity and Private Key did not match', 'red'),
-        'success': ('account restored!', 'green'), }
+        'success': ('account restored!', 'green'),
+    }
 
     def getOutput(self, state=None):
         if state is None:
@@ -169,15 +173,15 @@ class Installer(automat.Automat):
         if self.state == 'AT_STARTUP':
             if event == 'init':
                 self.state = 'WHAT_TO_DO?'
-                self.flagCmdLine=False
+                self.flagCmdLine = False
             elif event == 'register-cmd-line':
                 self.state = 'REGISTER'
-                self.flagCmdLine=True
+                self.flagCmdLine = True
                 self.doInit(*args, **kwargs)
                 id_registrator.A('start', *args, **kwargs)
             elif event == 'recover-cmd-line':
                 self.state = 'RECOVER'
-                self.flagCmdLine=True
+                self.flagCmdLine = True
                 self.doInit(*args, **kwargs)
                 id_restorer.A('start', *args, **kwargs)
         #---WHAT_TO_DO?---
@@ -232,15 +236,15 @@ class Installer(automat.Automat):
             if event == 'print':
                 self.doPrint(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_registrator.state' and args[0] == 'FAILED' ) and not self.flagCmdLine:
+            elif (event == 'id_registrator.state' and args[0] == 'FAILED') and not self.flagCmdLine:
                 self.state = 'INPUT_NAME'
                 self.doShowOutput(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_registrator.state' and args[0] == 'DONE' ) and not self.flagCmdLine:
+            elif (event == 'id_registrator.state' and args[0] == 'DONE') and not self.flagCmdLine:
                 self.state = 'AUTHORIZED'
                 self.doPrepareSettings(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_registrator.state' and args[0] in [ 'DONE' , 'FAILED' ] ) and self.flagCmdLine:
+            elif (event == 'id_registrator.state' and args[0] in ['DONE', 'FAILED']) and self.flagCmdLine:
                 self.state = 'DONE'
                 self.doUpdate(*args, **kwargs)
         #---AUTHORIZED---
@@ -256,14 +260,14 @@ class Installer(automat.Automat):
             if event == 'print':
                 self.doPrint(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_restorer.state' and args[0] in [ 'RESTORED!' , 'FAILED' ] ) and self.flagCmdLine:
+            elif (event == 'id_restorer.state' and args[0] in ['RESTORED!', 'FAILED']) and self.flagCmdLine:
                 self.state = 'DONE'
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_restorer.state' and args[0] == 'RESTORED!' ) and not self.flagCmdLine:
+            elif (event == 'id_restorer.state' and args[0] == 'RESTORED!') and not self.flagCmdLine:
                 self.state = 'RESTORED'
                 self.doRestoreSettings(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'id_restorer.state' and args[0] == 'FAILED' ) and not self.flagCmdLine:
+            elif (event == 'id_restorer.state' and args[0] == 'FAILED') and not self.flagCmdLine:
                 self.state = 'LOAD_KEY'
                 self.doUpdate(*args, **kwargs)
         #---DONE---
@@ -276,7 +280,7 @@ class Installer(automat.Automat):
             if event == 'print':
                 self.doPrint(*args, **kwargs)
                 self.doUpdate(*args, **kwargs)
-            elif ( event == 'install_wizard.state' and args[0] == 'DONE' ):
+            elif (event == 'install_wizard.state' and args[0] == 'DONE'):
                 self.state = 'DONE'
                 self.doUpdate(*args, **kwargs)
         #---RESTORED---
@@ -300,12 +304,9 @@ class Installer(automat.Automat):
         """
 
     def doUpdate(self, *args, **kwargs):
-        # from main import control
-        # control.request_update([{'state': self.state}, ])
         pass
 
     def doClearOutput(self, *args, **kwargs):
-        # lg.out(4, 'installer.doClearOutput')
         for state in self.output.keys():
             self.output[state] = {'data': [('', 'black')]}
 
@@ -347,7 +348,7 @@ class Installer(automat.Automat):
         src = args[0]['keysrc']
         lg.out(2, 'installer.doReadKey length=%s' % len(src))
         # src = bpio.ReadBinaryFile(keyfn)
-        if len(src) > 1024 * 10:
+        if len(src) > 1024*10:
             self.doPrint(('file is too big for private key', 'red'))
             return
         try:
@@ -407,6 +408,7 @@ class Installer(automat.Automat):
         Action method.
         """
 
+
 #    def doIncreaseDebugLevel(self, *args, **kwargs):
 #        """
 #        """
