@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: settings.
 
@@ -57,14 +56,14 @@ _Debug = False
 _DebugLevel = 4
 
 #------------------------------------------------------------------------------
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import deploy
+from bitdust.system import bpio
+from bitdust.system import deploy
 
-from lib import diskspace
+from bitdust.lib import diskspace
 
-from main import config
+from bitdust.main import config
 
 #------------------------------------------------------------------------------
 
@@ -77,9 +76,11 @@ _InitDone = False
 _BandwidthLimit = None
 _BackupBlockSize = None
 _BackupMaxBlockSize = None
+_P2PTimeOut = None
 
 #------------------------------------------------------------------------------
 
+
 def init(base_dir=None):
     """
     Must be called before all other things.
@@ -114,10 +115,12 @@ def shutdown():
     deploy.set_base_dir(None)
     config.shutdown()
 
+
 #------------------------------------------------------------------------------
 #---USER CONFIG----------------------------------------------------------------
 #------------------------------------------------------------------------------
 
+
 def override(key, value):
     """
     This method can be used to redefine values in UserConfig without writing
@@ -208,6 +211,7 @@ Below is a set of global constants.
 #--- LOGS --------------------------------------------------------------------
 #------------------------------------------------------------------------------
 
+
 def UpdateLogFilename():
     """
     A place to store logs from update porcess.
@@ -288,6 +292,235 @@ def defaultDebugLevel():
     return 0
 
 
+def MaxPacketsOutstanding():
+    """
+    PREPRO Should be a function of disk space available.
+    """
+    return 100
+
+
+def SendingSpeedLimit():
+    """
+    This is lower limit during file sending in bytes per second.
+
+    Used to calculate a packet timeout - bigger packets should have longer timeouts.
+    If sending below this speed - we count this supplier as failed.
+    If we sending too slow to all nodes - it's our problems, not suppliers.
+    """
+    return 30*1024
+
+
+def ReceivingSpeedLimit():
+    return 30*1024
+
+
+def DefaultBandwidthInLimit():
+    """
+    Incoming bandwidth limit in bytes per second, 0 - unlimited.
+    """
+    # 1 Mbps = 125000 B/s ~ 122 KB/s
+    return 100*1250000
+
+
+def DefaultBandwidthOutLimit():
+    """
+    Outgoing bandwidth limit in bytes per second, 0 - unlimited.
+    """
+    # 1 Mbps = 125000 B/s ~ 122 KB/s
+    return 100*125000
+
+
+def MaxRetries():
+    """
+    The idea was to create some "exponential backoff" -
+
+    double each time. Set to 1 at the moment - so failed packets is ignored.
+    """
+    return 1
+
+
+def DefaultEccMapName():
+    """
+    This is a ecc map name used by default.
+    Must comply with ``DefaultDesiredSuppliers()``.
+    """
+    return 'ecc/2x2'
+
+
+def DefaultDesiredSuppliers():
+    """
+    A starting number of suppliers for new users.
+
+    Definitely we want to have 64 by default, but we need to have much
+    more alive users to do that.
+
+    Must comply with ``DefaultEccMapName()``
+    """
+    return 2
+
+
+def MinimumUsernameLength():
+    """
+    A minimum possible user name length.
+    """
+    return 3
+
+
+def MaximumUsernameLength():
+    """
+    A maximum possible user name length.
+    """
+    return 20
+
+
+def DefaultDonatedBytes():
+    """
+    Default donated space value. User can set this at any moment in the settings.
+    """
+    return 8*1024*1024*1024  # 8 GB
+
+
+def DefaultNeededBytes():
+    """
+    Default needed space value. User can set this at any moment in the settings.
+    """
+    return 256*1024*1024  # 256 MB
+
+
+def MinimumDonatedBytes():
+    """
+    Minimum donated space amount in Megabytes - need to donate at least 2 Mb right now.
+    """
+    return 64*1024*1024  # 64 MB
+
+
+def MinimumNeededBytes():
+    return 32*1024*1024  # 32 MB - minimum 1 MB will be taken from every supplier
+
+
+def DefaultBackupBlockSize():
+    """
+    Default block size in bytes, user can set this in settings. We split a
+    backed up data into blocks of equal size and.
+
+    perform RAID operation on every block - one by one.
+    """
+    return 4*1024*1024  # 4 MB
+
+
+def DefaultBackupMaxBlockSize():
+    """
+    The maximum default block size, user can set this in the settings.
+    """
+    return 16*1024*1024  # 16 MB is fine
+
+
+def MinimumBandwidthInLimitKBSec():
+    """
+    Not used, idea was to limit the minimum bandwidth given to BitDust.
+    """
+    return 10
+
+
+def MinimumBandwidthOutLimitKBSec():
+    """
+    Not used.
+    """
+    return 10
+
+
+def MaxDeletedBackupIDsToKeep():
+    """
+    How many deleted backup IDs do we want to hold on to in backup db.
+
+    Not used.
+    """
+    return 100
+
+
+#------------------------------------------------------------------------------
+#--- CONSTANTS (TIMEOUTS/DELAYS) ------------------------------------------------------
+#------------------------------------------------------------------------------
+
+
+def P2PTimeOut():
+    """
+    A default timeout when sending and receiving packets.
+    """
+    global _P2PTimeOut
+    if _P2PTimeOut is None:
+        _P2PTimeOut = config.conf().getInt('services/gateway/p2p-timeout', 15)
+    return _P2PTimeOut
+
+
+def DefaultSendTimeOutEmail():
+    """
+    Timeout for email sending, not used.
+    """
+    return 300
+
+
+def DefaultSendTimeOutHTTP():
+    """
+    Timeout for http sending, not used.
+    """
+    return 60
+
+
+def DefaultAlivePacketTimeOut():
+    """
+    Lets send alive packets to our contacts every hour.
+    """
+    return 60*60
+
+
+def DefaultBandwidthReportTimeOut():
+    """
+    Send ``BandwidthReport`` packets every 24 hours.
+    """
+    return 60*60*24
+
+
+def DefaultNeedSuppliersPacketTimeOut():
+    """
+    If we need suppliers we will request it every 60 sec.
+
+    Not used right now.
+    """
+    return 60
+
+
+def DefaultLocaltesterLoop():
+    """
+    The code in ``p2p.local_tester`` will check the customers files
+    periodically.
+
+    This constant controls that - seconds between two calls.
+    """
+    return 20
+
+
+def DefaultLocaltesterValidateTimeout():
+    """
+    A period in seconds to call ``Validate`` action of the local tester.
+    """
+    return 120*60
+
+
+def DefaultLocaltesterUpdateCustomersTimeout():
+    """
+    A period in seconds to call ``UpdateCustomers`` action of the local tester.
+    """
+    return 5*60
+
+
+def DefaultLocaltesterSpaceTimeTimeout():
+    """
+    A period in seconds to call ``SpaceTime`` action of the local tester.
+    """
+    return 5*60
+
+
 def MinimumSendingDelay():
     """
     The lower limit of delay for repeated calls for sending processes.
@@ -322,240 +555,20 @@ def MaximumReceivingDelay():
     return 4.0
 
 
-def MaxPacketsOutstanding():
-    """
-    PREPRO Should be a function of disk space available.
-    """
-    return 100
-
-
-def SendingSpeedLimit():
-    """
-    This is lower limit during file sending in bytes per second.
-
-    Used to calculate a packet timeout - bigger packets should have longer timeouts.
-    If sending below this speed - we count this supplier as failed.
-    If we sending too slow to all nodes - it's our problems, not suppliers.
-    """
-    return 30 * 1024
-
-
-def ReceivingSpeedLimit():
-    return 30 * 1024
-
-
-def DefaultBandwidthInLimit():
-    """
-    Incoming bandwidth limit in bytes per second, 0 - unlimited.
-    """
-    # 1 Mbps = 125000 B/s ~ 122 KB/s
-    return 100 * 1250000
-
-
-def DefaultBandwidthOutLimit():
-    """
-    Outgoing bandwidth limit in bytes per second, 0 - unlimited.
-    """
-    # 1 Mbps = 125000 B/s ~ 122 KB/s
-    return 100 * 125000
-
-
-def SendTimeOut():
-    """
-    A default timeout when sending packets.
-    """
-    return 10
-
-
-def MaxRetries():
-    """
-    The idea was to create some "exponential backoff" -
-
-    double each time. Set to 1 at the moment - so failed packets is ignored.
-    """
-    return 1
-
-
-def DefaultSendTimeOutEmail():
-    """
-    Timeout for email sending, not used.
-    """
-    return 300
-
-
-def DefaultSendTimeOutHTTP():
-    """
-    Timeout for http sending, not used.
-    """
-    return 60
-
-
-def DefaultAlivePacketTimeOut():
-    """
-    Lets send alive packets to our contacts every hour.
-    """
-    return 60 * 60
-
-
-def DefaultBandwidthReportTimeOut():
-    """
-    Send ``BandwidthReport`` packets every 24 hours.
-    """
-    return 60 * 60 * 24
-
-
-def DefaultNeedSuppliersPacketTimeOut():
-    """
-    If we need suppliers we will request it every 60 sec.
-
-    Not used right now.
-    """
-    return 60
-
-
-def DefaultEccMapName():
-    """
-    This is a ecc map name used by default.
-    Must comply with ``DefaultDesiredSuppliers()``.
-    """
-    return 'ecc/2x2'
-
-
-def DefaultDesiredSuppliers():
-    """
-    A starting number of suppliers for new users.
-
-    Definitely we want to have 64 by default, but we need to have much
-    more alive users to do that.
-
-    Must comply with ``DefaultEccMapName()``
-    """
-    return 2
-
-
-def DefaultLocaltesterLoop():
-    """
-    The code in ``p2p.local_tester`` will check the customers files
-    periodically.
-
-    This constant controls that - seconds between two calls.
-    """
-    return 20
-
-
-def DefaultLocaltesterValidateTimeout():
-    """
-    A period in seconds to call ``Validate`` action of the local tester.
-    """
-    return 120 * 60
-
-
-def DefaultLocaltesterUpdateCustomersTimeout():
-    """
-    A period in seconds to call ``UpdateCustomers`` action of the local tester.
-    """
-    return 5 * 60
-
-
-def DefaultLocaltesterSpaceTimeTimeout():
-    """
-    A period in seconds to call ``SpaceTime`` action of the local tester.
-    """
-    return 5 * 60
-
-
-def MinimumUsernameLength():
-    """
-    A minimum possible user name length.
-    """
-    return 3
-
-
-def MaximumUsernameLength():
-    """
-    A maximum possible user name length.
-    """
-    return 20
-
-
-def DefaultDonatedBytes():
-    """
-    Default donated space value. User can set this at any moment in the settings.
-    """
-    return 8 * 1024 * 1024 * 1024  # 8 GB
-
-
-def DefaultNeededBytes():
-    """
-    Default needed space value. User can set this at any moment in the settings.
-    """
-    return 256 * 1024 * 1024  # 256 MB
-
-
-def MinimumDonatedBytes():
-    """
-    Minimum donated space amount in Megabytes - need to donate at least 2 Mb right now.
-    """
-    return 64 * 1024 * 1024  # 64 MB
-
-
-def MinimumNeededBytes():
-    return 32 * 1024 * 1024  # 32 MB - minimum 1 MB will be taken from every supplier
-
-
-def DefaultBackupBlockSize():
-    """
-    Default block size in bytes, user can set this in settings. We split a
-    backed up data into blocks of equal size and.
-
-    perform RAID operation on every block - one by one.
-    """
-    return 4 * 1024 * 1024  # 4 MB
-
-
-def DefaultBackupMaxBlockSize():
-    """
-    The maximum default block size, user can set this in the settings.
-    """
-    return 16 * 1024 * 1024  # 16 MB is fine
-
-
-def MinimumBandwidthInLimitKBSec():
-    """
-    Not used, idea was to limit the minimum bandwidth given to BitDust.
-    """
-    return 10
-
-
-def MinimumBandwidthOutLimitKBSec():
-    """
-    Not used.
-    """
-    return 10
-
-
 def FireHireMinimumDelay():
     """
     Really do not want to fire suppliers too often, so use 15 minutes interval.
     """
-    return 60 * 15
+    return 60*15
 
 
 def BackupDBSynchronizeDelay():
     """
     Save backup index database no more than one time per every 5 min.
     """
-    return 60 * 5
+    return 60*5
 
 
-def MaxDeletedBackupIDsToKeep():
-    """
-    How many deleted backup IDs do we want to hold on to in backup db.
-
-    Not used.
-    """
-    return 100
-
 #------------------------------------------------------------------------------
 #---CONSTANTS ( STRINGS ) -----------------------------------------------------
 #------------------------------------------------------------------------------
@@ -575,7 +588,7 @@ def ListFilesFormat():
 
     Can be "Text" or "Compressed". TODO: add "Encrypted" format
     """
-    return "Compressed"
+    return 'Compressed'
 
 
 def DefaultRepo():
@@ -642,20 +655,21 @@ def LegalUsernameChars():
     """
     A set of correct chars that can be used for user account names.
     """
-    return set("abcdefghijklmnopqrstuvwxyz0123456789-_")
+    return set('abcdefghijklmnopqrstuvwxyz0123456789-_')
 
 
 def LegalNickNameChars():
     """
     A set of correct chars that can be used for user account names.
     """
-    return set("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_.,{}[]()@!$^&*=+")
+    return set('abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_.,{}[]()@!$^&*=+')
 
 
 #------------------------------------------------------------------------------
 #--- FOLDERS ------------------------------------------------------------------
 #------------------------------------------------------------------------------
 
+
 def BaseDir():
     """
     Return current data folder location, also call ``init()`` to be sure all
@@ -673,7 +687,7 @@ def BaseDirPathFileName():
     folder file "appdata" can be created and it will keep the path to
     the data folder.
     """
-    return os.path.join(bpio.getExecutableDir(), "appdata")
+    return os.path.join(bpio.getExecutableDir(), 'appdata')
 
 
 def DefaultRestoreDir():
@@ -699,7 +713,7 @@ def MetaDataDir():
     """
     Return current location of the "metadata" folder - most important config files is here.
     """
-    return os.path.join(BaseDir(), "metadata")
+    return os.path.join(BaseDir(), 'metadata')
 
 
 def ConfigDir():
@@ -714,7 +728,7 @@ def TempDir():
     TODO: need to add some stuff to control how much extra space we use
     and be able limit that.
     """
-    return os.path.join(BaseDir(), "temp")
+    return os.path.join(BaseDir(), 'temp')
 
 
 def IdentityHistoryDir():
@@ -722,7 +736,7 @@ def IdentityHistoryDir():
     See ``lib.id_url`` module, this is a place to store all known idurl's to match
     "rotated" identies together.
     """
-    return os.path.join(BaseDir(), "identityhistory")
+    return os.path.join(BaseDir(), 'identityhistory')
 
 
 def IdentityCacheDir():
@@ -730,7 +744,7 @@ def IdentityCacheDir():
     See ``lib.identitycache`` module, this is a place to store user's identity
     files to have them on hands.
     """
-    return os.path.join(BaseDir(), "identitycache")
+    return os.path.join(BaseDir(), 'identitycache')
 
 
 def IdentityServerDir():
@@ -760,7 +774,7 @@ def DefaultCustomersDir():
     Here will be placed files uploaded by other users.
     Your customers will user your HDD to keep their personal data.
     """
-    return os.path.join(BaseDir(), "customers")
+    return os.path.join(BaseDir(), 'customers')
 
 
 def DefaultMessagesDir():
@@ -802,14 +816,14 @@ def BandwidthInDir():
     """
     Daily stats for incoming bandwidth is placed in that location.
     """
-    return os.path.join(BaseDir(), "bandin")
+    return os.path.join(BaseDir(), 'bandin')
 
 
 def BandwidthOutDir():
     """
     Daily stats for outgoing bandwidth is placed in that location.
     """
-    return os.path.join(BaseDir(), "bandout")
+    return os.path.join(BaseDir(), 'bandout')
 
 
 def RatingsDir():
@@ -854,15 +868,17 @@ def ServicesDataDir():
 def ServiceDir(service_name):
     return os.path.join(ServicesDataDir(), service_name.replace('service_', ''))
 
+
 #------------------------------------------------------------------------------
 #--- FILES --------------------------------------------------------------------
 #------------------------------------------------------------------------------
 
+
 def KeyFileName():
     """
     Location of user's Private Key file.
     """
-    return os.path.join(MetaDataDir(), "mykeyfile")
+    return os.path.join(MetaDataDir(), 'mykeyfile')
 
 
 def KeyFileNameLocation():
@@ -881,14 +897,14 @@ def CustomerIDsFilename():
     """
     IDs for places we store data for, keeps a list of IDURLs of our customers.
     """
-    return os.path.join(MetaDataDir(), "customerids")
+    return os.path.join(MetaDataDir(), 'customerids')
 
 
 def CustomersMetaInfoFilename():
     """
     Keeps a list of known ECCMaps and other info of my customers.
     """
-    return os.path.join(MetaDataDir(), "customersmetainfo")
+    return os.path.join(MetaDataDir(), 'customersmetainfo')
 
 
 def CorrespondentIDsFilename():
@@ -896,7 +912,7 @@ def CorrespondentIDsFilename():
     People we get messages from and other stuff not related to backup/restore
     process.
     """
-    return os.path.join(MetaDataDir(), "correspondentids")
+    return os.path.join(MetaDataDir(), 'correspondentids')
 
 
 def LocalIdentityFilename():
@@ -907,42 +923,42 @@ def LocalIdentityFilename():
     Further local identity file is propagated to the identity server
     and all our contacts so they got the fresh copy asap.
     """
-    return os.path.join(MetaDataDir(), "localidentity")
+    return os.path.join(MetaDataDir(), 'localidentity')
 
 
 def LocalIPFilename():
     """
     File contains string like "192.168.12.34" - local IP of that machine.
     """
-    return os.path.join(MetaDataDir(), "localip")
+    return os.path.join(MetaDataDir(), 'localip')
 
 
 def ExternalIPFilename():
     """
     File contains string like 201.42.133.2 - external IP of that machine.
     """
-    return os.path.join(MetaDataDir(), "externalip")
+    return os.path.join(MetaDataDir(), 'externalip')
 
 
 def ExternalUDPPortFilename():
     """
     File contains external UDP port number of that machine - detected after STUN.
     """
-    return os.path.join(MetaDataDir(), "externaludpport")
+    return os.path.join(MetaDataDir(), 'externaludpport')
 
 
 def DefaultTransportOrderFilename():
     """
     Location for file that keeps an order of used transports.
     """
-    return os.path.join(MetaDataDir(), "torder")
+    return os.path.join(MetaDataDir(), 'torder')
 
 
 def UserNameFilename():
     """
     File contains something like "guesthouse" - user account name.
     """
-    return os.path.join(MetaDataDir(), "username")
+    return os.path.join(MetaDataDir(), 'username')
 
 
 def BackupIndexFileName():
@@ -955,14 +971,14 @@ def BackupIndexFileName():
 
 
 def BackupIndexFilePath(customer_idurl=None, key_alias='master'):
-    from userid import my_id
-    from userid import id_url
+    from bitdust.userid import my_id
+    from bitdust.userid import id_url
     if customer_idurl is None:
         customer_idurl = my_id.getIDURL()
     customer_idurl = id_url.field(customer_idurl)
     customer_id = customer_idurl.to_id()
     index_dir_path = os.path.join(ServiceDir('service_backups'), 'index')
-    index_file_path = os.path.join(index_dir_path, '%s$%s' % (key_alias, customer_id, ))
+    index_file_path = os.path.join(index_dir_path, '%s$%s' % (key_alias, customer_id))
     return index_file_path
 
 
@@ -977,8 +993,8 @@ def SupplierPath(supplier_idurl, customer_idurl, filename=None):
         - "disconnected" : date and time when this suppler was fired
         - "listfiles" : a list of our local files stored on his machine
     """
-    from userid import global_id
-    from lib import nameurl
+    from bitdust.userid import global_id
+    from bitdust.lib import nameurl
     customer = global_id.UrlToGlobalID(customer_idurl)
     if filename is not None:
         return os.path.join(SuppliersDir(), customer, nameurl.UrlFilename(supplier_idurl), filename)
@@ -1039,9 +1055,11 @@ def CertificateFiles():
     The idea is to have a global certificate for BitDust server, just like
     https works.
     """
-    return [os.path.join(MetaDataDir(), 'bitdust.cer'),
-            os.path.join('.', 'bitdust.cer'),
-            os.path.join(bpio.getExecutableDir(), 'bitdust.cer'), ]
+    return [
+        os.path.join(MetaDataDir(), 'bitdust.cer'),
+        os.path.join('.', 'bitdust.cer'),
+        os.path.join(bpio.getExecutableDir(), 'bitdust.cer'),
+    ]
 
 
 def DHTDBFile():
@@ -1075,6 +1093,7 @@ def APISecretFile():
 def ChatMessagesHistoryDatabaseFile():
     return os.path.join(ChatMessagesDir(), 'message_v1.db')
 
+
 #------------------------------------------------------------------------------
 #--- BINARY FILES -------------------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1150,6 +1169,7 @@ def FontImageFile():
     """
     return os.path.join(FontsFolderPath(), 'Arial_Narrow.ttf')
 
+
 #------------------------------------------------------------------------------
 #---PORT NUMBERS---------------------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1266,6 +1286,7 @@ def DefaultWebTrafficPort():
     """
     return 9997
 
+
 #------------------------------------------------------------------------------
 #--- USER FOLDERS -------------------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1283,7 +1304,7 @@ def getCustomerFilesDir(idurl):
     Alias to get a given customer's files inside our donated location from
     settings.
     """
-    from userid import global_id
+    from bitdust.userid import global_id
     return os.path.join(getCustomersFilesDir(), global_id.UrlToGlobalID(idurl))
 
 
@@ -1315,6 +1336,7 @@ def getTempDir():
     """
     return TempDir()
 
+
 #------------------------------------------------------------------------------
 #--- OS PROXY SERVER OPTIONS --------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1369,7 +1391,8 @@ def getProxySettingsDict():
         'port': config.conf().getData('services/network/proxy/port').strip(),
         'username': config.conf().getData('services/network/proxy/username').strip(),
         'password': config.conf().getData('services/network/proxy/password').strip(),
-        'ssl': config.conf().getData('services/network/proxy/ssl').strip(), }
+        'ssl': config.conf().getData('services/network/proxy/ssl').strip(),
+    }
 
 
 def update_proxy_settings():
@@ -1377,7 +1400,7 @@ def update_proxy_settings():
     Calls ``lib.net_misc.detect_proxy_settings()`` to check current system
     proxy server settings.
     """
-    from lib import net_misc
+    from bitdust.lib import net_misc
     net_misc.init()
     if enableLocalProxy():
         if getProxyHost() == '' or getProxyPort() == '':
@@ -1395,9 +1418,10 @@ def update_proxy_settings():
             lg.out(_DebugLevel, '    HOST:      ' + net_misc.get_proxy_host())
             lg.out(_DebugLevel, '    PORT:      ' + str(net_misc.get_proxy_port()))
             lg.out(_DebugLevel, '    USERNAME:  ' + net_misc.get_proxy_username())
-            lg.out(_DebugLevel, '    PASSWORD:  ' + ('*' * len(net_misc.get_proxy_password())))
+            lg.out(_DebugLevel, '    PASSWORD:  ' + ('*'*len(net_misc.get_proxy_password())))
             lg.out(_DebugLevel, '    SSL:       ' + net_misc.get_proxy_ssl())
 
+
 #------------------------------------------------------------------------------
 #---OTHER USER CONFIGURATIONS--------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1448,27 +1472,27 @@ def enableFTPServer(enable=None):
 
 
 def getIdServerHost():
-    return config.conf().getData("services/identity-server/host").strip()
+    return config.conf().getData('services/identity-server/host').strip()
 
 
 def setIdServerHost(hostname_or_ip):
-    return config.conf().setData("services/identity-server/host", hostname_or_ip)
+    return config.conf().setData('services/identity-server/host', hostname_or_ip)
 
 
 def getIdServerWebPort():
-    return config.conf().getInt("services/identity-server/web-port", IdentityWebPort())
+    return config.conf().getInt('services/identity-server/web-port', IdentityWebPort())
 
 
 def setIdServerWebPort(web_port):
-    return config.conf().setInt("services/identity-server/web-port", web_port)
+    return config.conf().setInt('services/identity-server/web-port', web_port)
 
 
 def getIdServerTCPPort():
-    return config.conf().getInt("services/identity-server/tcp-port", IdentityServerPort())
+    return config.conf().getInt('services/identity-server/tcp-port', IdentityServerPort())
 
 
 def setIdServerTCPPort(tcp_port):
-    return config.conf().setInt("services/identity-server/tcp-port", tcp_port)
+    return config.conf().setInt('services/identity-server/tcp-port', tcp_port)
 
 
 def getRESTHTTPServerPort():
@@ -1476,7 +1500,7 @@ def getRESTHTTPServerPort():
 
 
 def setRESTHTTPServerPort(rest_http_port):
-    return config.conf().setInt("interface/api/rest-http-port", rest_http_port)
+    return config.conf().setInt('interface/api/rest-http-port', rest_http_port)
 
 
 def getWebSocketServerPort():
@@ -1484,7 +1508,7 @@ def getWebSocketServerPort():
 
 
 def setWebSocketServerPort(rest_http_port):
-    return config.conf().setInt("interface/api/web-socket-port", rest_http_port)
+    return config.conf().setInt('interface/api/web-socket-port', rest_http_port)
 
 
 def getFTPServerPort():
@@ -1492,7 +1516,7 @@ def getFTPServerPort():
 
 
 def setFTPServerPort(ftp_port):
-    return config.conf().setInt("interface/ftp/port", ftp_port)
+    return config.conf().setInt('interface/ftp/port', ftp_port)
 
 
 def getTransportPort(proto):
@@ -1543,14 +1567,14 @@ def getTCPPort():
     """
     Get a port number for tranport_tcp from user config.
     """
-    return config.conf().getInt("services/tcp-connections/tcp-port", DefaultTCPPort())
+    return config.conf().getInt('services/tcp-connections/tcp-port', DefaultTCPPort())
 
 
 def setTCPPort(port):
     """
     Set a port number for tranport_tcp in the user config.
     """
-    config.conf().setData("services/tcp-connections/tcp-port", str(port))
+    config.conf().setData('services/tcp-connections/tcp-port', str(port))
 
 
 def enableUDP(enable=None):
@@ -1584,21 +1608,21 @@ def getUDPPort():
     """
     Get a port number for tranport_udp from user config.
     """
-    return config.conf().getInt("services/udp-datagrams/udp-port", DefaultUDPPort())
+    return config.conf().getInt('services/udp-datagrams/udp-port', DefaultUDPPort())
 
 
 def setUDPPort(port):
     """
     Set a port number for tranport_udp in the user config.
     """
-    config.conf().setData("services/udp-datagrams/udp-port", str(port))
+    config.conf().setData('services/udp-datagrams/udp-port', str(port))
 
 
 def getDHTPort():
     """
     Get a UDP port number for entangled "DHT" network.
     """
-    return config.conf().getInt("services/entangled-dht/udp-port", DefaultDHTPort())
+    return config.conf().getInt('services/entangled-dht/udp-port', DefaultDHTPort())
 
 
 def enablePROXY(enable=None):
@@ -1663,14 +1687,14 @@ def getHTTPPort():
     """
     Get a port number for tranport_http from user config.
     """
-    return config.conf().getInt("services/http-connections/http-port", DefaultTCPPort())
+    return config.conf().getInt('services/http-connections/http-port', DefaultTCPPort())
 
 
 def setHTTPPort(port):
     """
     Set a port number for tranport_http in the user config.
     """
-    config.conf().setData("services/http-connections/http-port", str(port))
+    config.conf().setData('services/http-connections/http-port', str(port))
 
 
 def getTransportPriority(proto):
@@ -1685,7 +1709,7 @@ def setDHTPort(port):
     """
     Set a UDP port number for entangled "DHT" network.
     """
-    config.conf().setData("services/entangled-dht/udp-port", str(port))
+    config.conf().setData('services/entangled-dht/udp-port', str(port))
 
 
 def enableTransport(proto, enable=None):
@@ -1748,7 +1772,7 @@ def getDebugLevelStr():
     """
     This is just for checking if it is set, the int() would throw an error.
     """
-    return config.conf().getData("logs/debug-level")
+    return config.conf().getData('logs/debug-level')
 
 
 def getDebugLevel():
@@ -1762,7 +1786,7 @@ def setDebugLevel(level):
     """
     Set debug level.
     """
-    config.conf().setData("logs/debug-level", str(level))
+    config.conf().setData('logs/debug-level', str(level))
 
 
 def enableWebStream(enable=None):
@@ -1862,7 +1886,8 @@ def getUpdatesModeValues():
     return (
         'install automatically',
         'only notify',
-        'turn off updates', )
+        'turn off updates',
+    )
 
 
 def getUpdatesSheduleData():
@@ -1980,6 +2005,7 @@ def enableBroadcastRouting(enable=None):
         return config.conf().getBool('services/broadcasting/routing-enabled')
     config.conf().setBool('services/broadcasting/routing-enabled', enable)
 
+
 #------------------------------------------------------------------------------
 #--- INITIALIZE BASE DIR ------------------------------------------------------
 #------------------------------------------------------------------------------
@@ -2019,6 +2045,7 @@ def RenameBaseDir(newdir):
         lg.open_log_file(logfilename, True)
     return True
 
+
 #------------------------------------------------------------------------------
 #--- USER SETTINGS VALIDATION -------------------------------------------------
 #------------------------------------------------------------------------------
@@ -2061,7 +2088,7 @@ def _setUpDefaultSettings():
 
     Every option must have a default value, howerver there are exceptions possible :-)
     """
-    from main import config_defaults
+    from bitdust.main import config_defaults
     config_defaults.reset(config.conf())
 
 
@@ -2149,6 +2176,8 @@ def _checkStaticDirectories():
         if _Debug:
             lg.out(_DebugLevel, 'settings.init want to create folder: ' + ChatHistoryDir())
         os.makedirs(ChatHistoryDir())
+
+
 #     if not os.path.exists(BlockchainDir()):
 #         if _Debug:
 #             lg.out(_DebugLevel, 'settings.init want to create folder: ' + BlockchainDir())
@@ -2180,8 +2209,10 @@ def _checkCustomDirectories():
     if config.conf().getString('paths/restore', '') == '':
         config.conf().setString('paths/restore', DefaultRestoreDir())
 
+
 #-------------------------------------------------------------------------------
 
+
 def main():
     lg.set_debug_level(24)
     init()
@@ -2202,8 +2233,8 @@ def main():
         else:
             print(child, config.conf().getData(child))
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     main()
