@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: shutdowner.
 
@@ -60,7 +59,6 @@ _DebugLevel = 6
 
 #------------------------------------------------------------------------------
 
-import os
 import sys
 
 try:
@@ -72,12 +70,12 @@ from twisted.internet.defer import DeferredList
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from main import initializer
-from main import settings
+from bitdust.main import initializer
+from bitdust.main import settings
 
 #------------------------------------------------------------------------------
 
@@ -94,27 +92,27 @@ def shutdown(x=None):
     Calls method ``shutdown()`` in other modules.
     """
     if _Debug:
-        lg.out(_DebugLevel, "shutdowner.shutdown " + str(x))
+        lg.out(_DebugLevel, 'shutdowner.shutdown ' + str(x))
     dl = []
     try:
-        from services import driver
-        # from main import control
-        from main import events
-        from main import listeners
-        from logs import weblog
-        from logs import webtraffic
-        from system import tmpfile
-        from system import run_upnpc
-        from raid import eccmap
-        from lib import net_misc
-        from updates import git_proc
-        from interface import api_rest_http_server
-        from interface import api_web_socket
-        # from interface import ftp_server
-        from contacts import identitydb
-        from crypt import my_keys
-        from userid import id_url
-        from userid import my_id
+        from bitdust.services import driver
+        # from bitdust.main import control
+        from bitdust.main import events
+        from bitdust.main import listeners
+        from bitdust.logs import weblog
+        from bitdust.logs import webtraffic
+        from bitdust.system import tmpfile
+        from bitdust.system import run_upnpc
+        from bitdust.raid import eccmap
+        from bitdust.lib import net_misc
+        from bitdust.updates import git_proc
+        from bitdust.interface import api_rest_http_server
+        from bitdust.interface import api_web_socket
+        # from bitdust.interface import ftp_server
+        from bitdust.contacts import identitydb
+        from bitdust.crypt import my_keys
+        from bitdust.userid import id_url
+        from bitdust.userid import my_id
         my_keys.shutdown()
         my_id.shutdown()
         identitydb.shutdown()
@@ -129,7 +127,6 @@ def shutdown(x=None):
         listeners.shutdown()
         events.shutdown()
         tmpfile.shutdown()
-        # control.shutdown()
         try:
             weblog.shutdown()
         except:
@@ -157,8 +154,10 @@ def shutdown(x=None):
     # TODO: rework all shutdown() methods to return deferred objects
     return DeferredList(dl)
 
+
 #------------------------------------------------------------------------------
 
+
 def A(event=None, *args, **kwargs):
     global _Shutdowner
     if event is None:
@@ -175,8 +174,10 @@ def A(event=None, *args, **kwargs):
         _Shutdowner.event(event, *args, **kwargs)
     return _Shutdowner
 
+
 #------------------------------------------------------------------------------
 
+
 class Shutdowner(automat.Automat):
     """
     This is a state machine to manage a process of correctly finishing the
@@ -285,9 +286,7 @@ class Shutdowner(automat.Automat):
         _Shutdowner = None
         self.destroy()
         if _Debug:
-            lg.out(_DebugLevel, 'shutdowner.doDestroyMe %d machines left in memory:\n        %s' % (
-                len(automat.objects()), '\n        '.join(
-                    ['%d: %r' % (k, automat.by_index(k)) for k in automat.objects().keys()])))
+            lg.out(_DebugLevel, 'shutdowner.doDestroyMe %d machines left in memory:\n        %s' % (len(automat.objects()), '\n        '.join(['%d: %r' % (k, automat.by_index(k)) for k in automat.objects().keys()])))
 
         if self.enableMemoryProfile:
             try:
@@ -295,12 +294,12 @@ class Shutdowner(automat.Automat):
                 hp = hpy()
                 hp.setrelheap()
                 if _Debug:
-                    lg.out(_DebugLevel, 'hp.heap():\n'+str(hp.heap()))
-                    lg.out(_DebugLevel, 'hp.heap().byrcs:\n'+str(hp.heap().byrcs))
-                    lg.out(_DebugLevel, 'hp.heap().byvia:\n'+str(hp.heap().byvia))
+                    lg.out(_DebugLevel, 'hp.heap():\n' + str(hp.heap()))
+                    lg.out(_DebugLevel, 'hp.heap().byrcs:\n' + str(hp.heap().byrcs))
+                    lg.out(_DebugLevel, 'hp.heap().byvia:\n' + str(hp.heap().byvia))
             except:
                 if _Debug:
-                    lg.out(_DebugLevel, "guppy package is not installed")
+                    lg.out(_DebugLevel, 'guppy package is not installed')
 
     def _shutdown_restart(self, param=''):
         """
@@ -308,11 +307,11 @@ class Shutdowner(automat.Automat):
         program.
         """
         if _Debug:
-            lg.out(_DebugLevel, "shutdowner.shutdown_restart param=%s" % param)
+            lg.out(_DebugLevel, 'shutdowner.shutdown_restart param=%s' % param)
 
         def do_restart(param):
-            from lib import misc
-            from system import bpio
+            from bitdust.lib import misc
+            from bitdust.system import bpio
             settings.init()
             # appdata = settings.BaseDir()
             detach = False
@@ -320,15 +319,14 @@ class Shutdowner(automat.Automat):
                 detach = True
             misc.DoRestart(
                 param,
-                detach=detach,
-                # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
+                detach=detach,  # std_out=os.path.join(appdata, 'logs', 'stdout.log'),
                 # std_err=os.path.join(appdata, 'logs', 'stderr.log'),
             )
             settings.shutdown()
 
         def shutdown_finished(x, param):
             if _Debug:
-                lg.out(_DebugLevel, "shutdowner.shutdown_finished want to stop the reactor")
+                lg.out(_DebugLevel, 'shutdowner.shutdown_finished want to stop the reactor')
             reactor.addSystemEventTrigger('after', 'shutdown', do_restart, param)  # @UndefinedVariable
             reactor.stop()  # @UndefinedVariable
 
@@ -341,11 +339,11 @@ class Shutdowner(automat.Automat):
         the program.
         """
         if _Debug:
-            lg.out(_DebugLevel, "shutdowner.shutdown_exit")
+            lg.out(_DebugLevel, 'shutdowner.shutdown_exit')
 
         def shutdown_reactor_stop(x=None):
             if _Debug:
-                lg.out(_DebugLevel, "shutdowner.shutdown_reactor_stop want to stop the reactor")
+                lg.out(_DebugLevel, 'shutdowner.shutdown_reactor_stop want to stop the reactor')
             reactor.stop()  # @UndefinedVariable
 
         d = shutdown(x)
