@@ -20,8 +20,6 @@
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
 #
-
-
 """
 .. module:: id_rotator
 .. role:: red
@@ -74,20 +72,20 @@ from twisted.internet.defer import Deferred, DeferredList, CancelledError  # @Un
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import net_misc
-from lib import nameurl
-from lib import strng
+from bitdust.lib import net_misc
+from bitdust.lib import nameurl
+from bitdust.lib import strng
 
-from main import config
-from main import settings
+from bitdust.main import config
+from bitdust.main import settings
 
-from userid import identity
-from userid import known_servers
-from userid import my_id
+from bitdust.userid import identity
+from bitdust.userid import known_servers
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -95,6 +93,7 @@ _IdRotator = None
 
 #------------------------------------------------------------------------------
 
+
 def check():
     """
     Returns True/False via deferred object to report situation with my identity sources.
@@ -118,26 +117,19 @@ def run(preferred_servers={}, force=False):
     ir.automat('run', result_defer=result_defer, preferred_servers=preferred_servers, force=force)
     return result_defer
 
+
 #------------------------------------------------------------------------------
 
+
 class IdRotator(automat.Automat):
     """
     This class implements all the functionality of ``id_rotator()`` state machine.
     """
-
     def __init__(self, debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, publish_events=True, **kwargs):
         """
         Builds `id_rotator()` state machine.
         """
-        super(IdRotator, self).__init__(
-            name="id_rotator",
-            state="AT_STARTUP",
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            publish_events=publish_events,
-            **kwargs
-        )
+        super(IdRotator, self).__init__(name='id_rotator', state='AT_STARTUP', debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, publish_events=publish_events, **kwargs)
 
     def init(self):
         """
@@ -161,7 +153,7 @@ class IdRotator(automat.Automat):
                 self.state = 'FAILED'
                 self.doReportFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'ping-done' and ( self.isChecking(*args, **kwargs) or self.isHealthy(*args, **kwargs) ):
+            elif event == 'ping-done' and (self.isChecking(*args, **kwargs) or self.isHealthy(*args, **kwargs)):
                 self.state = 'DONE'
                 self.doReportDone(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
@@ -200,7 +192,7 @@ class IdRotator(automat.Automat):
                 self.state = 'DONE'
                 self.doReportDone(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'id-server-failed' or ( event == 'my-id-exist' and not self.isMyIdentityValid(*args, **kwargs) ):
+            elif event == 'id-server-failed' or (event == 'my-id-exist' and not self.isMyIdentityValid(*args, **kwargs)):
                 self.state = 'FAILED'
                 self.doReportFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
@@ -262,10 +254,13 @@ class IdRotator(automat.Automat):
                             tcp_port = settings.IdentityServerPort()
                         else:
                             host, web_port, tcp_port = parts
-                        self.preferred_servers[host] = (int(web_port), int(tcp_port), )
+                        self.preferred_servers[host] = (
+                            int(web_port),
+                            int(tcp_port),
+                        )
             except:
                 lg.exc()
-        self.preferred_servers = {strng.to_bin(k): v for k,v in self.preferred_servers.items()}
+        self.preferred_servers = {strng.to_bin(k): v for k, v in self.preferred_servers.items()}
         self.current_servers = []
         for idurl in my_id.getLocalIdentity().getSources(as_originals=True):
             self.current_servers.append(strng.to_bin(nameurl.GetHost(idurl)))
@@ -298,7 +293,7 @@ class IdRotator(automat.Automat):
             self.automat('no-id-servers-found')
             return
 
-        target_servers = {strng.to_bin(k): v for k,v in target_servers.items()}
+        target_servers = {strng.to_bin(k): v for k, v in target_servers.items()}
         target_hosts = list(target_servers.keys())
         random.shuffle(target_hosts)
         if _Debug:
@@ -348,7 +343,7 @@ class IdRotator(automat.Automat):
             if webport == 80:
                 webport = ''
             new_idurl = nameurl.UrlMake('http', strng.to_text(host), webport, my_id.getIDName() + '.xml')
-            d = net_misc.getPageTwisted(new_idurl, timeout=10)
+            d = net_misc.getPageTwisted(new_idurl, timeout=15)
             d.addCallback(_new_idurl_exist, new_idurl, pos)
             d.addErrback(_new_idurl_not_exist, new_idurl)
 
@@ -368,9 +363,8 @@ class IdRotator(automat.Automat):
             tcpport = int(tcpport)
             server_url = nameurl.UrlMake('http', strng.to_text(host), webport, '')
             if _Debug:
-                lg.out(_DebugLevel, 'id_rotator.doSelectNewIDServer._ping_one_server at %s known tcp port is %d' % (
-                    server_url, tcpport, ))
-            d = net_misc.getPageTwisted(server_url, timeout=10)
+                lg.out(_DebugLevel, 'id_rotator.doSelectNewIDServer._ping_one_server at %s known tcp port is %d' % (server_url, tcpport))
+            d = net_misc.getPageTwisted(server_url, timeout=15)
             d.addCallback(_server_replied, host, pos)
             d.addErrback(_server_failed, host, pos)
 
@@ -393,7 +387,7 @@ class IdRotator(automat.Automat):
         new_sources = []
         new_idurl = strng.to_bin(args[0])
         if _Debug:
-            lg.args(_DebugLevel, current_sources=current_sources, alive_idurls=self.alive_idurls, new_idurl=new_idurl, )
+            lg.args(_DebugLevel, current_sources=current_sources, alive_idurls=self.alive_idurls, new_idurl=new_idurl)
         # first get rid of "dead" sources
         for current_idurl in current_sources:
             if current_idurl not in self.alive_idurls:
@@ -412,10 +406,9 @@ class IdRotator(automat.Automat):
         if len(new_sources) > max_servers:
             all_new_sources = list(new_sources)
             new_sources = new_sources[max(0, len(new_sources) - max_servers):]
-            lg.warn('skip %d identity sources, require maximum %d sources' % (
-                len(all_new_sources)-len(new_sources), max_servers, ))
+            lg.warn('skip %d identity sources, require maximum %d sources' % (len(all_new_sources) - len(new_sources), max_servers))
         if len(new_sources) < min_servers:
-            additional_sources = self.possible_sources[:min_servers-len(new_sources)]
+            additional_sources = self.possible_sources[:min_servers - len(new_sources)]
             if additional_sources:
                 lg.warn('additional sources to be used: %r' % additional_sources)
                 new_sources.extend(additional_sources)
@@ -476,7 +469,7 @@ class IdRotator(automat.Automat):
 
         dl = []
         for idurl in my_id.getLocalIdentity().getSources(as_originals=True):
-            dl.append(net_misc.getPageTwisted(idurl, timeout=10))
+            dl.append(net_misc.getPageTwisted(idurl, timeout=15))
         d = DeferredList(dl, consumeErrors=True)
         d.addCallback(_cb)
         d.addErrback(_eb)
@@ -490,7 +483,10 @@ class IdRotator(automat.Automat):
         if event == 'ping-done':
             self.result_defer.callback((self._is_healthy(args[0]), False))
         elif event == 'my-id-exist':
-            self.result_defer.callback((True, self.rotated, ))
+            self.result_defer.callback((
+                True,
+                self.rotated,
+            ))
             # if self.rotated:
             #     events.send('my-identity-rotate-complete', data=dict())
 
@@ -622,7 +618,13 @@ class IdRotator(automat.Automat):
                 webport = int(self.known_servers[host][0])
             if not webport:
                 webport = _webport
-            url = net_misc.pack_address((host, webport, ), proto='http')
+            url = net_misc.pack_address(
+                (
+                    host,
+                    webport,
+                ),
+                proto='http',
+            )
             dlist.append(net_misc.http_post_data(
                 url=url,
                 data=payload,
@@ -636,7 +638,7 @@ class IdRotator(automat.Automat):
         my_sources = my_id.getLocalIdentity().getSources(as_originals=True)
         dl = []
         for idurl_bin in my_sources:
-            d = net_misc.getPageTwisted(idurl_bin, timeout=5)
+            d = net_misc.getPageTwisted(idurl_bin, timeout=15)
             dl.append(d)
         d = DeferredList(dl, consumeErrors=True)
         d.addCallback(self._do_check_ping_results)
@@ -655,7 +657,7 @@ class IdRotator(automat.Automat):
             lg.args(_DebugLevel, id_servers=id_servers)
         dl = []
         for url in id_servers:
-            d = net_misc.getPageTwisted(url, timeout=5)
+            d = net_misc.getPageTwisted(url, timeout=15)
             dl.append(d)
         d = DeferredList(dl, consumeErrors=True)
         d.addCallback(lambda result: self.automat('ping-done', []))
@@ -664,16 +666,18 @@ class IdRotator(automat.Automat):
     def _fallback_check_network_connected(self, err):
         if _Debug:
             lg.args(_DebugLevel, err)
-        from p2p import network_connector
+        from bitdust.p2p import network_connector
         if network_connector.A().state != 'CONNECTED':
             self.automat('ping-failed', err)
         else:
             self.automat('ping-done', [])
 
+
 #------------------------------------------------------------------------------
 
+
 def main():
-    from system import bpio
+    from bitdust.system import bpio
     bpio.init()
     settings.init()
     lg.set_debug_level(20)
@@ -685,7 +689,8 @@ def main():
     reactor.run()  # @UndefinedVariable
     settings.shutdown()
 
+
 #------------------------------------------------------------------------------
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
