@@ -24,8 +24,6 @@
 #
 #
 #
-
-
 """
 .. module:: online_status
 .. role:: red
@@ -62,7 +60,6 @@ EVENTS:
     * :red:`timer-20sec`
 """
 
-
 #------------------------------------------------------------------------------
 
 from __future__ import absolute_import
@@ -70,7 +67,7 @@ from __future__ import absolute_import
 #------------------------------------------------------------------------------
 
 _Debug = False
-_DebugLevel = 14
+_DebugLevel = 10
 
 #------------------------------------------------------------------------------
 
@@ -79,27 +76,27 @@ from twisted.internet.defer import Deferred
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import strng
-from lib import utime
+from bitdust.lib import strng
+from bitdust.lib import utime
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from main import events
-from main import listeners
+from bitdust.main import events
+from bitdust.main import listeners
 
-from p2p import ratings
-from p2p import commands
-from p2p import handshaker
+from bitdust.p2p import ratings
+from bitdust.p2p import commands
+from bitdust.p2p import handshaker
 
-from transport import callback
+from bitdust.transport import callback
 
-from userid import my_id
-from userid import id_url
-from userid import global_id
+from bitdust.userid import my_id
+from bitdust.userid import id_url
+from bitdust.userid import global_id
 
 #------------------------------------------------------------------------------
 
@@ -117,6 +114,7 @@ _OfflineCheckTask = None
 
 #------------------------------------------------------------------------------
 
+
 def init():
     """
     Called from top level code when the software is starting.
@@ -156,6 +154,7 @@ def shutdown():
 
 #------------------------------------------------------------------------------
 
+
 def online_statuses():
     global _OnlineStatusDict
     return _OnlineStatusDict
@@ -177,8 +176,10 @@ def check_create(idurl, keep_alive=True):
             lg.out(_DebugLevel, 'online_status.check_create instance for %r was not found, made a new with state OFFLINE' % idurl)
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def on_ping_failed(err, idurl=None, channel=None):
     if _Debug:
         lg.args(_DebugLevel, err=err, idurl=idurl, channel=channel)
@@ -216,11 +217,11 @@ def ping(idurl, channel=None, ack_timeout=15, ping_retries=0, keep_alive=False):
     return result
 
 
-def handshake(idurl, channel=None, ack_timeout=15, ping_retries=2, keep_alive=False):
+def handshake(idurl, channel=None, ack_timeout=None, ping_retries=2, keep_alive=False):
     """
     Immediately doing handshake with remote node by fetching remote identity file and then
     sending my own Identity() to remote peer and wait for an Ack() packet.
-    Returns Deferred object. 
+    Returns Deferred object.
     """
     idurl = strng.to_bin(idurl)
     if _Debug:
@@ -247,8 +248,10 @@ def handshake(idurl, channel=None, ack_timeout=15, ping_retries=2, keep_alive=Fa
     A(idurl, 'handshake', result, channel=channel, ack_timeout=ack_timeout, ping_retries=ping_retries, original_idurl=idurl.to_original())
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def isKnown(idurl):
     """
     Return `True` if state machine online_status() already exists for this
@@ -280,7 +283,10 @@ def isOnline(idurl):
     idurl = id_url.field(idurl)
     if not isKnown(idurl):
         return False
-    return A(idurl).state in ['CONNECTED', 'PING?', ]
+    return A(idurl).state in [
+        'CONNECTED',
+        'PING?',
+    ]
 
 
 def isOffline(idurl):
@@ -420,8 +426,10 @@ def countOnlineAmong(idurls_list):
                 num += 1
     return num
 
+
 #------------------------------------------------------------------------------
 
+
 def add_online_status_listener_callback(idurl, callback_method, oldstate=None, newstate=None, callback_id=None):
     """
     Attach new listener callback to the corresponding ``online_contact()`` automat for node with ``idurl``.
@@ -447,14 +455,18 @@ def remove_online_status_listener_callback(idurl, callback_method=None, callback
         return False
     return online_status_instance.removeStateChangedCallback(cb=callback_method, callback_id=callback_id) > 0
 
+
 #------------------------------------------------------------------------------
 
+
 def populate_online_statuses():
     for online_s in online_statuses().values():
         listeners.push_snapshot('online_status', snap_id=online_s.idurl.to_text(), data=online_s.to_json())
 
+
 #------------------------------------------------------------------------------
 
+
 def OutboxStatus(pkt_out, status, error=''):
     """
     This method is called when raised a status report after sending a packet to
@@ -474,7 +486,7 @@ def OutboxStatus(pkt_out, status, error=''):
             if pkt_out.outpacket.OwnerID == my_id.getIDURL() and pkt_out.outpacket.CreatorID == my_id.getIDURL():
                 # if not handshaker.is_running(pkt_out.outpacket.RemoteID):
                 if _Debug:
-                    lg.dbg(_DebugLevel, 'ping packet %s addressed to %r was "unanswered"' % (pkt_out, pkt_out.outpacket.RemoteID, ))
+                    lg.dbg(_DebugLevel, 'ping packet %s addressed to %r was "unanswered"' % (pkt_out, pkt_out.outpacket.RemoteID))
     else:
         if _Debug:
             lg.dbg(_DebugLevel, 'packet %s is "%s" with %s error: %r' % (pkt_out, status, pkt_out.outpacket, error))
@@ -510,7 +522,7 @@ def Inbox(newpacket, info, status, message):
 def PacketSendingTimeout(remoteID, packetID):
     """
     Called from ``p2p.io_throttle`` when some packet is timed out.
- 
+
     Right now this do nothing, to be improved.
     """
     global _ShutdownFlag
@@ -523,8 +535,10 @@ def PacketSendingTimeout(remoteID, packetID):
     A(remoteID, 'sent-timeout', packetID)
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def RunOfflineChecks():
     for o_status in list(_OnlineStatusDict.values()):
         if o_status.state != 'OFFLINE':
@@ -534,7 +548,7 @@ def RunOfflineChecks():
             # if no checks done yet but he is offline: ping user
             o_status.automat('offline-check')
             continue
-        if utime.get_sec1970() - o_status.latest_check_time > 10 * 60:
+        if utime.get_sec1970() - o_status.latest_check_time > 10*60:
             # user is offline and latest check was sent a while ago: lets try to ping user again
             o_status.automat('offline-check')
             continue
@@ -544,8 +558,10 @@ def RunOfflineChecks():
             continue
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def A(idurl, event=None, *args, **kwargs):
     """
     Access method to interact with a state machine created for given contact.
@@ -570,8 +586,10 @@ def A(idurl, event=None, *args, **kwargs):
         _OnlineStatusDict[idurl].automat(event, *args, **kwargs)
     return _OnlineStatusDict[idurl]
 
+
 #------------------------------------------------------------------------------
 
+
 class OnlineStatus(automat.Automat):
     """
     This class implements all the functionality of ``online_status()`` state machine.
@@ -580,7 +598,7 @@ class OnlineStatus(automat.Automat):
     timers = {
         'timer-1min': (60, ['CONNECTED']),
         'timer-20sec': (20.0, ['PING?']),
-        }
+    }
 
     def __init__(self, idurl, name, state, debug_level=0, log_events=False, log_transitions=False, **kwargs):
         """
@@ -590,14 +608,7 @@ class OnlineStatus(automat.Automat):
         self.latest_inbox_time = None
         self.latest_check_time = None
         self.keep_alive = False
-        super(OnlineStatus, self).__init__(
-            name=name,
-            state=state,
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            **kwargs
-        )
+        super(OnlineStatus, self).__init__(name=name, state=state, debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, **kwargs)
         if _Debug:
             lg.out(_DebugLevel, 'online_status.ContactStatus %s %s %s' % (name, state, idurl))
 
@@ -765,7 +776,7 @@ class OnlineStatus(automat.Automat):
                 d = handshaker.ping(
                     idurl=original_idurl,
                     ack_timeout=ack_timeout,
-                    cache_timeout=10,
+                    cache_timeout=15,
                     ping_retries=ping_retries,
                     force_cache=True,
                     channel='offline_ping',
@@ -775,7 +786,7 @@ class OnlineStatus(automat.Automat):
                 d = handshaker.ping(
                     idurl=original_idurl,
                     ack_timeout=ack_timeout,
-                    cache_timeout=10,
+                    cache_timeout=15,
                     ping_retries=ping_retries,
                     force_cache=True,
                     channel='idle_ping',
@@ -790,7 +801,7 @@ class OnlineStatus(automat.Automat):
         """
         to_be_remembered = True
         if self.latest_inbox_time:
-            if utime.get_sec1970() - self.latest_inbox_time < 5 * 60:
+            if utime.get_sec1970() - self.latest_inbox_time < 5*60:
                 to_be_remembered = False
         if to_be_remembered:
             ratings.remember_connected_time(self.idurl.to_bin())
@@ -868,8 +879,11 @@ class OnlineStatus(automat.Automat):
         except:
             lg.exc()
         if _Debug:
-            lg.out(_DebugLevel, 'online_status._on_ping_success %r : %r' % (self.idurl, result, ))
-        self.automat('shook-up-hands', (response, info, ))
+            lg.out(_DebugLevel, 'online_status._on_ping_success %r : %r' % (self.idurl, result))
+        self.automat('shook-up-hands', (
+            response,
+            info,
+        ))
         return None
 
     def _on_ping_failed(self, err):
@@ -878,7 +892,6 @@ class OnlineStatus(automat.Automat):
         except:
             msg = str(err)
         if _Debug:
-            lg.out(_DebugLevel, 'online_status._on_ping_failed %r : %s' % (self.idurl, msg, ))
+            lg.out(_DebugLevel, 'online_status._on_ping_failed %r : %s' % (self.idurl, msg))
         self.automat('ping-failed', err)
         return None
-
