@@ -20,7 +20,6 @@
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
 #
-
 """
 .. module:: p2p_connector.
 
@@ -67,7 +66,7 @@ from six.moves import range
 #------------------------------------------------------------------------------
 
 _Debug = False
-_DebugLevel = 12
+_DebugLevel = 16
 
 #------------------------------------------------------------------------------
 
@@ -77,31 +76,31 @@ from twisted.internet.task import LoopingCall  #@UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from main import settings
-from main import config
-from main import events
+from bitdust.main import settings
+from bitdust.main import config
+from bitdust.main import events
 
-from lib import net_misc
-from lib import strng
+from bitdust.lib import net_misc
+from bitdust.lib import strng
 
-from automats import automat
+from bitdust.automats import automat
 
-from contacts import identitycache
-from contacts import contactsdb
+from bitdust.contacts import identitycache
+from bitdust.contacts import contactsdb
 
-from transport import callback
+from bitdust.transport import callback
 
-from services import driver
+from bitdust.services import driver
 
-from p2p import propagate
-from p2p import network_connector
+from bitdust.p2p import propagate
+from bitdust.p2p import network_connector
 
-from userid import identity
-from userid import my_id
+from bitdust.userid import identity
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -120,7 +119,9 @@ def inbox(newpacket, info, status, message):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_connector.inbox %s %s' % (status, newpacket))
     # here need to mark this protocol as working
-    if info.proto in ['tcp', ]:
+    if info.proto in [
+        'tcp',
+    ]:
         if not net_misc.IpIsLocal(strng.to_text(info.host).split(':')[0]):
             # but we want to check that this packet is come from the Internet, not our local network
             # because we do not want to use this proto as first method if it is not working for all
@@ -129,7 +130,9 @@ def inbox(newpacket, info, status, message):
                     lg.out(_DebugLevel - 6, 'p2p_connector.inbox [transport_%s] seems to work !!!!!!!!!!!!!!!!!!!!!' % info.proto)
                     lg.out(_DebugLevel - 6, '                    We got packet from %s://%s' % (info.proto, str(info.host)))
                 active_protos().add(info.proto)
-    elif info.proto in ['http', ]:
+    elif info.proto in [
+        'http',
+    ]:
         if not net_misc.IpIsLocal(strng.to_text(info.host).split(':')[0]):
             # but we want to check that this packet is come from the Internet, not our local network
             # because we do not want to use this proto as first method if it is not working for all
@@ -138,13 +141,17 @@ def inbox(newpacket, info, status, message):
                     lg.out(_DebugLevel - 6, 'p2p_connector.inbox [transport_%s] seems to work !!!!!!!!!!!!!!!!!!!!!' % info.proto)
                     lg.out(_DebugLevel - 6, '                    We got packet from %s://%s' % (info.proto, str(info.host)))
                 active_protos().add(info.proto)
-    elif info.proto in ['udp', ]:
+    elif info.proto in [
+        'udp',
+    ]:
         if info.proto not in active_protos():
             if _Debug:
                 lg.out(_DebugLevel - 6, 'p2p_connector.inbox [transport_%s] seems to work !!!!!!!!!!!!!!!!!!!!!' % info.proto)
                 lg.out(_DebugLevel - 6, '                    We got packet from %s://%s' % (info.proto, str(info.host)))
             active_protos().add(info.proto)
-    elif info.proto in ['proxy', ]:
+    elif info.proto in [
+        'proxy',
+    ]:
         if info.proto not in active_protos():
             if _Debug:
                 lg.out(_DebugLevel - 6, 'p2p_connector.inbox [transport_%s] seems to work !!!!!!!!!!!!!!!!!!!!!' % info.proto)
@@ -153,6 +160,7 @@ def inbox(newpacket, info, status, message):
     A('inbox-packet', (newpacket, info, status, message))
     return False
 
+
 #------------------------------------------------------------------------------
 
 
@@ -222,15 +230,15 @@ class P2PConnector(automat.Automat):
         if self.state == 'AT_STARTUP':
             if event == 'init':
                 self.state = 'NETWORK?'
-                self.NeedPropagate=True
+                self.NeedPropagate = True
                 self.doInit(*args, **kwargs)
                 network_connector.A('reconnect')
         #---NETWORK?---
         elif self.state == 'NETWORK?':
-            if ( event == 'network_connector.state' and args[0] == 'CONNECTED' ):
+            if (event == 'network_connector.state' and args[0] == 'CONNECTED'):
                 self.state = 'MY_IDENTITY'
                 self.doUpdateMyIdentity(event, *args, **kwargs)
-            elif ( event == 'network_connector.state' and args[0] == 'DISCONNECTED' ):
+            elif (event == 'network_connector.state' and args[0] == 'DISCONNECTED'):
                 self.state = 'DISCONNECTED'
         #---INCOMMING?---
         elif self.state == 'INCOMMING?':
@@ -238,56 +246,56 @@ class P2PConnector(automat.Automat):
                 self.state = 'MY_IDENTITY'
                 self.doUpdateMyIdentity(event, *args, **kwargs)
                 self.doPopBestProto(*args, **kwargs)
-            elif event == 'timer-20sec' or ( event == 'network_connector.state' and args[0] == 'DISCONNECTED' ):
-                self.state = 'DISCONNECTED'
-                self.doInitRatings(*args, **kwargs)
-            elif event == 'check-synchronize' or ( event == 'network_connector.state' and args[0] == 'CONNECTED' ):
-                self.state = 'MY_IDENTITY'
-                self.doUpdateMyIdentity(event, *args, **kwargs)
-            elif ( event == 'instant' and not self.isAnyPeersKnown(*args, **kwargs) ) or ( event == 'inbox-packet' and self.isUsingBestProto(*args, **kwargs) ):
+            elif (event == 'instant' and not self.isAnyPeersKnown(*args, **kwargs)) or (event == 'inbox-packet' and self.isUsingBestProto(*args, **kwargs)):
                 self.state = 'CONNECTED'
                 self.doInitRatings(*args, **kwargs)
                 self.doRestartCustomersRejector(*args, **kwargs)
+            elif event == 'timer-20sec' or (event == 'network_connector.state' and args[0] == 'DISCONNECTED'):
+                self.state = 'DISCONNECTED'
+                self.doInitRatings(*args, **kwargs)
+            elif event == 'check-synchronize' or (event == 'network_connector.state' and args[0] == 'CONNECTED'):
+                self.state = 'MY_IDENTITY'
+                self.doUpdateMyIdentity(event, *args, **kwargs)
         #---CONNECTED---
         elif self.state == 'CONNECTED':
             if event == 'ping-contact':
                 self.doSendMyIdentity(*args, **kwargs)
-            elif ( event == 'network_connector.state' and args[0] == 'DISCONNECTED' ):
+            elif (event == 'network_connector.state' and args[0] not in ['CONNECTED', 'DISCONNECTED']):
+                self.state = 'NETWORK?'
+            elif (event == 'network_connector.state' and args[0] == 'DISCONNECTED'):
                 self.state = 'DISCONNECTED'
-            elif event == 'check-synchronize' or ( event == 'network_connector.state' and args[0] == 'CONNECTED' ):
+            elif event == 'check-synchronize' or (event == 'network_connector.state' and args[0] == 'CONNECTED'):
                 self.state = 'MY_IDENTITY'
                 self.doUpdateMyIdentity(event, *args, **kwargs)
-            elif ( event == 'network_connector.state' and args[0] not in [ 'CONNECTED' , 'DISCONNECTED' ] ):
-                self.state = 'NETWORK?'
         #---DISCONNECTED---
         elif self.state == 'DISCONNECTED':
-            if event == 'ping-contact':
-                self.doSendMyIdentity(*args, **kwargs)
-            elif event == 'inbox-packet' or event == 'check-synchronize' or ( ( event == 'network_connector.state' and args[0] == 'CONNECTED' ) ):
+            if event == 'inbox-packet' or event == 'check-synchronize' or ((event == 'network_connector.state' and args[0] == 'CONNECTED')):
                 self.state = 'MY_IDENTITY'
                 self.doUpdateMyIdentity(event, *args, **kwargs)
-            elif ( event == 'network_connector.state' and args[0] not in [ 'CONNECTED', 'DISCONNECTED', ] ):
+            elif event == 'ping-contact':
+                self.doSendMyIdentity(*args, **kwargs)
+            elif (event == 'network_connector.state' and args[0] not in ['CONNECTED', 'DISCONNECTED']):
                 self.state = 'NETWORK?'
         #---MY_IDENTITY---
         elif self.state == 'MY_IDENTITY':
             if event == 'my-id-updated' and self.isMyContactsChanged(*args, **kwargs):
                 self.state = 'NETWORK?'
-                self.NeedPropagate=True
+                self.NeedPropagate = True
                 network_connector.A('check-reconnect')
-            elif event == 'my-id-updated' and not self.isMyContactsChanged(*args, **kwargs) and ( self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs) ):
+            elif event == 'my-id-updated' and not self.isMyContactsChanged(*args, **kwargs) and (self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs)):
                 self.state = 'PROPAGATE'
                 self.doCheckRotatePropagateMyIdentity(*args, **kwargs)
-            elif event == 'my-id-updated' and not ( self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs) ) and ( network_connector.A().state is 'CONNECTED' ):
+            elif event == 'my-id-updated' and not (self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs)) and (network_connector.A().state == 'CONNECTED'):
                 self.state = 'CONNECTED'
-            elif event == 'my-id-updated' and not ( self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs) ) and ( network_connector.A().state is not 'CONNECTED' ):
+            elif event == 'my-id-updated' and not (self.NeedPropagate or self.isMyIdentityChanged(*args, **kwargs)) and (network_connector.A().state != 'CONNECTED'):
                 self.state = 'DISCONNECTED'
         #---PROPAGATE---
         elif self.state == 'PROPAGATE':
             if event == 'my-id-propagated':
                 self.state = 'INCOMMING?'
-                self.NeedPropagate=False
+                self.NeedPropagate = False
                 self.doRestartFireHire(*args, **kwargs)
-            elif ( ( event == 'network_connector.state' and args[0] == 'CONNECTED' ) ) or event == 'check-synchronize':
+            elif ((event == 'network_connector.state' and args[0] == 'CONNECTED')) or event == 'check-synchronize':
                 self.state = 'MY_IDENTITY'
                 self.doUpdateMyIdentity(event, *args, **kwargs)
         return None
@@ -357,7 +365,7 @@ class P2PConnector(automat.Automat):
         """
         if driver.is_on('service_customer_patrol'):
             # TODO: move this into a callback inside service_customer_patrol
-            from supplier import customers_rejector
+            from bitdust.supplier import customers_rejector
             customers_rejector.A('restart')
 
     def doRestartFireHire(self, *args, **kwargs):
@@ -366,7 +374,7 @@ class P2PConnector(automat.Automat):
         """
         if driver.is_on('service_employer'):
             # TODO: use events instead
-            from customer import fire_hire
+            from bitdust.customer import fire_hire
             fire_hire.A('restart')
 
     def _check_to_use_best_proto(self):
@@ -477,8 +485,7 @@ class P2PConnector(automat.Automat):
         if first != 'tcp' and 'tcp' in active_protos():
             wantedproto = 'tcp'
         if _Debug:
-            lg.out(_DebugLevel - 6, 'p2p_connector.PopWorkingProto will pop %s contact order=%s active_protos()=%s' % (
-                wantedproto, str(order), str(active_protos())))
+            lg.out(_DebugLevel - 6, 'p2p_connector.PopWorkingProto will pop %s contact order=%s active_protos()=%s' % (wantedproto, str(order), str(active_protos())))
         # now move best proto on the top
         # other users will use this method to send to us
         lid.popProtoContact(wantedproto)
@@ -517,9 +524,9 @@ class P2PConnector(automat.Automat):
 
     def _do_propagate(self, result, rotated):
         if _Debug:
-            lg.out(_DebugLevel, 'p2p_connector._do_propagate rotated=%r result=%r' % (rotated, result, ))
+            lg.out(_DebugLevel, 'p2p_connector._do_propagate rotated=%r result=%r' % (rotated, result))
         if driver.is_on('service_entangled_dht'):
-            from dht import dht_service
+            from bitdust.dht import dht_service
             dht_service.set_node_data('idurl', my_id.getIDURL().to_text())
         else:
             lg.warn('DHT node local store was not updated with my latest IDURL, service_entangled_dht was OFF')
@@ -533,8 +540,7 @@ class P2PConnector(automat.Automat):
         d.addCallback(lambda x: self.automat('my-id-propagated'))
         if rotated:
             d.addBoth(lambda x: events.send('my-identity-rotate-complete', data=dict()))
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_propagate')
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_propagate')
         d.addErrback(self._on_propagate_failed)
         # d.addTimeout(30, clock=reactor)
         return result
@@ -559,8 +565,7 @@ class P2PConnector(automat.Automat):
             return None
         d = propagate.update()
         d.addCallback(self._do_propagate, rotated)
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_update')
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_update')
         d.addErrback(self._on_update_failed)
         return ret
 
@@ -570,26 +575,27 @@ class P2PConnector(automat.Automat):
         check_result, rotated = ret
         if check_result:
             lg.info('identity sources are healthy, send my identity now')
-            self._do_update((True, False, ))
+            self._do_update((
+                True,
+                False,
+            ))
             return None
         lg.err('identity sources are not healthy, will execute identity rotate flow now')
-        from p2p import id_rotator
+        from bitdust.p2p import id_rotator
         d = id_rotator.run()
         d.addCallback(self._do_update)
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_rotate')
-        d.addErrback(lambda _: self._do_update((False, False, )))
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_rotate')
+        d.addErrback(lambda _: self._do_update((False, False)))
         return ret
 
     def _do_check(self, ret):
         if _Debug:
             lg.out(_DebugLevel, 'p2p_connector._do_check ret=%r' % repr(ret))
-        from p2p import id_rotator
+        from bitdust.p2p import id_rotator
         d = id_rotator.check()
         d.addCallback(self._do_rotate)
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_check')
-        d.addErrback(lambda _: self._do_rotate((False, False, )))
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='_check_rotate_propagate_my_identity._do_check')
+        d.addErrback(lambda _: self._do_rotate((False, False)))
         return ret
 
     def _check_rotate_propagate_my_identity(self):
