@@ -71,13 +71,14 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-import logs.lg
+import bitdust.logs.lg
 
-import raid.eccmap
-import raid.raidutils
+import bitdust.raid.eccmap
+import bitdust.raid.raidutils
 
 #------------------------------------------------------------------------------
 
+
 def RoundupFile(filename, stepsize):
     """
     For some things we need to have files which are round sizes, for example
@@ -94,7 +95,7 @@ def RoundupFile(filename, stepsize):
     if mod > 0:
         increase = stepsize - mod
         f = open(filename, 'ab')
-        f.write(b' ' * increase)
+        f.write(b' '*increase)
         f.close()
 
 
@@ -103,7 +104,7 @@ def ReadBinaryFile(filename):
         return b''
     if not os.access(filename, os.R_OK):
         return b''
-    f = open(filename, "rb")
+    f = open(filename, 'rb')
     data = f.read()
     f.close()
     return data
@@ -117,10 +118,11 @@ def WriteFile(filename, data):
     s = data
     if not isinstance(s, binary_type):
         s = s.encode('utf-8')
-    f = open(filename, "wb")
+    f = open(filename, 'wb')
     f.write(s)
     f.close()
 
+
 #------------------------------------------------------------------------------
 
 
@@ -143,17 +145,17 @@ def do_in_memory(filename, eccmapname, version, blockNumber, targetDir, threshol
             with open('/tmp/raid.log', 'a') as logfile:
                 logfile.write(u'make filename=%s eccmapname=%s blockNumber=%s\n' % (repr(filename), eccmapname, blockNumber))
         INTSIZE = 4
-        myeccmap = raid.eccmap.eccmap(eccmapname)
+        myeccmap = bitdust.raid.eccmap.eccmap(eccmapname)
         # any padding at end and block.Length fixes
-        RoundupFile(filename, myeccmap.datasegments * INTSIZE)
+        RoundupFile(filename, myeccmap.datasegments*INTSIZE)
         wholefile = ReadBinaryFileAsArray(filename)
         length = len(wholefile)
-        length = length * 4
-        seglength = (length + myeccmap.datasegments - 1) / myeccmap.datasegments
+        length = length*4
+        seglength = (length + myeccmap.datasegments - 1)/myeccmap.datasegments
 
         # dict of data segments
         sds = {}
-        for seg_num, chunk in enumerate(raid.raidutils.chunks(wholefile, int(seglength / 4))):
+        for seg_num, chunk in enumerate(bitdust.raid.raidutils.chunks(wholefile, int(seglength/4))):
             FileName = targetDir + '/' + str(blockNumber) + '-' + str(seg_num) + '-Data'
             with open(FileName, mode='wb') as f:
                 chunk_to_write = copy.copy(chunk)
@@ -161,9 +163,9 @@ def do_in_memory(filename, eccmapname, version, blockNumber, targetDir, threshol
                 sds[seg_num] = iter(chunk)
                 f.write(chunk_to_write)
 
-        psds_list = raid.raidutils.build_parity(
+        psds_list = bitdust.raid.raidutils.build_parity(
             sds,
-            int(seglength / INTSIZE),
+            int(seglength/INTSIZE),
             myeccmap.datasegments,
             myeccmap,
             myeccmap.paritysegments,
@@ -181,19 +183,13 @@ def do_in_memory(filename, eccmapname, version, blockNumber, targetDir, threshol
         return dataNum, parityNum
 
     except:
-        logs.lg.exc()
+        bitdust.logs.lg.exc()
         return -1, -1
 
 
 def main():
-    do_in_memory(
-        filename=sys.argv[1],
-        eccmapname=sys.argv[2],
-        version=sys.argv[3],
-        blockNumber=int(sys.argv[4]),
-        targetDir=sys.argv[5]
-    )
+    do_in_memory(filename=sys.argv[1], eccmapname=sys.argv[2], version=sys.argv[3], blockNumber=int(sys.argv[4]), targetDir=sys.argv[5])
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
