@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -54,22 +53,17 @@ from twisted.internet.defer import Deferred, DeferredList, succeed  # @Unresolve
 
 if __name__ == '__main__':
     import os.path as _p
-    sys.path.insert(
-        0, _p.abspath(
-            _p.join(
-                _p.dirname(
-                    _p.abspath(
-                        sys.argv[0])), '..')))
+    sys.path.insert(0, _p.abspath(_p.join(_p.dirname(_p.abspath(sys.argv[0])), '..')))
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from main import config
-from main import events
-from main import listeners
+from bitdust.main import config
+from bitdust.main import events
+from bitdust.main import listeners
 
 #------------------------------------------------------------------------------
 
@@ -198,7 +192,7 @@ def request(service_name, service_request_payload, request, info):
     try:
         result = svc.request(service_request_payload, request, info)
     except RequireSubclass:
-        from p2p import p2p_service
+        from bitdust.p2p import p2p_service
         lg.warn('service %s can not be requested remotely' % service_name)
         return p2p_service.SendFail(request, 'refused')
     except:
@@ -214,7 +208,7 @@ def cancel(service_name, service_cancel_payload, request, info):
     try:
         result = svc.cancel(service_cancel_payload, request, info)
     except RequireSubclass:
-        from p2p import p2p_service
+        from bitdust.p2p import p2p_service
         lg.warn('service %s can not be cancelled remotely' % service_name)
         return p2p_service.SendFail(request, 'refused')
     except:
@@ -222,6 +216,7 @@ def cancel(service_name, service_cancel_payload, request, info):
         return None
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -243,7 +238,7 @@ def init():
                 lg.out(_DebugLevel, '%s is hard disabled' % name)
             continue
         try:
-            py_mod = importlib.import_module('services.' + name)
+            py_mod = importlib.import_module('bitdust.services.' + name)
         except:
             if _Debug:
                 lg.out(_DebugLevel, '%s exception during module import' % name)
@@ -291,7 +286,7 @@ def build_order():
     while progress and not fail:
         progress = False
         counter += 1
-        if counter > len(enabled_services()) * len(enabled_services()):
+        if counter > len(enabled_services())*len(enabled_services()):
             lg.warn('dependency recursion')
             fail = True
             break
@@ -302,8 +297,7 @@ def build_order():
             for depend_name in svc.dependent_on():
                 if depend_name not in order:
                     fail = True
-                    lg.warn('dependency not satisfied: #%d:%s depend on %s' % (
-                        position, name, depend_name,))
+                    lg.warn('dependency not satisfied: #%d:%s depend on %s' % (position, name, depend_name))
                     break
                 depend_position = order.index(depend_name)
                 if depend_position > depend_position_max:
@@ -324,8 +318,7 @@ def start(services_list=[]):
     global _StartingDeferred
     global _StopingDeferred
     if _Debug:
-        lg.args(_DebugLevel, services_list=services_list,
-                starting=bool(_StartingDeferred), stoping=bool(_StopingDeferred))
+        lg.args(_DebugLevel, services_list=services_list, starting=bool(_StartingDeferred), stoping=bool(_StopingDeferred))
     if _StartingDeferred:
         lg.warn('driver.start already called')
         return _StartingDeferred
@@ -361,8 +354,7 @@ def stop(services_list=[]):
     global _StopingDeferred
     global _StartingDeferred
     if _Debug:
-        lg.args(_DebugLevel, services_list=services_list,
-                starting=bool(_StartingDeferred), stoping=bool(_StopingDeferred))
+        lg.args(_DebugLevel, services_list=services_list, starting=bool(_StartingDeferred), stoping=bool(_StopingDeferred))
     if _StopingDeferred:
         lg.warn('driver.stop already called')
         return _StopingDeferred
@@ -405,8 +397,10 @@ def resume(service_name, *args, **kwargs):
         return svc.resume(*args, **kwargs)
     return None
 
+
 #------------------------------------------------------------------------------
 
+
 def info(service_name):
     svc = services().get(service_name, None)
     if svc is None:
@@ -416,8 +410,10 @@ def info(service_name):
         return None
     return svc.to_json()
 
+
 #------------------------------------------------------------------------------
 
+
 def restart(service_name, wait_timeout=None):
     global _StopingDeferred
     global _StartingDeferred
@@ -427,25 +423,36 @@ def restart(service_name, wait_timeout=None):
         if _Debug:
             lg.out(_DebugLevel, 'driver.restart._on_started : %s with %s, dependencies_results=%r' % (service_name, start_result, dependencies_results))
         try:
-            stop_resp = {stop_result[0][1]: stop_result[0][0], }
+            stop_resp = {
+                stop_result[0][1]: stop_result[0][0],
+            }
         except:
-            stop_resp = {'stopped': str(stop_result), }
+            stop_resp = {
+                'stopped': str(stop_result),
+            }
         try:
-            start_resp = {start_result[0][1]: start_result[0][0], }
+            start_resp = {
+                start_result[0][1]: start_result[0][0],
+            }
         except:
-            start_resp = {'started': str(start_result), }
-        restart_result.callback([stop_resp, start_resp, ])
+            start_resp = {
+                'started': str(start_result),
+            }
+        restart_result.callback([
+            stop_resp,
+            start_resp,
+        ])
         return start_result
 
     def _on_failed(err):
-        lg.warn('failed service %s in driver.restart() : %r' % (service_name, err, ))
+        lg.warn('failed service %s in driver.restart() : %r' % (service_name, err))
         restart_result.errback(str(err))
         return None
 
     def _do_start(stop_result=None, dependencies_results=None):
         if _Debug:
             lg.out(_DebugLevel, 'driver.restart._do_start : %s' % service_name)
-        start_defer = start(services_list=[service_name, ])
+        start_defer = start(services_list=[service_name])
         start_defer.addCallback(_on_started, stop_result, dependencies_results)
         start_defer.addErrback(_on_failed)
         return start_defer
@@ -459,7 +466,7 @@ def restart(service_name, wait_timeout=None):
     def _do_stop(dependencies_results=None):
         if _Debug:
             lg.out(_DebugLevel, 'driver.restart._do_stop : %s' % service_name)
-        stop_defer = stop(services_list=[service_name, ])
+        stop_defer = stop(services_list=[service_name])
         stop_defer.addCallback(_on_stopped, dependencies_results)
         stop_defer.addErrback(_on_failed)
         return stop_defer
@@ -502,18 +509,27 @@ def restart(service_name, wait_timeout=None):
     dependencies.addErrback(_on_timeout)
     return restart_result
 
+
 #------------------------------------------------------------------------------
 
+
 def start_single(service_name):
     result = Deferred()
     _starting = Deferred()
     _stopping = Deferred()
 
     def _on_started(response):
-        if response in ['started', ]:
+        if response in [
+            'started',
+        ]:
             result.callback(True)
             return response
-        if response in ['not_installed', 'failed', 'depends_off', 'stopped', ]:
+        if response in [
+            'not_installed',
+            'failed',
+            'depends_off',
+            'stopped',
+        ]:
             result.callback(False)
             return response
         raise Exception('bad response: %r' % response)
@@ -525,7 +541,7 @@ def start_single(service_name):
         return response
 
     def _on_failed(err, action):
-        lg.warn('failed to %s service %s in driver.start_single()' % (action, service_name, ))
+        lg.warn('failed to %s service %s in driver.start_single()' % (action, service_name))
         return None
 
     _starting.addCallback(_on_started)
@@ -537,10 +553,15 @@ def start_single(service_name):
         return succeed(False)
     if svc.state == 'ON':
         return succeed(True)
-    if svc.state in ['STARTING', ]:
+    if svc.state in [
+        'STARTING',
+    ]:
         svc.add_callback(_starting)
         return result
-    if svc.state in ['STOPPING', 'INFLUENCE', ]:
+    if svc.state in [
+        'STOPPING',
+        'INFLUENCE',
+    ]:
         svc.add_callback(_stopping)
         return result
     svc.automat('start', _starting)
@@ -559,16 +580,22 @@ def stop_single(service_name):
         return response
 
     def _on_started(response):
-        if response in ['started', ]:
+        if response in [
+            'started',
+        ]:
             svc.automat('stop', _stopping)
             return response
-        if response in ['not_installed', 'failed', 'depends_off', ]:
+        if response in [
+            'not_installed',
+            'failed',
+            'depends_off',
+        ]:
             result.callback(True)
             return response
         raise Exception('bad response: %r' % response)
 
     def _on_failed(err, action):
-        lg.warn('failed to %s service %s in driver.stop_single()' % (action, service_name, ))
+        lg.warn('failed to %s service %s in driver.stop_single()' % (action, service_name))
         return None
 
     _starting.addCallback(_on_started)
@@ -580,17 +607,24 @@ def stop_single(service_name):
         return succeed(False)
     if svc.state == 'OFF':
         return succeed(True)
-    if svc.state in ['STARTING', ]:
+    if svc.state in [
+        'STARTING',
+    ]:
         svc.add_callback(_starting)
         return result
-    if svc.state in ['STOPPING', 'INFLUENCE', ]:
+    if svc.state in [
+        'STOPPING',
+        'INFLUENCE',
+    ]:
         svc.add_callback(_stopping)
         return result
     svc.automat('stop', _stopping)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def health_check(services_list=[]):
     if not services_list:
         services_list.extend(reversed(boot_up_order()))
@@ -613,8 +647,10 @@ def health_check(services_list=[]):
     health_result = DeferredList(dl, consumeErrors=True)
     return health_result
 
+
 #------------------------------------------------------------------------------
 
+
 def get_network_configuration(services_list=[]):
     if not services_list:
         services_list.extend(reversed(boot_up_order()))
@@ -650,8 +686,10 @@ def get_attached_dht_layers(services_list=[]):
             result[name] = dht_layers
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def populate_services():
     services_list = reversed(boot_up_order())
     for name in services_list:
@@ -662,8 +700,10 @@ def populate_services():
         svc_data['event'] = None
         listeners.push_snapshot('service', snap_id=name, data=svc_data)
 
+
 #------------------------------------------------------------------------------
 
+
 def do_finish_starting():
     global _StartingDeferred
     if _Debug:
@@ -677,8 +717,10 @@ def do_finish_stoping():
         lg.args(_DebugLevel, stoping=bool(_StopingDeferred))
     _StopingDeferred = None
 
+
 #------------------------------------------------------------------------------
 
+
 def on_service_callback(result, service_name):
     if _Debug:
         lg.out(_DebugLevel, 'driver.on_service_callback %s : [%s]' % (service_name, result))
@@ -776,6 +818,7 @@ def on_service_enabled_disabled(path, newvalue, oldvalue, result):
     else:
         lg.warn('%s not found: %s' % (svc_name, path))
 
+
 #------------------------------------------------------------------------------
 
 
@@ -798,11 +841,12 @@ class ServiceAlreadySuspended(Exception):
 class ServiceWasNotSuspended(Exception):
     pass
 
+
 #------------------------------------------------------------------------------
 
 
 def main():
-    from main import settings
+    from bitdust.main import settings
     lg.set_debug_level(20)
     settings.init()
     init()
