@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_backup_db
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -50,19 +49,23 @@ class BackupDBService(LocalService):
         ]
 
     def start(self):
-        from storage import backup_fs
-        from storage import index_synchronizer
+        from bitdust.storage import backup_fs
+        from bitdust.storage import index_synchronizer
         backup_fs.init()
         index_synchronizer.A('init')
         return True
 
     def stop(self):
-        from storage import backup_fs
-        from storage import index_synchronizer
+        from bitdust.storage import backup_fs
+        from bitdust.storage import index_synchronizer
         index_synchronizer.A('shutdown')
         backup_fs.shutdown()
         return True
 
     def health_check(self):
-        from storage import index_synchronizer
-        return index_synchronizer.A().state in ['IN_SYNC!', 'SENDING', 'REQUEST?', ]
+        from bitdust.storage import index_synchronizer
+        return index_synchronizer.A().state in [
+            'IN_SYNC!',
+            'SENDING',
+            'REQUEST?',
+        ]
