@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_backups
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -51,29 +50,25 @@ class BackupsService(LocalService):
         ]
 
     def start(self):
-        from storage import backup_control
-        from storage import backup_matrix
-        from storage import backup_monitor
-        from main.config import conf
-        # from main import control
-        from main import events
-        from main import listeners
-        from transport import callback
-        from p2p import p2p_connector
+        from bitdust.storage import backup_control
+        from bitdust.storage import backup_matrix
+        from bitdust.storage import backup_monitor
+        from bitdust.main.config import conf
+        # from bitdust.main import control
+        from bitdust.main import events
+        from bitdust.main import listeners
+        from bitdust.transport import callback
+        from bitdust.p2p import p2p_connector
         backup_control.init()
         backup_matrix.init()
         # backup_matrix.SetBackupStatusNotifyCallback(control.on_backup_stats)
         # backup_matrix.SetLocalFilesNotifyCallback(control.on_read_local_files)
         backup_monitor.A('init')
         backup_monitor.A('restart')
-        conf().addConfigNotifier('services/backups/keep-local-copies-enabled',
-                           self._on_keep_local_copies_modified)
-        conf().addConfigNotifier('services/backups/wait-suppliers-enabled',
-                           self._on_wait_suppliers_modified)
-        p2p_connector.A().addStateChangedCallback(
-            self._on_p2p_connector_state_changed, 'INCOMMING?', 'CONNECTED')
-        p2p_connector.A().addStateChangedCallback(
-            self._on_p2p_connector_state_changed, 'MY_IDENTITY', 'CONNECTED')
+        conf().addConfigNotifier('services/backups/keep-local-copies-enabled', self._on_keep_local_copies_modified)
+        conf().addConfigNotifier('services/backups/wait-suppliers-enabled', self._on_wait_suppliers_modified)
+        p2p_connector.A().addStateChangedCallback(self._on_p2p_connector_state_changed, 'INCOMMING?', 'CONNECTED')
+        p2p_connector.A().addStateChangedCallback(self._on_p2p_connector_state_changed, 'MY_IDENTITY', 'CONNECTED')
         callback.append_inbox_callback(self._on_inbox_packet_received)
         events.add_subscriber(self._on_my_identity_rotated, 'my-identity-rotated')
         events.add_subscriber(self._on_key_erased, 'key-erased')
@@ -83,12 +78,12 @@ class BackupsService(LocalService):
         return True
 
     def stop(self):
-        from storage import backup_monitor
-        from storage import backup_control
-        from transport import callback
-        from p2p import p2p_connector
-        from main import events
-        from main.config import conf
+        from bitdust.storage import backup_monitor
+        from bitdust.storage import backup_control
+        from bitdust.transport import callback
+        from bitdust.p2p import p2p_connector
+        from bitdust.main import events
+        from bitdust.main.config import conf
         events.remove_subscriber(self._on_key_erased, 'key-erased')
         events.remove_subscriber(self._on_my_identity_rotated, 'my-identity-rotated')
         callback.remove_inbox_callback(self._on_inbox_packet_received)
@@ -100,11 +95,17 @@ class BackupsService(LocalService):
         return True
 
     def health_check(self):
-        from storage import backup_monitor
-        return backup_monitor.A().state in ['READY', 'FIRE_HIRE', 'LIST_FILES', 'LIST_BACKUPS', 'REBUILDING', ]
+        from bitdust.storage import backup_monitor
+        return backup_monitor.A().state in [
+            'READY',
+            'FIRE_HIRE',
+            'LIST_FILES',
+            'LIST_BACKUPS',
+            'REBUILDING',
+        ]
 
     def _on_key_erased(self, evt):
-        from interface import api
+        from bitdust.interface import api
         ret = api.files_list(
             remote_path='',
             key_id=evt.data['key_id'],
@@ -116,42 +117,42 @@ class BackupsService(LocalService):
                 api.file_delete(one_file['remote_path'])
 
     def _on_keep_local_copies_modified(self, path, value, oldvalue, result):
-        from storage import backup_monitor
-        from logs import lg
+        from bitdust.storage import backup_monitor
+        from bitdust.logs import lg
         lg.warn('restarting backup_monitor() machine')
         backup_monitor.A('restart')
 
     def _on_wait_suppliers_modified(self, path, value, oldvalue, result):
-        from storage import backup_monitor
-        from logs import lg
+        from bitdust.storage import backup_monitor
+        from bitdust.logs import lg
         lg.warn('restarting backup_monitor() machine')
         backup_monitor.A('restart')
 
     def _on_p2p_connector_state_changed(self, oldstate, newstate, event_string, *args, **kwargs):
-        from storage import backup_monitor
+        from bitdust.storage import backup_monitor
         backup_monitor.A('restart')
 
     def _on_inbox_packet_received(self, newpacket, info, status, error_message):
-        from storage import backup_control
-        from p2p import commands
+        from bitdust.storage import backup_control
+        from bitdust.p2p import commands
         if newpacket.Command == commands.Files():
             return backup_control.on_files_received(newpacket, info)
         return False
 
     def _on_my_identity_rotated(self, evt):
-        from logs import lg
-        from lib import packetid
-        from storage import backup_matrix
+        from bitdust.logs import lg
+        from bitdust.lib import packetid
+        from bitdust.storage import backup_matrix
         backup_matrix.ReadLocalFiles()
         remote_files_ids = list(backup_matrix.remote_files().keys())
         for currentID in remote_files_ids:
             latestID = packetid.LatestBackupID(currentID)
             if latestID != currentID:
                 backup_matrix.remote_files()[latestID] = backup_matrix.remote_files().pop(currentID)
-                lg.info('detected backup ID change in remote_files() after identity rotate : %r -> %r' % (currentID, latestID, ))
+                lg.info('detected backup ID change in remote_files() after identity rotate : %r -> %r' % (currentID, latestID))
         remote_max_block_numbers_ids = list(backup_matrix.remote_max_block_numbers().keys())
         for currentID in remote_max_block_numbers_ids:
             latestID = packetid.LatestBackupID(currentID)
             if latestID != currentID:
                 backup_matrix.remote_max_block_numbers()[latestID] = backup_matrix.remote_max_block_numbers().pop(currentID)
-                lg.info('detected backup ID change in remote_max_block_numbers() after identity rotate : %r -> %r' % (currentID, latestID, ))
+                lg.info('detected backup ID change in remote_max_block_numbers() after identity rotate : %r -> %r' % (currentID, latestID))
