@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_keys_registry
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -49,10 +48,10 @@ class KeysRegistryService(LocalService):
         ]
 
     def start(self):
-        from transport import callback
-        from main import listeners
-        from crypt import my_keys
-        from access import key_ring
+        from bitdust.transport import callback
+        from bitdust.main import listeners
+        from bitdust.crypt import my_keys
+        from bitdust.access import key_ring
         key_ring.init()
         callback.add_outbox_callback(self._on_outbox_packet_sent)
         callback.append_inbox_callback(self._on_inbox_packet_received)
@@ -62,8 +61,8 @@ class KeysRegistryService(LocalService):
         return True
 
     def stop(self):
-        from transport import callback
-        from access import key_ring
+        from bitdust.transport import callback
+        from bitdust.access import key_ring
         callback.remove_inbox_callback(self._on_inbox_packet_received)
         callback.remove_outbox_callback(self._on_outbox_packet_sent)
         key_ring.shutdown()
@@ -71,21 +70,21 @@ class KeysRegistryService(LocalService):
 
     def request(self, json_payload, newpacket, info):
         # TODO: work in progress
-        # from main import events
-        from p2p import p2p_service
+        # from bitdust.main import events
+        from bitdust.p2p import p2p_service
         # events.send('key-registry-request', data=dict(idurl=newpacket.OwnerID))
         return p2p_service.SendAck(newpacket, 'accepted')
 
     def _on_outbox_packet_sent(self, pkt_out):
-        from p2p import commands
+        from bitdust.p2p import commands
         if pkt_out.outpacket.Command == commands.Key():
             # TODO: work in progress : need to store history of all keys transfers
             return True
         return False
 
     def _on_inbox_packet_received(self, newpacket, info, status, error_message):
-        from p2p import commands
-        from access import key_ring
+        from bitdust.p2p import commands
+        from bitdust.access import key_ring
         if newpacket.Command == commands.Key():
             # TODO: work in progress : need to store history of all keys transfers
             return key_ring.on_key_received(newpacket, info, status, error_message)
