@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_message_history
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -50,10 +49,10 @@ class MessageHistoryService(LocalService):
         ]
 
     def start(self):
-        from chat import message_database
-        from chat import message_keeper
-        from main import events
-        from main import listeners
+        from bitdust.chat import message_database
+        from bitdust.chat import message_keeper
+        from bitdust.main import events
+        from bitdust.main import listeners
         message_database.init()
         message_keeper.init()
         events.add_subscriber(self.on_key_registered, 'key-registered')
@@ -69,9 +68,9 @@ class MessageHistoryService(LocalService):
         return True
 
     def stop(self):
-        from chat import message_database
-        from chat import message_keeper
-        from main import events
+        from bitdust.chat import message_database
+        from bitdust.chat import message_keeper
+        from bitdust.main import events
         events.remove_subscriber(self.on_key_erased, 'key-erased')
         events.remove_subscriber(self.on_key_generated, 'key-generated')
         events.remove_subscriber(self.on_key_renamed, 'key-renamed')
@@ -93,16 +92,16 @@ class MessageHistoryService(LocalService):
         self.do_check_create_rename_key(evt.data['new_key_id'])
 
     def on_key_erased(self, evt):
-        from main import listeners
-        from crypt import my_keys
+        from bitdust.main import listeners
+        from bitdust.crypt import my_keys
         if evt.data['key_id'].startswith('group_'):
             local_key_id = my_keys.get_local_key_id(evt.data['key_id'])
             listeners.push_snapshot('conversation', snap_id=local_key_id, deleted=True)
 
     def do_check_create_rename_key(self, new_key_id):
-        from logs import lg
-        from crypt import my_keys
-        from chat import message_database
+        from bitdust.logs import lg
+        from bitdust.crypt import my_keys
+        from bitdust.chat import message_database
         try:
             new_public_key = my_keys.get_public_key_raw(new_key_id)
         except:
