@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_my_data
 """
 
 from __future__ import absolute_import
-from services.local_service import SlowStartingLocalService
+from bitdust.services.local_service import SlowStartingLocalService
 
 
 def create_service():
@@ -52,30 +51,29 @@ class MyDataService(SlowStartingLocalService):
 
     def init(self, **kwargs):
         SlowStartingLocalService.init(self, **kwargs)
-        from main import events
+        from bitdust.main import events
         events.add_subscriber(self._on_my_storage_ready, 'my-storage-ready')
         events.add_subscriber(self._on_my_storage_not_ready_yet, 'my-storage-not-ready-yet')
 
     def shutdown(self):
-        from main import events
+        from bitdust.main import events
         events.remove_subscriber(self._on_my_storage_not_ready_yet, 'my-storage-not-ready-yet')
         events.remove_subscriber(self._on_my_storage_ready, 'my-storage-ready')
         SlowStartingLocalService.shutdown(self)
 
     def start(self):
-        from logs import lg
-        from main import listeners
-        from storage import keys_synchronizer
-        from storage import index_synchronizer
-        from storage import backup_fs
+        from bitdust.logs import lg
+        from bitdust.main import listeners
+        from bitdust.storage import keys_synchronizer
+        from bitdust.storage import index_synchronizer
+        from bitdust.storage import backup_fs
         if keys_synchronizer.is_synchronized() and index_synchronizer.is_synchronized():
             self.confirm_service_started(result=True)
             if listeners.is_populate_requered('private_file'):
                 listeners.populate_later().remove('private_file')
                 backup_fs.populate_private_files()
         else:
-            lg.warn('can not start service_my_data right now, keys_synchronizer.is_synchronized=%r index_synchronizer.is_synchronized=%r' % (
-                keys_synchronizer.is_synchronized(), index_synchronizer.is_synchronized()))
+            lg.warn('can not start service_my_data right now, keys_synchronizer.is_synchronized=%r index_synchronizer.is_synchronized=%r' % (keys_synchronizer.is_synchronized(), index_synchronizer.is_synchronized()))
         return self.starting_deferred
 
     def stop(self):
@@ -85,10 +83,10 @@ class MyDataService(SlowStartingLocalService):
         return True
 
     def _on_my_storage_ready(self, evt):
-        from logs import lg
-        from main import listeners
-        from services import driver
-        from storage import backup_fs
+        from bitdust.logs import lg
+        from bitdust.main import listeners
+        from bitdust.services import driver
+        from bitdust.storage import backup_fs
         if self.starting_deferred:
             self.confirm_service_started(result=True)
             if listeners.is_populate_requered('private_file'):
@@ -100,8 +98,8 @@ class MyDataService(SlowStartingLocalService):
                 driver.start_single('service_my_data')
 
     def _on_my_storage_not_ready_yet(self, evt):
-        from logs import lg
-        from services import driver
+        from bitdust.logs import lg
+        from bitdust.services import driver
         if self.starting_deferred:
             self.confirm_service_started(result=Exception('my storage is not ready yet'))
         if driver.is_enabled('service_my_data'):
