@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_p2p_hookups
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -44,7 +43,7 @@ class P2PHookupsService(LocalService):
     config_path = 'services/p2p-hookups/enabled'
 
     def dependent_on(self):
-        from main import settings
+        from bitdust.main import settings
         depends = [
             'service_gateway',
             'service_identity_propagate',
@@ -57,23 +56,21 @@ class P2PHookupsService(LocalService):
 
     def start(self):
         from twisted.internet.defer import Deferred
-        from transport import callback
-        from main import events
-        from main import listeners
-        from p2p import online_status
-        from p2p import p2p_service
-        from p2p import p2p_connector
-        from p2p import network_connector
-        from p2p import ratings
+        from bitdust.transport import callback
+        from bitdust.main import events
+        from bitdust.main import listeners
+        from bitdust.p2p import online_status
+        from bitdust.p2p import p2p_service
+        from bitdust.p2p import p2p_connector
+        from bitdust.p2p import network_connector
+        from bitdust.p2p import ratings
         p2p_service.init()
         online_status.init()
         ratings.init()
         self._starting_defer = Deferred()
         p2p_connector.A('init')
-        p2p_connector.A().addStateChangedCallback(
-            self._on_p2p_connector_switched)
-        network_connector.A().addStateChangedCallback(
-            self._on_network_connector_switched)
+        p2p_connector.A().addStateChangedCallback(self._on_p2p_connector_switched)
+        network_connector.A().addStateChangedCallback(self._on_network_connector_switched)
         callback.append_inbox_callback(self._on_inbox_packet_received)
         callback.append_inbox_callback(p2p_service.inbox)
         events.add_subscriber(self._on_identity_url_changed, 'identity-url-changed')
@@ -84,22 +81,20 @@ class P2PHookupsService(LocalService):
         return True
 
     def stop(self):
-        from transport import callback
-        from main import events
-        from p2p import online_status
-        from p2p import p2p_service
-        from p2p import p2p_connector
-        from p2p import network_connector
-        from p2p import ratings
+        from bitdust.transport import callback
+        from bitdust.main import events
+        from bitdust.p2p import online_status
+        from bitdust.p2p import p2p_service
+        from bitdust.p2p import p2p_connector
+        from bitdust.p2p import network_connector
+        from bitdust.p2p import ratings
         events.remove_subscriber(self._on_my_identity_url_changed, 'my-identity-url-changed')
         events.remove_subscriber(self._on_identity_url_changed, 'identity-url-changed')
         callback.remove_inbox_callback(self._on_inbox_packet_received)
         callback.remove_inbox_callback(p2p_service.inbox)
         if network_connector.A():
-            network_connector.A().removeStateChangedCallback(
-                self._on_network_connector_switched)
-        p2p_connector.A().removeStateChangedCallback(
-            self._on_p2p_connector_switched)
+            network_connector.A().removeStateChangedCallback(self._on_network_connector_switched)
+        p2p_connector.A().removeStateChangedCallback(self._on_p2p_connector_switched)
         ratings.shutdown()
         online_status.shutdown()
         p2p_connector.Destroy()
@@ -107,7 +102,7 @@ class P2PHookupsService(LocalService):
         return True
 
     def _on_inbox_packet_received(self, newpacket, info, status, error_message):
-        from p2p import commands
+        from bitdust.p2p import commands
         if newpacket.Command == commands.RequestService():
             return self._on_request_service_received(newpacket, info)
         elif newpacket.Command == commands.CancelService():
@@ -116,12 +111,12 @@ class P2PHookupsService(LocalService):
 
     def _on_request_service_received(self, newpacket, info):
         from twisted.internet.defer import Deferred
-        from logs import lg
-        from lib import serialization
-        from services import driver
-        from p2p import p2p_service
-        from transport import packet_out
-        if len(newpacket.Payload) > 1024 * 10:
+        from bitdust.logs import lg
+        from bitdust.lib import serialization
+        from bitdust.services import driver
+        from bitdust.p2p import p2p_service
+        from bitdust.transport import packet_out
+        if len(newpacket.Payload) > 1024*10:
             lg.warn('too long payload')
             p2p_service.SendFail(newpacket, 'too long payload')
             return True
@@ -134,9 +129,9 @@ class P2PHookupsService(LocalService):
             p2p_service.SendFail(newpacket, 'json payload invalid')
             return True
         service_name = str(json_payload['name'])
-        lg.out(self.debug_level, "service_p2p_hookups.RequestService {%s} from %s" % (service_name, newpacket.OwnerID, ))
+        lg.out(self.debug_level, 'service_p2p_hookups.RequestService {%s} from %s' % (service_name, newpacket.OwnerID))
         if not driver.is_exist(service_name):
-            lg.warn("got wrong payload in %s" % service_name)
+            lg.warn('got wrong payload in %s' % service_name)
             p2p_service.SendFail(newpacket, 'service %s not exist' % service_name)
             return True
         if not driver.is_on(service_name):
@@ -149,22 +144,22 @@ class P2PHookupsService(LocalService):
             p2p_service.SendFail(newpacket, 'request processing failed with exception')
             return True
         if not result:
-            lg.out(self.debug_level, "service_p2p_hookups._send_request_service SKIP request %s" % service_name)
+            lg.out(self.debug_level, 'service_p2p_hookups._send_request_service SKIP request %s' % service_name)
             return False
         if isinstance(result, Deferred):
-            lg.out(self.debug_level, "service_p2p_hookups._send_request_service fired delayed execution")
+            lg.out(self.debug_level, 'service_p2p_hookups._send_request_service fired delayed execution')
         elif isinstance(result, packet_out.PacketOut):
-            lg.out(self.debug_level, "service_p2p_hookups._send_request_service outbox packet sent")
+            lg.out(self.debug_level, 'service_p2p_hookups._send_request_service outbox packet sent')
         return True
 
     def _on_cancel_service_received(self, newpacket, info):
         from twisted.internet.defer import Deferred
-        from logs import lg
-        from lib import serialization
-        from services import driver
-        from p2p import p2p_service
-        from transport import packet_out
-        if len(newpacket.Payload) > 1024 * 10:
+        from bitdust.logs import lg
+        from bitdust.lib import serialization
+        from bitdust.services import driver
+        from bitdust.p2p import p2p_service
+        from bitdust.transport import packet_out
+        if len(newpacket.Payload) > 1024*10:
             p2p_service.SendFail(newpacket, 'too long payload')
             return True
         try:
@@ -175,9 +170,9 @@ class P2PHookupsService(LocalService):
             p2p_service.SendFail(newpacket, 'json payload invalid')
             return True
         service_name = json_payload['name']
-        lg.out(self.debug_level, "service_p2p_hookups.CancelService {%s} from %s" % (service_name, newpacket.OwnerID, ))
+        lg.out(self.debug_level, 'service_p2p_hookups.CancelService {%s} from %s' % (service_name, newpacket.OwnerID))
         if not driver.is_exist(service_name):
-            lg.warn("got wrong payload in %s" % newpacket)
+            lg.warn('got wrong payload in %s' % newpacket)
             p2p_service.SendFail(newpacket, 'service %s not exist' % service_name)
             return True
         if not driver.is_on(service_name):
@@ -190,12 +185,12 @@ class P2PHookupsService(LocalService):
             p2p_service.SendFail(newpacket, 'request processing failed with exception')
             return True
         if not result:
-            lg.out(self.debug_level, "service_p2p_hookups._send_cancel_service SKIP request %s" % service_name)
+            lg.out(self.debug_level, 'service_p2p_hookups._send_cancel_service SKIP request %s' % service_name)
             return False
         if isinstance(result, Deferred):
-            lg.out(self.debug_level, "service_p2p_hookups._send_cancel_service fired delayed execution")
+            lg.out(self.debug_level, 'service_p2p_hookups._send_cancel_service fired delayed execution')
         elif isinstance(result, packet_out.PacketOut):
-            lg.out(self.debug_level, "service_p2p_hookups._send_cancel_service outbox packet sent")
+            lg.out(self.debug_level, 'service_p2p_hookups._send_cancel_service outbox packet sent')
         return True
 
     def _on_p2p_connector_switched(self, oldstate, newstate, evt, *args, **kwargs):
@@ -205,17 +200,17 @@ class P2PHookupsService(LocalService):
                 self._starting_defer = None
 
     def _on_network_connector_switched(self, oldstate, newstate, evt, *args, **kwargs):
-        from p2p import p2p_connector
+        from bitdust.p2p import p2p_connector
         if oldstate != newstate:
             if newstate == 'CONNECTED' or newstate == 'DISCONNECTED':
                 p2p_connector.A('network_connector.state', newstate)
 
     def _on_identity_url_changed(self, evt):
         from twisted.internet import reactor  # @UnresolvedImport
-        from logs import lg
-        from userid import id_url
-        from userid import global_id
-        from p2p import online_status
+        from bitdust.logs import lg
+        from bitdust.userid import id_url
+        from bitdust.userid import global_id
+        from bitdust.p2p import online_status
         for idurl, inst in online_status.online_statuses().items():
             if idurl == id_url.field(evt.data['old_idurl']):
                 idurl.refresh(replace_original=True)
@@ -223,12 +218,12 @@ class P2PHookupsService(LocalService):
                 inst.name = 'online_%s' % global_id.UrlToGlobalID(idurl)
                 inst.automat('shook-up-hands')
                 reactor.callLater(0, inst.automat, 'ping-now')  # @UndefinedVariable
-                lg.info('found %r with rotated identity and refreshed: %r' % (inst, idurl, ))
+                lg.info('found %r with rotated identity and refreshed: %r' % (inst, idurl))
 
     def _on_my_identity_url_changed(self, evt):
-        from services import driver
+        from bitdust.services import driver
         if driver.is_on('service_entangled_dht'):
-            from dht import dht_service
-            from userid import my_id
+            from bitdust.dht import dht_service
+            from bitdust.userid import my_id
             if my_id.getIDURL():
                 dht_service.set_node_data('idurl', my_id.getIDURL().to_text())
