@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_personal_messages
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -57,14 +56,13 @@ class PersonalMessagesService(LocalService):
     def start(self):
         from twisted.internet import reactor  # @UnresolvedImport
         from twisted.internet.defer import Deferred
-        from logs import lg
-        from main import settings
-        from access import groups
-        from crypt import my_keys
-        from userid import my_id
+        from bitdust.logs import lg
+        from bitdust.main import settings
+        from bitdust.access import groups
+        from bitdust.crypt import my_keys
+        from bitdust.userid import my_id
         self.starting_deferred = Deferred()
-        self.starting_deferred.addErrback(lambda err: lg.warn('service %r was not started: %r' % (
-            self.service_name, err.getErrorMessage() if err else 'unknown reason')))
+        self.starting_deferred.addErrback(lambda err: lg.warn('service %r was not started: %r' % (self.service_name, err.getErrorMessage() if err else 'unknown reason')))
         self.personal_group_key_id = my_keys.make_key_id(alias='person', creator_glob_id=my_id.getGlobalID())
 
         # TODO: needs more work, service_private_groups() must be reliable first
@@ -91,13 +89,13 @@ class PersonalMessagesService(LocalService):
         return self.starting_deferred
 
     def stop(self):
-        from interface import api
+        from bitdust.interface import api
         # api.group_leave(self.personal_group_key_id, erase_key=False)
         return True
 
     def _do_join_my_personal_group(self):
-        from logs import lg
-        from interface import api
+        from bitdust.logs import lg
+        from bitdust.interface import api
         lg.info('about to join my personal message group: %r' % self.personal_group_key_id)
         api.group_join(self.personal_group_key_id)
         if self.starting_deferred:
