@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_private_groups
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -50,10 +49,10 @@ class PrivateGroupsService(LocalService):
         ]
 
     def start(self):
-        from main import events
-        from services import driver
-        from access import groups
-        from access import group_member
+        from bitdust.main import events
+        from bitdust.services import driver
+        from bitdust.access import groups
+        from bitdust.access import group_member
         groups.init()
         events.add_subscriber(self._on_supplier_modified, 'supplier-modified')
         events.add_subscriber(self._on_dht_layer_connected, 'dht-layer-connected')
@@ -64,9 +63,9 @@ class PrivateGroupsService(LocalService):
         return True
 
     def stop(self):
-        from main import events
-        from access import groups
-        from access import group_member
+        from bitdust.main import events
+        from bitdust.access import groups
+        from bitdust.access import group_member
         events.remove_subscriber(groups.on_identity_url_changed, 'identity-url-changed')
         group_member.shutdown_group_members()
         events.remove_subscriber(self._on_dht_layer_connected, 'dht-layer-connected')
@@ -79,10 +78,10 @@ class PrivateGroupsService(LocalService):
         return True
 
     def _do_join_message_brokers_dht_layer(self):
-        from logs import lg
-        from dht import dht_service
-        from dht import dht_records
-        from dht import known_nodes
+        from bitdust.logs import lg
+        from bitdust.dht import dht_service
+        from bitdust.dht import dht_records
+        from bitdust.dht import known_nodes
         lg.info('going to join message brokers DHT layer: %d' % dht_records.LAYER_MESSAGE_BROKERS)
         known_seeds = known_nodes.nodes()
         dht_service.open_layer(
@@ -97,11 +96,11 @@ class PrivateGroupsService(LocalService):
             self._do_join_message_brokers_dht_layer()
 
     def _on_supplier_modified(self, evt):
-        from logs import lg
-        from access import key_ring
-        from crypt import my_keys
-        from userid import global_id
-        from userid import my_id
+        from bitdust.logs import lg
+        from bitdust.access import key_ring
+        from bitdust.crypt import my_keys
+        from bitdust.userid import global_id
+        from bitdust.userid import my_id
         if evt.data['new_idurl']:
             my_keys_to_be_republished = []
             for key_id in my_keys.known_keys():
