@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_shared_data
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -49,9 +48,9 @@ class SharedDataService(LocalService):
         ]
 
     def start(self):
-        from main import events
-        from transport import callback
-        from access import shared_access_coordinator
+        from bitdust.main import events
+        from bitdust.transport import callback
+        from bitdust.access import shared_access_coordinator
         callback.append_inbox_callback(self._on_inbox_packet_received)
         events.add_subscriber(shared_access_coordinator.on_supplier_modified, 'supplier-modified')
         events.add_subscriber(shared_access_coordinator.on_my_list_files_refreshed, 'my-list-files-refreshed')
@@ -63,9 +62,9 @@ class SharedDataService(LocalService):
         return True
 
     def stop(self):
-        from main import events
-        from transport import callback
-        from access import shared_access_coordinator
+        from bitdust.main import events
+        from bitdust.transport import callback
+        from bitdust.access import shared_access_coordinator
         events.remove_subscriber(shared_access_coordinator.on_key_registered, 'key-registered')
         events.remove_subscriber(shared_access_coordinator.on_key_erased, 'key-erased')
         events.remove_subscriber(shared_access_coordinator.on_share_connected, 'share-connected')
@@ -76,8 +75,8 @@ class SharedDataService(LocalService):
         return True
 
     def _on_inbox_packet_received(self, newpacket, info, status, error_message):
-        from p2p import commands
-        from access import key_ring
+        from bitdust.p2p import commands
+        from bitdust.access import key_ring
         if newpacket.Command == commands.Files():
             return key_ring.on_files_received(newpacket, info)
         return False
