@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_supplier
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -49,23 +48,25 @@ class SupplierService(LocalService):
         ]
 
     def installed(self):
-        from userid import my_id
+        from bitdust.userid import my_id
         if not my_id.isLocalIdentityReady():
             return False
         return True
 
     def attached_dht_layers(self):
-        from dht import dht_records
-        return [dht_records.LAYER_SUPPLIERS, ]
+        from bitdust.dht import dht_records
+        return [
+            dht_records.LAYER_SUPPLIERS,
+        ]
 
     def start(self):
-        from logs import lg
-        from transport import callback
-        from main import events
-        from contacts import contactsdb
-        from storage import accounting
-        from services import driver
-        from supplier import customer_space
+        from bitdust.logs import lg
+        from bitdust.transport import callback
+        from bitdust.main import events
+        from bitdust.contacts import contactsdb
+        from bitdust.storage import accounting
+        from bitdust.services import driver
+        from bitdust.supplier import customer_space
         callback.append_inbox_callback(self._on_inbox_packet_received)
         events.add_subscriber(customer_space.on_identity_url_changed, 'identity-url-changed')
         events.add_subscriber(customer_space.on_customer_accepted, 'existing-customer-accepted')
@@ -75,12 +76,14 @@ class SupplierService(LocalService):
         space_dict, _ = accounting.read_customers_quotas()
         for customer_idurl in contactsdb.customers():
             known_customer_meta_info = contactsdb.get_customer_meta_info(customer_idurl)
+            # yapf: disable
             events.send('existing-customer-accepted', data=dict(
                 idurl=customer_idurl,
                 allocated_bytes=space_dict.get(customer_idurl.to_bin()),
                 ecc_map=known_customer_meta_info.get('ecc_map'),
                 position=known_customer_meta_info.get('position'),
             ))
+            # yapf: enable
         if driver.is_on('service_entangled_dht'):
             self._do_connect_suppliers_dht_layer()
         else:
@@ -89,14 +92,14 @@ class SupplierService(LocalService):
         return True
 
     def stop(self):
-        from transport import callback
-        from main import events
-        from services import driver
-        from supplier import customer_space
+        from bitdust.transport import callback
+        from bitdust.main import events
+        from bitdust.services import driver
+        from bitdust.supplier import customer_space
         events.remove_subscriber(self._on_dht_layer_connected, 'dht-layer-connected')
         if driver.is_on('service_entangled_dht'):
-            from dht import dht_service
-            from dht import dht_records
+            from bitdust.dht import dht_service
+            from bitdust.dht import dht_records
             dht_service.suspend(layer_id=dht_records.LAYER_SUPPLIERS)
         events.remove_subscriber(customer_space.on_customer_accepted, 'existing-customer-accepted')
         events.remove_subscriber(customer_space.on_customer_accepted, 'new-customer-accepted')
@@ -108,15 +111,15 @@ class SupplierService(LocalService):
 
     def request(self, json_payload, newpacket, info):
         from twisted.internet import reactor  # @UnresolvedImport
-        from logs import lg
-        from main import events
-        from crypt import my_keys
-        from p2p import p2p_service
-        from contacts import contactsdb
-        from storage import accounting
-        from supplier import customer_space
-        from userid import id_url
-        from userid import global_id
+        from bitdust.logs import lg
+        from bitdust.main import events
+        from bitdust.crypt import my_keys
+        from bitdust.p2p import p2p_service
+        from bitdust.contacts import contactsdb
+        from bitdust.storage import accounting
+        from bitdust.supplier import customer_space
+        from bitdust.userid import id_url
+        from bitdust.userid import global_id
         customer_idurl = newpacket.OwnerID
         customer_id = global_id.UrlToGlobalID(customer_idurl)
         bytes_for_customer = 0
@@ -149,7 +152,7 @@ class SupplierService(LocalService):
                 return p2p_service.SendFail(newpacket, 'invalid key id')
             target_customer_idurl = global_id.GlobalUserToIDURL(target_customer_id)
             if not contactsdb.is_customer(target_customer_idurl):
-                lg.warn("target user %s is not a customer" % target_customer_id)
+                lg.warn('target user %s is not a customer' % target_customer_id)
                 return p2p_service.SendFail(newpacket, 'not a customer')
             if target_customer_idurl == customer_idurl:
                 lg.warn('customer %s requesting shared access to own files' % customer_idurl)
@@ -164,18 +167,17 @@ class SupplierService(LocalService):
                 # external customer requesting access to data which belongs not to that customer
                 # this is "third" customer accessing data belongs to "second" customer
                 # TODO: for now just stop it
-                lg.warn('under construction, key_id=%s customer_idurl=%s target_customer_idurl=%s' % (
-                    key_id, customer_idurl, target_customer_idurl, ))
+                lg.warn('under construction, key_id=%s customer_idurl=%s target_customer_idurl=%s' % (key_id, customer_idurl, target_customer_idurl))
                 p2p_service.SendFail(newpacket, 'under construction')
                 return False
             customer_space.register_customer_key(customer_public_key_id, customer_public_key)
             # do not create connection with that customer, only accept the request
-            lg.info('external customer %s requested access to shared data at %s' % (customer_id, key_id, ))
+            lg.info('external customer %s requested access to shared data at %s' % (customer_id, key_id))
             return p2p_service.SendAck(newpacket, 'accepted')
         # key_id is not present in the request:
         # this is a request to connect new customer (or reconnect existing one) to that supplier
         if not bytes_for_customer or bytes_for_customer < 0:
-            lg.warn("wrong payload : %s" % newpacket.Payload)
+            lg.warn('wrong payload : %s' % newpacket.Payload)
             return p2p_service.SendFail(newpacket, 'wrong storage value')
         current_customers = contactsdb.customers()
         if accounting.check_create_customers_quotas():
@@ -187,19 +189,18 @@ class SupplierService(LocalService):
             lg.exc()
             return p2p_service.SendFail(newpacket, 'broken space file')
         if (customer_idurl not in current_customers and customer_idurl.to_bin() in list(space_dict.keys())):
-            lg.warn("broken space file")
+            lg.warn('broken space file')
             return p2p_service.SendFail(newpacket, 'broken space file')
         if (customer_idurl in current_customers and customer_idurl.to_bin() not in list(space_dict.keys())):
             # seems like customer's idurl was rotated, but space file still have the old idurl
             # need to find that old idurl value and replace with the new one
             for other_customer_idurl in space_dict.keys():
                 if other_customer_idurl and other_customer_idurl != 'free' and id_url.field(other_customer_idurl) == customer_idurl:
-                    lg.info('found rotated customer identity in space file, switching: %r -> %r' % (
-                        other_customer_idurl, customer_idurl.to_bin()))
+                    lg.info('found rotated customer identity in space file, switching: %r -> %r' % (other_customer_idurl, customer_idurl.to_bin()))
                     space_dict[customer_idurl.to_bin()] = space_dict.pop(other_customer_idurl)
                     break
             if customer_idurl.to_bin() not in list(space_dict.keys()):
-                lg.warn("broken customers file")
+                lg.warn('broken customers file')
                 return p2p_service.SendFail(newpacket, 'broken customers file')
         if customer_idurl in current_customers:
             free_bytes += int(space_dict.get(customer_idurl.to_bin(), 0))
@@ -209,7 +210,7 @@ class SupplierService(LocalService):
         else:
             new_customer = True
         # lg.args(8, new_customer=new_customer, current_allocated_bytes=space_dict.get(customer_idurl.to_bin()))
-        from supplier import local_tester
+        from bitdust.supplier import local_tester
         if free_bytes <= bytes_for_customer:
             contactsdb.remove_customer_meta_info(customer_idurl)
             accounting.write_customers_quotas(space_dict, free_bytes)
@@ -219,10 +220,10 @@ class SupplierService(LocalService):
                 my_keys.erase_key(customer_public_key_id)
             reactor.callLater(0, local_tester.TestUpdateCustomers)  # @UndefinedVariable
             if new_customer:
-                lg.info("NEW CUSTOMER: DENIED     not enough space available")
+                lg.info('NEW CUSTOMER: DENIED     not enough space available')
                 events.send('new-customer-denied', data=dict(idurl=customer_idurl))
             else:
-                lg.info("OLD CUSTOMER: DENIED     not enough space available")
+                lg.info('OLD CUSTOMER: DENIED     not enough space available')
                 events.send('existing-customer-denied', data=dict(idurl=customer_idurl))
             return p2p_service.SendAck(newpacket, 'deny')
         free_bytes = free_bytes - bytes_for_customer
@@ -239,8 +240,7 @@ class SupplierService(LocalService):
         customer_space.register_customer_key(customer_public_key_id, customer_public_key)
         reactor.callLater(0, local_tester.TestUpdateCustomers)  # @UndefinedVariable
         if new_customer:
-            lg.info("NEW CUSTOMER: ACCEPTED   %s family_position=%s ecc_map=%s allocated_bytes=%s" % (
-                customer_idurl, family_position, ecc_map, bytes_for_customer))
+            lg.info('NEW CUSTOMER: ACCEPTED   %s family_position=%s ecc_map=%s allocated_bytes=%s' % (customer_idurl, family_position, ecc_map, bytes_for_customer))
             events.send('new-customer-accepted', data=dict(
                 idurl=customer_idurl,
                 allocated_bytes=bytes_for_customer,
@@ -250,8 +250,7 @@ class SupplierService(LocalService):
                 key_id=customer_public_key_id,
             ))
         else:
-            lg.info("OLD CUSTOMER: ACCEPTED  %s family_position=%s ecc_map=%s allocated_bytes=%s" % (
-                customer_idurl, family_position, ecc_map, bytes_for_customer))
+            lg.info('OLD CUSTOMER: ACCEPTED  %s family_position=%s ecc_map=%s allocated_bytes=%s' % (customer_idurl, family_position, ecc_map, bytes_for_customer))
             events.send('existing-customer-accepted', data=dict(
                 idurl=customer_idurl,
                 allocated_bytes=bytes_for_customer,
@@ -264,12 +263,12 @@ class SupplierService(LocalService):
 
     def cancel(self, json_payload, newpacket, info):
         from twisted.internet import reactor  # @UnresolvedImport
-        from logs import lg
-        from main import events
-        from p2p import p2p_service
-        from contacts import contactsdb
-        from storage import accounting
-        from crypt import my_keys
+        from bitdust.logs import lg
+        from bitdust.main import events
+        from bitdust.p2p import p2p_service
+        from bitdust.contacts import contactsdb
+        from bitdust.storage import accounting
+        from bitdust.crypt import my_keys
         customer_idurl = newpacket.OwnerID
         try:
             customer_public_key = json_payload['customer_public_key']
@@ -279,13 +278,13 @@ class SupplierService(LocalService):
             customer_public_key_id = None
         customer_ecc_map = json_payload.get('ecc_map')
         if not contactsdb.is_customer(customer_idurl):
-            lg.warn("got packet from %s, but he is not a customer" % customer_idurl)
+            lg.warn('got packet from %s, but he is not a customer' % customer_idurl)
             return p2p_service.SendFail(newpacket, 'not a customer')
         if accounting.check_create_customers_quotas():
             lg.info('created a new space file')
         space_dict, free_space = accounting.read_customers_quotas()
         if customer_idurl.to_bin() not in list(space_dict.keys()):
-            lg.warn("got packet from %s, but not found him in space dictionary" % customer_idurl)
+            lg.warn('got packet from %s, but not found him in space dictionary' % customer_idurl)
             return p2p_service.SendFail(newpacket, 'not a customer')
         try:
             free_bytes = int(free_space)
@@ -303,17 +302,17 @@ class SupplierService(LocalService):
         if customer_public_key_id:
             my_keys.erase_key(customer_public_key_id)
         # TODO: erase customer's groups keys also
-        from supplier import local_tester
+        from bitdust.supplier import local_tester
         reactor.callLater(0, local_tester.TestUpdateCustomers)  # @UndefinedVariable
-        lg.info("OLD CUSTOMER TERMINATED %r" % customer_idurl)
+        lg.info('OLD CUSTOMER TERMINATED %r' % customer_idurl)
         events.send('existing-customer-terminated', data=dict(idurl=customer_idurl, ecc_map=customer_ecc_map))
         return p2p_service.SendAck(newpacket, 'accepted')
 
     def _do_connect_suppliers_dht_layer(self):
-        from logs import lg
-        from dht import dht_service
-        from dht import dht_records
-        from dht import known_nodes
+        from bitdust.logs import lg
+        from bitdust.dht import dht_service
+        from bitdust.dht import dht_records
+        from bitdust.dht import known_nodes
         known_seeds = known_nodes.nodes()
         d = dht_service.open_layer(
             layer_id=dht_records.LAYER_SUPPLIERS,
@@ -325,8 +324,8 @@ class SupplierService(LocalService):
         d.addErrback(lambda *args: lg.err(str(args)))
 
     def _on_inbox_packet_received(self, newpacket, info, status, error_message):
-        from p2p import commands
-        from supplier import customer_space
+        from bitdust.p2p import commands
+        from bitdust.supplier import customer_space
         if newpacket.Command == commands.DeleteFile():
             return customer_space.on_delete_file(newpacket)
         elif newpacket.Command == commands.DeleteBackup():
@@ -340,17 +339,17 @@ class SupplierService(LocalService):
         return False
 
     def _on_suppliers_dht_layer_connected(self, ok):
-        from logs import lg
-        from dht import dht_service
-        from dht import dht_records
-        from userid import my_id
+        from bitdust.logs import lg
+        from bitdust.dht import dht_service
+        from bitdust.dht import dht_records
+        from bitdust.userid import my_id
         lg.info('connected to DHT layer for suppliers: %r' % ok)
         if my_id.getIDURL():
             dht_service.set_node_data('idurl', my_id.getIDURL().to_text(), layer_id=dht_records.LAYER_SUPPLIERS)
         return ok
 
     def _on_dht_layer_connected(self, evt):
-        from dht import dht_records
+        from bitdust.dht import dht_records
         if evt.data['layer_id'] == 0:
             self._do_connect_suppliers_dht_layer()
         elif evt.data['layer_id'] == dht_records.LAYER_SUPPLIERS:
