@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: backup.
 
@@ -101,33 +100,33 @@ from twisted.internet.defer import maybeDeferred, Deferred, succeed
 
 #------------------------------------------------------------------------------
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     import os.path as _p
     sys.path.append(_p.join(_p.dirname(_p.abspath(sys.argv[0])), '..'))
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import packetid
-from lib import strng
+from bitdust.lib import packetid
+from bitdust.lib import strng
 
-from userid import my_id
-from userid import global_id
+from bitdust.userid import my_id
+from bitdust.userid import global_id
 
-from system import nonblocking
-from system import tmpfile
+from bitdust.system import nonblocking
+from bitdust.system import tmpfile
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from automats import automat
+from bitdust.automats import automat
 
-from raid import eccmap
-from raid import raid_worker
+from bitdust.raid import eccmap
+from bitdust.raid import raid_worker
 
-from crypt import encrypted
-from crypt import key
+from bitdust.crypt import encrypted
+from bitdust.crypt import key
 
 #-------------------------------------------------------------------------------
 
@@ -142,17 +141,19 @@ class backup(automat.Automat):
         'timer-001sec': (0.01, ['READ']),
     }
 
-    def __init__(self,
-                 backupID,
-                 pipe,
-                 finishCallback=None,
-                 blockResultCallback=None,
-                 notifyNewDataCallback=None,
-                 blockSize=None,
-                 sourcePath=None,
-                 keyID=None,
-                 ecc_map=None,
-                 creatorIDURL=None,):
+    def __init__(
+        self,
+        backupID,
+        pipe,
+        finishCallback=None,
+        blockResultCallback=None,
+        notifyNewDataCallback=None,
+        blockSize=None,
+        sourcePath=None,
+        keyID=None,
+        ecc_map=None,
+        creatorIDURL=None,
+    ):
         self.backupID = backupID
         self.creatorIDURL = creatorIDURL or my_id.getIDURL()
         _parts = packetid.SplitBackupID(self.backupID)
@@ -183,8 +184,14 @@ class backup(automat.Automat):
         self.finishCallback = finishCallback
         self.blockResultCallback = blockResultCallback
         self.notifyNewDataCallback = notifyNewDataCallback
-        automat.Automat.__init__(self, name='backup_%s' % self.version, state='AT_STARTUP',
-                                 debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, )
+        automat.Automat.__init__(
+            self,
+            name='backup_%s' % self.version,
+            state='AT_STARTUP',
+            debug_level=_DebugLevel,
+            log_events=_Debug,
+            log_transitions=_Debug,
+        )
 
     def init(self):
         """
@@ -200,15 +207,16 @@ class backup(automat.Automat):
                 self.doFirstBlock(*args, **kwargs)
         #---READ---
         elif self.state == 'READ':
-            if event == 'read-success' and not self.isReadingNow(*args, **kwargs) and ( self.isBlockReady(*args, **kwargs) or self.isEOF(*args, **kwargs) ):
+            if event == 'read-success' and not self.isReadingNow(*args, **kwargs) and (self.isBlockReady(*args, **kwargs) or self.isEOF(*args, **kwargs)):
                 self.state = 'ENCRYPT'
                 self.doEncryptBlock(*args, **kwargs)
-            elif event == 'fail' or ( ( event == 'read-success' or event == 'timer-001sec' ) and self.isAborted(*args, **kwargs) ):
+            elif event == 'fail' or ((event == 'read-success' or event == 'timer-001sec') and self.isAborted(*args, **kwargs)):
                 self.state = 'ABORTED'
                 self.doClose(*args, **kwargs)
                 self.doReport(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'read-success' or event == 'timer-001sec' ) and not self.isAborted(*args, **kwargs) and self.isPipeReady(*args, **kwargs) and not self.isEOF(*args, **kwargs) and not self.isReadingNow(*args, **kwargs) and not self.isBlockReady(*args, **kwargs):
+            elif (event == 'read-success' or event
+                  == 'timer-001sec') and not self.isAborted(*args, **kwargs) and self.isPipeReady(*args, **kwargs) and not self.isEOF(*args, **kwargs) and not self.isReadingNow(*args, **kwargs) and not self.isBlockReady(*args, **kwargs):
                 self.doRead(*args, **kwargs)
             elif event == 'block-raid-done' and not self.isAborted(*args, **kwargs):
                 self.doPopBlock(*args, **kwargs)
@@ -232,7 +240,7 @@ class backup(automat.Automat):
                 self.doPopBlock(*args, **kwargs)
                 self.doBlockReport(*args, **kwargs)
                 self.doNotifyNewData(*args, **kwargs)
-            elif event == 'fail' or ( ( event == 'timer-01sec' or event == 'block-raid-done' or event == 'block-raid-started' ) and self.isAborted(*args, **kwargs) ):
+            elif event == 'fail' or ((event == 'timer-01sec' or event == 'block-raid-done' or event == 'block-raid-started') and self.isAborted(*args, **kwargs)):
                 self.state = 'ABORTED'
                 self.doClose(*args, **kwargs)
                 self.doReport(*args, **kwargs)
@@ -316,9 +324,7 @@ class backup(automat.Automat):
             size = self.blockSize - self.currentBlockSize
             if size < 0:
                 if _Debug:
-                    lg.args(_DebugLevel,
-                        eccmap_nodes=self.eccmap.nodes(), block_size=self.blockSize,
-                        current_block_size=self.currentBlockSize, )
+                    lg.args(_DebugLevel, eccmap_nodes=self.eccmap.nodes(), block_size=self.blockSize, current_block_size=self.currentBlockSize)
                 raise Exception('size < 0, blockSize=%s, currentBlockSize=%s' % (self.blockSize, self.currentBlockSize))
             elif size == 0:
                 return succeed(b'')
@@ -381,8 +387,7 @@ class backup(automat.Automat):
             )
             del raw_bytes
             if _Debug:
-                lg.out(_DebugLevel, 'backup.doEncryptBlock blockNumber=%d size=%d atEOF=%s dt=%s EncryptKey=%s' % (
-                    self.blockNumber, self.currentBlockSize, self.stateEOF, str(time.time() - dt), self.keyID))
+                lg.out(_DebugLevel, 'backup.doEncryptBlock blockNumber=%d size=%d atEOF=%s dt=%s EncryptKey=%s' % (self.blockNumber, self.currentBlockSize, self.stateEOF, str(time.time() - dt), self.keyID))
             return block
 
         d = maybeDeferred(_doBlock)
@@ -409,19 +414,17 @@ class backup(automat.Automat):
         fileno, filename = tmpfile.make('raid', extension='.raid')
         serializedblock = newblock.Serialize()
         blocklen = len(serializedblock)
-        os.write(fileno, strng.to_bin(blocklen) + b":" + serializedblock)
+        os.write(fileno, strng.to_bin(blocklen) + b':' + serializedblock)
         os.close(fileno)
         self.workBlocks[newblock.BlockNumber] = filename
         dt = time.time()
-        outputpath = os.path.join(
-            settings.getLocalBackupsDir(), self.customerGlobalID, self.pathID, self.version)
+        outputpath = os.path.join(settings.getLocalBackupsDir(), self.customerGlobalID, self.pathID, self.version)
         task_params = (filename, self.eccmap.name, self.version, newblock.BlockNumber, outputpath)
         raid_worker.add_task('make', task_params, lambda cmd, params, result: self._raidmakeCallback(params, result, dt))
         self.automat('block-raid-started', newblock)
         del serializedblock
         if _Debug:
-            lg.out(_DebugLevel, 'backup.doBlockPushAndRaid %s : start process data from %s to %s, %d' % (
-                newblock.BlockNumber, filename, outputpath, id(self.terminating)))
+            lg.out(_DebugLevel, 'backup.doBlockPushAndRaid %s : start process data from %s to %s, %d' % (newblock.BlockNumber, filename, outputpath, id(self.terminating)))
 
     def doPopBlock(self, *args, **kwargs):
         """
@@ -532,22 +535,20 @@ class backup(automat.Automat):
         """
         if self.totalSize <= 0:
             return 0.0
-        percent = min(100.0, 100.0 * self.dataSent / self.totalSize)
+        percent = min(100.0, 100.0*self.dataSent/self.totalSize)
         return percent
 
     def _raidmakeCallback(self, params, result, dt):
         _, _, _, blockNumber, _ = params
         if result is None:
             if _Debug:
-                lg.out(_DebugLevel, 'backup._raidmakeCallback WARNING - result is None :  %r eof=%s dt=%s' % (
-                    blockNumber, str(self.stateEOF), str(time.time() - dt)))
+                lg.out(_DebugLevel, 'backup._raidmakeCallback WARNING - result is None :  %r eof=%s dt=%s' % (blockNumber, str(self.stateEOF), str(time.time() - dt)))
             events.send('backup-raidmake-failed', data=dict(backup_id=self.backupID))
             self.ask4abort = True
             self._kill_pipe()
         else:
             if _Debug:
-                lg.out(_DebugLevel, 'backup._raidmakeCallback %r %r eof=%s dt=%s' % (
-                    blockNumber, result, str(self.stateEOF), str(time.time() - dt)))
+                lg.out(_DebugLevel, 'backup._raidmakeCallback %r %r eof=%s dt=%s' % (blockNumber, result, str(self.stateEOF), str(time.time() - dt)))
             self.automat('block-raid-done', (blockNumber, result))
 
     def _kill_pipe(self):
@@ -559,12 +560,13 @@ class backup(automat.Automat):
             except:
                 lg.exc()
 
+
 #------------------------------------------------------------------------------
 
 
 def main():
-    from system import bpio
-    from storage import backup_tar
+    from bitdust.system import bpio
+    from bitdust.storage import backup_tar
 
     bpio.init()
     settings.init()
@@ -589,7 +591,7 @@ def main():
         backupPipe = backup_tar.backuptarfile_thread(sourcePath, compress=compress_mode)
 
     def _bk_done(bid, result):
-        from crypt import signed
+        from bitdust.crypt import signed
         customer, remotePath = packetid.SplitPacketID(bid)
         try:
             os.mkdir(os.path.join(settings.getLocalBackupsDir(), customer, remotePath + '.out'))
@@ -598,13 +600,7 @@ def main():
         for filename in os.listdir(os.path.join(settings.getLocalBackupsDir(), customer, remotePath)):
             filepath = os.path.join(settings.getLocalBackupsDir(), customer, remotePath, filename)
             payld = bpio.ReadBinaryFile(filepath)
-            newpacket = signed.Packet(
-                'Data',
-                my_id.getIDURL(),
-                my_id.getIDURL(),
-                filename,
-                payld,
-                'http://megafaq.ru/cvps1010.xml')
+            newpacket = signed.Packet('Data', my_id.getIDURL(), my_id.getIDURL(), filename, payld, 'http://megafaq.ru/cvps1010.xml')
             newfilepath = os.path.join(settings.getLocalBackupsDir(), customer, remotePath + '.out', filename)
             bpio.WriteBinaryFile(newfilepath, newpacket.Serialize())
 
@@ -624,5 +620,5 @@ def main():
     settings.shutdown()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
