@@ -22,7 +22,6 @@
 #
 #
 #
-
 """
 .. module:: backup_control.
 
@@ -49,6 +48,7 @@ _DebugLevel = 12
 import os
 import sys
 import time
+import zlib
 import pprint
 
 #------------------------------------------------------------------------------
@@ -62,48 +62,48 @@ from twisted.internet.defer import Deferred
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import tmpfile
-from system import dirsize
+from bitdust.system import bpio
+from bitdust.system import tmpfile
+from bitdust.system import dirsize
 
-from lib import misc
-from lib import packetid
-from lib import nameurl
-from lib import strng
+from bitdust.lib import misc
+from bitdust.lib import packetid
+from bitdust.lib import nameurl
+from bitdust.lib import strng
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from raid import eccmap
+from bitdust.raid import eccmap
 
-from crypt import encrypted
-from crypt import key
-from crypt import my_keys
+from bitdust.crypt import encrypted
+from bitdust.crypt import key
+from bitdust.crypt import my_keys
 
-from userid import global_id
-from userid import id_url
+from bitdust.userid import global_id
+from bitdust.userid import id_url
 
-from services import driver
+from bitdust.services import driver
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from p2p import p2p_service
+from bitdust.p2p import p2p_service
 
-from stream import data_sender
+from bitdust.stream import data_sender
 
-from storage import backup_fs
-from storage import backup_matrix
-from storage import backup
+from bitdust.storage import backup_fs
+from bitdust.storage import backup_matrix
+from bitdust.storage import backup
 
-from userid import my_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
 MAXIMUM_JOBS_STARTED = 1  # let's do only one backup at once for now
 
-_Jobs = {}   # here are already started backups ( by backupID )
+_Jobs = {}  # here are already started backups ( by backupID )
 _Tasks = []  # here are tasks to start backups in the future ( pathID )
 _LastTaskNumber = 0
 _LoadingFlag = False
@@ -128,6 +128,7 @@ def tasks():
     global _Tasks
     return _Tasks
 
+
 #------------------------------------------------------------------------------
 
 
@@ -148,12 +149,16 @@ def shutdown():
     if _Debug:
         lg.out(_DebugLevel, 'backup_control.shutdown')
 
+
 #------------------------------------------------------------------------------
 
-def Save(customer_idurl=None, key_alias='master', increase_revision=True):
+
+def SaveFSIndex(customer_idurl=None, key_alias='master', increase_revision=True):
     """
-    Save index data base to local file and notify "index_synchronizer()" state machine.
+    Save index data base to local file and notify "index_synchronizer()" or "shared_access_coordinator()" state machines.
     """
+    if _Debug:
+        lg.args(_DebugLevel, c=customer_idurl, k=key_alias, increase_revision=increase_revision)
     global _LoadingFlag
     if _LoadingFlag:
         return False
@@ -166,13 +171,20 @@ def Save(customer_idurl=None, key_alias='master', increase_revision=True):
             key_alias=key_alias,
         )
     backup_fs.SaveIndex(customer_idurl, key_alias)
-    if driver.is_on('service_backup_db'):
-        # TODO: switch to event
-        from storage import index_synchronizer
-        index_synchronizer.A('push')
+    if increase_revision:
+        if key_alias == 'master':
+            if driver.is_on('service_backup_db'):
+                from bitdust.storage import index_synchronizer
+                index_synchronizer.A('push')
+        else:
+            if driver.is_on('service_shared_data'):
+                from bitdust.access import shared_access_coordinator
+                shared_access_coordinator.on_index_file_updated(customer_idurl, key_alias)
+
 
 #------------------------------------------------------------------------------
 
+
 def on_files_received(newpacket, info):
     list_files_global_id = global_id.ParseGlobalID(newpacket.PacketID)
     if not list_files_global_id['idurl']:
@@ -191,19 +203,28 @@ def on_files_received(newpacket, info):
     if not contactsdb.is_supplier(newpacket.OwnerID):
         # ignore Files() if this is not my supplier
         if _Debug:
-            lg.dbg(_DebugLevel, 'incoming %r received, but %r is not my supplier' % (newpacket, newpacket.OwnerID, ))
+            lg.dbg(_DebugLevel, 'incoming %r received, but %r is not my supplier' % (newpacket, newpacket.OwnerID))
         return False
     if _Debug:
-        lg.args(_DebugLevel, "service_backups._on_inbox_packet_received: %r for us from %s at %s" % (
-            newpacket, newpacket.CreatorID, info))
+        lg.dbg(_DebugLevel, '%r for us from %s' % (newpacket, newpacket.CreatorID))
     if IncomingSupplierListFiles(newpacket, list_files_global_id):
         p2p_service.SendAck(newpacket)
     else:
         p2p_service.SendFail(newpacket)
     return True
 
+
 #------------------------------------------------------------------------------
 
+
+def UnpackListFiles(payload, method):
+    if method == 'Text':
+        return payload
+    elif method == 'Compressed':
+        return strng.to_text(zlib.decompress(strng.to_bin(payload)))
+    return payload
+
+
 def IncomingSupplierListFiles(newpacket, list_files_global_id):
     """
     Called when command "Files" were received from one of my suppliers.
@@ -211,39 +232,39 @@ def IncomingSupplierListFiles(newpacket, list_files_global_id):
     list of our files stored on his machine.
     """
     supplier_idurl = newpacket.OwnerID
-    # incoming_key_id = newpacket.PacketID.strip().split(':')[0]
     customer_idurl = list_files_global_id['idurl']
     num = contactsdb.supplier_position(supplier_idurl, customer_idurl=customer_idurl)
     if num < -1:
         lg.warn('unknown supplier: %s' % supplier_idurl)
         return False
-    from supplier import list_files
-    from customer import list_files_orator
+    from bitdust.customer import list_files_orator
     target_key_id = my_keys.latest_key_id(list_files_global_id['key_id'])
     if not my_keys.is_key_private(target_key_id):
-        lg.warn('key %r not registered, not possible to decrypt ListFiles() packet from %r' % (target_key_id, supplier_idurl, ))
+        lg.warn('key %r not registered, not possible to decrypt ListFiles() packet from %r' % (target_key_id, supplier_idurl))
         return False
     try:
-        block = encrypted.Unserialize(newpacket.Payload, decrypt_key=target_key_id, )
+        block = encrypted.Unserialize(
+            newpacket.Payload,
+            decrypt_key=target_key_id,
+        )
         input_data = block.Data()
     except:
         lg.err('failed decrypting data from packet %r received from %r' % (newpacket, supplier_idurl))
         return False
-    list_files_raw = list_files.UnpackListFiles(input_data, settings.ListFilesFormat())
+    from bitdust.storage import index_synchronizer
+    is_in_sync = index_synchronizer.is_synchronized() and backup_fs.revision() > 0
+    list_files_raw = UnpackListFiles(input_data, settings.ListFilesFormat())
     remote_files_changed, backups2remove, paths2remove, missed_backups = backup_matrix.process_raw_list_files(
         supplier_num=num,
         list_files_text_body=list_files_raw,
         customer_idurl=None,
-        is_in_sync=None,
-        auto_create=False,
+        is_in_sync=is_in_sync,
     )
     list_files_orator.IncomingListFiles(newpacket)
     if remote_files_changed:
         backup_matrix.SaveLatestRawListFiles(supplier_idurl, list_files_raw)
     if _Debug:
-        lg.args(_DebugLevel, supplier=nameurl.GetName(supplier_idurl), customer=nameurl.GetName(customer_idurl),
-                backups2remove=len(backups2remove), paths2remove=len(paths2remove),
-                files_changed=remote_files_changed, missed_backups=len(missed_backups), )
+        lg.args(_DebugLevel, s=nameurl.GetName(supplier_idurl), c=nameurl.GetName(customer_idurl), backups2remove=len(backups2remove), paths2remove=len(paths2remove), files_changed=remote_files_changed, missed_backups=len(missed_backups))
     if len(backups2remove) > 0:
         p2p_service.RequestDeleteListBackups(backups2remove)
         if _Debug:
@@ -253,7 +274,7 @@ def IncomingSupplierListFiles(newpacket, list_files_global_id):
         if _Debug:
             lg.out(_DebugLevel, '    also sent requests to remove %d paths' % len(paths2remove))
     if len(missed_backups) > 0:
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_rebuilder
         backup_rebuilder.AddBackupsToWork(missed_backups)
         backup_rebuilder.A('start')
         if _Debug:
@@ -264,7 +285,7 @@ def IncomingSupplierListFiles(newpacket, list_files_global_id):
     return True
 
 
-def IncomingSupplierBackupIndex(newpacket, key_id=None):
+def IncomingSupplierBackupIndex(newpacket, key_id=None, deleted_path_ids=[]):
     """
     Called by ``p2p.p2p_service`` when a remote copy of our local index data
     base ( in the "Data" packet ) is received from one of our suppliers.
@@ -292,28 +313,27 @@ def IncomingSupplierBackupIndex(newpacket, key_id=None):
             pass
         return None
     inpt.close()
-#     if supplier_revision >= 0 and backup_fs.revision() > supplier_revision:
-#         if _Debug:
-#             lg.out(_DebugLevel, 'backup_control.IncomingSupplierBackupIndex SKIP, supplier %s revision=%d, local revision=%d' % (
-#                 newpacket.RemoteID, supplier_revision, backup_fs.revision(), ))
-#         return supplier_revision
+    #     if supplier_revision >= 0 and backup_fs.revision() > supplier_revision:
+    #         if _Debug:
+    #             lg.out(_DebugLevel, 'backup_control.IncomingSupplierBackupIndex SKIP, supplier %s revision=%d, local revision=%d' % (
+    #                 newpacket.RemoteID, supplier_revision, backup_fs.revision(), ))
+    #         return supplier_revision
     if _Debug:
-        lg.args(_DebugLevel, k=key_id, p=newpacket.PacketID, sz=len(text_data), inp=len(newpacket.Payload))
-    count, updated_customers_keys = backup_fs.ReadIndex(text_data, new_revision=supplier_revision)
+        lg.args(_DebugLevel, k=key_id, p=newpacket.PacketID, sz=len(text_data), inp=len(newpacket.Payload), deleted=len(deleted_path_ids))
+    count, updated_customers_keys = backup_fs.ReadIndex(text_data, new_revision=supplier_revision, deleted_path_ids=deleted_path_ids)
     if updated_customers_keys:
         # backup_fs.commit(supplier_revision)
         # backup_fs.Scan()
         # backup_fs.Calculate()
         for customer_idurl, key_alias in updated_customers_keys:
             backup_fs.SaveIndex(customer_idurl, key_alias)
-            # control.request_update()
             if _Debug:
-                lg.out(_DebugLevel, 'backup_control.IncomingSupplierBackupIndex updated to revision %d for %s of %s from %s' % (
-                    backup_fs.revision(customer_idurl, key_alias), customer_idurl, key_alias, newpacket.RemoteID))
+                lg.out(_DebugLevel, 'backup_control.IncomingSupplierBackupIndex updated to revision %d for %s of %s from %s' % (backup_fs.revision(customer_idurl, key_alias), customer_idurl, key_alias, newpacket.RemoteID))
     # else:
     #     lg.warn('failed to read catalog index from supplier')
     return supplier_revision
 
+
 #------------------------------------------------------------------------------
 
 
@@ -334,9 +354,7 @@ def DeleteAllBackups():
     # check and calculate used space
     backup_fs.Calculate()
     # save the index
-    Save()
-    # refresh the GUI
-    # control.request_update()
+    SaveFSIndex()
 
 
 def DeleteBackup(backupID, removeLocalFilesToo=True, saveDB=True, calculate=True):
@@ -355,21 +373,22 @@ def DeleteBackup(backupID, removeLocalFilesToo=True, saveDB=True, calculate=True
     10) save the modified index data base, soon it will be synchronized with "index_synchronizer()" state machine
     """
     backupID = global_id.CanonicalID(backupID)
+    key_alias, customer, _, _ = packetid.SplitBackupIDFull(backupID)
+    customer_idurl = global_id.GlobalUserToIDURL(customer)
     # if the user deletes a backup, make sure we remove any work we're doing on it
     # abort backup if it just started and is running at the moment
     if AbortRunningBackup(backupID):
         if _Debug:
             lg.out(_DebugLevel, 'backup_control.DeleteBackup %s is in process, stopping' % backupID)
         return True
-    from stream import io_throttle
-    from storage import backup_rebuilder
+    from bitdust.stream import io_throttle
+    from bitdust.storage import backup_rebuilder
     if _Debug:
         lg.out(_DebugLevel, 'backup_control.DeleteBackup ' + backupID)
     # if we requested for files for this backup - we do not need it anymore
     io_throttle.DeleteBackupRequests(backupID)
     io_throttle.DeleteBackupSendings(backupID)
     # remove interests in transport_control
-    # callback.delete_backup_interest(backupID)
     # mark it as being deleted in the db, well... just remove it from the index now
     if not backup_fs.DeleteBackupID(backupID):
         return False
@@ -384,13 +403,12 @@ def DeleteBackup(backupID, removeLocalFilesToo=True, saveDB=True, calculate=True
     backup_rebuilder.RemoveAllBackupsToWork()
     backup_rebuilder.SetStoppedFlag()
     # check and calculate used space
-    if calculate:
-        backup_fs.Scan()
-        backup_fs.Calculate()
+    if calculate or key_alias != 'master':
+        backup_fs.Scan(customer_idurl=customer_idurl, key_alias=key_alias)
+        backup_fs.Calculate(iterID=backup_fs.fsID(customer_idurl, key_alias))
     # in some cases we want to save the DB later
-    if saveDB:
-        Save()
-        # control.request_update([('backupID', backupID), ])
+    if saveDB or key_alias != 'master':
+        SaveFSIndex(customer_idurl, key_alias)
     return True
 
 
@@ -399,8 +417,8 @@ def DeletePathBackups(pathID, removeLocalFilesToo=True, saveDB=True, calculate=T
     This removes all backups of given path ID
     Doing same operations as ``DeleteBackup()``.
     """
-    from storage import backup_rebuilder
-    from stream import io_throttle
+    from bitdust.storage import backup_rebuilder
+    from bitdust.stream import io_throttle
     pathID = global_id.CanonicalID(pathID)
     # get the working item
     customer, remotePath = packetid.SplitPacketID(pathID)
@@ -423,7 +441,6 @@ def DeletePathBackups(pathID, removeLocalFilesToo=True, saveDB=True, calculate=T
         io_throttle.DeleteBackupRequests(backupID)
         io_throttle.DeleteBackupSendings(backupID)
         # remove interests in transport_control
-        # callback.delete_backup_interest(backupID)
         # remove local files for this backupID
         if removeLocalFilesToo:
             backup_fs.DeleteLocalBackup(settings.getLocalBackupsDir(), backupID)
@@ -438,15 +455,15 @@ def DeletePathBackups(pathID, removeLocalFilesToo=True, saveDB=True, calculate=T
     backup_rebuilder.RemoveAllBackupsToWork()
     backup_rebuilder.SetStoppedFlag()
     # check and calculate used space
-    if calculate:
-        backup_fs.Scan()
-        backup_fs.Calculate()
+    if calculate or key_alias != 'master':
+        backup_fs.Scan(customer_idurl=customer_idurl, key_alias=key_alias)
+        backup_fs.Calculate(iterID=backup_fs.fsID(customer_idurl, key_alias))
     # save the index if needed
-    if saveDB:
-        Save()
-        # control.request_update()
+    if saveDB or key_alias != 'master':
+        SaveFSIndex(customer_idurl, key_alias)
     return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -468,9 +485,8 @@ class Task():
     As soon as task get executed it fires the result call back and removed from the list.
     When task executes a new backup job gets created.
     """
-
     def __init__(self, pathID, localPath=None, keyID=None):
-        self.number = NewTaskNumber()                   # index number for the task
+        self.number = NewTaskNumber()  # index number for the task
         self.created = time.time()
         self.backupID = None
         self.pathID = None
@@ -489,6 +505,7 @@ class Task():
         self.set_local_path(localPath)
         if _Debug:
             lg.out(_DebugLevel, 'new Task created: %r' % self)
+        # yapf: disable
         events.send('backup-task-created', data=dict(
             number=self.number,
             created=self.created,
@@ -500,14 +517,15 @@ class Task():
             local_path=self.localPath,
             remote_path=self.fullGlobPath,
         ))
+        # yapf: enable
 
     def destroy(self, message=None):
         if _Debug:
-            lg.out(_DebugLevel, 'backup_control.Task-%d.destroy %s -> %s' % (
-                self.number, self.localPath, self.backupID))
+            lg.out(_DebugLevel, 'backup_control.Task-%d.destroy %s -> %s' % (self.number, self.localPath, self.backupID))
         if self.result_defer and not self.result_defer.called:
             self.result_defer.cancel()
             self.result_defer = None
+        # yapf: disable
         events.send('backup-task-finished', data=dict(
             number=self.number,
             created=self.created,
@@ -520,6 +538,7 @@ class Task():
             remote_path=self.fullGlobPath,
             message=message,
         ))
+        # yapf: enable
 
     def set_path_id(self, pathID):
         parts = global_id.NormalizeGlobalID(pathID)
@@ -534,10 +553,8 @@ class Task():
     def set_key_id(self, key_id):
         self.keyID = key_id
         self.keyAlias = packetid.KeyAlias(self.keyID)
-        self.fullGlobPath = global_id.MakeGlobalID(
-            customer=self.customerGlobID, key_alias=self.keyAlias, path=self.remotePath)
-        self.fullCustomerID = global_id.MakeGlobalID(
-            customer=self.customerGlobID, key_alias=self.keyAlias)
+        self.fullGlobPath = global_id.MakeGlobalID(customer=self.customerGlobID, key_alias=self.keyAlias, path=self.remotePath)
+        self.fullCustomerID = global_id.MakeGlobalID(customer=self.customerGlobID, key_alias=self.keyAlias)
 
     def set_local_path(self, localPath):
         self.localPath = localPath
@@ -610,7 +627,7 @@ class Task():
         else:
             compress_mode = 'bz2'  # 'none' # 'gz'
         arcname = os.path.basename(sourcePath)
-        from storage import backup_tar
+        from bitdust.storage import backup_tar
         if bpio.pathIsDir(self.localPath):
             backupPipe = backup_tar.backuptardir_thread(self.localPath, arcname=arcname, compress=compress_mode)
         else:
@@ -637,16 +654,15 @@ class Task():
             backup_fs.SaveIndex(customer_idurl=self.customerIDURL, key_alias=self.keyAlias)
             if self.keyAlias == 'master':
                 if driver.is_on('service_backup_db'):
-                    # TODO: switch to event
-                    from storage import index_synchronizer
+                    from bitdust.storage import index_synchronizer
                     index_synchronizer.A('push')
         jobs()[self.backupID].automat('start')
         reactor.callLater(0, FireTaskStartedCallbacks, self.pathID, dataID)  # @UndefinedVariable
         if _Debug:
-            lg.out(_DebugLevel, 'backup_control.Task-%d.run [%s/%s], size=%d, %s' % (
-                self.number, self.pathID, dataID, itemInfo.size, self.localPath))
+            lg.out(_DebugLevel, 'backup_control.Task-%d.run [%s/%s], size=%d, %s' % (self.number, self.pathID, dataID, itemInfo.size, self.localPath))
         return None
 
+
 #------------------------------------------------------------------------------
 
 
@@ -686,7 +702,7 @@ def RunTask():
         return False
     if len(jobs()) >= MAXIMUM_JOBS_STARTED:
         return False
-    from customer import fire_hire
+    from bitdust.customer import fire_hire
     if not fire_hire.IsAllHired():
         if _Debug:
             lg.out(_DebugLevel, 'backup_control.RunTask some suppliers not hired yet, retry after 5 sec')
@@ -695,10 +711,13 @@ def RunTask():
     T = tasks().pop(0)
     message = T.run()
     if message:
-        events.send('backup-task-failed', data=dict(path_id=T.pathID, message=message, ))
+        events.send('backup-task-failed', data=dict(
+            path_id=T.pathID,
+            message=message,
+        ))
         T.result_defer.errback((T.pathID, message))
     else:
-    #     events.send('backup-task-executed', data=dict(path_id=T.pathID, backup_id=T.backupID, ))
+        #     events.send('backup-task-executed', data=dict(path_id=T.pathID, backup_id=T.backupID, ))
         T.result_defer.callback((T.backupID, None))
     T.destroy(message)
     return True
@@ -735,8 +754,10 @@ def AbortPendingTask(pathID):
             return True
     return False
 
+
 #------------------------------------------------------------------------------
 
+
 def OnFoundFolderSize(pth, sz, arg):
     """
     This is a callback, fired from ``lib.dirsize.ask()`` method after finish
@@ -750,8 +771,8 @@ def OnFoundFolderSize(pth, sz, arg):
         item = backup_fs.GetByID(pathID, iterID=backup_fs.fsID(customerIDURL, keyAlias))
         if item:
             item.set_size(sz)
-            backup_fs.Calculate()
-            Save()
+            backup_fs.Calculate(iterID=backup_fs.fsID(customerIDURL, keyAlias))
+            SaveFSIndex(customerIDURL, keyAlias)
         if version:
             backupID = packetid.MakeBackupID(customerGlobID, pathID, version, key_alias=keyAlias)
             job = GetRunningBackupObject(backupID)
@@ -769,8 +790,8 @@ def OnJobDone(backupID, result):
 
     Here we need to save the index data base.
     """
-    from storage import backup_rebuilder
-    # from customer import io_throttle
+    from bitdust.storage import backup_rebuilder
+    # from bitdust.customer import io_throttle
     lg.info('job done [%s] with result "%s", %d more tasks' % (backupID, result, len(tasks())))
     jobs().pop(backupID)
     keyAlias, customerGlobalID, remotePath, version = packetid.SplitBackupIDFull(backupID)
@@ -788,16 +809,13 @@ def OnJobDone(backupID, result):
                         backup_rebuilder.RemoveBackupToWork(backupID)
                         # io_throttle.DeleteBackupRequests(backupID)
                         # io_throttle.DeleteBackupSendings(backupID)
-                        # callback.delete_backup_interest(backupID)
                         backup_fs.DeleteLocalBackup(settings.getLocalBackupsDir(), backupID)
                         backup_matrix.EraseBackupLocalInfo(backupID)
                         backup_matrix.EraseBackupLocalInfo(backupID)
         backup_fs.ScanID(remotePath)
-        backup_fs.Calculate()
-        Save()
-        # control.request_update([('pathID', remotePath), ])
+        backup_fs.Calculate(iterID=backup_fs.fsID(customer_idurl, keyAlias))
+        SaveFSIndex(customer_idurl, keyAlias)
         # TODO: check used space, if we have over use - stop all tasks immediately
-        # backup_matrix.RepaintBackup(backupID)
     elif result == 'abort':
         DeleteBackup(backupID)
     if len(tasks()) == 0:
@@ -805,7 +823,7 @@ def OnJobDone(backupID, result):
         # if we have a lot tasks started this will produce a lot unneeded actions
         # will be smarter to restart it once we finish all tasks
         # because user will probably leave BitDust working after starting a long running operations
-        from storage import backup_monitor
+        from bitdust.storage import backup_monitor
         if _Debug:
             lg.out(_DebugLevel, 'backup_control.OnJobDone restarting backup_monitor() machine because no tasks left')
         backup_monitor.A('restart')
@@ -851,6 +869,7 @@ def OnTaskFailedCallback(result):
     lg.err('pathID: %s, error: %s' % (result[0], result[1]))
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -898,6 +917,7 @@ def FireTaskFinishedCallbacks(remotePath, version, result):
         cb(remotePath, version, result)
     _TaskFinishedCallbacks.pop(remotePath, None)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -905,7 +925,7 @@ def StartSingle(pathID, localPath=None, keyID=None):
     """
     A high level method to start a backup of single file or folder.
     """
-    from storage import backup_monitor
+    from bitdust.storage import backup_monitor
     t = PutTask(pathID=pathID, localPath=localPath, keyID=keyID)
     reactor.callLater(0, RunTask)  # @UndefinedVariable
     reactor.callLater(0, backup_monitor.A, 'restart')  # @UndefinedVariable
@@ -920,7 +940,7 @@ def StartRecursive(pathID, keyID=None):
     tasks for them.
     """
     pathID = global_id.CanonicalID(pathID)
-    from storage import backup_monitor
+    from bitdust.storage import backup_monitor
     startedtasks = []
 
     def visitor(_pathID, path, info):
@@ -936,6 +956,7 @@ def StartRecursive(pathID, keyID=None):
         lg.out(_DebugLevel, 'backup_control.StartRecursive %s  :  %d tasks started' % (pathID, len(startedtasks)))
     return startedtasks
 
+
 #------------------------------------------------------------------------------
 
 
@@ -1015,6 +1036,7 @@ def GetRunningBackupObject(backupID):
     backupID = global_id.CanonicalID(backupID)
     return jobs().get(backupID, None)
 
+
 #------------------------------------------------------------------------------
 #------------------------------------------------------------------------------
 #------------------------------------------------------------------------------
@@ -1024,11 +1046,11 @@ def test():
     """
     For tests.
     """
-#    backup_fs.Calculate()
-#    print backup_fs.counter()
-#    print backup_fs.numberfiles()
-#    print backup_fs.sizefiles()
-#    print backup_fs.sizebackups()
+    #    backup_fs.Calculate()
+    #    print backup_fs.counter()
+    #    print backup_fs.numberfiles()
+    #    print backup_fs.sizefiles()
+    #    print backup_fs.sizebackups()
     pprint.pprint(backup_fs.fsID())
     pprint.pprint(backup_fs.fs())
     print(backup_fs.GetByID('0'))
@@ -1045,10 +1067,10 @@ def test2():
     # reactor.callLater(1, StartDirRecursive, 'c:/temp')
     reactor.run()  # @UndefinedVariable
 
+
 #------------------------------------------------------------------------------
 
-
-if __name__ == "__main__":
+if __name__ == '__main__':
     bpio.init()
     lg.set_debug_level(20)
     settings.init()
