@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: backup_monitor.
 
@@ -91,27 +90,26 @@ except:
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import diskspace
-from lib import nameurl
-from lib import packetid
-from lib import misc
+from bitdust.lib import diskspace
+from bitdust.lib import packetid
+from bitdust.lib import misc
 
-from main import settings
+from bitdust.main import settings
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from storage import backup_matrix
-from storage import backup_fs
-from storage import backup_control
+from bitdust.storage import backup_matrix
+from bitdust.storage import backup_fs
+from bitdust.storage import backup_control
 
-from userid import global_id
-from userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import my_id
 
-from p2p import online_status
+from bitdust.p2p import online_status
 
 #------------------------------------------------------------------------------
 
@@ -127,7 +125,8 @@ def A(event=None, *args, **kwargs):
     global _BackupMonitor
     if _BackupMonitor is None:
         _BackupMonitor = BackupMonitor(
-            'backup_monitor', 'AT_STARTUP',
+            'backup_monitor',
+            'AT_STARTUP',
             debug_level=_DebugLevel,
             log_events=False,
             log_transitions=_Debug,
@@ -171,11 +170,11 @@ class BackupMonitor(automat.Automat):
             self.automat('instant')
 
     def A(self, event, *args, **kwargs):
-        from customer import fire_hire
-        from customer import list_files_orator
-        from storage import backup_rebuilder
-        from storage import index_synchronizer
-        from stream import data_sender
+        from bitdust.customer import fire_hire
+        from bitdust.customer import list_files_orator
+        from bitdust.storage import backup_rebuilder
+        from bitdust.storage import index_synchronizer
+        from bitdust.stream import data_sender
         #---AT_STARTUP---
         if self.state == 'AT_STARTUP':
             if event == 'init':
@@ -275,27 +274,28 @@ class BackupMonitor(automat.Automat):
         # also erase local info
         backup_matrix.ClearLocalInfo()
         # finally save the list of current suppliers and clear all stats
-        from stream import io_throttle
+        from bitdust.stream import io_throttle
         io_throttle.DeleteAllSuppliers()
 
     def doUpdateSuppliers(self, *args, **kwargs):
         """
         Action method.
         """
-        from stream import io_throttle
-        # supplierList = contactsdb.suppliers()
-        # take a list of suppliers positions that was changed
+        from bitdust.stream import io_throttle
+        # take a list of suppliers positions that ware changed
         changedSupplierNums = backup_matrix.SuppliersChangedNumbers(self.current_suppliers)
-        # notify io_throttle that we do not neeed already this suppliers
+        # notify io_throttle that we do not need already those suppliers
         for supplierNum in changedSupplierNums:
             suplier_idurl = self.current_suppliers[supplierNum]
             if suplier_idurl:
-                io_throttle.DeleteSuppliers([suplier_idurl, ])
+                io_throttle.DeleteSuppliers([
+                    suplier_idurl,
+                ])
             # erase (set to 0) remote info for this guys
             backup_matrix.ClearSupplierRemoteInfo(supplierNum)
 
     def doPrepareListBackups(self, *args, **kwargs):
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_rebuilder
         if backup_control.HasRunningBackup():
             # if some backups are running right now no need to rebuild something - too much use of CPU
             backup_rebuilder.RemoveAllBackupsToWork()
@@ -321,7 +321,7 @@ class BackupMonitor(automat.Automat):
         # here we check all backups we have and remove the old one
         # user can set how many versions of that file or folder to keep
         # other versions (older) will be removed here
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_rebuilder
         try:
             self.backups_progress_last_iteration = len(backup_rebuilder.A().backupsWasRebuilt)
         except:
@@ -330,7 +330,7 @@ class BackupMonitor(automat.Automat):
         if not contactsdb.num_suppliers():
             bytesUsed = 0
         else:
-            bytesUsed = backup_fs.sizebackups() / contactsdb.num_suppliers()
+            bytesUsed = backup_fs.sizebackups()/contactsdb.num_suppliers()
         bytesNeeded = diskspace.GetBytesFromString(settings.getNeededString(), 0)
         customerGlobID = my_id.getGlobalID()
         if _Debug:
@@ -346,8 +346,7 @@ class BackupMonitor(automat.Automat):
                 while len(versions) > versionsToKeep:
                     backupID = packetid.MakeBackupID(customerGlobID, pathID, versions.pop(0))
                     if _Debug:
-                        lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups %d of %d backups for %s, so remove older %s' % (
-                            len(versions), versionsToKeep, localPath, backupID))
+                        lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups %d of %d backups for %s, so remove older %s' % (len(versions), versionsToKeep, localPath, backupID))
                     backup_control.DeleteBackup(backupID, saveDB=False, calculate=False)
                     delete_count += 1
         # we need also to fit used space into needed space (given from other users)
@@ -368,8 +367,7 @@ class BackupMonitor(automat.Automat):
                     versionInfo = itemInfo.get_version_info(version)
                     if versionInfo[1] > 0:
                         if _Debug:
-                            lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups over use %d of %d, so remove %s of %s' % (
-                                bytesUsed, bytesNeeded, backupID, localPath))
+                            lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups over use %d of %d, so remove %s of %s' % (bytesUsed, bytesNeeded, backupID, localPath))
                         backup_control.DeleteBackup(backupID, saveDB=False, calculate=False)
                         delete_count += 1
                         bytesUsed -= versionInfo[1]
@@ -379,14 +377,11 @@ class BackupMonitor(automat.Automat):
         if delete_count > 0:
             backup_fs.Scan()
             backup_fs.Calculate()
-            backup_control.Save()
-            # from main import control
-            # control.request_update()
+            backup_control.SaveFSIndex()
         collected = gc.collect()
         if self.backups_progress_last_iteration > 0:
             if _Debug:
-                lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups  sending "restart", backups_progress_last_iteration=%s' % 
-                    self.backups_progress_last_iteration)
+                lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups  sending "restart", backups_progress_last_iteration=%s' % self.backups_progress_last_iteration)
             reactor.callLater(1, self.automat, 'restart')  # @UndefinedVariable
         if _Debug:
             lg.out(_DebugLevel, 'backup_monitor.doCleanUpBackups collected %d objects' % collected)
@@ -395,7 +390,7 @@ class BackupMonitor(automat.Automat):
         """
         Action method.
         """
-        from customer import fire_hire
+        from bitdust.customer import fire_hire
         if not fire_hire.IsAllHired():
             if _Debug:
                 lg.out(_DebugLevel, 'backup_monitor.doOverallCheckUp some suppliers not hired yet, restart now')
@@ -408,7 +403,7 @@ class BackupMonitor(automat.Automat):
                     lg.out(_DebugLevel, 'backup_monitor.doOverallCheckUp   restart after 1 min, found offline suppliers')
                 self.automat('restart')
                 return
-        if time.time() - self.last_execution_time > 60 * 10:
+        if time.time() - self.last_execution_time > 60*10:
             # also re-sync every 10 min.
             if _Debug:
                 lg.out(_DebugLevel, 'backup_monitor.doOverallCheckUp   periodic 10 min. restart')
