@@ -20,7 +20,6 @@
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
 #
-
 """
 .. module:: restore_monitor.
 
@@ -32,30 +31,30 @@ Manages currently restoring backups.
 
 from __future__ import absolute_import
 
-#------------------------------------------------------------------------------ 
+#------------------------------------------------------------------------------
 
 _Debug = False
 _DebugLevel = 8
 
-#------------------------------------------------------------------------------ 
+#------------------------------------------------------------------------------
 
 import os
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from main import events
+from bitdust.main import events
 
-from lib import misc
+from bitdust.lib import misc
 
-from system import tmpfile
+from bitdust.system import tmpfile
 
-from storage import backup_tar
-from storage import backup_matrix
-from storage import backup_control
+from bitdust.storage import backup_tar
+from bitdust.storage import backup_matrix
+from bitdust.storage import backup_control
 
-from userid import global_id
+from bitdust.userid import global_id
 
 #------------------------------------------------------------------------------
 
@@ -80,8 +79,10 @@ def shutdown():
     if _Debug:
         lg.out(_DebugLevel, 'restore_monitor.shutdown')
 
+
 #------------------------------------------------------------------------------
 
+
 def block_restored_callback(backupID, block):
     global OnRestoreBlockFunc
     if OnRestoreBlockFunc is not None:
@@ -131,7 +132,7 @@ def extract_failed(err, backupID, source_filename, output_location, callback_met
     _WorkingRestoreProgress.pop(backupID, None)
     tmpfile.throw_out(source_filename, 'file extract failed')
     if OnRestoreDoneFunc is not None:
-        OnRestoreDoneFunc(backupID, 'extract failed')    
+        OnRestoreDoneFunc(backupID, 'extract failed')
     if callback_method:
         try:
             callback_method(backupID, 'extract failed')
@@ -175,8 +176,10 @@ def restore_done(result, backupID, outfd, tarfilename, outputlocation, callback_
             lg.exc()
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def Start(backupID, outputLocation, callback=None, keyID=None):
     if _Debug:
         lg.out(_DebugLevel, 'restore_monitor.Start %s to %s' % (backupID, outputLocation))
@@ -189,7 +192,7 @@ def Start(backupID, outputLocation, callback=None, keyID=None):
         extension='.tar.gz',
         prefix=backupID.replace('@', '_').replace('.', '_').replace('/', '_').replace(':', '_') + '_',
     )
-    from storage import restore_worker
+    from bitdust.storage import restore_worker
     r = restore_worker.RestoreWorker(backupID, outfd, KeyID=keyID)
     r.MyDeferred.addCallback(restore_done, backupID, outfd, outfilename, outputLocation, callback)
     r.set_block_restored_callback(block_restored_callback)
@@ -212,6 +215,7 @@ def Abort(backupID):
         lg.out(_DebugLevel, 'restore_monitor.Abort %s' % backupID)
     return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -282,7 +286,7 @@ def GetBackupStatusInfo(backupID, item_info, item_name, parent_path_existed=None
             currentBlock = max(0, restoreObj.block_number)
             percent = 0.0
             if maxBlockNum > 0:
-                percent = 100.0 * currentBlock / maxBlockNum
+                percent = 100.0*currentBlock/maxBlockNum
             ret['state'] = 'downloading'
             ret['progress'] = misc.percent2string(percent)
             return ret
