@@ -39,32 +39,33 @@ import zlib
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from lib import strng
-from lib import packetid
-from lib import misc
+from bitdust.lib import strng
+from bitdust.lib import packetid
+from bitdust.lib import misc
 
-from main import settings
+from bitdust.main import settings
 
-from crypt import encrypted
-from crypt import key
-from crypt import my_keys
+from bitdust.crypt import encrypted
+from bitdust.crypt import key
+from bitdust.crypt import my_keys
 
-from p2p import commands
-from p2p import p2p_service
-from contacts import identitycache
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.contacts import identitycache
 
-from userid import my_id
-from userid import global_id
+from bitdust.userid import my_id
+from bitdust.userid import global_id
 
 #------------------------------------------------------------------------------
 
+
 def send(customer_idurl, packet_id, format_type, key_id, remote_idurl, query_items=[]):
     if not query_items:
-        query_items = ['*', ]
+        query_items = ['*']
     key_id = my_keys.latest_key_id(key_id)
     parts = global_id.NormalizeGlobalID(key_id)
     if parts['key_alias'] == 'master' and parts['idurl'] != my_id.getIDURL():
@@ -75,12 +76,10 @@ def send(customer_idurl, packet_id, format_type, key_id, remote_idurl, query_ite
             if not my_keys.register_key(key_id, known_ident.getPublicKey()):
                 lg.err('failed to register known public key of the customer: %r' % key_id)
     if not my_keys.is_key_registered(key_id):
-        lg.warn('not able to return Files() for customer %s, key %s not registered' % (
-            customer_idurl, key_id, ))
+        lg.warn('not able to return Files() for customer %s, key %s not registered' % (customer_idurl, key_id))
         return p2p_service.SendFailNoRequest(customer_idurl, packet_id, response='key not registered')
     if _Debug:
-        lg.out(_DebugLevel, "list_files.send to %s, customer_idurl=%s, key_id=%s, query_items=%r" % (
-            remote_idurl, customer_idurl, key_id, query_items, ))
+        lg.out(_DebugLevel, 'list_files.send to %s, customer_idurl=%s, key_id=%s, query_items=%r' % (remote_idurl, customer_idurl, key_id, query_items))
     ownerdir = settings.getCustomerFilesDir(customer_idurl)
     plaintext = ''
     if os.path.isdir(ownerdir):
@@ -121,13 +120,20 @@ def process_query_item(query_path, key_alias, ownerdir):
     ret = ''
     ret += 'Q%s\n' % query_path
     if query_path == '*':
+        if key_alias == 'master':
+            key_alias_dir = os.path.join(ownerdir, key_alias)
+            ret += TreeSummary(key_alias_dir, key_alias)
         for one_key_alias in os.listdir(ownerdir):
+            if one_key_alias == 'master':
+                continue
+            if key_alias and key_alias != 'master' and one_key_alias != key_alias:
+                continue
             if not misc.ValidKeyAlias(strng.to_text(one_key_alias)):
                 continue
             key_alias_dir = os.path.join(ownerdir, one_key_alias)
-            ret += TreeSummary(key_alias_dir, key_alias=one_key_alias)
+            ret += TreeSummary(key_alias_dir, one_key_alias)
         if _Debug:
-            lg.args(_DebugLevel, ownerdir=ownerdir, query_path=query_path, result_bytes=len(ret))
+            lg.args(_DebugLevel, o=ownerdir, q=query_path, k=key_alias, result_bytes=len(ret))
         return ret
     # TODO: more validations to be added
     clean_path = query_path.replace('.', '').replace('~', '').replace(':', '').replace('\\', '/').lstrip('/')
@@ -137,49 +143,45 @@ def process_query_item(query_path, key_alias, ownerdir):
     if not os.path.exists(local_path):
         lg.warn('local file or folder not exist: %r' % local_path)
         return ''
-    if os.path.isdir(local_path):
-        ret += TreeSummary(local_path, key_alias=key_alias)
+    ret += TreeSummary(local_path, key_alias)
     if _Debug:
-        lg.args(_DebugLevel, ownerdir=ownerdir, query_path=query_path, local_path=local_path, result_bytes=len(ret))
+        lg.args(_DebugLevel, o=ownerdir, q=query_path, k=key_alias, p=local_path, result_bytes=len(ret))
     return ret
 
+
 #------------------------------------------------------------------------------
 
+
 def on_acked(response, info):
     if _Debug:
-        lg.out(_DebugLevel, 'list_files.on_acked with %s in %s' % (response, info, ))
+        lg.out(_DebugLevel, 'list_files.on_acked with %s in %s' % (response, info))
 
 
 def on_failed(response, error):
-    lg.warn('send files %s failed with %s' % (response, error, ))
+    lg.warn('send files %s failed with %s' % (response, error))
 
 
 def on_timeout(pkt_out):
     lg.warn('send files with %s was timed out' % pkt_out)
 
+
 #------------------------------------------------------------------------------
 
+
 def PackListFiles(plaintext, method):
-    if method == "Text":
+    if method == 'Text':
         return plaintext
-    elif method == "Compressed":
+    elif method == 'Compressed':
         return zlib.compress(strng.to_bin(plaintext))
     return ''
 
 
-def UnpackListFiles(payload, method):
-    if method == "Text":
-        return payload
-    elif method == "Compressed":
-        return strng.to_text(zlib.decompress(strng.to_bin(payload)))
-    return payload
-
 #------------------------------------------------------------------------------
 
-def TreeSummary(ownerdir, key_alias=None):
+
+def TreeSummary(ownerdir, key_alias):
     out = StringIO()
-    if key_alias is not None:
-        out.write('K%s\n' % key_alias)
+    out.write('K%s\n' % key_alias)
 
     def cb(result, realpath, subpath, name):
         if not os.access(realpath, os.R_OK):
@@ -252,8 +254,7 @@ def TreeSummary(ownerdir, key_alias=None):
                     parityMissing[supplierNum].discard(blockNum)
         suppliers = set(list(dataBlocks.keys()) + list(parityBlocks.keys()))
         for supplierNum in suppliers:
-            versionString = '%s %d 0-%d %d' % (
-                subpath, supplierNum, maxBlock, versionSize[supplierNum])
+            versionString = '%s %d 0-%d %d' % (subpath, supplierNum, maxBlock, versionSize[supplierNum])
             if len(dataMissing[supplierNum]) > 0 or len(parityMissing[supplierNum]) > 0:
                 versionString += ' missing'
                 if len(dataMissing[supplierNum]) > 0:
@@ -272,4 +273,5 @@ def TreeSummary(ownerdir, key_alias=None):
     out.close()
     return src
 
+
 #------------------------------------------------------------------------------
