@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: bpio.
 
@@ -57,11 +56,11 @@ import shutil
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import local_fs
+from bitdust.system import local_fs
 
 #------------------------------------------------------------------------------
 
@@ -109,7 +108,7 @@ def InstallLocale():
         if sys.version_info[0] == 2:
             reload(sys)  # @UndefinedVariable
             if Windows():
-                if hasattr(sys, "setdefaultencoding"):
+                if hasattr(sys, 'setdefaultencoding'):
                     import locale
                     denc = locale.getpreferredencoding()
                     if not denc:
@@ -200,21 +199,21 @@ def Linux():
     """
     Return True if current platform is Linux.
     """
-    return ostype() == "Linux"
+    return ostype() == 'Linux'
 
 
 def Windows():
     """
     Return True if current platform is Windows.
     """
-    return ostype() == "Windows"
+    return ostype() == 'Windows'
 
 
 def Mac():
     """
     Return True if current platform is Mac.
     """
-    return ostype() == "Darwin"
+    return ostype() == 'Darwin'
 
 
 def Android():
@@ -241,6 +240,7 @@ def isConsoled():
         return False
     return True
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -269,19 +269,20 @@ def list_dir_recursive(dirpath):
     return r
 
 
-def traverse_dir_recursive(callback, basepath, relpath=''):
+def traverse_dir_recursive(callback, basepath, relative_path=''):
     """
     Call ``callback`` method for every file and folder under ``basepath``.
 
     If method ``callback`` can returns False traverse process will not
     go deeper. Useful to count size of the whole folder.
     """
-    for name in os.listdir(basepath):
-        realpath = os.path.join(basepath, name)
-        subpath = name if relpath == '' else relpath + '/' + name
-        go_down = callback(realpath, subpath, name)
-        if os.path.isdir(realpath) and go_down:
-            traverse_dir_recursive(callback, realpath, subpath)
+    if os.path.isdir(basepath):
+        for name in os.listdir(basepath):
+            real_path = os.path.join(basepath, name)
+            sub_path = name if relative_path == '' else relative_path + '/' + name
+            go_down = callback(real_path, sub_path, name)
+            if os.path.isdir(real_path) and go_down:
+                traverse_dir_recursive(callback, real_path, sub_path)
 
 
 def rmdir_recursive(dirpath, ignore_errors=False, pre_callback=None):
@@ -318,7 +319,7 @@ def rmdir_recursive(dirpath, ignore_errors=False, pre_callback=None):
                         os.remove(full_name)
                         counter += 1
                     except Exception as exc:
-                        lg.err('can not remove file %r : %r' % (full_name, exc, ))
+                        lg.err('can not remove file %r : %r' % (full_name, exc))
                         continue
     if pre_callback:
         if not pre_callback(dirpath):
@@ -329,7 +330,7 @@ def rmdir_recursive(dirpath, ignore_errors=False, pre_callback=None):
         try:
             os.rmdir(dirpath)
         except Exception as exc:
-            lg.err('can not remove dir %r : %r' % (dirpath, exc, ))
+            lg.err('can not remove dir %r : %r' % (dirpath, exc))
     return counter
 
 
@@ -376,6 +377,7 @@ def getDirectorySize(directory, include_subfolders=True):
                     if name not in DIR_EXCLUDES:
                         total_size += _get_dir_size(path + '\\' + name)
             return total_size
+
         return _get_dir_size(directory)
     dir_size = 0
     if not include_subfolders:
@@ -397,8 +399,10 @@ def getDirectorySize(directory, include_subfolders=True):
                         pass
     return dir_size
 
+
 #-------------------------------------------------------------------------------
 
+
 def WriteBinaryFile(filename, data):
     return local_fs.WriteBinaryFile(filename=filename, data=data)
 
@@ -414,6 +418,7 @@ def WriteTextFile(filepath, data):
 def ReadTextFile(filename):
     return local_fs.ReadTextFile(filename=filename)
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -445,7 +450,9 @@ def _unpack_list(src):
         return words, None
     res = words[1:]
     if len(res) < length:
-        res += [u'', ] * (length - len(res))
+        res += [
+            u'',
+        ]*(length - len(res))
     elif len(res) > length:
         return res[:length], res[length:]
     return res, None
@@ -557,6 +564,7 @@ def _dir_remove(path):
     """
     rmdir_recursive(path)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -628,6 +636,7 @@ def remove_backuped_file(path):
         lg.out(1, 'bpio.remove_backuped_file ERROR can not remove file ' + bkpath)
         lg.exc()
 
+
 #------------------------------------------------------------------------------
 
 
@@ -674,6 +683,7 @@ def HigherPriority():
         import os
         os.nice(1)
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -854,6 +864,7 @@ def pathIsNetworkLocation(path):
         return False
     return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -863,9 +874,9 @@ def main_is_frozen():
 
     http://www.py2exe.org/index.cgi/HowToDetermineIfRunningFromExe
     """
-    return (hasattr(sys, "frozen") or       # new py2exe
-            hasattr(sys, "importers") or    # old py2exe
-            imp.is_frozen("__main__"))      # tools/freeze
+    return (hasattr(sys, 'frozen') or  # new py2exe
+            hasattr(sys, 'importers') or  # old py2exe
+            imp.is_frozen('__main__'))  # tools/freeze
 
 
 def isGUIpossible():
@@ -895,7 +906,7 @@ def X11_is_running():
         return X11isRunning
     try:
         from subprocess import Popen, PIPE
-        p = Popen(["xset", "-q"], stdout=PIPE, stderr=PIPE)
+        p = Popen(['xset', '-q'], stdout=PIPE, stderr=PIPE)
         p.communicate()
         result = p.returncode == 0
     except:
@@ -903,6 +914,7 @@ def X11_is_running():
     X11isRunning = result
     return X11isRunning
 
+
 #------------------------------------------------------------------------------
 
 
@@ -952,6 +964,7 @@ def getUserName():
         pass
     return os.path.basename(strng.to_text(os.path.expanduser('~')))
 
+
 #------------------------------------------------------------------------------
 
 
@@ -982,7 +995,7 @@ def listLocalDrivesWindows():
     try:
         import win32api  # @UnresolvedImport
         import win32file  # @UnresolvedImport
-        drives = (drive for drive in win32api.GetLogicalDriveStrings().split("\000") if drive)
+        drives = (drive for drive in win32api.GetLogicalDriveStrings().split('\000') if drive)
         for drive in drives:
             if win32file.GetDriveType(drive) == 3:
                 rootlist.append(drive)
@@ -1070,6 +1083,7 @@ def getMountPointLinux(path):
         path = os.path.dirname(path)
     return path
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -1123,7 +1137,7 @@ def kill_process(pid):
     if Android():
         return
     ostype = platform.uname()[0]
-    if ostype == "Windows":
+    if ostype == 'Windows':
         kill_process_win32(pid)
     else:
         kill_process_linux(pid)
@@ -1147,10 +1161,10 @@ def list_processes_linux():
     for pid_path in glob.glob('/proc/[0-9]*'):
         try:
             # cmdline represents the command whith which the process was started
-            f = open("%s/cmdline" % pid_path)
-            pid = pid_path.split("/")[2]  # get the PID
+            f = open('%s/cmdline' % pid_path)
+            pid = pid_path.split('/')[2]  # get the PID
             # we replace the \x00 to spaces to make a prettier output from kernel
-            cmdline = f.read().replace("\x00", " ").rstrip()
+            cmdline = f.read().replace('\x00', ' ').rstrip()
             f.close()
             yield (pid, cmdline)
         except:
@@ -1189,8 +1203,8 @@ def find_process_win32(applist):
     pidsL = []
     try:
         import win32com.client  # @UnresolvedImport
-        objWMI = win32com.client.GetObject("winmgmts:\\\\.\\root\\CIMV2")
-        colProcs = objWMI.ExecQuery("SELECT * FROM Win32_Process")
+        objWMI = win32com.client.GetObject('winmgmts:\\\\.\\root\\CIMV2')
+        colProcs = objWMI.ExecQuery('SELECT * FROM Win32_Process')
         for Item in colProcs:
             pid = int(Item.ProcessId)
             if pid == os.getpid():
@@ -1248,16 +1262,17 @@ def kill_process_win32(pid):
         return False
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file=True):
     if Android():
         return []
     q = [
         'bitdustnode.exe',
         'BitDustNode.exe',
-        'BitDustConsole.exe',
-        # 'bitdust.py',
+        'BitDustConsole.exe',  # 'bitdust.py',
     ]
     if os.environ.get('BITDUST_IN_DOCKER') == '1':
         q.extend([
@@ -1276,7 +1291,7 @@ def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file
         return appList
     try:
         if not pid_file_path:
-            from main import settings
+            from bitdust.main import settings
             pid_file_path = os.path.join(settings.MetaDataDir(), 'processid')
         processid = int(ReadTextFile(pid_file_path))
     except:
@@ -1285,7 +1300,9 @@ def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file
         return appList
     if processid not in appList:
         return []
-    return [processid, ]
+    return [
+        processid,
+    ]
 
 
 def lookup_main_process():
@@ -1306,6 +1323,7 @@ def lookup_main_process():
         ])
     return find_process(q)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -1314,18 +1332,18 @@ def detect_number_of_cpu_cores():
     Detects the number of effective CPUs in the system.
     """
     # for Linux, Unix and MacOS
-    if hasattr(os, "sysconf"):
-        if "SC_NPROCESSORS_ONLN" in os.sysconf_names:
+    if hasattr(os, 'sysconf'):
+        if 'SC_NPROCESSORS_ONLN' in os.sysconf_names:
             #Linux and Unix
-            ncpus = os.sysconf("SC_NPROCESSORS_ONLN")
+            ncpus = os.sysconf('SC_NPROCESSORS_ONLN')
             if isinstance(ncpus, int) and ncpus > 0:
                 return ncpus
         else:
             # MacOS X
-            return int(os.popen2("sysctl -n hw.ncpu")[1].read())  # @UndefinedVariable
+            return int(os.popen2('sysctl -n hw.ncpu')[1].read())  # @UndefinedVariable
     # for Windows
-    if "NUMBER_OF_PROCESSORS" in os.environ:
-        ncpus = int(os.environ["NUMBER_OF_PROCESSORS"])
+    if 'NUMBER_OF_PROCESSORS' in os.environ:
+        ncpus = int(os.environ['NUMBER_OF_PROCESSORS'])
         if ncpus > 0:
             return ncpus
     # return the default value
