@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: child_process.
 
@@ -44,15 +43,15 @@ from twisted.internet import protocol
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import nonblocking
+from bitdust.system import bpio
+from bitdust.system import nonblocking
 
 #------------------------------------------------------------------------------
 
-class ChildProcessProtocol(protocol.ProcessProtocol):
 
+class ChildProcessProtocol(protocol.ProcessProtocol):
     def __init__(self, name):
         self.name = name
 
@@ -63,8 +62,10 @@ class ChildProcessProtocol(protocol.ProcessProtocol):
     def processEnded(self, reason):
         lg.out(2, 'child process [%s] FINISHED' % self.name)
 
+
 #------------------------------------------------------------------------------
 
+
 def run(child_name, params=[], base_dir='.', process_protocol=None):
     """
     This is another portable solution to execute a process.
@@ -91,15 +92,11 @@ def run(child_name, params=[], base_dir='.', process_protocol=None):
         from twisted.internet import _dumbwin32proc
         real_CreateProcess = _dumbwin32proc.win32process.CreateProcess  # @UndefinedVariable
 
-        def fake_createprocess(_appName, _commandLine, _processAttributes,
-                               _threadAttributes, _bInheritHandles, creationFlags,
-                               _newEnvironment, _currentDirectory, startupinfo):
+        def fake_createprocess(_appName, _commandLine, _processAttributes, _threadAttributes, _bInheritHandles, creationFlags, _newEnvironment, _currentDirectory, startupinfo):
             import win32con  # @UnresolvedImport
             flags = win32con.CREATE_NO_WINDOW
-            return real_CreateProcess(_appName, _commandLine,
-                                      _processAttributes, _threadAttributes,
-                                      _bInheritHandles, flags, _newEnvironment,
-                                      _currentDirectory, startupinfo)
+            return real_CreateProcess(_appName, _commandLine, _processAttributes, _threadAttributes, _bInheritHandles, flags, _newEnvironment, _currentDirectory, startupinfo)
+
         setattr(_dumbwin32proc.win32process, 'CreateProcess', fake_createprocess)
 
     if process_protocol is None:
@@ -142,6 +139,7 @@ def kill_child(child_name):
         killed = True
     return killed
 
+
 #------------------------------------------------------------------------------
 
 
@@ -152,7 +150,7 @@ def pipe(cmdargs):
 
     See ``lib.nonblocking`` module.
     """
-    lg.out(6, "child_process.pipe %s" % str(cmdargs))
+    lg.out(6, 'child_process.pipe %s' % str(cmdargs))
     try:
         if bpio.Windows():
             import win32process  # @UnresolvedImport
@@ -182,7 +180,7 @@ def pipe(cmdargs):
 
 
 def detach(cmdargs):
-    lg.out(2, "child_process.detach %s" % str(cmdargs))
+    lg.out(2, 'child_process.detach %s' % str(cmdargs))
     try:
         if bpio.Windows():
             import win32process  # @UnresolvedImport
