@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: local_fs.
 
@@ -34,7 +33,6 @@
 
 from __future__ import absolute_import
 from io import open
-import six
 
 #------------------------------------------------------------------------------
 
@@ -43,9 +41,9 @@ import platform
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
-from logs import lg
+from bitdust.logs import lg
 
 #------------------------------------------------------------------------------
 
@@ -53,6 +51,7 @@ _PlatformInfo = None
 
 #------------------------------------------------------------------------------
 
+
 def WriteBinaryFile(filename, data):
     """
     A smart way to write data to binary file. Return True if success.
@@ -62,7 +61,7 @@ def WriteBinaryFile(filename, data):
     if _PlatformInfo is None:
         _PlatformInfo = platform.uname()
     try:
-        tmpfilename = filename + ".new"
+        tmpfilename = filename + '.new'
         f = open(tmpfilename, 'wb')
         bin_data = strng.to_bin(data)
         f.write(bin_data)
@@ -138,6 +137,7 @@ def ReadBinaryFile(filename, decode_encoding=None):
         lg.exc('file read failed: %r' % filename)
         return b''
 
+
 #------------------------------------------------------------------------------
 
 
@@ -158,7 +158,7 @@ def WriteTextFile(filepath, data):
         except:
             lg.exc()
             return False
-    fout = open(temp_path, 'wt', encoding="utf-8")
+    fout = open(temp_path, 'wt', encoding='utf-8')
     text_data = strng.to_text(data)
     fout.write(text_data)
     fout.flush()
@@ -186,7 +186,7 @@ def ReadTextFile(filename):
     if not os.access(filename, os.R_OK):
         return u''
     try:
-        infile = open(filename, 'rt', encoding="utf-8")
+        infile = open(filename, 'rt', encoding='utf-8')
         data = infile.read()
         infile.close()
         return strng.to_text(data)
@@ -194,6 +194,7 @@ def ReadTextFile(filename):
         lg.exc('file read failed: %r' % filename)
     return u''
 
+
 #------------------------------------------------------------------------------
 
 
@@ -214,9 +215,8 @@ def RoundupFile(filename, stepsize):
     if mod > 0:
         increase = stepsize - mod
         fil = open(filename, 'a')
-        fil.write(u' ' * increase)
+        fil.write(u' '*increase)
         fil.flush()
         os.fsync(fil)
         fil.close()
     return increase
-
