@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: tmpfile.
 
@@ -51,9 +50,9 @@ from twisted.internet import task  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
 #------------------------------------------------------------------------------
 
@@ -61,47 +60,22 @@ _TempDirPath = None
 _FilesDict = {}
 _CollectorTask = None
 _SubDirs = {
-
-    'outbox': 60 * 60 * 1,
-    # hold onto outbox files 1 hour
+    'outbox': 60*60*1,  # hold onto outbox files 1 hour
     # so we can handle resends if contact is off-line
-
-    'tcp-in': 60 * 10,
-    # 10 minutes for incoming tcp files
-
-    'udp-in': 60 * 10,
-    # 10 minutes for incoming udp files
-
-    'proxy-in': 60 * 10,
-    # 10 minutes for incoming proxy files
-
-    'proxy-out': 60 * 10,
-    # 10 minutes for outgoing proxy files
-
-    'propagate': 60 * 10,
-    # propagate happens often enough,
+    'tcp-in': 60*10,  # 10 minutes for incoming tcp files
+    'udp-in': 60*10,  # 10 minutes for incoming udp files
+    'proxy-in': 60*10,  # 10 minutes for incoming proxy files
+    'proxy-out': 60*10,  # 10 minutes for outgoing proxy files
+    'propagate': 60*10,  # propagate happens often enough,
     # 10 minutes should be enough
-
-    'backup': 60 * 10,
-    # 10 minutes for backup files
-
-    'restore': 0,
-    # never remove files during restore process, they must be cleaned afterwards
-
-    'raid': 60 * 10,
-    # 10 minutes for backup files
-
-    'idsrv': 60,
-    # 1 minute for incoming xml identity files
-
-    'error': 60 * 60 * 24 * 30,
-    # store errors for one month
-
-    'all': 0,
-    # other files. do not know when to remove
+    'backup': 60*10,  # 10 minutes for backup files
+    'restore': 0,  # never remove files during restore process, they must be cleaned afterwards
+    'raid': 60*10,  # 10 minutes for backup files
+    'idsrv': 60,  # 1 minute for incoming xml identity files
+    'error': 60*60*24*30,  # store errors for one month
+    'all': 0,  # other files. do not know when to remove
     # they can be even in another location
     # use register(name, filename)
-
 }
 
 #------------------------------------------------------------------------------
@@ -160,7 +134,7 @@ def init(temp_dir_path=''):
 
     if _CollectorTask is None:
         _CollectorTask = task.LoopingCall(collect)
-        _CollectorTask.start(60 * 5)
+        _CollectorTask.start(60*5)
 
 
 def shutdown():
@@ -385,8 +359,8 @@ def startup_clean():
                 else:
                     raise Exception('path %s not exist' % filepath)
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     lg.set_debug_level(18)
