@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: http_interface.
 
@@ -44,25 +43,24 @@ import six
 import sys
 
 try:
-    from twisted.internet import reactor  # @UnresolvedImport
+    pass
 except:
     sys.exit('Error initializing twisted.internet.reactor in http_interface.py')
 
 from twisted.web import xmlrpc
 from twisted.internet.defer import succeed, fail
-from twisted.python.failure import Failure
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from main import settings
+from bitdust.main import settings
 
-from lib import misc
-from lib import strng
-from lib import net_misc
+from bitdust.lib import misc
+from bitdust.lib import strng
+from bitdust.lib import net_misc
 
-from transport.http import http_node
+from bitdust.transport.http import http_node
 
 #------------------------------------------------------------------------------
 
@@ -75,11 +73,11 @@ def proxy():
     global _GateProxy
     return _GateProxy
 
+
 #------------------------------------------------------------------------------
 
 
 class GateInterface():
-
     def init(self, xml_rpc_url_or_object):
         """
         """
@@ -166,6 +164,7 @@ class GateInterface():
         """
         return http_node.send_file(remote_idurl, filename)
 
+
 #     def connect_to(self, host):
 #         """
 #         """
@@ -243,16 +242,14 @@ def interface_disconnected(result=None):
 
 def interface_register_file_sending(host, receiver_idurl, filename, size=0, description=''):
     if proxy():
-        return proxy().callRemote(
-            'register_file_sending', 'http', net_misc.pack_address(host), receiver_idurl, filename, size, description)
+        return proxy().callRemote('register_file_sending', 'http', net_misc.pack_address(host), receiver_idurl, filename, size, description)
     lg.warn('transport_http is not ready')
     return fail(Exception('transport_http is not ready'))
 
 
 def interface_register_file_receiving(host, sender_idurl, filename, size=0):
     if proxy():
-        return proxy().callRemote(
-            'register_file_receiving', 'http', net_misc.pack_address(host), sender_idurl, filename, size)
+        return proxy().callRemote('register_file_receiving', 'http', net_misc.pack_address(host), sender_idurl, filename, size)
     lg.warn('transport_http is not ready')
     return fail(Exception('transport_http is not ready'))
 
@@ -273,7 +270,6 @@ def interface_unregister_file_receiving(transfer_id, status, size=0, error_messa
 
 def interface_cancelled_file_sending(host, filename, size=0, description=None, error_message=None):
     if proxy():
-        return proxy().callRemote(
-            'cancelled_file_sending', 'http', net_misc.pack_address(host), filename, size, description, error_message)
+        return proxy().callRemote('cancelled_file_sending', 'http', net_misc.pack_address(host), filename, size, description, error_message)
     lg.warn('transport_http is not ready')
     return fail(Exception('transport_http is not ready'))
