@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: packet_in.
 
@@ -64,31 +62,31 @@ from twisted.internet import reactor  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from main import settings
-from main import config
+from bitdust.main import settings
+from bitdust.main import config
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import nameurl
-from lib import strng
+from bitdust.lib import nameurl
+from bitdust.lib import strng
 
-from system import bpio
-from system import tmpfile
+from bitdust.system import bpio
+from bitdust.system import tmpfile
 
-from userid import global_id
-from userid import id_url
+from bitdust.userid import global_id
+from bitdust.userid import id_url
 
-from contacts import contactsdb
-from contacts import identitycache
+from bitdust.contacts import contactsdb
+from bitdust.contacts import identitycache
 
-from services import driver
+from bitdust.services import driver
 
-from p2p import commands
-from p2p import p2p_stats
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_stats
 
-from transport import callback
+from bitdust.transport import callback
 
 #------------------------------------------------------------------------------
 
@@ -98,6 +96,7 @@ _History = []
 
 #------------------------------------------------------------------------------
 
+
 def init():
     global _PacketLogFileEnabled
     _PacketLogFileEnabled = config.conf().getBool('logs/packet-enabled')
@@ -107,8 +106,10 @@ def shutdown():
     global _PacketLogFileEnabled
     _PacketLogFileEnabled = False
 
+
 #------------------------------------------------------------------------------
 
+
 def get_packets_counter():
     global _PacketsCounter
     return _PacketsCounter
@@ -118,6 +119,7 @@ def increment_packets_counter():
     global _PacketsCounter
     _PacketsCounter += 1
 
+
 #------------------------------------------------------------------------------
 
 
@@ -143,7 +145,9 @@ def search(sender_idurl=None, proto=None, host=None):
     Returns list of transfer ids of incoming packets which satisfies given criteria.
     """
     if sender_idurl and not isinstance(sender_idurl, list):
-        sender_idurl = [sender_idurl, ]
+        sender_idurl = [
+            sender_idurl,
+        ]
     results = set()
     for transfer_id, itm in inbox_items().items():
         if sender_idurl:
@@ -169,6 +173,7 @@ def history():
     global _History
     return _History
 
+
 #------------------------------------------------------------------------------
 
 
@@ -177,27 +182,38 @@ def process(newpacket, info):
     Main entry point where all incoming signed packets are coming from remote peers.
     The main aspect here is to "authenticate" remote node - need to know it identity.
     """
-    # from p2p import p2p_service
-    from transport import gateway
-    from userid import my_id
+    # from bitdust.p2p import p2p_service
+    from bitdust.transport import gateway
+    from bitdust.userid import my_id
     if not driver.is_on('service_p2p_hookups'):
         if _Debug:
             lg.out(_DebugLevel, 'packet_in.process SKIP incoming packet, service_p2p_hookups is not started')
         return None
     if _Debug:
-        lg.out(_DebugLevel, 'packet_in.process [%s/%s/%s]:%s(%s) from %s://%s is "%s"' % (
-            nameurl.GetName(newpacket.OwnerID), nameurl.GetName(newpacket.CreatorID), nameurl.GetName(newpacket.RemoteID),
-            newpacket.Command, newpacket.PacketID, info.proto, info.host, info.status, ))
+        lg.out(
+            _DebugLevel, 'packet_in.process [%s/%s/%s]:%s(%s) from %s://%s is "%s"' % (
+                nameurl.GetName(newpacket.OwnerID),
+                nameurl.GetName(newpacket.CreatorID),
+                nameurl.GetName(newpacket.RemoteID),
+                newpacket.Command,
+                newpacket.PacketID,
+                info.proto,
+                info.host,
+                info.status,
+            )
+        )
     if info.status != 'finished':
         if _Debug:
             lg.out(_DebugLevel, '    skip, packet status is : [%s]' % info.status)
         return None
+
+
 #     if _PacketLogFileEnabled:
 #         lg.out(0, '        \033[0;49;92mIN %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
 #             newpacket.Command, newpacket.PacketID, info.bytes_received,
 #             global_id.UrlToGlobalID(info.sender_idurl), global_id.UrlToGlobalID(newpacket.RemoteID),
 #             info.transfer_id), log_name='packet', showtime=True)
-    # we must know recipient identity
+# we must know recipient identity
     if not id_url.is_cached(newpacket.RemoteID):
         d = identitycache.immediatelyCaching(newpacket.RemoteID)
         d.addCallback(lambda _: process(newpacket, info))
@@ -235,7 +251,7 @@ def handle(newpacket, info):
     """
     Actually process incoming packet. Here we can be sure that owner/creator of the packet is identified.
     """
-    from transport import packet_out
+    from bitdust.transport import packet_out
     handled = False
     # check that signed by a contact of ours
     try:
@@ -246,13 +262,8 @@ def handle(newpacket, info):
         #     info.proto, info.host, newpacket.Serialize()))
     if not is_signature_valid:
         if _Debug:
-            lg.args(_DebugLevel,
-                    PacketID=newpacket.PacketID,
-                    OwnerID=newpacket.OwnerID,
-                    CreatorID=newpacket.CreatorID,
-                    RemoteID=newpacket.RemoteID, )
-        lg.warn('signature is not valid for %r from %r|%r to %r' % (
-            newpacket, newpacket.OwnerID, newpacket.CreatorID, newpacket.RemoteID))
+            lg.args(_DebugLevel, PacketID=newpacket.PacketID, OwnerID=newpacket.OwnerID, CreatorID=newpacket.CreatorID, RemoteID=newpacket.RemoteID)
+        lg.warn('signature is not valid for %r from %r|%r to %r' % (newpacket, newpacket.OwnerID, newpacket.CreatorID, newpacket.RemoteID))
         return None
     try:
         if not commands.IsRelay(newpacket.Command):
@@ -267,34 +278,59 @@ def handle(newpacket, info):
         handled = callback.run_inbox_callbacks(newpacket, info, info.status, info.error_message) or handled
     except:
         lg.exc()
-    if not handled and newpacket.Command not in [commands.Ack(), commands.Fail(), commands.Identity(), ]:
+    if not handled and newpacket.Command not in [
+        commands.Ack(),
+        commands.Fail(),
+        commands.Identity(),
+    ]:
         lg.warn('incoming %s from [%s://%s] was NOT HANDLED' % (newpacket, info.proto, info.host))
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[1;49;91mIN NOT HANDLED %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
-                newpacket.Command, newpacket.PacketID, info.bytes_received,
-                global_id.UrlToGlobalID(info.sender_idurl), global_id.UrlToGlobalID(newpacket.RemoteID),
-                info.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0,
+                '                \033[1;49;91mIN NOT HANDLED %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
+                    newpacket.Command,
+                    newpacket.PacketID,
+                    info.bytes_received,
+                    global_id.UrlToGlobalID(info.sender_idurl),
+                    global_id.UrlToGlobalID(newpacket.RemoteID),
+                    info.transfer_id,
+                ),
+                log_name='packet',
+                showtime=True,
+            )
     else:
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[0;49;93mIN OK %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
-                newpacket.Command, newpacket.PacketID, info.bytes_received,
-                global_id.UrlToGlobalID(info.sender_idurl), global_id.UrlToGlobalID(newpacket.RemoteID),
-                info.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0,
+                '                \033[0;49;93mIN OK %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
+                    newpacket.Command,
+                    newpacket.PacketID,
+                    info.bytes_received,
+                    global_id.UrlToGlobalID(info.sender_idurl),
+                    global_id.UrlToGlobalID(newpacket.RemoteID),
+                    info.transfer_id,
+                ),
+                log_name='packet',
+                showtime=True,
+            )
     if _Debug and False:
-        history().append({
-            'time': newpacket.Date,
-            'command': newpacket.Command,
-            'packet_id': newpacket.PacketID,
-            'creator_id': newpacket.CreatorID,
-            'owner_id': newpacket.OwnerID,
-            'remote_id': newpacket.RemoteID,
-            'payload': len(newpacket.Payload),
-            'address': '%s://%s' % (info.proto, info.host),
-        })
+        history().append(
+            {
+                'time': newpacket.Date,
+                'command': newpacket.Command,
+                'packet_id': newpacket.PacketID,
+                'creator_id': newpacket.CreatorID,
+                'owner_id': newpacket.OwnerID,
+                'remote_id': newpacket.RemoteID,
+                'payload': len(newpacket.Payload),
+                'address': '%s://%s' % (info.proto, info.host),
+            }
+        )
         if len(history()) > 100:
             history().pop(0)
     return handled
 
+
 #------------------------------------------------------------------------------
 
 
@@ -303,7 +339,6 @@ class PacketIn(automat.Automat):
     This class implements all the functionality of the ``packet_in()`` state
     machine.
     """
-
     def __init__(self, transfer_id):
         self.transfer_id = transfer_id
         self.time = None
@@ -336,9 +371,9 @@ class PacketIn(automat.Automat):
         return '%s%s(%s)' % (self.id, self.label, self.state)
 
     def is_timed_out(self):
-#         if self.time is None or self.timeout is None:
-#             return False
-#         return time.time() - self.time > self.timeout
+        #         if self.time is None or self.timeout is None:
+        #             return False
+        #         return time.time() - self.time > self.timeout
         return False
 
     def init(self):
@@ -424,10 +459,10 @@ class PacketIn(automat.Automat):
         self.proto, self.host, self.sender_idurl, self.filename, self.size = args[0]
         self.time = time.time()
         # 300  # max(10 * int(self.size/float(settings.SendingSpeedLimit())), 10)
-        if self.size < 1024 * 10:
+        if self.size < 1024*10:
             self.timeout = 10
-        elif self.size > 1024 * 1024:
-            self.timeout = int(self.size / float(settings.SendingSpeedLimit()))
+        elif self.size > 1024*1024:
+            self.timeout = int(self.size/float(settings.SendingSpeedLimit()))
         else:
             self.timeout = 300
         if not self.sender_idurl:
@@ -444,7 +479,7 @@ class PacketIn(automat.Automat):
         """
         Action method.
         """
-        from transport import gateway
+        from bitdust.transport import gateway
         t = gateway.transports().get(self.proto, None)
         if t:
             t.call('cancel_file_receiving', self.transfer_id)
@@ -461,18 +496,25 @@ class PacketIn(automat.Automat):
         """
         Action method.
         """
-        from transport import gateway
+        from bitdust.transport import gateway
         self.status, self.bytes_received, self.error_message = args[0]
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[2;49;32mRECEIVED %d bytes from %s://%s TID:%s\033[0m' % (
-                self.bytes_received, self.proto, self.host, self.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0,
+                '                \033[2;49;32mRECEIVED %d bytes from %s://%s TID:%s\033[0m' % (self.bytes_received, self.proto, self.host, self.transfer_id),
+                log_name='packet',
+                showtime=True,
+            )
         # DO UNSERIALIZE HERE , no exceptions
         newpacket = gateway.inbox(self)
         if newpacket is None:
             if _Debug:
                 lg.out(_DebugLevel, '<<< IN <<< !!!NONE!!! [%s] %s from %s %s' % (
-                    self.proto.upper().ljust(5), self.status.ljust(8),
-                    self.host, os.path.basename(self.filename),))
+                    self.proto.upper().ljust(5),
+                    self.status.ljust(8),
+                    self.host,
+                    os.path.basename(self.filename),
+                ))
             # net_misc.ConnectionFailed(None, proto, 'receiveStatusReport %s' % host)
             try:
                 fd, _ = tmpfile.make('error', extension='.inbox')
@@ -512,10 +554,14 @@ class PacketIn(automat.Automat):
             status = 'failed'
             bytes_received = 0
         p2p_stats.count_inbox(self.sender_idurl, self.proto, status, bytes_received)
-        lg.warn('incoming packet failed %s with %s' % (self.transfer_id, status, ))
+        lg.warn('incoming packet failed %s with %s' % (self.transfer_id, status))
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[0;49;31mIN FAILED with status "%s" from %s://%s TID:%s\033[0m' % (
-                status, self.proto, self.host, self.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0,
+                '                \033[0;49;31mIN FAILED with status "%s" from %s://%s TID:%s\033[0m' % (status, self.proto, self.host, self.transfer_id),
+                log_name='packet',
+                showtime=True,
+            )
 
     def doReportCacheFailed(self, *args, **kwargs):
         """
@@ -530,8 +576,12 @@ class PacketIn(automat.Automat):
             msg = 'unknown reason'
         lg.warn('cache failed : %s' % self.sender_idurl)
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[0;49;31mIN CACHE FAILED with "%s" for %s TID:%s\033[0m' % (
-                msg, self.sender_idurl, self.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0,
+                '                \033[0;49;31mIN CACHE FAILED with "%s" for %s TID:%s\033[0m' % (msg, self.sender_idurl, self.transfer_id),
+                log_name='packet',
+                showtime=True,
+            )
 
     def doDestroyMe(self, *args, **kwargs):
         """
