@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 .. module:: proxy_interface.
 
@@ -47,11 +46,11 @@ from twisted.internet.defer import succeed, fail, Deferred
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from main import settings
+from bitdust.main import settings
 
-from contacts import identitycache
+from bitdust.contacts import identitycache
 
 #------------------------------------------------------------------------------
 
@@ -64,19 +63,19 @@ def proxy():
     global _GateProxy
     return _GateProxy
 
+
 #------------------------------------------------------------------------------
 
 
 class GateInterface():
-
     def init(self, xml_rpc_url_or_object):
         """
         """
         global _GateProxy
         if _Debug:
             lg.out(4, 'proxy_interface.init')
-        from transport.proxy import proxy_receiver
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_sender
         if isinstance(xml_rpc_url_or_object, six.string_types):
             _GateProxy = xmlrpc.Proxy(xml_rpc_url_or_object, allowNone=True)
         else:
@@ -91,8 +90,8 @@ class GateInterface():
         """
         if _Debug:
             lg.out(4, 'proxy_interface.shutdown')
-        from transport.proxy import proxy_receiver
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_sender
         ret = self.disconnect()
         proxy_receiver.A('shutdown')
         proxy_sender.A('shutdown')
@@ -106,8 +105,8 @@ class GateInterface():
         """
         if _Debug:
             lg.out(4, 'proxy_interface.connect %s' % str(options))
-        from transport.proxy import proxy_receiver
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_sender
         if settings.enablePROXYreceiving():
             proxy_receiver.A('start', options)
         else:
@@ -123,8 +122,8 @@ class GateInterface():
         """
         if _Debug:
             lg.out(4, 'proxy_interface.disconnect')
-        from transport.proxy import proxy_receiver
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_sender
         if not proxy_receiver.A():
             lg.warn('proxy_receiver is not ready')
             interface_disconnected()
@@ -139,8 +138,8 @@ class GateInterface():
     def build_contacts(self, id_obj):
         """
         """
-        from transport.proxy import proxy_receiver
-        # from userid import my_id
+        from bitdust.transport.proxy import proxy_receiver
+        # from bitdust.userid import my_id
         # current_identity_contacts = my_id.getLocalIdentity().getContacts()
         if not proxy_receiver.GetRouterIdentity():
             # if not yet found one node to route your traffic - do nothing
@@ -156,15 +155,14 @@ class GateInterface():
         # he will receive all packets addressed to me and redirect to me
         result = proxy_receiver.GetRouterIdentity().getContacts()
         if _Debug:
-            lg.out(4, 'proxy_interface.build_contacts %s : %r' % (
-                proxy_receiver.GetRouterIdentity().getIDName(), result))
+            lg.out(4, 'proxy_interface.build_contacts %s : %r' % (proxy_receiver.GetRouterIdentity().getIDName(), result))
         return result
 
     def verify_contacts(self, id_obj):
         """
         Check if router is ready and his contacts exists in that identity.
         """
-        from transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_receiver
         if not proxy_receiver.A() or not proxy_receiver.GetRouterIDURL() or not proxy_receiver.GetRouterIdentity():
             # if not yet found any node to route your traffic - do nothing
             if _Debug:
@@ -222,6 +220,7 @@ class GateInterface():
                 lg.exc()
                 res.callback(True)
                 return True
+
         d = identitycache.immediatelyCaching(proxy_receiver.GetRouterIDURL())
         d.addCallback(lambda src: _finish_verification(result))
         d.addErrback(lambda err: result.callback(False) and None)
@@ -230,8 +229,8 @@ class GateInterface():
     def list_sessions(self):
         """
         """
-        from transport.proxy import proxy_receiver
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_sender
         result = []
         if proxy_receiver.A():
             result.append(proxy_receiver.A())
@@ -244,43 +243,43 @@ class GateInterface():
         """
         return []
 
+
 #------------------------------------------------------------------------------
 
+
 def proxy_errback(x):
     if _Debug:
         lg.out(6, 'proxy_interface.proxy_errback ERROR %s' % x)
     return None
 
+
 #------------------------------------------------------------------------------
 
+
 def interface_transport_initialized(xmlrpcurl):
     if proxy():
-        return proxy().callRemote(
-            'transport_initialized', 'proxy', xmlrpcurl).addErrback(proxy_errback)
+        return proxy().callRemote('transport_initialized', 'proxy', xmlrpcurl).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
 
 
 def interface_receiving_started(host, new_options={}):
     if proxy():
-        return proxy().callRemote(
-            'receiving_started', 'proxy', host, new_options).addErrback(proxy_errback)
+        return proxy().callRemote('receiving_started', 'proxy', host, new_options).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
 
 
 def interface_receiving_failed(error_code=None):
     if proxy():
-        return proxy().callRemote(
-            'receiving_failed', 'proxy', error_code).addErrback(proxy_errback)
+        return proxy().callRemote('receiving_failed', 'proxy', error_code).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
 
 
 def interface_disconnected(result=None):
     if proxy():
-        return proxy().callRemote(
-            'disconnected', 'proxy', result).addErrback(proxy_errback)
+        return proxy().callRemote('disconnected', 'proxy', result).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     # return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
     return succeed(result)
@@ -289,7 +288,13 @@ def interface_disconnected(result=None):
 def interface_register_file_sending(host, receiver_idurl, filename, size=0, description=''):
     if proxy():
         return proxy().callRemote(
-            'register_file_sending', 'proxy', host, receiver_idurl, filename, size, description,
+            'register_file_sending',
+            'proxy',
+            host,
+            receiver_idurl,
+            filename,
+            size,
+            description,
         ).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
@@ -298,7 +303,12 @@ def interface_register_file_sending(host, receiver_idurl, filename, size=0, desc
 def interface_register_file_receiving(host, sender_idurl, filename, size=0):
     if proxy():
         return proxy().callRemote(
-            'register_file_receiving', 'proxy', host, sender_idurl, filename, size,
+            'register_file_receiving',
+            'proxy',
+            host,
+            sender_idurl,
+            filename,
+            size,
         ).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
@@ -307,7 +317,11 @@ def interface_register_file_receiving(host, sender_idurl, filename, size=0):
 def interface_unregister_file_sending(transfer_id, status, size=0, error_message=None):
     if proxy():
         return proxy().callRemote(
-            'unregister_file_sending', transfer_id, status, size, error_message,
+            'unregister_file_sending',
+            transfer_id,
+            status,
+            size,
+            error_message,
         ).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
@@ -316,7 +330,11 @@ def interface_unregister_file_sending(transfer_id, status, size=0, error_message
 def interface_unregister_file_receiving(transfer_id, status, size=0, error_message=None):
     if proxy():
         return proxy().callRemote(
-            'unregister_file_receiving', transfer_id, status, size, error_message,
+            'unregister_file_receiving',
+            transfer_id,
+            status,
+            size,
+            error_message,
         ).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
@@ -325,7 +343,13 @@ def interface_unregister_file_receiving(transfer_id, status, size=0, error_messa
 def interface_cancelled_file_sending(host, filename, size=0, description=None, error_message=None):
     if proxy():
         return proxy().callRemote(
-            'cancelled_file_sending', 'proxy', host, filename, size, description, error_message,
+            'cancelled_file_sending',
+            'proxy',
+            host,
+            filename,
+            size,
+            description,
+            error_message,
         ).addErrback(proxy_errback)
     lg.warn('transport_proxy is not ready')
     return fail(Exception('transport_proxy is not ready')).addErrback(proxy_errback)
