@@ -24,8 +24,6 @@
 #
 #
 #
-
-
 """
 .. module:: tcp_node.
 
@@ -59,11 +57,11 @@ from twisted.internet.error import CannotListenError  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import net_misc
+from bitdust.lib import net_misc
 
-from transport.tcp import tcp_stream
+from bitdust.transport.tcp import tcp_stream
 
 #------------------------------------------------------------------------------
 
@@ -94,6 +92,7 @@ def opened_connections_count():
     global _ConnectionsCounter
     return _ConnectionsCounter
 
+
 #------------------------------------------------------------------------------
 
 
@@ -106,6 +105,7 @@ def decrease_connections_counter():
     global _ConnectionsCounter
     _ConnectionsCounter -= 1
 
+
 #------------------------------------------------------------------------------
 
 
@@ -127,14 +127,16 @@ def my_host(normalize=False):
         return net_misc.normalize_address(_MyHost)
     return _MyHost
 
+
 #------------------------------------------------------------------------------
 
+
 def receive(options):
     global _MyIDURL
     global _MyHost
     global _InternalPort
     global _Listener
-    from transport.tcp import tcp_interface
+    from bitdust.transport.tcp import tcp_interface
     if _Debug:
         lg.out(_DebugLevel, 'tcp_node.receive %r' % options)
     if _Listener:
@@ -214,7 +216,7 @@ def disconnect_from(host):
 
 def disconnect():
     global _Listener
-    from transport.tcp import tcp_interface
+    from bitdust.transport.tcp import tcp_interface
     if not _Listener:
         tcp_interface.interface_disconnected(None)
         return True
@@ -238,15 +240,14 @@ def send(filename, remoteaddress, description=None, keep_alive=True):
     remoteaddress = net_misc.normalize_address(remoteaddress)
     result_defer = Deferred()
     if remoteaddress == my_host(normalize=True):
-        lg.err('sending file %r %r to my own host connection at %r is blocked' % (filename, description, remoteaddress, ))
+        lg.err('sending file %r %r to my own host connection at %r is blocked' % (filename, description, remoteaddress))
         result_defer.callback((filename, description, 'failed', 'cancelled'))
         return result_defer
     if remoteaddress in started_connections():
         started_connections()[remoteaddress].add_outbox_file(filename, description, result_defer, keep_alive)
         if not keep_alive:
             if _Debug:
-                lg.out(_DebugLevel, 'tcp_node.send single, use started connection to %s, %d already started and %d opened' % (
-                    str(remoteaddress), len(started_connections()), len(opened_connections())))
+                lg.out(_DebugLevel, 'tcp_node.send single, use started connection to %s, %d already started and %d opened' % (str(remoteaddress), len(started_connections()), len(opened_connections())))
         return result_defer
     for peeraddr, connections in opened_connections().items():
         for connection in connections:
@@ -254,16 +255,14 @@ def send(filename, remoteaddress, description=None, keep_alive=True):
                 connection.append_outbox_file(filename, description, result_defer, keep_alive)
                 if not keep_alive:
                     if _Debug:
-                        lg.out(_DebugLevel, 'tcp_node.send single, use opened connection to %s, %d already started and %d opened' % (
-                            str(remoteaddress), len(started_connections()), len(opened_connections())))
+                        lg.out(_DebugLevel, 'tcp_node.send single, use opened connection to %s, %d already started and %d opened' % (str(remoteaddress), len(started_connections()), len(opened_connections())))
                 return result_defer
             if connection.getConnectionAddress():
                 if connection.getConnectionAddress() == remoteaddress:
                     connection.append_outbox_file(filename, description, result_defer, keep_alive)
                     if not keep_alive:
                         if _Debug:
-                            lg.out(_DebugLevel, 'tcp_node.send single, use opened connection to %s, %d already started and %d opened' % (
-                                str(remoteaddress), len(started_connections()), len(opened_connections())))
+                            lg.out(_DebugLevel, 'tcp_node.send single, use opened connection to %s, %d already started and %d opened' % (str(remoteaddress), len(started_connections()), len(opened_connections())))
                     return result_defer
     if _Debug:
         lg.out(_DebugLevel, 'tcp_node.send start connecting to "%s"' % str(remoteaddress))
@@ -273,8 +272,7 @@ def send(filename, remoteaddress, description=None, keep_alive=True):
     connection.connector = reactor.connectTCP(remoteaddress[0], remoteaddress[1], connection, timeout=_ConnectionTimeout)  # @UndefinedVariable
     if not keep_alive:
         if _Debug:
-            lg.out(_DebugLevel, 'tcp_node.send opened a single connection to %s, %d already started and %d opened' % (
-                str(remoteaddress), len(started_connections()), len(opened_connections())))
+            lg.out(_DebugLevel, 'tcp_node.send opened a single connection to %s, %d already started and %d opened' % (str(remoteaddress), len(started_connections()), len(opened_connections())))
     return result_defer
 
 
@@ -310,14 +308,14 @@ def cancel_file_receiving(transferID):
     # at the moment for TCP transport we can not stop particular file transfer
     # we can only close connection itself, which is not we really want
     # need to find a way to notify remote side about to stop
-#     for connections in opened_connections().values():
-#         for connection in connections:
-#             for in_file in connection.stream.inboxFiles.values():
-#                 if in_file.transfer_id and in_file.transfer_id == transferID:
-#                     connection.automat('disconnect')
-#                     return True
-#     lg.warn('%r not found' % transferID)
-#     return False
+    #     for connections in opened_connections().values():
+    #         for connection in connections:
+    #             for in_file in connection.stream.inboxFiles.values():
+    #                 if in_file.transfer_id and in_file.transfer_id == transferID:
+    #                     connection.automat('disconnect')
+    #                     return True
+    #     lg.warn('%r not found' % transferID)
+    #     return False
     return False
 
 
@@ -337,7 +335,7 @@ def cancel_outbox_file(host, filename):
     host = net_misc.normalize_address(host)
     if _Debug:
         lg.args(_DebugLevel, host=host, filename=filename)
-    from transport.tcp import tcp_interface
+    from bitdust.transport.tcp import tcp_interface
     for connections in opened_connections().values():
         for connection in connections:
             if connection.peer_address and connection.peer_address == host or \
@@ -358,8 +356,7 @@ def cancel_outbox_file(host, filename):
                 if fn == filename:
                     connection.pendingoutboxfiles.pop(i)
                     try:
-                        tcp_interface.interface_cancelled_file_sending(
-                            host, filename, 0, description, 'cancelled')
+                        tcp_interface.interface_cancelled_file_sending(host, filename, 0, description, 'cancelled')
                     except Exception as exc:
                         lg.warn(str(exc))
                     if result_defer:
@@ -367,6 +364,7 @@ def cancel_outbox_file(host, filename):
                     continue
                 i += 1
 
+
 #------------------------------------------------------------------------------
 
 
@@ -374,7 +372,7 @@ class TCPFactory(protocol.ClientFactory):
     protocol = None
 
     def __init__(self, connection_address, keep_alive=True):
-        from transport.tcp import tcp_connection
+        from bitdust.transport.tcp import tcp_connection
         self.protocol = tcp_connection.TCPConnection
         self.connection_address = connection_address
         self.keep_alive = keep_alive
@@ -385,20 +383,17 @@ class TCPFactory(protocol.ClientFactory):
         return 'TCPFactory(%s)' % str(self.connection_address)
 
     def clientConnectionFailed(self, connector, reason):
-        from transport.tcp import tcp_interface
+        from bitdust.transport.tcp import tcp_interface
         protocol.ClientFactory.clientConnectionFailed(self, connector, reason)
         destaddress = (connector.getDestination().host, int(connector.getDestination().port))
         connection = started_connections().pop(self.connection_address, None)
         if connection:
             connection.connector = None
         if _Debug:
-            lg.out(_DebugLevel, 'tcp_node.clientConnectionFailed with %s, %d more connections started : %r' % (
-                str(destaddress), len(started_connections()), reason, ))
+            lg.out(_DebugLevel, 'tcp_node.clientConnectionFailed with %s, %d more connections started : %r' % (str(destaddress), len(started_connections()), reason))
         for filename, description, result_defer, keep_alive in self.pendingoutboxfiles:
             try:
-                tcp_interface.interface_cancelled_file_sending(
-                    destaddress, filename, 0, description, 'connection failed'
-                ).addErrback(lambda err: lg.exc(err))
+                tcp_interface.interface_cancelled_file_sending(destaddress, filename, 0, description, 'connection failed').addErrback(lambda err: lg.exc(err))
             except Exception as exc:
                 lg.warn(str(exc))
             if result_defer:
@@ -408,4 +403,3 @@ class TCPFactory(protocol.ClientFactory):
     def add_outbox_file(self, filename, description='', result_defer=None, keep_alive=True):
         self.pendingoutboxfiles.append((filename, description, result_defer, keep_alive))
         tcp_stream.process_streams()
-
