@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 ..module:: tcp_stream
 """
@@ -50,14 +48,14 @@ from zope.interface import implementer
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import tmpfile
+from bitdust.system import tmpfile
 
-from main import settings
+from bitdust.main import settings
 
-from lib import misc
-from lib import strng
+from bitdust.lib import misc
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
@@ -75,6 +73,7 @@ _StreamCounter = 0
 
 #------------------------------------------------------------------------------
 
+
 def start_process_streams():
     reactor.callLater(0, process_streams)  # @UndefinedVariable
     return True
@@ -91,7 +90,7 @@ def stop_process_streams():
 
 
 def process_streams():
-    from transport.tcp import tcp_node
+    from bitdust.transport.tcp import tcp_node
     global _ProcessStreamsDelay
     global _ProcessStreamsTask
     has_activity = False
@@ -103,18 +102,23 @@ def process_streams():
             if has_timeouts or has_sends or has_outbox:
                 has_activity = True
     _ProcessStreamsDelay = misc.LoopAttenuation(
-        _ProcessStreamsDelay, has_activity,
+        _ProcessStreamsDelay,
+        has_activity,
         MIN_PROCESS_STREAMS_DELAY,
-        MAX_PROCESS_STREAMS_DELAY,)
+        MAX_PROCESS_STREAMS_DELAY,
+    )
     # attenuation
     _ProcessStreamsTask = reactor.callLater(  # @UndefinedVariable
-        _ProcessStreamsDelay, process_streams)
+        _ProcessStreamsDelay,
+        process_streams,
+    )
+
 
 #------------------------------------------------------------------------------
 
 
 def list_input_streams(sorted_by_time=True):
-    from transport.tcp import tcp_node
+    from bitdust.transport.tcp import tcp_node
     streams = []
     for connections in tcp_node.opened_connections().values():
         for connection in connections:
@@ -126,7 +130,7 @@ def list_input_streams(sorted_by_time=True):
 
 
 def list_output_streams(sorted_by_time=True):
-    from transport.tcp import tcp_node
+    from bitdust.transport.tcp import tcp_node
     streams = []
     for connections in tcp_node.opened_connections().values():
         for connection in connections:
@@ -138,7 +142,7 @@ def list_output_streams(sorted_by_time=True):
 
 
 def find_stream(file_id=None, transfer_id=None):
-    from transport.tcp import tcp_node
+    from bitdust.transport.tcp import tcp_node
     for connections in tcp_node.opened_connections().values():
         for connection in connections:
             if connection.stream:
@@ -154,12 +158,14 @@ def find_stream(file_id=None, transfer_id=None):
                         return in_file
     return None
 
+
 #------------------------------------------------------------------------------
 
+
 def make_stream_id():
     global _StreamCounter
     _StreamCounter += 1
-    return random.randint(10, 99) * 1000000 + random.randint(10, 99) * 10000 + _StreamCounter % 10000
+    return random.randint(10, 99)*1000000 + random.randint(10, 99)*10000 + _StreamCounter % 10000
 
 
 def make_file_id():
@@ -167,7 +173,7 @@ def make_file_id():
     Generate a unique file ID for OutboxFile.
     """
     global _LastFileID
-    newid = int(str(int(time.time() * 100.0))[4:])
+    newid = int(str(int(time.time()*100.0))[4:])
     if _LastFileID is None:
         _LastFileID = newid
     elif _LastFileID >= newid:
@@ -176,11 +182,11 @@ def make_file_id():
         _LastFileID = newid
     return _LastFileID
 
+
 #------------------------------------------------------------------------------
 
 
 class TCPFileStream():
-
     def __init__(self, connection):
         self.stream_id = make_stream_id()  # not used at the moment, use file_id instead
         self.connection = connection
@@ -197,7 +203,7 @@ class TCPFileStream():
         self.connection = None
 
     def abort_files(self, reason='connection closed'):
-        from transport.tcp import tcp_connection
+        from bitdust.transport.tcp import tcp_connection
         inbox_file_ids_to_remove = [fid for fid in self.inboxFiles.keys()]
         outbox_file_ids_to_remove = [fid for fid in self.outboxFiles.keys()]
         if _Debug:
@@ -215,7 +221,7 @@ class TCPFileStream():
     def data_received(self, payload):
         """
         """
-        from transport.tcp import tcp_connection
+        from bitdust.transport.tcp import tcp_connection
         inp = BytesIO(payload)
         try:
             file_id = int(struct.unpack('i', inp.read(4))[0])
@@ -227,7 +233,7 @@ class TCPFileStream():
         inp_data = inp.read()
         inp.close()
         if file_id not in self.inboxFiles:
-            if len(self.inboxFiles) >= 2 * MAX_SIMULTANEOUS_OUTGOING_FILES:
+            if len(self.inboxFiles) >= 2*MAX_SIMULTANEOUS_OUTGOING_FILES:
                 # too many incoming files, seems remote guy is cheating - drop
                 # that session!
                 lg.warn('too many incoming files, close connection %s' % str(self.connection))
@@ -253,7 +259,7 @@ class TCPFileStream():
             return
         self.outboxFiles[file_id].ok_received = True
         if _Debug:
-            lg.args(_DebugLevel * 2, file_id)
+            lg.args(_DebugLevel*2, file_id)
         if not self.outboxFiles[file_id].registration:
             self.outbox_file_done(file_id, 'finished')
 
@@ -273,10 +279,9 @@ class TCPFileStream():
         return self.connection.sendData(command, payload)
 
     def create_inbox_file(self, file_id, file_size):
-        from transport.tcp import tcp_interface
+        from bitdust.transport.tcp import tcp_interface
         infile = InboxFile(self, file_id, file_size)
-        d = tcp_interface.interface_register_file_receiving(
-            self.connection.getAddress(), self.connection.peer_idurl, infile.filename)
+        d = tcp_interface.interface_register_file_receiving(self.connection.getAddress(), self.connection.peer_idurl, infile.filename)
         d.addCallback(self.on_inbox_file_registered, file_id)
         d.addErrback(self.on_inbox_file_register_failed, file_id)
         infile.registration = d
@@ -298,13 +303,19 @@ class TCPFileStream():
         lg.warn('failed to register file_id=%r session=%r err: %s' % (file_id, self.session, str(err)))
         self.connection.automat('disconnect')
 
-    def create_outbox_file(self, filename, filesize, description, result_defer, keep_alive,):
-        from transport.tcp import tcp_interface
+    def create_outbox_file(
+        self,
+        filename,
+        filesize,
+        description,
+        result_defer,
+        keep_alive,
+    ):
+        from bitdust.transport.tcp import tcp_interface
         file_id = make_file_id()
         outfile = OutboxFile(self, filename, file_id, filesize, description, result_defer, keep_alive)
         if keep_alive:
-            d = tcp_interface.interface_register_file_sending(
-                self.connection.getAddress(), self.connection.peer_idurl, filename, description)
+            d = tcp_interface.interface_register_file_sending(self.connection.getAddress(), self.connection.peer_idurl, filename, description)
             d.addCallback(self.on_outbox_file_registered, file_id)
             d.addErrback(self.on_outbox_file_register_failed, file_id)
             outfile.registration = d
@@ -340,18 +351,16 @@ class TCPFileStream():
             lg.warn('incoming TCP file %s not exist' % file_id)
 
     def report_outbox_file(self, transfer_id, status, bytes_sent, error_message=None):
-        from transport.tcp import tcp_interface
-        tcp_interface.interface_unregister_file_sending(
-            transfer_id, status, bytes_sent, error_message)
+        from bitdust.transport.tcp import tcp_interface
+        tcp_interface.interface_unregister_file_sending(transfer_id, status, bytes_sent, error_message)
 
     def report_inbox_file(self, transfer_id, status, bytes_received, error_message=None):
-        from transport.tcp import tcp_interface
-        tcp_interface.interface_unregister_file_receiving(
-            transfer_id, status, bytes_received, error_message)
+        from bitdust.transport.tcp import tcp_interface
+        tcp_interface.interface_unregister_file_receiving(transfer_id, status, bytes_received, error_message)
 
     def inbox_file_done(self, file_id, status, error_message=None):
         if _Debug:
-            lg.args(_DebugLevel * 2, file_id, status, error_message)
+            lg.args(_DebugLevel*2, file_id, status, error_message)
         if file_id not in self.inboxFiles:
             lg.warn('file_id=%r not exist' % file_id)
             return
@@ -367,7 +376,7 @@ class TCPFileStream():
 
     def outbox_file_done(self, file_id, status, error_message=None):
         if _Debug:
-            lg.args(_DebugLevel * 2, file_id, status, error_message)
+            lg.args(_DebugLevel*2, file_id, status, error_message)
         if file_id not in self.outboxFiles:
             lg.warn('file_id=%r not exist' % file_id)
             return
@@ -384,11 +393,11 @@ class TCPFileStream():
             self.connection.automat('disconnect')
         del outfile
 
+
 #------------------------------------------------------------------------------
 
 
 class InboxFile():
-
     def __init__(self, stream, file_id, file_size):
         self.typ = 'tcp-in'
         self.transfer_id = None
@@ -396,19 +405,17 @@ class InboxFile():
         self.stream = stream
         self.file_id = file_id
         self.size = file_size
-        self.fin, self.filename = tmpfile.make("tcp-in", extension='.tcp')
+        self.fin, self.filename = tmpfile.make('tcp-in', extension='.tcp')
         self.bytes_received = 0
         self.started = time.time()
         self.last_block_time = time.time()
-        self.timeout = max(int(self.size / settings.SendingSpeedLimit()), 3)
+        self.timeout = max(int(self.size/settings.SendingSpeedLimit()), 3)
         if _Debug:
-            lg.out(_DebugLevel, '<<<TCP-IN %s with %d bytes write to %s' % (
-                self.file_id, self.size, self.filename))
+            lg.out(_DebugLevel, '<<<TCP-IN %s with %d bytes write to %s' % (self.file_id, self.size, self.filename))
 
     def close(self):
         if _Debug:
-            lg.out(_DebugLevel, '<<<TCP-IN %s CLOSED with %s | %s' % (
-                self.file_id, self.stream.connection.peer_address, self.stream.connection.peer_external_address))
+            lg.out(_DebugLevel, '<<<TCP-IN %s CLOSED with %s | %s' % (self.file_id, self.stream.connection.peer_address, self.stream.connection.peer_external_address))
         if self.fin:
             os.close(self.fin)
             self.fin = None
@@ -429,11 +436,11 @@ class InboxFile():
     def is_timed_out(self):
         return time.time() - self.started > self.timeout
 
+
 #------------------------------------------------------------------------------
 
 
 class OutboxFile():
-
     def __init__(self, stream, filename, file_id, filesize, description='', result_defer=None, keep_alive=True):
         self.typ = 'tcp-out'
         self.transfer_id = None
@@ -449,17 +456,14 @@ class OutboxFile():
         self.bytes_sent = 0
         self.bytes_out = 0
         self.started = time.time()
-        self.timeout = max(int(self.size / settings.SendingSpeedLimit()), 6)
+        self.timeout = max(int(self.size/settings.SendingSpeedLimit()), 6)
         self.fout = open(self.filename, 'rb')
         if _Debug:
-            lg.out(
-                _DebugLevel, '>>>TCP-OUT %s with %d bytes reading from %s' %
-                (self.file_id, self.size, self.filename))
+            lg.out(_DebugLevel, '>>>TCP-OUT %s with %d bytes reading from %s' % (self.file_id, self.size, self.filename))
 
     def close(self):
         if _Debug:
-            lg.out(_DebugLevel, '>>>TCP-OUT %s CLOSED with %s | %s' % (
-                self.file_id, self.stream.connection.peer_address, self.stream.connection.peer_external_address))
+            lg.out(_DebugLevel, '>>>TCP-OUT %s CLOSED with %s | %s' % (self.file_id, self.stream.connection.peer_address, self.stream.connection.peer_external_address))
         self.stop()
         if self.fout:
             self.fout.close()
@@ -495,7 +499,7 @@ class OutboxFile():
             self.stream.outbox_file_done(self.file_id, 'finished')
         else:
             if _Debug:
-                lg.args(_DebugLevel * 2, self.file_id)
+                lg.args(_DebugLevel*2, self.file_id)
 
     def transfer_failed(self, err):
         try:
@@ -507,7 +511,7 @@ class OutboxFile():
         return None
 
     def send_chunk(self, chunk):
-        from transport.tcp import tcp_connection
+        from bitdust.transport.tcp import tcp_connection
         self.stream.connection.sendData(tcp_connection.CMD_DATA, chunk)
 
     def transform_data(self, data):
@@ -521,12 +525,14 @@ class OutboxFile():
         self.stream.connection.total_bytes_sent += datalength
         return datagram
 
+
 #------------------------------------------------------------------------------
 
+
 @implementer(interfaces.IProducer)
 class MultipleFilesSender:
 
-    CHUNK_SIZE = 2 ** 14
+    CHUNK_SIZE = 2**14
 
     def __init__(self, consumer):
         self.active_files = {}
@@ -549,7 +555,7 @@ class MultipleFilesSender:
         deferred = defer.Deferred()
         self.active_files[file_id] = (deferred, file_object, writer, transform)
         if _Debug:
-            lg.args(_DebugLevel * 2, file_id, file_object, [fid for fid in self.active_files.keys()])
+            lg.args(_DebugLevel*2, file_id, file_object, [fid for fid in self.active_files.keys()])
         if not self.consumer.producerPaused:
             self.resumeProducing()
         return deferred
@@ -557,18 +563,28 @@ class MultipleFilesSender:
     def stopFileTransfer(self, file_id, reason='cancelled'):
         if file_id not in self.active_files:
             raise ValueError('file_id=%r is not registered for transfer' % file_id)
-        deferred, _, _, _ = self.active_files.pop(file_id, (None, None, None, None, ))
+        deferred, _, _, _ = self.active_files.pop(file_id, (
+            None,
+            None,
+            None,
+            None,
+        ))
         if _Debug:
-            lg.args(_DebugLevel * 2, file_id, [fid for fid in self.active_files.keys()])
+            lg.args(_DebugLevel*2, file_id, [fid for fid in self.active_files.keys()])
         if deferred:
             deferred.errback(Exception(reason))
 
     def resumeProducing(self):
         if _Debug:
-            lg.args(_DebugLevel * 2, [fid for fid in self.active_files.keys()])
+            lg.args(_DebugLevel*2, [fid for fid in self.active_files.keys()])
         files_to_be_removed = []
         for file_id in self.active_files.keys():
-            deferred, file_object, writer, transform = self.active_files.get(file_id, (None, None, None, None, ))
+            deferred, file_object, writer, transform = self.active_files.get(file_id, (
+                None,
+                None,
+                None,
+                None,
+            ))
             if not file_object:
                 lg.warn('did not found file object for file_id=%r' % file_id)
                 files_to_be_removed.append(file_id)
@@ -597,8 +613,8 @@ class MultipleFilesSender:
 
     def pauseProducing(self):
         if _Debug:
-            lg.args(_DebugLevel * 2, [fid for fid in self.active_files.keys()])
+            lg.args(_DebugLevel*2, [fid for fid in self.active_files.keys()])
 
     def stopProducing(self):
         if _Debug:
-            lg.args(_DebugLevel * 2, [fid for fid in self.active_files.keys()])
+            lg.args(_DebugLevel*2, [fid for fid in self.active_files.keys()])
