@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -45,7 +44,7 @@ import sys
 #------------------------------------------------------------------------------
 
 try:
-    from twisted.internet import reactor  # @UnresolvedImport
+    pass
 except:
     sys.exit('Error initializing twisted.internet.reactor in udp_interface.py')
 
@@ -54,9 +53,9 @@ from twisted.internet.defer import Deferred, succeed, fail
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import nameurl
+from bitdust.lib import nameurl
 
 #------------------------------------------------------------------------------
 
@@ -73,6 +72,7 @@ def proxy():
     global _GateProxy
     return _GateProxy
 
+
 #------------------------------------------------------------------------------
 
 
@@ -80,7 +80,10 @@ def idurl_to_id(idurl):
     proto, host, port, filename = nameurl.UrlParse(idurl)
     assert proto == 'http'
     user_id = filename.replace('.xml', '') + '@' + host
-    if port and port not in ['80', 80, ]:
+    if port and port not in [
+        '80',
+        80,
+    ]:
         user_id += ':%s' % str(port)
     return user_id
 
@@ -93,11 +96,11 @@ def id_to_idurl(user_id):
         return None
     return 'http://%s/%s' % (host, filename)
 
+
 #------------------------------------------------------------------------------
 
 
 class GateInterface():
-
     def init(self, xml_rpc_url_or_object):
         """
         """
@@ -114,7 +117,7 @@ class GateInterface():
     def shutdown(self):
         """
         """
-        from transport.udp import udp_node
+        from bitdust.transport.udp import udp_node
         global _GateProxy
         if _Debug:
             lg.out(4, 'udp_interface.shutdown')
@@ -127,7 +130,7 @@ class GateInterface():
     def connect(self, options):
         """
         """
-        from transport.udp import udp_node
+        from bitdust.transport.udp import udp_node
         if _Debug:
             lg.out(8, 'udp_interface.connect %s' % str(options))
         udp_node.A('go-online', options)
@@ -136,7 +139,7 @@ class GateInterface():
     def disconnect(self):
         """
         """
-        from transport.udp import udp_node
+        from bitdust.transport.udp import udp_node
         if _Debug:
             lg.out(4, 'udp_interface.disconnect')
         udp_node.A('go-offline')
@@ -146,10 +149,7 @@ class GateInterface():
         """
         """
         result = []
-        result.append(
-            'udp://%s@%s' %
-            (id_obj.getIDName().lower(),
-             id_obj.getIDHost()))
+        result.append('udp://%s@%s' % (id_obj.getIDName().lower(), id_obj.getIDHost()))
         if _Debug:
             lg.out(4, 'udp_interface.build_contacts : %s' % str(result))
         return result
@@ -157,13 +157,10 @@ class GateInterface():
     def verify_contacts(self, id_obj):
         """
         """
-        udp_contact = 'udp://%s@%s' % (id_obj.getIDName().lower(),
-                                       id_obj.getIDHost())
+        udp_contact = 'udp://%s@%s' % (id_obj.getIDName().lower(), id_obj.getIDHost())
         if id_obj.getContactIndex(contact=udp_contact) < 0:
             if _Debug:
-                lg.out(
-                    4,
-                    'udp_interface.verify_contacts returning False: udp contact not found or changed')
+                lg.out(4, 'udp_interface.verify_contacts returning False: udp contact not found or changed')
             return False
         if _Debug:
             lg.out(4, 'udp_interface.verify_contacts returning True')
@@ -172,25 +169,22 @@ class GateInterface():
     def send_file(self, remote_idurl, filename, host, description=''):
         """
         """
-        from transport.udp import udp_session
-        from transport.udp import udp_node
+        from bitdust.transport.udp import udp_session
+        from bitdust.transport.udp import udp_node
         # lg.out(20, 'udp_interface.send_file %s %s %s' % (filename, host, description))
         result_defer = Deferred()
-#        if udp_node.A().state not in ['LISTEN', 'DHT_READ',]:
-#            result_defer.callback(False)
-#            lg.out(4, 'udp_interface.send_file WARNING udp_node state is %s' % udp_node.A().state)
-#            return result_defer
+        #        if udp_node.A().state not in ['LISTEN', 'DHT_READ',]:
+        #            result_defer.callback(False)
+        #            lg.out(4, 'udp_interface.send_file WARNING udp_node state is %s' % udp_node.A().state)
+        #            return result_defer
         active_sessions = udp_session.get_by_peer_id(host)
         if active_sessions:
             if description.startswith('Identity') or description.startswith('Ack'):
-                active_sessions[0].file_queue.insert_outbox_file(
-                    filename, description, result_defer, keep_alive=True)
+                active_sessions[0].file_queue.insert_outbox_file(filename, description, result_defer, keep_alive=True)
             else:
-                active_sessions[0].file_queue.append_outbox_file(
-                    filename, description, result_defer, keep_alive=True)
+                active_sessions[0].file_queue.append_outbox_file(filename, description, result_defer, keep_alive=True)
         else:
-            udp_session.add_pending_outbox_file(
-                filename, host, description, result_defer, keep_alive=True)
+            udp_session.add_pending_outbox_file(filename, host, description, result_defer, keep_alive=True)
             udp_node.A('connect', host)
         return result_defer
 
@@ -202,14 +196,14 @@ class GateInterface():
     def send_keep_alive(self, host):
         """
         """
-        from transport.udp import udp_session
+        from bitdust.transport.udp import udp_session
         for sess in udp_session.sessions_by_peer_id().get(host, []):
             sess.automat('send-keep-alive')
 
     def connect_to_host(self, host=None, idurl=None):
         """
         """
-        from transport.udp import udp_node
+        from bitdust.transport.udp import udp_node
         if not host:
             host = idurl_to_id(idurl)
         if _Debug:
@@ -223,7 +217,7 @@ class GateInterface():
     def cancel_outbox_file(self, host, filename):
         """
         """
-        from transport.udp import udp_session
+        from bitdust.transport.udp import udp_session
         ok = False
         for sess in udp_session.sessions().values():
             if sess.peer_id != host:
@@ -239,17 +233,17 @@ class GateInterface():
                 else:
                     i += 1
         udp_session.remove_pending_outbox_file(host, filename)
-#        for fn, descr, result_defer, single in sess.file_queue.outboxQueue:
-#            if fn == filename and sess.peer_id == host:
-#                lg.out(6, 'udp_interface.cancel_outbox_file    host=%s  want to close session' % host)
-#                sess.automat('shutdown')
-#                return True
+        #        for fn, descr, result_defer, single in sess.file_queue.outboxQueue:
+        #            if fn == filename and sess.peer_id == host:
+        #                lg.out(6, 'udp_interface.cancel_outbox_file    host=%s  want to close session' % host)
+        #                sess.automat('shutdown')
+        #                return True
         return ok
 
     def cancel_file_sending(self, transferID):
         """
         """
-        from transport.udp import udp_session
+        from bitdust.transport.udp import udp_session
         for sess in udp_session.sessions().values():
             for out_file in sess.file_queue.outboxFiles.values():
                 if out_file.transfer_id and out_file.transfer_id == transferID:
@@ -262,26 +256,26 @@ class GateInterface():
         """
         # at the moment for UDP transport we can not stop particular file transfer
         # we can only close the whole session which is not we really want
-#         for sess in udp_session.sessions().values():
-#             for in_file in sess.file_queue.inboxFiles.values():
-#                 if in_file.transfer_id and in_file.transfer_id == transferID:
-#                     if _Debug:
-#                         lg.out(6, 'udp_interface.cancel_file_receiving transferID=%s   want to close session' % transferID)
-#                     sess.automat('shutdown')
-#                     return True
-#         return False
+        #         for sess in udp_session.sessions().values():
+        #             for in_file in sess.file_queue.inboxFiles.values():
+        #                 if in_file.transfer_id and in_file.transfer_id == transferID:
+        #                     if _Debug:
+        #                         lg.out(6, 'udp_interface.cancel_file_receiving transferID=%s   want to close session' % transferID)
+        #                     sess.automat('shutdown')
+        #                     return True
+        #         return False
         return False
 
     def list_sessions(self):
         """
         """
-        from transport.udp import udp_session
+        from bitdust.transport.udp import udp_session
         return list(udp_session.sessions().values())
 
     def list_streams(self, sorted_by_time=True):
         """
         """
-        from transport.udp import udp_stream
+        from bitdust.transport.udp import udp_stream
         result = []
         for stream in udp_stream.streams().values():
             result.append(stream.consumer)
@@ -292,7 +286,7 @@ class GateInterface():
     def find_session(self, host=None, idurl=None):
         """
         """
-        from transport.udp import udp_session
+        from bitdust.transport.udp import udp_session
         if idurl:
             return udp_session.sessions_by_peer_id().get(idurl_to_id(idurl), [])
         return udp_session.sessions_by_peer_id().get(host, [])
@@ -300,7 +294,7 @@ class GateInterface():
     def find_stream(self, stream_id=None, transfer_id=None):
         """
         """
-        from transport.udp import udp_stream
+        from bitdust.transport.udp import udp_stream
         for stream in udp_stream.streams().values():
             if stream_id and stream_id == stream.consumer.stream_id:
                 return stream.consumer
@@ -308,13 +302,16 @@ class GateInterface():
                 return stream.consumer
         return None
 
+
 #------------------------------------------------------------------------------
 
+
 def proxy_errback(x):
     if _Debug:
         lg.out(6, 'udp_interface.proxy_errback ERROR %s' % x)
     return None
 
+
 #------------------------------------------------------------------------------
 
 
@@ -349,50 +346,41 @@ def interface_disconnected(result=None):
 
 def interface_register_file_sending(host, receiver_idurl, filename, size, description=''):
     if proxy():
-        return proxy().callRemote(
-            'register_file_sending', 'udp', host, receiver_idurl, filename, size, description).addErrback(proxy_errback)
+        return proxy().callRemote('register_file_sending', 'udp', host, receiver_idurl, filename, size, description).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
 
 
 def interface_register_file_receiving(host, sender_idurl, filename, size):
     if proxy():
-        return proxy().callRemote(
-            'register_file_receiving', 'udp', host, sender_idurl, filename, size).addErrback(proxy_errback)
+        return proxy().callRemote('register_file_receiving', 'udp', host, sender_idurl, filename, size).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
 
 
 def interface_unregister_file_sending(transfer_id, status, bytes_sent, error_message=None):
     if proxy():
-        return proxy().callRemote(
-            'unregister_file_sending', transfer_id, status,
-            bytes_sent, error_message).addErrback(proxy_errback)
+        return proxy().callRemote('unregister_file_sending', transfer_id, status, bytes_sent, error_message).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
 
 
 def interface_unregister_file_receiving(transfer_id, status, bytes_received, error_message=None):
     if proxy():
-        return proxy().callRemote(
-            'unregister_file_receiving', transfer_id, status,
-            bytes_received, error_message).addErrback(proxy_errback)
+        return proxy().callRemote('unregister_file_receiving', transfer_id, status, bytes_received, error_message).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
 
 
 def interface_cancelled_file_sending(host, filename, size, description=None, error_message=None):
     if proxy():
-        return proxy().callRemote(
-            'cancelled_file_sending', 'udp', host, filename,
-            size, description, error_message).addErrback(proxy_errback)
+        return proxy().callRemote('cancelled_file_sending', 'udp', host, filename, size, description, error_message).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
 
 
 def interface_cancelled_file_receiving(host, filename, size, error_message=None):
     if proxy():
-        return proxy().callRemote(
-            'cancelled_file_receiving', 'udp', host, filename, size, error_message).addErrback(proxy_errback)
+        return proxy().callRemote('cancelled_file_receiving', 'udp', host, filename, size, error_message).addErrback(proxy_errback)
     lg.warn('transport_udp is not ready')
     return fail(Exception('transport_udp is not ready')).addErrback(proxy_errback)
