@@ -25,7 +25,6 @@
 #
 #
 #
-
 """
 .. module:: identity.
 
@@ -149,25 +148,25 @@ from xml.dom.minidom import getDOMImplementation
 #------------------------------------------------------------------------------
 
 try:
-    from logs import lg
+    from bitdust.logs import lg
 except:
     dirpath = os.path.dirname(os.path.abspath(sys.argv[0]))
     sys.path.insert(0, os.path.abspath(os.path.join(dirpath, '..')))
-    from logs import lg
+    from bitdust.logs import lg
 
 #------------------------------------------------------------------------------
 
-from main import settings
+from bitdust.main import settings
 
-from system import bpio
+from bitdust.system import bpio
 
-from lib import strng
-from lib import nameurl
+from bitdust.lib import strng
+from bitdust.lib import nameurl
 
-from crypt import key
+from bitdust.crypt import key
 
-from userid import global_id
-from userid import id_url
+from bitdust.userid import global_id
+from bitdust.userid import id_url
 
 #------------------------------------------------------------------------------
 
@@ -204,29 +203,18 @@ class identity(object):
     * publickey : the public part of user's key, string in twisted.conch.ssh format
     * signature : digital signature to protect the file
     """
-    sources = []        # list of URLs, first is primary URL and name
-    contacts = []       # list of ways to contact this identity
-    certificates = []   # signatures by identity servers
-    scrubbers = []      # list of URLs for people allowed to scrub
-    postage = b'1'      # a price for message delivery if not on correspondents list
-    date = b''          # date
-    version = b''       # version string
-    revision = b'0'     # revision number, every time my id were modified this value will be increased by 1
-    publickey = b''     # string in twisted.conch.ssh format
-    signature = b''     # digital signature
+    sources = []  # list of URLs, first is primary URL and name
+    contacts = []  # list of ways to contact this identity
+    certificates = []  # signatures by identity servers
+    scrubbers = []  # list of URLs for people allowed to scrub
+    postage = b'1'  # a price for message delivery if not on correspondents list
+    date = b''  # date
+    version = b''  # version string
+    revision = b'0'  # revision number, every time my id were modified this value will be increased by 1
+    publickey = b''  # string in twisted.conch.ssh format
+    signature = b''  # digital signature
 
-    def __init__(self,
-                 sources=[],
-                 contacts=[],
-                 certificates=[],
-                 scrubbers=[],
-                 postage=b'1',
-                 date=b'',
-                 version=b'',
-                 revision=b'0',
-                 publickey=b'',
-                 xmlsrc=None,
-                 filename=b''):
+    def __init__(self, sources=[], contacts=[], certificates=[], scrubbers=[], postage=b'1', date=b'', version=b'', revision=b'0', publickey=b'', xmlsrc=None, filename=b''):
 
         self.sources = []
         if sources:
@@ -262,16 +250,16 @@ class identity(object):
         """
         Erase all fields data, clear identity.
         """
-        self.sources = []       # list of URLs for fetching this identiy, first is primary URL and name - called IDURL
+        self.sources = []  # list of URLs for fetching this identiy, first is primary URL and name - called IDURL
         self.certificates = []  # identity servers each sign the source they are with - hash just (IDURL + publickey)
-        self.publickey = b''    # string
-        self.contacts = []      # list of ways to contact this identity
-        self.scrubbers = []     # list of URLs for people allowed to scrub
-        self.date = b''         # date
-        self.postage = b'1'     # postage price for message delivery if not on correspondents list
-        self.version = b''      # version string
-        self.signature = b''    # digital signature
-        self.revision = b'0'    # revision number
+        self.publickey = b''  # string
+        self.contacts = []  # list of ways to contact this identity
+        self.scrubbers = []  # list of URLs for people allowed to scrub
+        self.date = b''  # date
+        self.postage = b'1'  # postage price for message delivery if not on correspondents list
+        self.version = b''  # version string
+        self.signature = b''  # digital signature
+        self.revision = b'0'  # revision number
 
     def default(self):
         """
@@ -318,23 +306,23 @@ class identity(object):
                 return False
             proto, host, port, filename = nameurl.UrlParse(source)
             if filename.count('/'):
-                lg.warn("incorrect identity name: %s" % filename)
+                lg.warn('incorrect identity name: %s' % filename)
                 return False
             name, justxml = filename.split('.')
             names.add(name)
             # SECURITY check that name is simple
-            if justxml != "xml":
-                lg.warn("incorrect identity name: %s" % filename)
+            if justxml != 'xml':
+                lg.warn('incorrect identity name: %s' % filename)
                 return False
             if len(name) > settings.MaximumUsernameLength():
-                lg.warn("incorrect identity name: %s" % filename)
+                lg.warn('incorrect identity name: %s' % filename)
                 return False
             if len(name) < settings.MinimumUsernameLength():
-                lg.warn("incorrect identity name: %s" % filename)
+                lg.warn('incorrect identity name: %s' % filename)
                 return False
             for c in name:
                 if c not in settings.LegalUsernameChars():
-                    lg.warn("incorrect identity name: %s" % filename)
+                    lg.warn('incorrect identity name: %s' % filename)
                     return False
         if len(names) > 1:
             lg.warn('names are not consistent: %s' % str(names))
@@ -373,8 +361,8 @@ class identity(object):
         hashcode = self.makehash()
         self.signature = key.Sign(hashcode)
         if not self.Valid():
-            lg.warn("identity is not valid after making sign!")
-            raise Exception("identity sign fails")
+            lg.warn('identity is not valid after making sign!')
+            raise Exception('identity sign fails')
 
     def Valid(self):
         """
@@ -409,7 +397,7 @@ class identity(object):
             return key.DecryptLocalPrivateKey(inp)
         if callable(private_key):
             return private_key(inp)
-        from crypt import my_keys
+        from bitdust.crypt import my_keys
         if my_keys.is_valid_key_id(private_key):
             return my_keys.decrypt(private_key, inp)
         return key.DecryptOpenSSHPrivateKey(private_key, inp)
@@ -423,7 +411,7 @@ class identity(object):
         try:
             doc = minidom.parseString(strng.to_bin(xmlsrc))
         except:
-            lg.exc("xmlsrc=%r" % xmlsrc)
+            lg.exc('xmlsrc=%r' % xmlsrc)
             return
         self.clear_data()
         self.from_xmlobj(doc.documentElement)
@@ -550,7 +538,7 @@ class identity(object):
         signature.appendChild(doc.createTextNode(strng.to_text(self.signature)))
         root.appendChild(signature)
 
-        xmlsrc = doc.toprettyxml(indent="  ", newl="\n", encoding="utf-8")
+        xmlsrc = doc.toprettyxml(indent='  ', newl='\n', encoding='utf-8')
         return xmlsrc, root, doc
 
     def from_xmlobj(self, root_node):
@@ -1011,30 +999,31 @@ class identity(object):
 
 #-------------------------------------------------------------------------------
 
+
 def test1():
     """
     Some tests.
     """
-    from userid import my_id
+    from bitdust.userid import my_id
     myidentity = my_id.getLocalIdentity()
     print('getIP =', myidentity.getIP())
     if myidentity.Valid():
-        print("myidentity is Valid!!!!")
+        print('myidentity is Valid!!!!')
     else:
-        print("myidentity is not Valid")
-        my_id.saveLocalIdentity()            # sign and save
-        raise Exception("myidentity is not Valid")
-    print("myidentity.contacts")
+        print('myidentity is not Valid')
+        my_id.saveLocalIdentity()  # sign and save
+        raise Exception('myidentity is not Valid')
+    print('myidentity.contacts')
     print(myidentity.contacts)
-    print("len myidentity.contacts ")
+    print('len myidentity.contacts ')
     print(len(myidentity.contacts))
-    print("len myidentity.contacts[0] ")
+    print('len myidentity.contacts[0] ')
     print(myidentity.contacts[0])
     con = myidentity.getContact()
-    print("con:", con, type(con))
+    print('con:', con, type(con))
     protocol, machine, port, filename = nameurl.UrlParse(con)
     print(protocol, machine, port, filename)
-    print("identity.main serialize:\n", myidentity.serialize())
+    print('identity.main serialize:\n', myidentity.serialize())
     for index in range(myidentity.getContactsNumber()):
         proto, host, port, filename = myidentity.getContactParts(index)
         print('[%s] [%s] [%s] [%s]' % (proto, host, port, filename))
@@ -1044,18 +1033,20 @@ def test2():
     """
     More tests.
     """
-    from userid import my_id
+    from bitdust.userid import my_id
     ident = my_id.buildDefaultIdentity()
     print(ident.serialize())
 
+
 #------------------------------------------------------------------------------
 
+
 def main():
     """
     This should print a current identity or create a new one.
     """
     settings.init(base_dir='/tmp/fake_id')
-    from userid import my_id
+    from bitdust.userid import my_id
     my_id.loadLocalIdentity()
     if my_id.isLocalIdentityReady():
         my_id.getLocalIdentity().sign()
@@ -1087,7 +1078,7 @@ def update():
     A good way to check all things - load and sign again.
     Also will test rebuilding of the identity
     """
-    from userid import my_id
+    from bitdust.userid import my_id
     bpio.init()
     settings.init()
     src = bpio.ReadTextFile(settings.LocalIdentityFilename())
@@ -1102,7 +1093,6 @@ def update():
 
 #------------------------------------------------------------------------------
 
-
 if __name__ == '__main__':
     lg.set_debug_level(18)
     main()
