@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -52,22 +51,22 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import local_fs
+from bitdust.system import bpio
+from bitdust.system import local_fs
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from lib import misc
-from lib import nameurl
-from lib import strng
+from bitdust.lib import misc
+from bitdust.lib import nameurl
+from bitdust.lib import strng
 
-from crypt import key
+from bitdust.crypt import key
 
-from userid import identity
-from userid import id_url
+from bitdust.userid import identity
+from bitdust.userid import id_url
 
 #------------------------------------------------------------------------------
 
@@ -75,7 +74,12 @@ _LocalIdentity = None
 _LocalIDURL = None
 _LocalID = None
 _LocalName = None
-_ValidTransports = ['tcp', 'udp', 'http', 'proxy', ]
+_ValidTransports = [
+    'tcp',
+    'udp',
+    'http',
+    'proxy',
+]
 
 #------------------------------------------------------------------------------
 
@@ -96,6 +100,7 @@ def shutdown():
         lg.out(_DebugLevel, 'my_id.shutdown')
     forgetLocalIdentity()
 
+
 #-------------------------------------------------------------------------------
 
 
@@ -191,7 +196,7 @@ def getGlobalID(key_alias=None):
         return _LocalID
     if key_alias == 'master' and _LocalID is not None:
         return strng.to_text('{}${}'.format(key_alias, _LocalID))
-    from userid import global_id
+    from bitdust.userid import global_id
     glob_id = global_id.UrlToGlobalID(getIDURL())
     if not glob_id:
         return glob_id
@@ -218,6 +223,7 @@ def getID():
     """
     return getGlobalID()
 
+
 #------------------------------------------------------------------------------
 
 
@@ -231,28 +237,38 @@ def loadLocalIdentity():
     """
     global _LocalIdentity
     xmlid = ''
-    filename = bpio.portablePath(settings.LocalIdentityFilename())
-    if os.path.exists(filename):
-        xmlid = bpio.ReadTextFile(filename)
+    lid_filename = bpio.portablePath(settings.LocalIdentityFilename())
+    key_filename = settings.KeyFileName()
+    if not os.path.isfile(key_filename):
+        keyfilenamelocation = settings.KeyFileNameLocation()
+        if not os.path.isfile(keyfilenamelocation):
+            lg.warn('not possible to load local identity because master key file does not exist at specified location')
+            return False
+        key_filename = bpio.ReadTextFile(keyfilenamelocation).strip()
+        if not os.path.isfile(key_filename):
+            lg.warn('not possible to load local identity because master key file does not exist at default location')
+            return False
+    if os.path.exists(lid_filename):
+        xmlid = bpio.ReadTextFile(lid_filename)
         if _Debug:
-            lg.out(_DebugLevel, 'my_id.loadLocalIdentity %d bytes read from %s' % (len(xmlid), filename))
+            lg.out(_DebugLevel, 'my_id.loadLocalIdentity %d bytes read from %s' % (len(xmlid), lid_filename))
     if not xmlid:
         if _Debug:
-            lg.out(_DebugLevel, "my_id.loadLocalIdentity SKIPPED, local identity in %s is EMPTY !!!" % filename)
+            lg.out(_DebugLevel, 'my_id.loadLocalIdentity SKIPPED, local identity in %s is EMPTY !!!' % lid_filename)
         return False
     lid = identity.identity(xmlsrc=xmlid)
     if not lid.isCorrect():
         if _Debug:
-            lg.out(_DebugLevel, "my_id.loadLocalIdentity ERROR loaded identity is not Correct")
+            lg.out(_DebugLevel, 'my_id.loadLocalIdentity ERROR loaded identity is not Correct')
         return False
     if not lid.Valid():
         if _Debug:
-            lg.out(_DebugLevel, "my_id.loadLocalIdentity ERROR loaded identity is not Valid")
+            lg.out(_DebugLevel, 'my_id.loadLocalIdentity ERROR loaded identity is not Valid')
         return False
     setLocalIdentity(lid)
     setTransportOrder(getOrderFromContacts(_LocalIdentity))
     if _Debug:
-        lg.out(_DebugLevel, "my_id.loadLocalIdentity my global id is %s" % getGlobalID())
+        lg.out(_DebugLevel, 'my_id.loadLocalIdentity my global id is %s' % getGlobalID())
     return True
 
 
@@ -264,7 +280,7 @@ def saveLocalIdentity():
     """
     global _LocalIdentity
     if not isLocalIdentityReady():
-        lg.warn("ERROR local identity not exist!")
+        lg.warn('ERROR local identity not exist!')
         return False
     if not _LocalIdentity.isCorrect():
         lg.warn('local identity is not correct')
@@ -279,7 +295,7 @@ def saveLocalIdentity():
     setTransportOrder(getOrderFromContacts(_LocalIdentity))
     events.send('local-identity-written', data=dict(idurl=_LocalIdentity.getIDURL(), filename=filename))
     if _Debug:
-        lg.out(_DebugLevel, "my_id.saveLocalIdentity %d bytes wrote to %s" % (len(xmlid), filename))
+        lg.out(_DebugLevel, 'my_id.saveLocalIdentity %d bytes wrote to %s' % (len(xmlid), filename))
     return True
 
 
@@ -290,10 +306,10 @@ def forgetLocalIdentity():
     global _LocalName
     if not isLocalIdentityReady():
         if _Debug:
-            lg.out(_DebugLevel, "my_id.forgetLocalIdentity ERROR local identity not exist!")
+            lg.out(_DebugLevel, 'my_id.forgetLocalIdentity ERROR local identity not exist!')
         return False
     if _Debug:
-        lg.out(_DebugLevel, "my_id.saveLocalIdentity")
+        lg.out(_DebugLevel, 'my_id.saveLocalIdentity')
     _LocalIdentity = None
     _LocalIDURL = None
     _LocalID = None
@@ -314,11 +330,11 @@ def eraseLocalIdentity(do_backup=True):
     filename = bpio.portablePath(settings.LocalIdentityFilename())
     if not os.path.exists(filename):
         if _Debug:
-            lg.out(_DebugLevel, "my_id.eraseLocalIdentity SKIP file %s not exist" % filename)
+            lg.out(_DebugLevel, 'my_id.eraseLocalIdentity SKIP file %s not exist' % filename)
         return True
     if not os.path.isfile(filename):
         if _Debug:
-            lg.out(_DebugLevel, "my_id.eraseLocalIdentity ERROR path %s is not a file" % filename)
+            lg.out(_DebugLevel, 'my_id.eraseLocalIdentity ERROR path %s is not a file' % filename)
         return False
     try:
         os.remove(filename)
@@ -327,9 +343,10 @@ def eraseLocalIdentity(do_backup=True):
         return False
     events.send('local-identity-erased', data=dict())
     if _Debug:
-        lg.out(_DebugLevel, "my_id.eraseLocalIdentity file %s was deleted" % filename)
+        lg.out(_DebugLevel, 'my_id.eraseLocalIdentity file %s was deleted' % filename)
     return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -366,6 +383,8 @@ def validateTransports(orderL):
         if _Debug:
             lg.out(_DebugLevel, 'my_id.validateTransports ERROR no valid transports, using default transports ' + str(_ValidTransports))
         transports = _ValidTransports
+
+
 #    if len(transports) != len(orderL):
 #        lg.out(1, 'my_id.validateTransports ERROR Transports contained an invalid entry, need to figure out where it came from.')
     return transports
@@ -409,6 +428,7 @@ def getOrderFromContacts(ident):
     """
     return ident.getProtoOrder()
 
+
 #------------------------------------------------------------------------------
 
 
@@ -419,7 +439,7 @@ def buildProtoContacts(id_obj, skip_transports=[]):
 
     Make calls to transport services to build a list of my contacts.
     """
-    from services import driver
+    from bitdust.services import driver
     # prepare contacts
     current_contats = id_obj.getContactsByProto()
     current_order = id_obj.getProtoOrder()
@@ -453,7 +473,7 @@ def buildProtoContacts(id_obj, skip_transports=[]):
         new_order_correct = current_order
         lg.warn('service_gateway() is not started, use my current contacts as a source')
     else:
-        from transport import gateway
+        from bitdust.transport import gateway
         # build contacts data according transports priorities
         new_order = current_order
         for proto in active_transports:
@@ -558,8 +578,7 @@ def rebuildLocalIdentity(identity_object=None, skip_transports=[], new_sources=N
     # remember the current identity - full XML source code
     current_identity_xmlsrc = getLocalIdentity().serialize()
     if _Debug:
-        lg.out(_DebugLevel, 'my_id.rebuildLocalIdentity current identity is %d bytes long new_revision=%r' % (
-            len(current_identity_xmlsrc), new_revision,))
+        lg.out(_DebugLevel, 'my_id.rebuildLocalIdentity current identity is %d bytes long new_revision=%r' % (len(current_identity_xmlsrc), new_revision))
     # getting a copy of local identity to be modified or another object to be used
     lid = identity_object or identity.identity(xmlsrc=current_identity_xmlsrc)
     # create a full list of needed transport methods
